(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    770210,      26560]*)
(*NotebookOutlinePosition[    771877,      26612]*)
(*  CellTagsIndexPosition[    771606,      26602]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["matlabio - a MATLAB MAT-file reader/writer", "Title",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  "Original version by\nDoug Stein (doug@wri.com)\nWolfram Research, Inc.\n16 \
February 1994\n\nUpdated for compatibility with Matlab R2006a, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 5.2 and Fedora Core 5 by\nChris Rodgers (rodgers AT DELMEFORNOSPAM \
physchem DOT ox DOT ac DOT uk)\n18 August 2006\n\n This program comes with \
absolutely no warranty! Use at your own risk."
}], "Subsubtitle",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Installation", "Section",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  "The ",
  StyleBox["MathLink",
    FontSlant->"Italic"],
  " template program ",
  StyleBox["matlabio",
    FontWeight->"Bold"],
  " reads and writes MATLAB MAT-files. Here's how to install it.\n\nN.B. You \
may need to give the full path to matlabio here."
}], "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(matlabio = Install["\<matlabio\>"]\)], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \(LinkObject["./matlabio", 2, 2]\)], "Output"]
}, Open  ]],

Cell["\<\
Here are the names it defines. They exist in their own package \
context called MATLABIO.\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Names["\<MATLABIO`*\>"]\)], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({"MATLABCreateMATFile", "MATLABIO", "MATLABMatrixNames", "MATLABQ", 
      "MATLABReadMatrix", "MATLABWriteMatrix"}\)], "Output"]
}, Open  ]],

Cell["Here are the usage messages for the four functions.", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Information["\<MATLABMatrixNames\>", LongForm \[Rule] False]\)], "Input",\

  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \("MATLABMatrixNames[\"filename\"] returns a list containing the names of \
the matrices stored in the MATLAB MAT-file \"filename\"."\)], "Print",
  CellTags->"Info3364912292-5031012"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Information["\<MATLABQ\>", LongForm \[Rule] False]\)], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \("MATLABQ[x] returns True if x is expressible as a MATLAB matrix."\)], \
"Print",
  CellTags->"Info3364912293-8828048"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Information["\<MATLABReadMatrix\>", LongForm \[Rule] False]\)], "Input",\

  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \("MATLABReadMatrix[\"filename\", \"matrixname\"] returns the named \
matrix from the MATLAB MAT-file."\)], "Print",
  CellTags->"Info3364912294-6536674"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Information["\<MATLABCreateMATFile\>", 
      LongForm \[Rule] False]\)], "Input"],

Cell[BoxData[
    \("MATLABCreateMATFile[\"filename\"] creates an empty MATLAB MAT-file \
\"filename\"."\)], "Print",
  CellTags->"Info3364912295-1779424"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Information["\<MATLABWriteMatrix\>", LongForm \[Rule] False]\)], "Input",\

  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \("MATLABWriteMatrix[\"filename\", \"matrixname\", mat] writes the \
Mathematica matrix mat into a MATLAB MAT-file. It writes into the file \
\"filename\" and calls the matrix \"matrixname\"."\)], "Print",
  CellTags->"Info3364912295-8635360"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example: Reading and modifying MATLAB's \"Penny\"", "Section",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Read the Penny data", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  "First, let's see what matrices are in the file. MAT-files allow multiple \
matrices in a file, so ",
  StyleBox["MATLABMatrixNames",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " effectively gives the \"table of contents\" of the MAT-file."
}], "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(MATLABMatrixNames["\<penny.mat\>"]\)], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({"P"}\)], "Output"]
}, Open  ]],

Cell["\<\
It seems that the data is descriptively named \"P\". I have to \
reverse the data since the MAT-file has Lincoln upside down. The MATLAB folks \
take care of this by setting a funny plotting option; we can handle this by \
reversing the data.\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(penny = 
        Reverse[MATLABReadMatrix["\<penny.mat\>", "\<P\>"]];\)\)], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dimensions[penny]\)], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({128, 128}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plotting the Penny", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["Here are three obvious visualizations using this data:", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListDensityPlot[penny, Mesh \[Rule] False];\)\)], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.16947 -0.0125 -6 -9 ]
[.16947 -0.0125 6 0 ]
[.31971 -0.0125 -6 -9 ]
[.31971 -0.0125 6 0 ]
[.46995 -0.0125 -6 -9 ]
[.46995 -0.0125 6 0 ]
[.62019 -0.0125 -6 -9 ]
[.62019 -0.0125 6 0 ]
[.77043 -0.0125 -9 -9 ]
[.77043 -0.0125 9 0 ]
[.92067 -0.0125 -9 -9 ]
[.92067 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .16947 -12 -4.5 ]
[-0.0125 .16947 0 4.5 ]
[-0.0125 .31971 -12 -4.5 ]
[-0.0125 .31971 0 4.5 ]
[-0.0125 .46995 -12 -4.5 ]
[-0.0125 .46995 0 4.5 ]
[-0.0125 .62019 -12 -4.5 ]
[-0.0125 .62019 0 4.5 ]
[-0.0125 .77043 -18 -4.5 ]
[-0.0125 .77043 0 4.5 ]
[-0.0125 .92067 -18 -4.5 ]
[-0.0125 .92067 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.16947 0 m
.16947 .00625 L
s
[(20)] .16947 -0.0125 0 1 Mshowa
.31971 0 m
.31971 .00625 L
s
[(40)] .31971 -0.0125 0 1 Mshowa
.46995 0 m
.46995 .00625 L
s
[(60)] .46995 -0.0125 0 1 Mshowa
.62019 0 m
.62019 .00625 L
s
[(80)] .62019 -0.0125 0 1 Mshowa
.77043 0 m
.77043 .00625 L
s
[(100)] .77043 -0.0125 0 1 Mshowa
.92067 0 m
.92067 .00625 L
s
[(120)] .92067 -0.0125 0 1 Mshowa
.125 Mabswid
.05679 0 m
.05679 .00375 L
s
.09435 0 m
.09435 .00375 L
s
.13191 0 m
.13191 .00375 L
s
.20703 0 m
.20703 .00375 L
s
.24459 0 m
.24459 .00375 L
s
.28215 0 m
.28215 .00375 L
s
.35727 0 m
.35727 .00375 L
s
.39483 0 m
.39483 .00375 L
s
.43239 0 m
.43239 .00375 L
s
.50751 0 m
.50751 .00375 L
s
.54507 0 m
.54507 .00375 L
s
.58263 0 m
.58263 .00375 L
s
.65775 0 m
.65775 .00375 L
s
.69531 0 m
.69531 .00375 L
s
.73287 0 m
.73287 .00375 L
s
.80799 0 m
.80799 .00375 L
s
.84555 0 m
.84555 .00375 L
s
.88311 0 m
.88311 .00375 L
s
.95823 0 m
.95823 .00375 L
s
.99579 0 m
.99579 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .16947 m
.00625 .16947 L
s
[(20)] -0.0125 .16947 1 0 Mshowa
0 .31971 m
.00625 .31971 L
s
[(40)] -0.0125 .31971 1 0 Mshowa
0 .46995 m
.00625 .46995 L
s
[(60)] -0.0125 .46995 1 0 Mshowa
0 .62019 m
.00625 .62019 L
s
[(80)] -0.0125 .62019 1 0 Mshowa
0 .77043 m
.00625 .77043 L
s
[(100)] -0.0125 .77043 1 0 Mshowa
0 .92067 m
.00625 .92067 L
s
[(120)] -0.0125 .92067 1 0 Mshowa
.125 Mabswid
0 .05679 m
.00375 .05679 L
s
0 .09435 m
.00375 .09435 L
s
0 .13191 m
.00375 .13191 L
s
0 .20703 m
.00375 .20703 L
s
0 .24459 m
.00375 .24459 L
s
0 .28215 m
.00375 .28215 L
s
0 .35727 m
.00375 .35727 L
s
0 .39483 m
.00375 .39483 L
s
0 .43239 m
.00375 .43239 L
s
0 .50751 m
.00375 .50751 L
s
0 .54507 m
.00375 .54507 L
s
0 .58263 m
.00375 .58263 L
s
0 .65775 m
.00375 .65775 L
s
0 .69531 m
.00375 .69531 L
s
0 .73287 m
.00375 .73287 L
s
0 .80799 m
.00375 .80799 L
s
0 .84555 m
.00375 .84555 L
s
0 .88311 m
.00375 .88311 L
s
0 .95823 m
.00375 .95823 L
s
0 .99579 m
.00375 .99579 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.16947 .99375 m
.16947 1 L
s
.31971 .99375 m
.31971 1 L
s
.46995 .99375 m
.46995 1 L
s
.62019 .99375 m
.62019 1 L
s
.77043 .99375 m
.77043 1 L
s
.92067 .99375 m
.92067 1 L
s
.125 Mabswid
.05679 .99625 m
.05679 1 L
s
.09435 .99625 m
.09435 1 L
s
.13191 .99625 m
.13191 1 L
s
.20703 .99625 m
.20703 1 L
s
.24459 .99625 m
.24459 1 L
s
.28215 .99625 m
.28215 1 L
s
.35727 .99625 m
.35727 1 L
s
.39483 .99625 m
.39483 1 L
s
.43239 .99625 m
.43239 1 L
s
.50751 .99625 m
.50751 1 L
s
.54507 .99625 m
.54507 1 L
s
.58263 .99625 m
.58263 1 L
s
.65775 .99625 m
.65775 1 L
s
.69531 .99625 m
.69531 1 L
s
.73287 .99625 m
.73287 1 L
s
.80799 .99625 m
.80799 1 L
s
.84555 .99625 m
.84555 1 L
s
.88311 .99625 m
.88311 1 L
s
.95823 .99625 m
.95823 1 L
s
.99579 .99625 m
.99579 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .16947 m
1 .16947 L
s
.99375 .31971 m
1 .31971 L
s
.99375 .46995 m
1 .46995 L
s
.99375 .62019 m
1 .62019 L
s
.99375 .77043 m
1 .77043 L
s
.99375 .92067 m
1 .92067 L
s
.125 Mabswid
.99625 .05679 m
1 .05679 L
s
.99625 .09435 m
1 .09435 L
s
.99625 .13191 m
1 .13191 L
s
.99625 .20703 m
1 .20703 L
s
.99625 .24459 m
1 .24459 L
s
.99625 .28215 m
1 .28215 L
s
.99625 .35727 m
1 .35727 L
s
.99625 .39483 m
1 .39483 L
s
.99625 .43239 m
1 .43239 L
s
.99625 .50751 m
1 .50751 L
s
.99625 .54507 m
1 .54507 L
s
.99625 .58263 m
1 .58263 L
s
.99625 .65775 m
1 .65775 L
s
.99625 .69531 m
1 .69531 L
s
.99625 .73287 m
1 .73287 L
s
.99625 .80799 m
1 .80799 L
s
.99625 .84555 m
1 .84555 L
s
.99625 .88311 m
1 .88311 L
s
.99625 .95823 m
1 .95823 L
s
.99625 .99579 m
1 .99579 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0102010101010E4F8CC1EBF0E8DED5CCC4BBB5C1CDD3D7D9DADBDBDAD9D8D7D5D2CECBC8
C4BFBCB8B7B4B4B2B0ADAAA9ABA99C908D8070788C8F8F8F92A5BAC6CECDC7C2BBB3ACAD
BBD5D9D7D3D4D6D7D3CDC6C3C1BEB5A395918B858B89929CA09F919193979B9FA3A8ADB2
B8BDC4C8CCD2D8E9EEEDE8E1B06A0A0303030303
0101010101044484BAE6F2E9E2D7CFC7BFB7B1BDCAD0D4D5D7D7D7D7D6D6D4D3D0CCC7C2
BCB8B7B6B4B4AFAFACA9A8AAAAA294908D756D7C8B8F8F8C92A7B9C6CAC5C1BBB6AEA9AC
BFD4D7D3D0D2D4D2CCC8C1C1BEB5A596918E8580858590979A8F8A8C8F93979B9FA3A8AD
B2B8BDC3C8CCD2D9EBEEECE7DDA45A0504030303
01010101012565A2D7F1EEE5DDD4CBC4BCB4ADB1C2CBCFD3D4D5D5D5D4D3D3D1CEC7C0B9
B9B6B6B6B4B3AFADA9A8A8ABA79D95958A716B7B8A8D8E8C8FA2B6C3C4C0BAB5B1AAA6AB
BFD2D4D2CFD0D0CFC9C4BFBEB7AB9A918E8A827D7F7F8B92938584878A8D9195999DA2A7
ACB1B6BCC3C7CBD1D9EAEEEBE7E0A65906040403
010101012264A2DAF3ECE5DDD4CCC5BDB5ADA7B0C0C8CDD0D2D4D3D3D2D2D0CDC5BDB8B6
B6B6B6B4B2B0A8A8A6A8ABA8A099988F786B70868B8D8E8C94A9BBBFBCB8B4B0AAA4A6B3
C9D1D2CFCDCECECAC4BEBCB5A999918D87817B7B79828A8B807D8083878A8F92979B9FA4
A8ADB3B9BFC4C8CED3E0EDEDEAE6C88125030403
010101115495CFF3EEE6DED6CFC8C0B9B1A8A2A8BAC4CACDD0D2D2D2D2D0CDC6BEBAB8B7
B6B5B4B2AFADA6A6A8ACAAA39E9C96836E6F77898C8D8E8E98AEBBBAB6B2AFACA5A2A7B9
CBCFCFCBCBCBCAC5C0BBB7AC9E938D857F7B7574777F837B76787B7F8286898E92979A9F
A4A9ADB3B9BFC4C9CED5E4EDECE9E5BD6F0C0303
0201013175B4E5F2E9E2DBD2CCC4BCB6ADA69F9DB1BFC6CBCED0D1D1D1D0CBC5BFBDBBB8
B7B5B2AFACACA9A8ABADA9A39F9A917C6F727C8B8C8E8F8E98AEB6B5B1AEADA9A4A1A7B9
C7CCCCC9C8C7C7C3BCB7AFA49A9289817A766E6D727A7A6F6F7175797D8185898D91959A
9FA3A7ADB3B9BFC4C9CED6E5EDEDE9E4B4670404
02021B61A2DDF3EAE4DCD4CDC6BFB7B0A8A29A98ABBBC3C8CDCFD0D1D1CDC9C3BFBEBCB9
B7B4B0ADABAAABAAADABA7A1999488757578858E8C8C90909EB0B2AFACABA9A5A0A0A9BA
C4C8C8C7C5C4C2BDB5AFA69C958B817975706668707469686A6D7075787C8084888D9195
9A9FA4A9AEB4BAC1C5CAD0D7EAEEEAE9E0A04A04
0103498FC8F3EDE6DED7CEC8C1B9B2ABA49D9693A6B8C0C6CBCED0D0CFCCC7C2BFBEBDBA
B7B2AFACABABACABABA7A199948E80797C818C8F8C8C8E91A4AEADA9A7A6A6A19DA0ACBB
C0C4C5C4C3C0BDB6AFA69D978F837A736E6660666D67616366696D7174787C8085888C91
969BA0A5AAAFB5BBC1C7CBD2DCEDECEBE7D38A25
01448BC5F4EEE5DED6CEC8C1B9B2ACA59D96918EA6B6BEC5CACDCFCFCDC9C5C1C0BFBEB9
B6B1AEACABA9A7A9A79F98948E847F82838B908D8B8C8E99AAAAA6A3A3A2A09C9FA5B2BB
BFC2C2C1BFBBB5ADA69E988F847B726D655C60665D595C5F62666A6D7175787D8185898E
93989CA2A6ADB2B9BFC4CACFD6E8EEECE8E4A954
135EA3DCF4E9E2DAD2CAC5BDB6AFA8A19B938C899AACB8C0C7CBCDCDCBC8C4C2C1C0BEBB
B7B3AFADAAA9A8A7A39D97918A818487898E908C8A898C9AA7A5A09A9898969498A0B0B8
BABEBFBEBCB7AFA7A39B948B80776F675E585E5D5355575A5D6065686C6F73777B808489
8D92979CA2A7AEB2B8BEC4C9CFD7EAEDEBE8E2A2
559BD4F6EAE2DBD3CBC5BEB6AFA9A29C958D888498A9B5BFC6C9CAC9C7C5C4C3C2C0BEBA
B7B2AFACABA8A7A4A099928B84868B8D8F908E88868690A2A29E999495969699A0AAB3B6
B9BCBDBBB6B0A49F9A938A80766D655B5358574D4E5153575A5C6165686B6F73787D8185
8B8F94999FA4A9AFB5BBC2C7CCD3E2EDECE9E6BA
81BFF1EEE5DED5CEC7C0B8B1ABA59E979089827D8DA2B0BAC1C5C7C6C5C4C4C3C2C0BEBB
B7B3B0AEABAAA8A49E989086868C8F9092908C84808495A19E9996969698989CA5AFB2B5
B7B9BAB8B2A69C9892897D756D63595152524848494D4F52555A5C5F65676B6F74787D82
878B90959B9FA5ABB0B6BDC3C8CED7EAEDEBE8E1
A5E3F6E7E0D8CFC9C1BAB3ACA69F99928B847E787F99A8B5BCC1C4C4C4C2C3C3C1C1BEBB
B8B5B2AFACAAA7A49D958A858C919292928D857D7C859A9E999594939494989FA8AEB0B2
B5B7B6B4AC9B9591887C746C62564E4D4D42414344474B4F5154585C5F62656A6F74787D
81878C91969CA1A7ACB2B8BEC4CAD1DDECEBE9E7
C5F4EBE4DBD3CBC3BCB5AEA8A19B948D878078726F899EAEB7BCBFC0C1C3C3C1C1BFBEBC
B8B5B2AFACA9A6A2998F888B919393918E877E787D8C9C9C9792918F909298A1A9ADAFB0
B3B4B2AEA3938F8A7D736A61554A47493E3C3D3E4145474A4C5054585B5E61656A707579
7F83888D93989DA3A8ADB3B9C0C5CCD4E8EDEBE6
DBF7E8E0D9D0C9C1B9B1ABA49E97918A847D766F686E8A9FADB5BABEBFC2C1C1C0C0BEBB
B9B6B2AFACA8A49E958B8C919395928F887F7977808E9D9B96928E8D8C8F96A0A9ABADAD
AFAFAEA99B8F8B85786E64574A4244403736373A3D404244484C565956585C60646A7074
797E83898E92989DA2A8ADB3B9BFC5CCD6EAECEA
F1EEE3DBD3CCC4BDB5AEA69F98938C867F78716A6360748FA1ADB5BABFC0BFC0BFBEBBB9
B6B4B1ACA8A29C938E8F939596948F887F7A757A86959C98948E8A89888E96A2A9ABACAC
ACABA8A08F8A867E7266594A40403F34323334383A3B3E414347586A5D55575B61656B70
767B80858A8E93989EA4A9AFB4BAC1C7CFE0EDEB
F5E5DCD4CDC6BEB6AFA7A099938C867F79726B665E58638296A4AFB6BBBCBDBDBCBAB8B5
B3AFAAA59D97918F92959796958F877D777579828F9A99958E898585878E9AA5A8A9AAAA
A8A59F8E87847F776859473C3C3B2F2E2E30313437393A3E40434760695554575D636970
787C7F84888B8F969CA3A8ABB1B8BFC5CCD9ECEC
EEE3DBD3CBC3BBB4ACA49E97908A837D76706B635C5652657E91A0ACB3B6B8B8B7B5B3B1
ADA7A19C9793909396989896938B837A76767B868D91908F8A848181838C98A2A6A7A7A8
A5A1988884807B70614F3D383B2E2A2A2B2B2E31343B3B383B3E40455C6A5353585D6D84
8F91877F83868A9197A4B7AAADB3B9BFC6CEE0EC
E8DFD7CEC7BFB7B0A7A19A938D867F79726C666059544D516F81919DA6ACAFAFADADAAA7
A39E9C9997949596979796938D847C76767A84878581888B84807E7E848C9AA2A4A5A6A4
A09A8B837F7B7262513F36382F27262727282B2D314A4635373A3C404667605054607F7D
7A8E9B817F83888E95A8C1A9ABAFB4BBC2C9D4EA
E1D9D0C8C0B9B0A9A29B948D87817A746C67605B554F494A637887939CA2A5A6A7A5A4A2
A09E9D9B989797969795918B837B77777C85888380828A857F7C7B7E83909CA1A3A4A3A1
9B8D827E796E5E4D3E36372D242223232526272A304B37313436393C4161664D53717662
687D9A7C808E959CA5B7C3B9B8AEB1B8C0C7CFE7
DED5CCC4BDB4ADA59E979089837D76706A635D57524C46435068798791989D9FA0A1A1A0
9F9F9D9C9A98959594908C847C797A7F87898682808488827D79797B84919B9FA1A2A09D
94847F796E5C4D3F36362D2320201F21212224272C48342D2F34423A3E53684B4E6C7560
6478917580A0ABACB0B9C0BFBEAAAEB5BCC3CBDB
D9D1C9C1B9B0A9A29A938D867F7A736D66605A534F4944403F556879858E95989B9C9D9E
9E9E9C9A989795938F8B857E7D80858B8B8783818088857E7876767B86929A9C9E9F9D98
8A81796D5E4C3F36362D211E1D1C1D1D1E202123284532292D465039394866484A5B7778
79877A707690A49292A9B9A0A1A6ABB2B9C0C7D1
D6CDC6BCB4ACA59E979189827C76706A645E58524D47423D3941566979838C9195979A9B
9C9B99989695938F8B868282868B8C8C8884807F8488827A7675777D8991979B9C9B9890
847B6F5F4E4037352D201D1B1A191A1A1A1C1E1F25412F262C4B373235476244464D6B79
78876E6C717992A191A3B59A9DA2A8AFB6BEC3CB
D3CAC2BAB1A9A19A938C867F79736C66605B554F4A443F3B37344156697782898F919698
999998969594928E8B8A8B8D8E8C8A8885827F8188867F79767679808A91949797989388
7E7263534338352E1E1C1A181816161718191B1D203E2D232B4A322F344E5A40424B6F60
5E7D75686D737A95A4A7B3979B9FA5ACB3BBC1C7
CFC8BEB6ADA59E968F88827B766F6A645E58524C47423D3833302F405667757F868B9093
949696959494939290908F8F8D898583807F7F8787827C7977777A828A8F919394938C82
776858483A352F1E1B191715161413141515181A1E3A2A202342443A4255453B3E456968
657D6D646970767E9AADB096989CA2A8AFB8BDC4
CEC6BEB5ACA49C958E87807B746E68635C56514B47413D37332E2B2A3B5162707A82878C
8E90929393939392908F8E8B8884807F7D7D818987817B7977777B81888C8A8E908E8E84
7162523F34321F1B181715141211101112131416182D2F1D1E23384448413335393D4863
6E705E5E646B7177809AA99A95989DA4AAB1B9C0
CBC2B8AFA79F979089827B76706A645E59534D48433E3935302C27242843576570797F84
888C8D8E90908F8E8D8B8885817D7B7A7A808886817B787777787D8488898A9295958F82
645443302C251B1616141311100F0F0F0F101213141A171A1C1F2326292C2F33363A4046
4E52575D636970767C848A8E92979DA2A8B0B7BE
C7BEB5ACA49C948C867F78736C67615C56504A46413C37332F2B25221F294657636E767C
828487888B8B8B8A888684807D7A79797D8686817B78767677787F838787889193938F84
6252462B1F2419151412100E0D0D0C0C0D0E0E0F10121316181B1E2225282B2F333A3B41
474D535960656C737980868A8F94999FA6ADB5BB
C4BBB2AAA19A928A837D766F6A655F59544D48433F3B36322D2924201D1C324857626B72
787B7F82848685848483807D7B79797E8486837E7874737475797D808584848E8F878F87
6F5D563E1F1C1B1312110F0D0B0B090A0A0A0C0D0D0F111316191B1E2226292D3034393E
434950565C62696F767C82878D92979DA3AAB1B9
C1B8AFA69F968E88817A736D67615C56504B47413D3834302C2823201C191D394B57616A
7074777B7D7F8080807F7E7C7A7A808686837F7A7572727274797D808383838A8C898F7F
6D615843271F2314100F0D0B0A0807080808090A0B0C0E111316181B1F23272A2D32363B
40464C535A60666C72787F848A8F949AA0A7AEB6
C1B7AEA69D968F878079726C66605B554F4B45413C38342F2C27231F1B1715203A4A565F
666C707377797A7C7C7B7A7A797E8585827F7B777370707174787C7F8181828286898D7F
68605B492B1E1D13100D0C090807060505050607090A0C0D0F1315191C2023262A2F3337
3D42484E555B61686E747A80868B91969DA3AAB2
BBB2A9A199918A837B756E68625D57514C48423D3934302C2925211E1A16141A3346505B
61666C6F73757677787A797B7F8584807D797571706F7072767A7D7F807F7A787B898776
615A52381F1E13100E0C090706050404040404050707090C0E1113171A1D2225292D3236
3C41474D535A60666C73797F858A90969CA1A9B0
BAB0AAA0999189827B746E68615B57514B46413D3836302D2826211E1B1614121F374651
5A61666A6F71737476797A7E8283817C797672706E6F7073767A7D7E7D787474787A7968
5952452A1F1D120F0D0B09070404020202020203040507090B0E1114171B1E2127292F32
383D43484F555B62676F757B81878C91989EA5AB
B8AFA69E978E877F78716B655E59544E4944403C37332F2B2723201D19161312152D3F4C
565E64696D707274777B7E81817F7B787572706F6E6F7275777A7B7C766F6F7273716D61
4F3824131212100E0C0A0806030303030303030203030506090C0E1114191C2023282C30
353B40464C52585F656C72797E84898F959CA2A9
B6ADA49C938C847D766F68625C57514C47433E3935322D2927221F1C18151210101F3646
525B63696D7072757A7D7F7F7E7A7774726F706F6E717476797B7A746E6D6E6F6F6C6A60
452C141010100F0D0C090705030302030202020202020405070A0C1012161A1D22262A2E
33393D43494F565C636A70767C82878E949BA0A6
B1A8A0978F888079726B655E59524D4944403B37322F2C2723201D1A1613100F0E183042
4F5A62696D71757A7D7D7C7B787572706F6E6F6F717376787878716D6D6C6C6C6B695F48
33160F0E0E0D0D0C0A07040403030203020202020202020305080B0E1214171B2024292D
31383D43494F565B62696F757B81878C92999FA6
AFA69D958D857F776F69635C56504B46423E3A35312D292622201B181513100E0B0E2239
48555F676E73787A7C7B79787472706E6E6F71717374777876706D6B6B6A6B69675E4D3F
220F0C0B0D0C0A09080604030303030302030202020202020406090C0F1216191D21252A
30353A40454D535A60666C72797E848A90979DA3
ACA39A928A837C746D67605A544E4944403C3834302C2825211F1B181513110E0D0B0F29
3D4C59646D72777879777573716F6E6E6F71727374767775706C6B6A6A6967645C524B3F
28140B0A09090807060503030202020202020202020202020205070A0D0F13161A1F2328
2E32373E434A50565D646A70777C82888E949BA2
AAA1988F87807A726B645E58524D47423F3C3734302B2824231E1A17151413110E0B0A13
2E4155616A6F7275757573716F6E6D6F707273747576746E6B6B6B6A68656059504D4940
352615080707050503020202020202020202020202020202020306080A0E1014181D2126
2B30353B41484E545B61686E747A80868C9399A0
ABA1999087807A726A635D5A534D48423F3C3734302D292528231B1815151C1B0F0A0908
1031485761686C70717171706E6E6D6F7172737576736D6B6A6B6A69655E544F4D4A4840
39312709050403030302020202020202020202020202020202020306080A0E1115191E22
272C32373D434950575D646A70777D82888E959C
A7A29F8C8A908A7E685E5D6B68604A40514034403F2A25263D2A1A1715182D1F100B0807
08223B4C5860666A6C6E6F6E6E6E7070727475736D6A6A6B6B6A6863564C4A4D4B494440
3B35260E04030202020202020202020202020201020202020202020406090C1014171C21
262C30353C42484F555B62696F757B82878E959C
ACA1B191859C877B7F605A6D5A4C453F4F4B36473D2925253B341C1715172729110C0B07
0507233A4C575E63676B6D6D6F6F6F717374726B686A6B6B6B69655B4F4A4B4C4C4A4947
41392E1E0E070504030303020202020202020302020202020202020204070A0D1014191E
22272C32383E444A51585E656B71787E848B9198
A69EB290829A7E78825F576B5C4D403D4E53494E312724243B331B171618272B110D0A07
05040A2B404E585D64676A6C6D6F7072726F6968696B6C6B69635B524C4C4C4C4D4D4E4C
453A3127221D1A1A1918150A040303020202020202020201020202020305080B0E12171B
20242A2F353C42484F555C626970767C82898F96
A0A0AD8884988E8A6F57556F68573E3A55524E4C2F2623243F281A16171F352D120D0907
040303213948525A6065686C6D6F706F6967686A6C6D6B66615B544E4C4F4F4F4E4F524E
443E3A35312F2E2F2F2D271A0F0503030202020202020202020102020204070A0E12161A
1F242A2F343B41484E545B62686F767C828A9097
9F9FAB858296787E7255536C53473C395243334A3624242A382C1B17172E2B2E250E0906
0403030D2D404C555C6166696C6D696666696B6D6D6B66625D58534F4F50515252525350
4C4D4942404141414240382C22110403020202020202020202020202020306090C0F1418
1D22272C333A3F454C535960686E757B81888E96
9E9EAA848091777B725350695A4F3F374F4640492F23343E3539301A212C14162A160906
0403020320374650585E646869646365696C6D6C6A6563605C57534F5154565757555458
5B5D555151525252514D423A311F0603030302020202020202020202020205080A0E1217
1C20252B31383D444A51585E666C737980878D95
9C9DA4827F8E847B5F514D605C543E354646413424212C2D2A2723181B141110100F0906
04030203122E404C545B6263606063676B6D6B68666564615D57555456585B5D5C5B5D63
696A666362615D5B585149453928100403030202020202020202020201020407090D1116
1A1F242A2F363C434A50575D646B72797F858C93
9E958E807771686057504B46423C37332F2C2926221F1D1A19171512100F0E0D0B0A0806
05030202031D33434D565A5A5C6064686A686767676766635F5A5756585B5F646364676C
7271726D6B6B65625E59544D43331E0503030201020202020202020202020205080B0E12
181C21272D32393F464D545A61686F767C828991
9A91877C736B625A544D48433D3833302C2926221F1D1A18161411100F0C0C0A09070505
030302020217303F484B52585E64666665666769696866625D5A57585B5F6568696D7176
7775726A6E6E6A66605C585044331C0403020202020202020202020202020204070B0F13
171C22262D32393F464D545B62696F767D838A92
9A90867C726A625A534D47413C37322D2A2724211E1B181613110F0F0D0B090807060504
03020202020B26313B46515A5F6161626467686A6B6965605C58585B5F676B6D71727679
76756F6A6D6E6D68605C574E42311A0403030202020202020202020202020204060A0E12
161B20262B31373E454C535A61676E757C828991
9B90867B72696159524C45403B35312D2925221F1B19171413100E0C0B0A070706050303
030202020202142939465156585B5E626567696B6A68625E5B5A5A61656D727576767979
75716A676A6A6A665D564E41321F06030302020202020102020202020202020306090D11
151A1F242A31373D444B52595F666D747B828990
9B91867C726A6158524B453F39342F2B2724201D1A171513110F0D0B0908070605040303
020202020202042437444A4F555A5E616467696A6A66605D5C5E62686E72727678797B78
736E666367666460564B3E331E0403030202020202020202020202020202020205090D10
14191E232930373C444A52595F666D737A81888F
9A90867C72696059504B443E38322D2926221E1C19161312100D0B0A0807060505040302
02020202020202122E3B454D53585D616466686967625F5C5D64696F737373787A7B7977
726B6160605E5D564B3F3221050303020202020202020202020202020202020305080B10
13181D23292F353C434A51585E656C737980878F
9D92887E746B625A524C453E39332D2925211E1B181513110F0D0B080707060403040302
02020202020202062537424A50555A5F6365676765615F5B60686E72767678797A7B7974
726C625E5A5B5A50453D3015040303020302020202020202020202020202020204080A0E
12161C21272D343A41484F565C636A71777F858D
9A90867C72695F585049433C36302B27231F1C1A1614110F0D0B09070605040403030202
0202020202030F1D2F3D484C50565A5F62656665625F5A5D686E717678787A7A79777572
6E685E5B5B5A5446423C3017040303020202020202020202020202020202020204080B0F
13181D22282E353C424950575E656C727980878E
9B91867C726960585049423C352F2A26221E1B181613100E0D0B09070504040302030202
020202020417212C38444D4E50565A5D62646462605D5A626C7173797B797B7B7773726F
6B675D5D5E5E5443403D372C170403020202030202020202020202020202020205080B0F
13181C22272D343B424951585E656C72797F878E
9D93897F756B6259524A433D36302B26221F1B191513100E0C0A08070504030302020202
020202020D22283B4A4D4D5252565A5D5F6161615F5B5D676F73777C7D7C7B7A76726E6C
68665E5B60605B4A3F3F3D35270603030302020202020202020202020202020203070A0E
12161B20262C333A404850565D646A70777E848C
9C91877C726960585048423A352F2A25211D191714120F0D0B0807050403030202030202
02010206202F3949525154565A5A5C5D5E5E5F5E5B5C666E74797A7E7F7E7B7673706D68
64645B595E5D5B4D3A35332B1D0703020303020202020202020202020202020204070B0F
13181D22282E343C434A51585F666C727980888E
9F948A80756C635A524A433D36302B25211D1A1714110E0D0A0806050403020302020202
0202020822333B48504F555D5E5D5D5E5D5D5E5C5B5E676F75797A7E7F7F7D7872706F6A
65635E545A5B5956483D3A352D1D05030302020202020202020202020202020203060A0E
11161B21272D333A424950575D646A71787E858D
9D93897E746B61585049423B352E2925211D191614100E0B090705030303030303020202
0202031D263C424C4F535D5E5A62605D5B5A58575C656D73767A7B7F7F7F7E7975757069
64625D5155595554514B463F352605030202020202020202020202020202020205080B0F
13181C23282F363D444B525960676C737A80888F
9E93897F746B61595149433C352F2A25201C191513100D0B080604030302020202020202
02020621283F4750575C64636466615C595653545F686E7277797A7E7E7F7D7B7976726B
63615F5554585C59514E4A42392A05030303020202020202020202020202020205080B10
14181E232A30363E444B535A60676D737A818890
A0958A81756C6259524A433C37302A25201C1915120F0C0A080504030203020202020202
020207212F414C5A6367656168665F5C56534D5560666C717678797C7D7B7C7B7977736D
6563635E5A5B5E5E564D463F392C06030302020202020202020202020202020306090C10
14191F242A31373F464C535A61676E747B828991
A1978C82776D645B534B443D37312B25211D1915130F0C09070403030202020102020202
02020E2839485561696A65676A615F5B544F4F5A5F6269707476797B79797A7A7977746F
68656965636263645D4E413A362F0C0303020202020302020202020202030203060A0D11
151A1F252B32393F464D545B61686F757C838B92
A3998D83796F655C544C453D38312B26211E1915120F0C0A070403020202020202020202
02032137444F5A646B6E6E716D665F61595C7071645F68707274757677797B7A78777571
6D6E717472716F6E6A5C403C3B372C1D12060403020202030202020202020204070B0E12
161C20262D333A41474E565C636970767D848C94
A59A8F857A70675E554E463E38322C27211C1915120F0C09070403030302020202020202
020F2F3B41535C626C737475716C6B68667A888673606A6D70737374757A7C7A7A797571
71767B7D7E7C79746F6448434A49433A31271504030302030202020202020204080C0F13
181C21272E353B424950575E646A72777F868D95
A69C91867C72695F574F474039322D27221E1A16130F0C09060403030202030203030202
021B353C4759606571747476757372707C8A8D847766696A70727373767C7C787A787673
77808487898780786F6752464B4C443C383326050303030202020202020302060A0D1114
181E23292F353C444B51585E656B727980888E97
A89E93887E746A61585049413B342E28231E1A16130F0C09060403030302020202020202
0222393F4E6068707675776F73787A83878B897E736968696E7475757B7E7C7C7B767478
808A8E90918F877C6F655744403E3935353426050303020302020202020204060A0E1115
1A1F242B30383E454B525960666D737A81899098
AAA0958B80766C645B524B433C362F29231F1A16120F0C09060403030303030302020201
0C27394452657178797B7774777A848C8485867A6F6A67686E7377797E807F7F7A787980
8A92939495948C81716054463C3A383737321B040302030302020202020204070B0F1317
1B20252C33383F464D535B61676E757B838B929A
ACA2988D83796E655C544D453E37302A241F1B17140F0C0A060403030303020202020302
1B2D3B434F65757C7E807F8281818E8B83848071706B696B6F75787D81858785827F838B
9296979797959085735E4D423C3A3938352B05030303020302020202020205090C101318
1C22282D343A41484E555B636970767D848C939B
AFA49A90857B71685E564E474039322B26211C1814100D0A07040302030202020202020C
26373B475867787C7D828384848A948D83746D6C74706E7073787C80858B908E8C8A8E93
9799999A999893877457493E3A3A3836311C030302020202020202020203070A0D11151A
1E23292F353C424950585E646A71787E868D959E
B2A79D93887E746A61585049413A332D27221D1915110D0A080503030302020202020213
2E3E4359676C7A7C7F837E818894978F79686A797E797675777B82878B9298989796979A
9C9C9C9C9B9891857254453C393937342906030303020202020202020204080B0E13171B
20252A31373D444B52595F666C737980888F979F
B4AAA0968B81776D635D534B433C362F29241E1A16120E0B08050403030203020302021C
354351656F747F82898980888B9B978C70646B83837F7D7C7E858D9295999E9F9E9EA09F
A09E9D9B96908B8374543E39383836301B04030203020202020202020307090D1015181C
21262C323940464D545A61686E757B82899199A2
B8ADA3988F847A70675E564E473F38322B25201C1714100C0A0604030303030302020D25
3B4C5B6A747B838B918C888C939E99886E646E84838081828790979C9EA0A2A2A3A3A4A3
A19E9C978D888580745137363637352906030303020202020202020205080B0E1215191E
23282E343B41484E565C636970777D838B949CA5
BEB3A99E958B81766C635A524B433C352F29231E1916120F0B080604030302030302102A
3C4F5D69747E858D91908F8F9CA39D8D6E6B6B777A7C80848B939B9FA1A2A3A3A3A3A4A3
A09D99968A838180765C35313135342405020302020302020202020306090C0F13161A1F
23282F353B42494F575D646A71777E848C949CA4
BFB5AAA0958B82776E655C534B433D36302A241F1A16120E0C0907040303020202021F36
4554616D7A848A8D90949AA2A7A29B866B6D6C6D71777D848E95999EA0A2A2A4A2A1A09E
9A979591857F7C7B704C312D33372D07030302020202020202020306090C0D1215191D22
272C32383F464C535B61686E757B81899099A1A9
C2B8ADA3998F857B71685F574F474039332D27211C1914110D0B0906030202020202213A
475565727E898E8D939EA6ACACA19C88706B74716D6F757F8D939A999EA3A4A19F9E9C99
959596958D827B77704E33313A3A1E040302020202020203030205080B0D1014171B2024
2A2F353A41484E555C636A70777D848B939BA3AD
C5BCB1A79D93897C756B625A524A433C352F29241F1B1613100C09070503030202031F3C
4A5A6A77838B90939BA4ACAFAD9E9C8A79717C7B6F686D7D8D9595969FA2A09E9B9A9894
9293999B9B958783795C3C3B4039140403020302020202020203070A0D111317191D2227
2C31373D444A51575F666C73797F878E969EA7AF
CBC2B6ADA3998F867C726860575048403A342E28221E1A16120F0D0A0806040303031435
4B596C788288939A9EA5A8A4AA9F9C917F797F877A70737E899392959BA1A09E97949392
9093999FA5A6A09187744C444740230403030203020202020305090B0F1316181C1F2328
2D33383E454B52595F666D737A81878F979FA7B0
CDC3B8AEA49B92887D746A625A5149433C36302925201C1714110E0B0807060503031D3A
4D62757F828E99999EA7A3A1ACA29C937E788A8D817B81838C9394989CA39F9C95929291
93969BA0A8AEAB9E8865545456452404030202020202020205070B0F1216191C1F23282C
31373C42494F575D646B71787E868D949CA4ACB9
D4C9C0B5ABA1988F847B716860575048413B352F2A24201C1815110F0B0A080604040A35
4761767F85939B9CA5AAA5A1AAB0A8A3918488938F8C8C8B8E9496989CA3A3A09C979696
97989B9EA4AEB2ADA08976726E5C390A0403020202020204060A0D1014171B1E2225292E
33393F454B51585E656C72787F878E979EA6AEBE
D5CBC1B6ACA39A90877D746A6259524A433D38312C26221E1A1612100D0B09070506143E
556B7D85919A9EA3ABADA2A2ADB6B3AC9D949892969A959596989B9C9FA6AAA6A09D9B9A
9B9EA0A3A8B0B4B2AA9C928B7E6030060403030202020407090C1013171A1E2126292D33
373D444950565C636A70767E858C939BA3ACB5D4
DBCFC4BBB1A79E948A82786F675E554F48423B36302A25201C1816120F0D0B0A08071942
586D818C979FA3A8B1ADA2A6ADB6B8B6AEA5A1989AA3A19EA1A0A3A5A6AAAEAAA5A2A1A0
A2A4A6A9ACAFB4B5B2ABA19885622A0604030203030507090C0F1216191D2024282C3135
3A40464C535960676D747981878F969FA7B0C2DC
E0D4C9BFB5ACA2998F867D736B635B534D464039332E2924201B1814130F0D0B0A0A1C41
536C82919BA3A4ADB3ADA4A8A9ACB4B8B7B1A9A09EA4A8A8ACABA9AEAFAFB0AEA8A6A6A8
A9ABAEB1B2B3B5B5B2ABA295825B1F06040403040507090B0E1214191C1F23272C303439
3E444A50575D646A70767D848B939BA3ACB4D0E0
E7DACFC4B9B0A79D958B837970676058504A443E37322D28231E1B1715120F0D0B0B1D3C
526F85949DA2A4B0B3AFA9AAA9ABAEB2B8B9B1ABA8A6AAB1B5B5B1B3B2B3B4B3AEAAABAE
AFB1B5B7B7B7B5B3AFA69E91794B0E060505050607090D0E1214181B1F2226292E32373D
42484D545A61676D747A81878F969EA7B0BFDBE0
F5E0D3C9BFB5ACA29990887E756C645D554E49423B36312D27221E1B181512100E0D1C41
5E7486959DA0A7B0B2B1AFAEADAEAEB2B7BCBAB7B1ADACB4B9B8B7B7B5B8B8B6B3B0B1B4
B5B6B8BABBBAB6B1AAA2988A703E0A08070708080A0C0F1114171B1E2125292D31353A3F
454C51575E656B71777D848B939AA3ABB5CEDFDF
FFE7DACDC4B9B1A79E968C847B726A625A544D47403B35312B26221F1B19151210102049
617284959EA4AAB0B2B4B4B0B0B5B6B4B1B8BBBBB3B0B1B5B8B6BBBBBABBBBB8B5B4B6B7
B9BBBCBDBCBBB7B1A89D948568300A0908090A0B0C0F1114171A1D2124282C2F34393D43
494F555C636A6F757B81888F979EA6B0BEDAE0DE
FAFBE3D6CCC2B7AFA59C948C837A7169615A534D47413B36302D28241F1D1A1614142146
5B70808F9CA3ACB1B3B7B9B5B7B7B5ADABADB3B7B4ADACAFB2B6BCBBBDBDBDBCB9B8B9BA
BBBDBEBFBEBCB9B3A99F93846B390D0A0A0B0C0E0F111416191C2023262A2D32363B4046
4C52585E666B71777D838A9199A1A9B2C6DCDFDD
F2FFE7DACFC4BBB1A9A0988F877E756D655E57514A453F3A362F2C27241F1C1A1616334C
647985949DA5AFB1B3B9BBBCBDB8B0AEAEACABAFB0ADA8ABB3B8B9BBBDBDBDBDBCBBBCBE
BEBFBFC0C0BCB8B2A89D8F7A5B1F0D0C0D0E0F101215181B1E2024272A2F33373C40454B
51575E656A70767D828990979FA7B0C0DADFDDDC
D3FCF5E0D5CAC0B6AEA59C958C847B736B635C554E49443F3A36322C2824201D1919324C
677B8B979EA5AFB3B4BABBBBBCBBB7B4B2B0ADABACAFADAEB4B4B7BBBEBDBDBDBEBDBEBF
C0C0C0C1C0BDB9B2A89E8E7753170E0E0F11111316181B1E212427292D31363B3E44494F
555B63696F757A80868D939BA4ACB6D0DEDEDDDA
A3E0FAF2DED3C8BFB5ACA39C958D847B726B635C554F4A44403B37332E2926211E1C2243
5C7689949FA5A9B2B7B9BCBAB7B7C0BEB8B5B6B3AFB1B4B2B4B6B6BBBFBFBEBFBEBEBFBF
C0C0C0C0BFBDBAB4ADA1917A5217101212141416181B1E2123262B2D3134383D42474D51
585F666E72777C83888F969DA6AFBED8DFDDDCE0
8DCCF7F9E2D6CBC2B8AFA7A099928B7F766E676059544E4844403B37322D2926211E2245
5B7A8893A1A7AAB3B7BCBDB4ADB4C4C4C1BEBCBDBABAB9B4B4B9BCBEBFC0BFBFBEBEBEBF
C0C0BEBEBCBAB7B3A99A86662B1212131617181B1C202325292C2F3136393E42474D5358
5E6673807C7D82888F959DA4ACB9D5DDDEDCDAE7
62A7E3F7EFDDD1C7BDB5ADA7A0A2A0897D756D665F59534E4945413B36332F2A25212443
5874838D9CA4A9B4BBBFBEB4AEBAC4C6C5C4C3C1BEC0C0B9B4B9BFC0BFBEBDBDBCBDBDBD
BEBEBCBABAB8B6B0A5937A4F18141517191A1C1D222326292C2F3337393E42464C51575D
636A758D948A888E989CA2A8B1C9DDDEDDDCE8CD
357EBCF4F7E4D7CDC3BCB4AEB2B59F8C837B736C645F59544F4A46413C38332F2A25253F
566D7A8A929DA7B3BBBFC0BCBABDBFC5C5C2C0BDBDC2C3BFB7B9BDBCBDBCBCBABAB9BABA
B9BAB8B7B7B5B2AC9C8666331718181A1C1E212225282B2E3133373B3E42474B50565B61
676D757C93A09BA1B2ABA7AEC1D9DFDDDCE0E596
025198D2F9F6DED2C9C1BBBFC3AD9A928A837A726A655F5A554F4B47413D38332F2B2838
526772858B96A6B4BABDC2C3C0B8B5C1C4C2BEBCBDBFC1C3BFBABCBDBBBBB9B7B7B7B7B5
B5B5B4B2B3B2ACA08C7251241A1A1A1D1F212427292C2F3234373C3F43474B50555A6066
6C72797E8699AEB6B5A6ACB6D3DEDDDCDAE9BE5B
020C599FD9FBF3DCD1C9CAD2C0ABA39B9698877A736C66625C57524D48433F39352F2C2B
435E6C77868EA1B1B9BEC2C3C0B9B4B6C1C2BEBBBBBFBFC2C3C1BCB8B7B6B5B4B3ADAFB0
AFAEADACACAAA395826A4932221F1E202325282A2C303336383C3F42464A5054595E646A
6E747A808790A9BBA6A8B0C3DADEDDDBE0E69D31
02022B74B3E8FBE9D8CFCDCBB7AFA9A4AFA88B827A726C68625C58524D48433E3934302D
355567727F8D9EACB2BABEC0BCB3B2B8C0C1BEBEBFC1C2C1C1BDB9B3AEAEADADADAAA6A4
A7A7A6A6A49F94857664483A3629232426292B2F313437393C4044474B4E54595E646A70
74797F858C99B5ACA6ACBAD6DEDDDBD9E9BE6103
020202438AC5ECF9E2D6CDC5BCB5B1BDBA9D928A8279746E68635D58524D48423D393530
31495A677785979FA6AFB4BBB7B1B6BEC0BDBABFC2C3C3C2C0BDB8ADA5A3A4A7A5A1A2A2
9A9C9D9D9991867A72695B4C423C2D292B2D303335383A3E4144484C50555A5E65718084
7D7F848A9099A9A3AAB4CFDEDEDCDBE7D3810F03
010202236CACE0F8F0D8D0C7C0BFCDC8B8AEA8A3947F78726C67615C57504B46403C3733
323F515C6B7D8F98A0A3A9B6B4B4BBC0BCBABCBFC2C2C1C0BEBBB0A29D9D9FA09E9A9C9B
989394928E88827E766E6A5A4B44352D303234373A3D4043474A4D52565B606675898997
8A858B90969CA3AAB4CFDCDEDCDAE7D886180303
020202023C80BCEBF9EAD5CCC6D3D8D0C3B8B6B5A0877D78736C66615B56504A453F3A37
34333A4D5C6D8692989C99ACB3B5BABFBAB8BDBFBFBEBEB9B3B2AB9B969696999A939794
8D8C8D908F8E8E8B83807A62534B3D333436383D3E4245484C4F52575B60666C83847D9C
938A8F959AA0A8AFC8DCDEDCDAE1E39F3E040203
02020201024082BDEBF8ECD6CDC6C3BBB3ADBAB8978D857E79746D67625D57514B45403C
3835323B495A718B92969799ABB4B7BCBCBBBCBDBDBBB9B8B1A8A59C8F8E8E8E97959196
8A85889297979A9A97928B6F5B554537383A3D3F4245494C4F54585B60646A6F7D84809C
9990969A9FA4ABBED5DEDDDCDAE5C67104020303
02020201021760A1D9F5F5E1D1CAC2BDB6C1BEA1968F89837D77716A65605B554F4A4440
3C38353544566F838D91949BA5B0B5B9BBBAB9BAB9B9B8B7B2A9A5948885868D9394989B
928F8F959F9E9C9E988F796B60533F3B3C3F4345484C4F52565A5E62676B71767A8089A6
95A2AAA2A7ADBFD6DDDDDBDAE3C56D0403030203
0102020202022B72ADE1F8F5DCCFC6C0C8CAACA49B948E88837D78716B65615B564F4A45
423C393537495F707E84878E95A0A9B1B3B2B3B5B5B5B4B2B0AAA3908886898D9190979C
959496999FA09F9A928372655953403E4144474A4E5155585C60656B6F7275797F848CAB
AAB5A9A8AEBBD4DDDDDBDBE4D0811E0303020202
020201010202013A80BAEBFCF4DBCDC5C3BBB0A8A19A948F89847E79716C67625D56514C
49433D39353335465F6C72787F8A94A0A7A4A2A9AFB0ADADA9A89C8B8384888E9295979B
93868A92969E9D918373635954464144464A4C5054575B5E63697A85877E7B808589909D
ACA8A9AEBCD3DDDDDCDAE2D68E2D030302020303
0201020101020201367DB6EBFCF9E0CEC6BFB9B0A9A19B96918C898683786E68635F5954
4F4B46403B363431384C596165727C85939A9898A5A8A8A3A5A59D8C8282818187959999
97897F858B94978E7A6C5E57454245474A4D5155585C5F646873887C80948C85898D9298
9EA5ABB6CDDCDEDCDBDBDFAA5804030302020202
0202020202020201014287BDEDFDF8DCCDC6BEB7AFA8A29D97969EA09C937E716A65605A
55504B47403C39363333474F5A5E6E767C838A8F9BA2A19CA1A19B928F8B87817F889697
958C817F838B88837662554A4646494C4F52565A5E62666A6D7D8D7C7E869D928E94989D
A3A9B6CCDCDEDCDBD9DFAF5D0403020203030202
01020202020202020202508CC2F1FEF4DCCDC5BEB7AFA8A39EA9AD948E98947B706A6660
5C56514C46433F3C38353744565B616A6F72768092999A999D9C999593928D8781828E90
918A7D76757C7C756C5E4F47494B4E5255595C6164676C6F737E9486838794A697989DA2
A8B3CCDCDEDDDCDADEB6690B0302020202020202
0101020201020202020206518FC5F1FDF7DECEC5BEB6AFA9A8BBA2969AA6A38278726D69
625C57524E4845413E3B39394158606465676E7A868C90939294969291908E8B86838585
83786C6B665C504E4A484A4B4E5153575B5F62666E777374787E9496898D92A6A89FA4A9
B5CDDBDEDDDCDADDBB7010030302020202020202
02020202020102010202011F669ED2F7FDF3D9CDC4BCB5B0BCBDA19BA8B08E847D787571
6A635D5853504C4845413E3C3D465558585A6572797E83858383898483888787827D7976
7269605A4C454648494C4D5254575A5D63676A6F8386787D7F848FA19494999EA3A6ACBD
D4DDDDDCDBDDDBAB600803030202020202020202
02010201020202010202020223619CCFF5FBF6DCCDC4BEB8BEC4AAA39E9D918B85848E8F
857065605B58544E4D4845444142424453595D656A6F727372747A776F6B73797A726B66
6562524748484A4C4F5154575A5D60656B7774768A8D7E8185898EA2A79B9EA3A7AFC1D6
DEDEDDDBDBDBA961090302030202020202020202
0201020202020102020202020203508DC0E9F9FAE8D2C8C2BEC6C5B7AA9F99948F99A08C
8F91736A66615D5955514E4B4A4847444548535A5B5F615E656A6F6C676261686B6C6863
62594B4C4D4E505255585B5E6063666A70808A7F8D9986868A8E9297AAA2A3A8AFC1D5DE
DEDDDBDBDCB46F1E030302030202020102020202
0202020202020202020202020202145B93C5F0F8F8E8D1C8C4C1C6C4AFA59E9AA3AC8E87
8B9B79716E6A67635D5A565452504E4B4948494848565A5D6164645D5F5D5D5B534E5155
525051525456585A5D5F6366686B6E727882969AA2A2988F9095999EA2A5ACB8CDDBDFDE
DCDBDCCD97500403030303030302030302020202
020201020202020202020201020202075389B9E6F9F7EED9CCC6C1BBB3ACA6A2B6AD948E
92A3807A75747E7E6F64605D5B585653514F4E4C4B4C4E50555959514E4C4C4C4D4E5051
535557595B5C5F6164687476717376797D839CA38F93AA99999C9FA4A8AFC0D3DDDFDEDC
DBDBBD8541040302020302020202020202020202
0202020202020201020202020202020202437EACD9F8F8F5E4D2C9C1BAB5AEABC1AD9C96
A3A487827E7E95948D786B6663605E5B5957575553525252525252505151525252545759
5B5D5E61636567696B707A89797A7D80838793A89AA1B3A09FA3A6ACB4C9D8DEDEDEDADB
D8B6793404030302020203020202020202020202
0202010202020202020202020202020202013872A1CCF2F9F5ECD8CBC3BCB6B2C0BBA8AA
B69D8F8A888CA089868F756F6C69666262605F5D5D5C5C5A595958585759595B5B5E5F62
626466696A6C6F7173767B92858284878A8D93AEB3B7ACA4A7ABB0C1D2DDDFDFDDDCDCD4
A4661B0403030202020202020202020202020202
02020202020202020202020202020201020202266090BBE3F6F7F0E4CFC6BFBABAC8C3C2
B49C9793909EA689889B817874716F6D6A696868686A6D65646663616163696D706E6969
6B6C6E70727477787C7E8394978A8C8E929497A6AFA8A9ACAFB9CAD9DFDFDEDCDBDAC98E
4F04030303030202020202020302020202020202
02020202020202020202020201020202020202020E487CA6D2EBF4EFEBDDCBC3BFBBBBB5
A9A29E9C9AAEA68F91A688817E7A787674737272737F8B767285766A6A6E868887807272
737576787A7C7F8083868A91A5939699999B9FA3A9ADB0B7C6D6DEE0DFDEDCDBD1B17635
0403030202020202020202020202020202020202
02020202020202020202020202020202020201020202215584ACD3E7ECE9E9DCCEC4BFB8
B3AEA9A5A4BCAE9CA2B0928B878482807E7D7D7D7D8B9C92829A937774758B8B7A7A7879
7A7E7F80828487898B8D9296ADB1B0ADA2A3A7ABAFB5C1D0DCE0DFDFDEDCD9C59F662404
0302030203030202020202020202020202020202
02020202010202020201020202020202020202020202021447729AC2DCE6E6EBE7D7C8C1
BBB4B1ADB5C6BCB7BCA296928F8D8B88878787878AA2A79F9CA69B817E7F978F89818182
848588898C8D90919497A5B1B7AEA7A8AAADB0B6C3D3DEE1E1DFDEDDDBCEA67235040302
0302030202020202020202020202020202020202
0202020202020202020202010202020102020202020201020329527DA3C7DCE4E5EBE5D8
C9BFB9B5B4B4B8BAAEA39E9B98969491919090919AAD9FAEAEA9A88E88899FA6A18D8A8A
8D8E90929495979A9DA0AAAAA9ACAEB0B3BAC6D2DEE2E1E0E0DEDCD4B582500F03030302
0202020202020202020202020202020202020202
0202020202020202020202020202020202020202020202020202042D5880A6C9DEE7EAEA
E8DBCCC1BDBAB7B3AFABA7A4A3A09E9C9B9B9A9AABB29EB8B9A0AF9F9494A5AA99969394
9697999C9D9FA1A3A5A9ADAFB1B4B9C0CCD8DFE1E2E0E0DFDDD4BC8D5B22040302020202
0302020202020202020202020202020203020202
020202020202020202010201020202020202020201020202020202010D315A83A7CBDEE6
E8EBECE1D6CAC2BDBAB5B2AFACAAA8A7A7A4A3A4BCB1A3B9BCA3B0AF9F9FACB6AFAAA19F
9FA1A3A6A8AAABADB0B2B6B9C1CAD5DDE1E3E2E1E0DFDCD3BC9165300503030203020202
0202020202020202020202020202020202020202
02020202020202020202020202020202020202020202020102020202020108345D83A5C8
DDE5EAECEDEAE1D4C9C1BCB9B7B4B2B0AFAEADADB6AEABB1B4AAAFB8AAA9B0B4B3B1ACA9
A9ABAEB0B2B3B6B9BCC2CBD4DDE2E4E3E3E2E0DFDBD0B890673605030303030203020202
0202020202020202020202020202020202020302
02020202020202020202020201020202020202020202020202020202020202020A345C81
A4C4D9E2E8EBECEDEAE0D6CDC6C1BFBBBABBB7B7B6B5B3B2B2B5B3B3B3B3B4B4B4B3B2B3
B4B6B8BABEC3C8D1D9DFE3E4E5E4E3E1E0DED9CCAD876034050303030303020302020202
0203020202020202020202020202020202020202
020202020202020202020202020202020202020202020202020202020202020202020223
4B6E8CAECAD9E3E8EAEBECECEAE4DDD6D0CBC7C4C3C1C0BEBEBDBCBCBDBEBFBFC1C0C1C2
C5C9CED5DADFE3E5E6E6E5E3E2E2DFDCD5C4A47F5B310504030302020202030202020202
0202020202020202020202020202020202020102
010202020202020202020202020202020202020202020102020202020202020102020202
021B406381A0BACEDAE2E5E7EAEBECECEBEBE8E5E2DDDBDAD8D8D6D6D7D8DADCDDDFE2E4
E5E6E7E7E7E6E6E5E4E3E2DEDAD1BC9F80603A0F04030302020202020202020202020202
0202020202020202020202020202020202020202
020202020202020202020202020202020202020202020202020202020202020202020202
020202092C4E68829FB7C8D6DEE1E3E6E6E9EBEBEBEBEBEBEBEBEAE9E9EAEAE9E9E8E8E8
E7E8E7E6E4E3E2DFDCD5CBB79D8264462205030303030203020302020202020203020202
0202020202020202020202020202020202020202
020202020302020202020202020202020202020202020202020202020202020202020202
02020202020206213F5A6F8498ACBEC7D1D7DBDEE0E1E2E4E4E5E4E5E6E4E5E6E5E4E3E2
E1DDD8D8CFC5BDAB97806B51341504030303020303030202020203020302020202020202
0202020202020202020202020202020202020202
020202020202020202020202020202020202020102020202020202020202020202020202
02020202020202020202122B44596B788795A2ACB4C0C4CBCFD3D2D4D5D6D4D2D1CCC9C2
B7B1A394827462513C230604030303030302030202020202020202020202020202020203
0202020202020202020202020202020202020202
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282, 282},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{-0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J00016Q000`40n007h00Ooooo6ooo003ooolK
ool00?oooa_oo`00oooo6ooo003ooolKool00?oooa_oo`00oooo6ooo000Iool2000Qool40003ool2
000Pool00`00ooooo`02ool2000Oool20004ool2000Oool20004ool2000Kool40003ool20004ool2
000Hool40002ool40003ool2000?ool001Soo`04003ooooo000Pool00`00ooooo`03ool01000oooo
o`007ooo00D00?ooooooo`0000;oo`03003ooooo01_oo`04003ooooo0002ool01000ooooo`007Ooo
00@00?ooool000;oo`04003ooooo000Lool01@00oooooooo00000_oo00@00?ooool000;oo`03003o
oooo01Ooo`05003oooooool00005ool01000ooooo`003_oo000Hool01000ooooo`008Ooo00<00?oo
ool00_oo00@00?ooool001coo`D000;oo`04003ooooo000Mool01000ooooo`000_oo00@00?ooool0
01goo`04003ooooo0002ool01000ooooo`007?oo00D00?ooooooo`0000;oo`04003ooooo0002ool0
0`00ooooo`0Gool00`00ooooo`02ool00`00ooooo`02ool01000ooooo`003_oo000Hool01000oooo
o`008_oo00D00?ooooooo`0000;oo`03003ooooo01[oo`04003ooooo0003ool01000ooooo`007Ooo
0`000ooo00@00?ooool001koo`8000?oo`04003ooooo000Lool01@00oooooooo00000_oo00@00?oo
ool000;oo`03003ooooo01Ooo`03003ooooo00?oo`05003oooooool00002ool00`00ooooo`0<ool0
01Soo`04003ooooo000Sool01000ooooo`000_oo00<00?ooool06ooo00<00?oo00000ooo00@00?oo
ool001goo`03003ooooo00?oo`04003ooooo000Mool01000ooooo`000_oo00@00?ooool001coo`05
003oooooool00002ool01000ooooo`000_oo00<00?ooool05ooo00<00?ooool01?oo00@00?ooool0
00;oo`03003ooooo00coo`006?oo00@00?ooool0023oo`04003ooooo0002ool01000ooooo`007_oo
0P000ooo00@00?ooool001goo`03003ooooo00?oo`04003ooooo000Mool01000ooooo`000_oo00@0
0?ooool001[oo`<000?oo`04003ooooo0002ool01000ooooo`005ooo0`000ooo00@00?ooool000;o
o`04003ooooo000>ool001Woo`8002;oo`8000Coo`80023oo`03003ooooo00;oo`8001ooo`<000?o
o`8001ooo`8000Coo`8001goo`03003ooooo00;oo`8000Coo`8001[oo`03003ooooo00;oo`8000Co
o`8000ooo`00oooo6ooo003ooolKool00?oooa_oo`005Oooo`001@000Ooo000Eool00`00ooooo`02
ool00`00ooooo`06ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`06
ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`06
ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`06ool00`00ooooo`07
ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`06ool00`00ooooo`07ool00`00ooooo`07
ool00`00ooooo`07ool00`00ooooo`06ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07
ool00`00ooooo`06ool20001ool001Goo`03003ooooo00;oo`03003ooooo02Coo`03003ooooo02Co
o`03003ooooo02Coo`03003ooooo02Coo`03003ooooo02Coo`03003ooooo02Coo`03003ooooo017o
o`40007oo`003_oo0P001Ooo00<00?ooool0oooo0Ooo0@000Ooo000=ool01000ooooo`001?oo00<0
0?ooool0oooo0Ooo0@000Ooo000=ool01000ooooo`001?oo0P00oooo0Ooo0P000Ooo000=ool01000
ooooo`001?oo00<00?ooool00_oo2`000PQQ0TYY0Xaa0/HH0^mM0_NN0^mM0]kk0]Jj0/ii0/Hh0[gG
0[Ff0/HH0/ii0]JJ0]Jj3MkK1=Jj0]JJ0/ii1<iI0/Hh1;gg0[gG1[Ff1;FF0Zee2:eE0Ycc0YBB00><
LH@@Q1000W>>0W_?28aa0YBB0ZDd0[gG0/Hh1<ii0/Hh0/HH0[gG0[FF1:ee0[gG0]Jj0]kK0]Jj00?F
V]Jje[X01=Jj0]JJ0/ii0/Hh1<HH0[gg0[Ff0ZDD0YBb0YBB0XaA0X@`18aA0YBB0Ycc0ZDD0Ycc1IBB
0YBb0YcC0Ycc0ZDD0ZeE0Zee0[FF0[gG0[gg0/Hh0/iI0/ii0]JJ0]kK0^mM1>mm0^mM0^LL0[FF0V]=
0PQ12@001?oo0@000Ooo000=ool01000ooooo`001?oo00<00?ooool00_oo2`000PQQ0TYY0Xaa0/HH
0^mM0_NN0^mM0]kk0]Jj0/ii0/Hh0[gG0[Ff0/HH0/ii0]JJ0]Jj3MkK1=Jj0]JJ0/ii1<iI0/Hh1;gg
0[gG1[Ff1;FF0Zee2:eE0Ycc0YBB00><LH@@Q1000W>>0W_?28aa0YBB0ZDd0[gG0/Hh1<ii0/Hh0/HH
0[gG0[FF1:ee0[gG0]Jj0]kK0]Jj00?FV]Jje[X01=Jj0]JJ0/ii0/Hh1<HH0[gg0[Ff0ZDD0YBb0YBB
0XaA0X@`18aA0YBB0Ycc0ZDD0Ycc1IBB0YBb0YcC0Ycc0ZDD0ZeE0Zee0[FF0[gG0[gg0/Hh0/iI0/ii
0]JJ0]kK0^mM1>mm0^mM0^LL0[FF0V]=0PQ12@001?oo0@000Ooo000=ool01000ooooo`001?oo00<0
0?ooool00_oo2@000P0P0T8X0X@`0[gG0^Ll0_NN0^mM0^LL0]Jj0/ii0/Hh0[gg0[Ff0[FF0[gg0/iI
0]JJ4MJj1=JJ0/ii0/Hh0/HH0[gg0[gG2;Ff1Zee2:eE0ZDD0YBb0YBB00><LG>^Ljh00V]]0W__0XaA
1Xaa0YBB0ZDd0[gG0/Hh0/iI0/Hh0/HH0[gG0[Ff0Zee0ZeE0Zee0[gg1=Jj1MJJ0]Jj0]JJ0/ii0/iI
1<HH0[gg0[Ff0ZDd0YBb0YBB0Xaa0X@`0X@@18@`0YBB0YBb0YcC0Xaa0XaA0haa0YBB0YBb0YcC0Ycc
0ZDD0ZeE0Zee0[FF0[gG0[gg0/HH0/iI0/ii0]JJ0]kK0^mM1>mm0^Ll0]kk0ZDd0U[;0`0P1P001?oo
0@000Ooo000>ool20005ool00`00ooooo`02ool900020202@RP2Q302_ML2ic`2mih2ked2ia`2e[X2
cWT2aSP2_OL2]KH2]IH2_OL2cUT2eYXAe[X4eYX2cWT2aSP2aQP2_OL2_ML8]KH6[GD8[ED2YA@2U;82
U9800haaLjic[P02Jfd2Nnl2S546S742U982YC@2_ML2aSP2cUT2aSP2aQP2_ML2]KH2[GD2[ED2[GD2
_OL4e[X5eYX2e[X2eYX2cWT2cUT4aQP2_OL2]KH2YC@2U;82U982S742Q302Q104Q302U982U;82W=<2
S742S543S742U982U;82W=<2W?<2YA@2[ED2[GD2]IH2_ML2_OL2aQP2cUT2cWT2eYX2g]/2ked4kgd2
ic`2g_/2YC@2F//302060004ool10001ool001Goo`03003ooooo00;oo`T0008Q909S;0:U50;F^P;g
WP;_O@;W?0;Nn`;F^P;>F@;6>0:mm`:e]P:]M@:eUP;660;>F@;>N@;FVPWF^PKFVP;>N@;6>0;660Bm
e`Re]P:eUPB]M@R]E@:U=0:Ll`BD/P03S55cSW>>009[C@9kc`:<D@R<L@:U50:e]P;660;6>0;660:m
e`:e]P:eUP:]E@:U=0:]E@:mm`;FVP;F^P;FVP03cWWFV]JJ00;FVP;>N@;>F@;6>0Bmm`:e]P:]E@:L
d`:DTP:<L@:<D@:440Ikk`:<D@BDTPJ4<003S56<LHaa00:DTP:D/P:Ld`:Ll`:U50:U=0:]M@:eUP:e
]P:mm`;660;6>0;>F@;FVP;Nf`;_G@;_O@;_G@;W?0;W70:U=09Jb`D0808000Coo`40007oo`005Ooo
00<00?ooool00_oo2@000R4T0V</0ZDD0]Jj0_NN0^mm0^Ll0]kk0]Jj0/iI0/Hh0[gg0[Ff0Zee0[FF
0/HH0/iI0/ii0]JJ2MJj1]JJ0/ii0/Hh0/HH1;gG2;Ff0[FF1:ee2:eE0ZDd0Ycc19Bb00><DG>>Lhh0
0V]=0W_?0XaA28aa0ZDD0[Ff0/HH0/Hh0/HH0[gG0[Ff0[FF0ZeE0ZDd0ZeE0[gg0]JJ0]Jj0]JJ00?>
NMJJeYX00]JJ0/ii0/iI0/Hh1;gg0[Ff0ZeE0YcC0YBB0Xaa0XaA0X@@1W__0XaA19BB1X@`00><DHaa
S7400YBB0YBb0YcC0Ycc0ZDD0ZDd0Zee0[FF0[Ff0[gg0/HH0/Hh0/iI0]JJ0]kK0^mM0^mm0^mM0^Ll
0^LL0ZDd0U[;1@0P0P001?oo0@000Ooo000Eool00`00ooooo`02ool800000b44HbaS;002YA@2g]/2
mih2kgd2ic`2g_/2e[X2cWT2aSP2_OL2]KH2[GD2YC@2]IH2aQP2cUT2cWT4eYX2e[X9eYX2cWT2aSP2
_OL2_ML:]KH4]IH4[ED2YC@6[ED2YA@4W=<2S7400g_?Jde[C@02Lhh2Q302S546S742U;82[ED2_ML4
_OL2_ML2]KH2]IH2[ED4YC@2]IH2cUT4eYX7cWT2cUT2aSP4_OL2]KH2[ED2W=<2U982S742Q302Q106
Nll2Q104S542Q102Nnl4Q1000h@`S56<D@02S742U982U;82W=<2W?<2YC@2[ED2[GD2]IH2_ML2_OL2
aSP2cUT2cWT2eYX2ia`4kgd2ked2ic`2cUT2Q1000b4T0000000202020004ool10001ool001Goo`03
003ooooo00;oo`P000038@AS;6</00:U50;Nf`;gWP;_O@;W?0;Nn`;F^P;>N@;6>0:mm`:e]P:]M@:U
=0:eUP;660;>F@;>N@CFVP;F^PWFVP;>N@;6>0:mm`:me`Ze]PBeUPB]E@:U=0J]E@:U50BLd`:<L@03
Nlm[CF]=009cSP:4<0:<D@J<L@:D/P:]E@:me`Bmm`:me`:e]P:eUP:]E@BU=0:eUP;>F@CFVPO>N@;>
F@;6>0Bmm`:e]P:]E@:Ld`:DTP:<L@:4<0:440Ikc`:440B<D@:4409kk`B44003Q32<DHaA00:<L@:D
TP:D/P:Ld`:Ll`:U=0:]E@:]M@:eUP:me`:mm`;6>0;>F@;>N@;FVP;W70C_O@;_G@;W?0;>F@:44003
8B@000000080808000Coo`40007oo`005Ooo00<00?ooool00_oo1P000Q2200=BZYBbU;800/ii0_NN
0^mm0^Ll0]kk0]Jj0/ii0/iI0/HH0[gG0[FF0ZeE0ZDD0ZeE0[gG0/Hh0/iI0/ii2mJJ0/ii0/Hh0[gg
1;gG2;Ff0[FF1:ee1:Dd0ZeE0Zee0ZeE0ZDD19cc0YBb0X@@0f]]0W>^0XaA28aa0YcC0Zee1;gG0[Ff
0[FF1:ee0ZDd0ZDD0ZDd0[gG0/iI1<ii1liI0/Hh0/HH0[gG0[Ff0Zee0Ycc0YBB0Xaa0X@`0W__0W_?
1W>^0W__0X@@0W_?0W>^17_?0W__00>448@`Q3000XaA0Xaa0YBB0YBb0YcC0Ycc0ZDd0ZeE0Zee0[FF
0[gG0[gg0/Hh0/iI0/ii0]Jj0^Ll1>mm0^mM0^Ll0[gg00=[K@QQ264010001?oo0@000Ooo000Eool2
0003ool6000248800e:ZU;:D/P02cWT2mih2kgd2ic`2g_/2e[X2cWT2cUT2aQP2_ML2]IH2[ED2YA@2
[ED2_ML2aSP2cUT2cWT;eYX2cWT2aSP2_OL4_ML8]KH2]IH4[GD4YC@2[ED2[GD2[ED2YA@4W?<2U;82
Q103Jfd2Ljh2S548S742W=<2[GD4_ML2]KH2]IH4[GD2YC@2YA@2YC@2_ML2cUT4cWT7cUT2aSP2aQP2
_ML2]KH2[GD2W?<2U982S742Q302Nnl2Nll6Ljh2Nnl2Q102Nll2Ljh4Nll2Nnl00h@@Q324<002S542
S742U982U;82W=<2W?<2YC@2[ED2[GD2]IH2_ML2_OL2aSP2cUT2cWT2e[X2ic`4kgd2ked2ic`2_OL0
0f]]2648H@040003ool20001ool001Goo`03003ooooo00;oo`H0008aQP03Ljje][Ff00;W?0;gWP;_
G@;W70;Nf`;FVP;>N@;6>0:mm`:e]P:]M@:U=0BLl`:eUP:mm`;6>0;>F@;>N@WFVP;>F@;6>0Bmm`Bm
e`Be]P:eUPJ]M@J]E@:]M@:]E@:U50:Ll`:Ld`:DTP9kk`03JfecSW>>009kk`:<D@R<L@:Ld`:]M@Be
]P:eUPB]M@:]E@:U=0:U50:U=0:me`;6>0C>N@?>F@C6>0;660:mm`:e]P:]M@:U=0:Ld`:DTP:<D@:4
409kc`9c[PA[K@9cSPAkc`A[K@9cSP9c[P9kc`03Nnn448@@00:4<0:<D@:<L@:DTP:D/P:Ld`:Ll`:U
50:U=0:]M@:eUP:me`:mm`;6>0;>F@;>N@;F^P;W?0C_O@;_G@;W?003]KIS;6</00@080Coo`40007o
o`005Ooo00<00?ooool00_oo1P000S6600=c[[Ff]KH00^Ll0_NN0^mM0^LL0]kK0]JJ0/ii0/Hh0[gg
0[Ff0Zee0ZDd19cc0[FF0[gg0/Hh0/iI0/ii2MJJ0/iI0/Hh1;gg1;gG1;Ff0[FF1Zee1ZeE0Zee0ZeE
0ZDD0Ycc0YcC0YBB0W__00=[KG>>Lhh00W__0XaA28aa0YcC0Zee1;Ff0[FF1:ee0ZeE0ZDd0ZDD0ZDd
0[gG0/Hh1<ii0liI1<Hh0/HH0[gg0[Ff0Zee0ZDd0YcC0YBB0XaA0X@@0W_?0W>^16]]0W>>17_?16]]
0W>>0W>^0W_?00=kkh@@Q1000X@`0XaA0Xaa0YBB0YBb0YcC0Ycc0ZDD0ZDd0Zee0[FF0[gG0[gg0/Hh
0/iI0/ii0]Jj0^Ll1>mm0^mM0^Ll00>e]V</Hb`0100P1?oo0@000Ooo000Eool00`00ooooo`02ool4
00026<<2H``00jDDg__Nn`02mih2ked2ic`2g_/2e[X2cWT2aSP2_OL2]KH2]IH2[ED2YA@4W=<2[ED2
_ML2aQP2cUT4cWT5eYX2cWT2cUT2aQP6_OL2_ML4]KH2]IH2[GD8[ED2[GD2[ED2YC@2YA@2W=<2U;82
S543Ljh2Nll2Q306S744U982W?<4]IH4[GD4[ED2YC@4YA@2[ED2_ML2aSP4cUT5aSP2aQP2_OL2]KH2
[GD2YC@2W?<2U;82S542Q102Nll2Ljh2Lhh2Hb`2Jdd2Lhh2Ljh6Jdd2Jfd2Lhh2Ljh00g_?Nnmkk`02
Q102Q302S542S742U982U;82W=<2W?<2YC@2[ED2[GD2]KH2_ML2aQP2aSP2cUT2eYX2e[X2ked2kgd4
ked00nLLYABU5002BTT20204ool10001ool001Goo`03003ooooo00;oo`@0008H``9S3003YACNnmkk
00;gWP;_G@;W?0;Nn`;F^P;>N@;6>0:mm`:e]P:eUP:]E@:U50BLd`:]E@:me`;660;>F@C>N@GFVP;>
N@;>F@;660Jmm`:me`Be]P:eUP:]M@R]E@:]M@:]E@:U=0:U50:Ld`:D/P:<D@=c[P9kc`:4<0J<L@BD
TP:Ll`BeUPB]M@B]E@:U=0BU50:]E@:me`;6>0C>F@G6>0;660:mm`:e]P:]M@:U=0:Ll`:D/P:<D@:4
409kc`9c[P9cSP9S;09[C@9cSP9c[PI[C@9[K@9cSP9c[P03Nlmkkg__00:440:4<0:<D@:<L@:DTP:D
/P:Ld`:Ll`:U=0:]E@:]M@:e]P:me`;660;6>0;>F@;FVP;F^P;_G@;_O@C_G@03iabU5:DD009:B@80
80Coo`40007oo`005Ooo00<00?ooool00_oo10000TY90Xaa00?>FONNmih00^mm0^Ll0]kk0]Jj0/ii
0/iI0/HH0[gG0[FF0ZeE0ZDd0Ycc0YBb0YBB0ZDd0[gG0/HH0/Hh0/iI0/ii1=JJ0lii0/Hh0/HH1[gg
0[gG0[Ff0[FF1:ee1:eE0Zee1:eE0ZDd0ZDD0YcC0YBb0Xaa0X@@0W_?00=kkh@@Q1002Xaa0YBB0ZDd
1:ee0ZeE1ZDd0ZDD0Ycc0ZDD0Zee0[gG0/HH1/Hh0lHH0[gg0[Ff0Zee0ZDd0Ycc0YBb0Xaa0X@@0W_?
0W>>0V]]0V</0V<<0V</0V]]0V</16<<0V</0V]=0V]]0W>>00=c[W_?Nll00W__0X@@0X@`0XaA0Xaa
0YBB0YBb0YcC0ZDD0ZDd0ZeE0Zee0[Ff0[gG0/HH0/Hh0/iI0]JJ0]kk1>mm0^mM00?W?=JJeYX00XaA
0R4T1?oo0@000Ooo000Eool00`00ooooo`02ool40002BTT2S7400liImikgWP02kgd2ic`2g_/2e[X2
cWT2cUT2aQP2_ML2]IH2[ED2YC@2W?<2U;82U982YC@2_ML2aQP2aSP2cUT2cWT4eYX3cWT2aSP2aQP6
_OL2_ML2]KH2]IH4[GD4[ED2[GD4[ED2YC@2YA@2W=<2U;82S742Q102Nll00g__Q124400:S742U982
YC@4[GD2[ED6YC@2YA@2W?<2YA@2[GD2_ML2aQP6aSP3aQP2_OL2]KH2[GD2YC@2W?<2U;82S742Q102
Nll2Lhh2Jfd2Hb`2H``2Hb`2Jfd2Hb`4H``2Hb`2Jdd2Jfd2Lhh00g>^Nlmkc`02Nnl2Q102Q302S542
S742U982U;82W=<2YA@2YC@2[ED2[GD2]KH2_ML2aQP2aSP2cUT2eYX2g_/4kgd2ked00nLleY[FVP02
S5428B@4ool10001ool001Goo`03003ooooo00;oo`800092:0:<D@;6>003mkk_ONmm00;W?0;Nn`;F
^P;>N@;>F@;660:me`:eUP:]M@:U=0:Ll`:D/P:DTP:<L@:U=0:e]P:mm`;6>0;>F@O>N@;>F@;6>0C6
60Bmm`:me`:e]P:eUPB]M@B]E@:U=0:]E@:U=0:Ll`:Ld`:D/P:<L@:4<09kk`>440:<D@:DTP:<L@:<
D@B<L@:Ld`B]E@:U=0RU50BLl`:U=0:eUP:me`:mm`K66003_ONmekgG00:e]P:]M@:U=0:Ll`:Ld`:<
L@:4<09kc`9cSP9[K@9S;09Jj`9S309S;09Jj`9Jb`AJj`9S309S;09[C@9[K@03Lhic[W>^009kc`9k
k`:440:4<0:<D@:<L@:DTP:Ld`:Ll`:U50:U=0:]M@:eUP:me`:mm`;6>0;>F@;>N@;F^P;_G@C_O@03
kegW?>Ll00:]E@9BZPCoo`40007oo`005Ooo00<00?ooool00_oo0P000T8X0XaA0/Hh00?g_^mmkgd0
0^Ll0]kk0]Jj0/ii0/iI0/HH0[gG0[FF0Zee0ZDd0Ycc0YBb0YBB0Xaa0ZDd0[Ff0[gg0/Hh0/iI1lii
0/iI0/Hh1<HH1;gg0[gG0[Ff0[FF1:ee1:eE0ZDd0ZeE0ZDd0Ycc0YcC0YBb0Xaa0X@`0W__0h@@0XaA
0YBB0Xaa0XaA18aa0YcC1:eE0ZDd2:DD19cc0ZDd0[FF0[gG0[gg1/HH00>mmkgG_ML00[Ff0Zee0ZDd
0Ycc0YcC0Xaa0X@`0W_?0W>>0V]]0V</0U[[0V<<0V</0U[[0U[;15[[0V<<0V</0V]=0V]]00=cSW>^
Ljh00W_?0W__0X@@0X@`0XaA0Xaa0YBB0YcC0Ycc0ZDD0ZDd0Zee0[FF0[gG0[gg0/Hh0/iI0/ii0]Jj
0^mM1>mm00?_GNLlic`00ZeE0U:Z1?oo0@000Ooo000Eool00`00ooooo`02ool24882F^/2YA@2g_/0
0oNnkeg_G@02ia`2g]/2eYX2cUT2aSP2_OL2]KH2[GD2[ED2YA@2W=<2U982S742S542W=<2[GD2_ML2
aQP2aSP2cUT4cWT3cUT2aSP6aQP2_OL2_ML2]KH2]IH4[GD6[ED2YC@2YA@2W?<2U;82U982S542Q104
Q3000haAS76<L@02U982S744S542S742W=<4YC@2YA@6W=<4U;82W=<2YA@2]IH4_ML7_OL2]KH2[GD2
YC@2YA@2W=<2U;82S542Q102Ljh2Jfd2Hb`2F^/2F//4F^/2DXX4DZX2F//2F^/2H``2Hb`2Jdd3Jfd2
Lhh2Ljh2Nll2Q102Q302S542S742U982U;82W?<2YA@2YC@2[GD2]IH2_ML2_OL2aSP2cUT2cWT2e[X2
ked2kgd3ked2ia`2YA@4ool10001ool001Goo`8000?oo`8@PP9Jj`:U50;Nn`03mkk_GNmM00;W70;N
f`;FVP;>F@;6>0:mm`:e]P:]M@:]E@:U50:Ld`:DTP:<L@:<D@:Ld`:]M@:me`;660;6>0;>F@C>N@?>
F@;6>0K660:mm`:me`:e]P:eUPB]M@J]E@:U=0:U50:Ll`:D/P:DTP:<D@:440B4<003S56<LHaa00:D
TP:<L@B<D@:<L@:Ld`BU=0:U50JLd`BD/P:Ld`:U50:eUPBme`Nmm`:e]P:]M@:U=0:U50:Ld`:D/P:<
D@:4409c[P9[K@9S;09Jj`9Jb`AJj`9BRPABZP9Jb`9Jj`9S309S;09[C@=[K@9cSP9c[P9kc`:440:4
<0:<D@:<L@:DTP:D/P:Ll`:U50:U=0:]M@:eUP:me`:mm`;6>0;>F@;>N@;F^P;_G@;_O@?_G@;W70:U
50?oo`80007oo`005Ooo00<00?ooool00_oo0U:Z0YcC0]Jj0_Nn00?_GNLLia`00]kK0]JJ0/iI0/Hh
0[gg0[Ff0Zee0ZeE0ZDD0Ycc0YBb0Xaa0XaA0X@`0YcC0ZeE0[Ff0[gg0/Hh1/iI1LHh1/HH0[gg0[gG
0[Ff0[FF1:ee1:eE1:Dd0ZDD0YcC0YBB0XaA18@`0XaA0haa0YBB0Xaa0XaA18@`0YBB1:DD0Ycc0YcC
29Bb0YcC0ZDD0ZeE0[FF0[Ff0[gG1;gg0[gG00>e][FF]IH00ZDd0Ycc0YcC0YBB0XaA0X@@0W>^0V]]
0V</0U[;0U::0U[;0U:Z14YY15::0U:Z0U[;0U[[0V<<0V</0f]=0V]]0W>>0W_?0W__0X@@0X@`0XaA
0Xaa0YBb0YcC0Ycc0ZDd0ZeE0Zee0[Ff0[gG0/HH0/Hh0/ii0]JJ0^LL0nmm0^mM0^Ll0[gG1?oo0@00
0Ooo000Eool00`00ooooo`02ool2DZX2W=<2e[X2mkh00nmMiacW7002g]/2eYX2cUT2aSP2_OL2]KH2
[GD2[ED2YA@2W?<2U;82S742S542Q302W=<2[ED2]KH2_OL2aSP6cUT5aSP6aQP2_OL2_ML2]KH2]IH4
[GD4[ED4YC@2YA@2W=<2U982S544Q302S543S742U982S742S544Q302U984YA@2W?<2W=<8U;82W=<2
YA@2[ED2]IH2]KH2_ML4_OL2_ML00kFf]IJeUP02YC@2W?<2W=<2U982S542Q102Ljh2Jfd2Hb`2F//2
DXX2F//2DZX4BVT4DXX2DZX2F//2F^/2H``2Hb`3Jdd2Jfd2Lhh2Nll2Nnl2Q102Q302S542S742U;82
W=<2W?<2YC@2[ED2[GD2]KH2_ML2aQP2aSP2cWT2eYX2ia`3kgd2ked2ic`2_ML4ool10001ool001Go
o`03003ooooo00;oo`:440:mm`;gWP;_O@03iccNnmkk00;F^P;>N@;6>0;660:me`:eUP:]E@:U=0:L
l`:D/P:DTP:<D@:4409kk`:<L@:U50:eUP:me`;660_6>0K660:mm`:me`:e]PBeUP:]M@J]E@:U=0:L
l`:Ld`:DTPB4<0B<L@FDTP:<L@:4<0:440:4<0:D/P:U50:Ll`:Ld`JD/PBLd`:Ll`:U=0:]M@:eUPBe
]PJme`03]IJU=:Dd00:Ll`:Ld`:DTP:<D@9kk`9c[P9[K@9S309Jb`IBRPI:B@A:J@9BRP9BZP9Jb`AJ
j`=S;09[C@9[K@9c[P9kc`9kk`:440:4<0:<D@:DTP:D/P:Ld`:Ll`:U=0:]E@:eUP:e]P:mm`;660;>
F@;>N@;F^P;_G@03kgg_GNmM00;_G@;W70Coo`40007oo`005Ooo00<00?ooool00_oo0X@@0[gg0_NN
0^mm00?W?=kkg_/00]Jj0/ii0/Hh0/HH0[gG0[FF0ZeE0ZDd0Ycc0YBb0YBB0XaA0X@@0W__0Xaa0ZDD
0[FF0[gG0/HH2lHh1/HH0[gg0[gG0[Ff1;FF0Zee1ZeE0ZDd0Ycc0YcC0YBB18@`18aa1IBB0Xaa0X@`
0X@@0X@`0YBb0ZDD0Ycc0YcC1YBb19cC0Ycc0ZDd0Zee0[FF1;Ff1[gG00>eUZDdYC@00Ycc0YcC0YBB
0XaA0W__0W>^0V]]0V<<0U[;1U::1TY914YY0U::0U:Z0U[;15[[0f</0V]=0V]]0W>^0W_?0W__0X@@
0X@`0XaA0YBB0YBb0YcC0Ycc0ZDd0ZeE0[FF0[Ff0[gg0/HH0/iI0/ii0]Jj0^mM00?_ONmMked00^mM
0^LL1?oo0@000Ooo000Eool00`00ooooo`02ool2YC@2ia`2mkh2ic`00nLLg]_Nf`02cWT2cUT2aQP2
_ML2]IH2[GD2YC@2W?<2W=<2U982S542Q302Nnl2Nll2Nnl2W=<2[ED2]KH2_OL2aQP5aSP:aQP2_OL4
_ML2]KH2]IH4[GD2[ED4YC@2W?<2U;82S542Q302S747U982S742Q304Nnl2Q302W=<2W?<2W=<4U;82
U984U;82W=<2W?<2[ED2[GD4]IH8]KH00jeeW=>Ld`02U;82U982S542Nnl2Ljh2Jfd2H``2DZX6BVT6
@PP4@RP2BTT2BVT2DXX2DZX2F//3F^/2H``2Hb`2Jdd2Jfd2Ljh2Nll2Nnl2Q102Q302S742U982U;82
W?<2YA@2YC@2[GD2]IH2_ML2_OL2aSP2cUT2eYX2g_/00nmmkeg_G@02ked2ic`4ool10001ool001Go
o`03003ooooo00;oo`:U=0;W70;g_P;W?003iacNfmkK00;>N@;>F@;660:me`:eUP:]M@:U=0:Ll`:L
d`:DTP:<D@:4<09kk`9kc`9kk`:Ld`:]E@:e]P:mm`;660G6>0[660:mm`Bme`:e]P:eUPB]M@:]E@BU
=0:Ll`:D/P:<D@:4<0:<L@NDTP:<L@:4<0Akk`:4<0:Ld`:Ll`:Ld`BD/P:DTPBD/P:Ld`:Ll`:]E@:]
M@BeUPRe]P03[GFLdicC00:D/P:DTP:<D@9kk`9c[P9[K@9S309BZPI:J@I220A2:09:B@9:J@9BRP9B
ZP9Jb`=Jj`9S309S;09[C@9[K@9c[P9kc`9kk`:440:4<0:<L@:DTP:D/P:Ll`:U50:U=0:]M@:eUP:m
e`:mm`;6>0;>F@;FVP;Nn`03kgg_GNmM00;_G@;W?0Coo`40007oo`005Ooo00<00?ooool00_oo0/Hh
0_Nn0^mM0^Ll00?NfmJJeYX00/iI0/HH0[gg0[Ff0Zee0ZeE0ZDD0YcC0YBb0Xaa0X@`0X@@0W_?0W>>
0V]]0XaA0Ycc0Zee0[Ff1;gg2lHH1[gg0[gG0[Ff0[FF1:ee0ZeE0ZDd0ZDD0YcC0Xaa18aA29BB00><
LH@`Q3000W__0W_?0W__0Xaa19cc0YBb19BB0Xaa19BB0YcC0ZDD0ZeE1:ee1;FF0[Ff0[FF0Zee00>U
59BBU9800Xaa0XaA0W__0W>>0V]=0V<<0U:Z0TY90T8X0TY923WW0T88148X0TY90TYY0U::0U:Z0e[;
0U[[0V<<0V</0V]=0W>>0W>^0W_?0W__0X@@0XaA0Xaa0YBB0YcC0Ycc0ZDD0ZeE0Zee0[FF0[gG0/HH
0/Hh0/ii0]Jj00?_GNmmkgd00^mM0^Ll1?oo0@000Ooo000Eool00`00ooooo`02ool2aSP2mkh2ked2
ic`00mkKeY[FVP02cUT2aQP2_OL2]KH2[GD2[ED2YA@2W=<2U;82S742Q302Q102Nll2Lhh2Jfd2S542
W?<2[GD2]KH4_OL;aQP6_OL2_ML2]KH2]IH4[GD2[ED2YC@2YA@2W=<2S744S548U9800haaQ324<002
Nnl2Nll2Nnl2S744W?<2U;84U982S744U982W=<2YA@2[ED4[GD4]IH2]KH2]IH2[GD00jDDU9:DTP02
S742S542Nnl2Lhh2Jdd2H``2DZX2BTT2@RP2BTT8>NL2@PP4@RP2BTT2BVT2DXX2DZX3F//2F^/2H``2
Hb`2Jdd2Lhh2Ljh2Nll2Nnl2Q102S542S742U982W=<2W?<2YA@2[ED2[GD2]IH2_ML2aQP2aSP2cWT2
e[X00nmMkgg_O@02ked2ic`4ool10001ool001Goo`03003ooooo00;oo`;Nf`;g_P;_G@;W7003g]_F
V]JJ00;>F@;660:me`:eUP:]E@:U=0:Ll`:D/P:DTP:<D@:4<09kk`9c[P9[K@9[C@9[K@:<D@:Ll`:]
M@:e]P:me`>mm`[660:mm`Bme`:e]P:eUPB]M@:]E@:U=0:Ll`:D/P:<D@:<L@BDTP:D/P:DTP:<L@03
S55kkg__009kc`9c[P:440:<L@:Ll`:Ld`:D/P:DTPR<L@:D/P:U50B]E@Z]M@:]E@03W=><LHaa00:<
D@:4<09kc`9[K@9S;09BZP9:B@922092:09220HaYP8ia`8ii`A22092:09:B@9:J@9BZP9Jb`03DZYJ
be[;009Jj`9S309S;09[C@9cSP9c[P9kc`9kk`:440:<D@:<L@:DTP:Ld`:Ll`:U50:]E@:]M@:eUP:m
e`:mm`;6>0;>N@03e[[_GNmM00;_O@;_G@Coo`40007oo`005Ooo0P000ooo0_NN0^mm0^LL0]kK00?F
V/iicWT00/Hh0[gg0[Ff0Zee0ZDd0Ycc0YcC0YBB0Xaa0X@`0W__0W_?0W>>0V]=16<<0W>^0Xaa0ZDD
0Zee0[Ff0[gG00>mmlHHaQP00[gg0/HH1;gg1;gG1;Ff0[FF0Zee0ZeE0ZDD0Ycc0YBB18aa0YBB1YBb
0Xaa0XaA00=kkg_?Nll00W>^0W_?0X@`0YBb0Ycc0YcC0YBb0Xaa1XaA0Xaa0YBb0ZDD1:eE1Zee1:eE
0ZDD00><LHaAS5400X@`0W__0W>>0V</0U[;0TY914880SWW0S6V13660S6V1SW70SWW14880T8X0U[;
0V]=00=Jje:ZDZX00U:Z0U[;0V<<0V</0V]=0W>>0W>^0W_?0X@@0X@`0XaA0Xaa0YBB0YcC0Ycc0ZDd
0ZeE0Zee0[Ff0[gG0/HH0/Hh00?>NNLLia`00^mm0^mM0ooo0P000Ooo000Eool00`00ooooo`02ool2
mih2kgd2ia`2g]/00mJJcWW>N@02aSP2_OL2]KH2[GD2YC@2W?<2W=<2U982S742Q302Nnl2Nll2Lhh2
Jdd4H``2Ljh2S742YA@2[GD2]KH2_ML00kggaQS66002_OL2aQP4_OL4_ML4]KH2]IH2[GD2[ED2YA@2
W?<2U984S742U986U;82S742S5400g__Nlmkc`02Ljh2Nll2Q302U;82W?<2W=<2U;82S746S542S742
U;82YA@4[ED6[GD4[ED2YA@00haaS56<D@02Q302Nnl2Lhh2Hb`2F//2BTT4@PP2>NL2<JH4<HH2<JH6
>LL2>NL4@PP2@RP2F//2Jdd00e[[DZYBZP02DZX2F//2H``2Hb`2Jdd2Lhh2Ljh2Nll2Q102Q302S542
S742U982W=<2W?<2YC@2[ED2[GD2]KH2_ML2aQP2aSP00liiiacW7002kgd2ked4ool10001ool001Go
o`03003ooooo00;oo`;g_P;W?0;Nn`;F^P03cWW6><Hh00:mm`:e]P:]M@:U=0:U50:Ld`:DTP:<L@:4
<09kk`9kc`9cSP9[C@9S;09Jj`9Jb`9S30:440:D/P:U=0:]M@:e]P03_MNmmkgg00Jmm`Bme`:e]P:e
UP:]M@:]E@:U=0:Ll`:D/P:DTP:<L@:DTPRD/P:<L@:4<09kk`=c[P9kc`:440:<L@BLd`:D/P:<L@:<
D@J4<0:<L@:Ld`:U=0Z]E@:U=0:Ll`:<L@>4<09kk`9c[P9[C@9Jb`92:0@ii`8ia`HYI@@aQP@aYP@i
a`8ii`A22092:09S3003JdeBZU:Z00ABZP9Jj`9S309[C@9cSP9kc`Akk`:4<0B<D@:<L@:D/P:Ll`:U
50B]E@:eUP:me`:mm`;6>003cWWNfmkK00C_O@Coo`40007oo`005Ooo00<00?ooool00_oo0_Nn0^Ll
0]kk0]Jj00?>NLHhaSP00[gg0[Ff0Zee0ZDd0ZDD0YcC0YBB0Xaa0X@`0W__0W_?0W>>0V]=0V</0U[[
0U[;0V<<0X@@0YBb0ZDd0Zee0[Ff00>mekgg_OL01[gg1;gG0[Ff0[FF0Zee0ZeE0ZDd0Ycc0YBb0YBB
0Xaa0YBB29Bb0Xaa0X@`0W__0g>^0W_?0X@@0Xaa19cC0YBb0Xaa0XaA1X@`0Xaa0YcC0ZDd2ZeE0ZDd
0Ycc0Xaa0h@`0W__0W>^0V]=0U[;0T8X13WW0SW71RUU1366136V13W70SWW14880T8X0V<<00=[CE:Z
DZX015:Z0U[[0V<<0V]=0W>>0W_?17__0X@`18aA0Xaa0YBb0Ycc0ZDD1:eE0[FF0[gG0[gg0/Hh00?>
NMkKg]/01>mm1?oo0@000Ooo000Eool00`00ooooo`02ool2kgd2ia`2g]/2eYX00liIaQS66002_ML2
]KH2[GD2YC@2W?<2U;82U982S542Q102Nnl2Ljh2Lhh2Jdd2H``2F^/2DZX2DXX2Hb`2Nnl2U982YA@2
[GD00kFF]KJe]P04_ML4]KH4]IH2[GD2YC@2YA@2W?<2U;86U982U;84W=<2U;82U982S542Q102Nll3
Ljh2Nll2Q302S744U982S742S542Q306Q102S742W=<2YA@6YC@2[ED2YC@2YA@2W=<2S5400h@`Q124
4002Nll2Lhh2H``2BVT2>NL4>LL2:FD8:DD2:FD2<HH2<JH8>LL2>NL2@PP2@RP00e[[Jde[C@04DXX2
F//2F^/2Jfd2Q302S742U982Q302Nnl2Q102Q302S542U982U;82YC@2]KH2[ED2[GD2]IH2_ML2_OL0
0lHhcWW>N@02ia`2kgd4ool10001ool001Goo`03003ooooo00;oo`;_O@;W70;Nf`;FVP03cUW66<HH
00:me`:e]P:]M@:U=0:Ll`:D/P:DTP:<D@:4409kk`9c[P9cSP9[C@9S309Jj`9BZP9BRP9S;09kk`:D
TP:U50:]M@03]IJe][Ff00Bme`Be]PBeUP:]M@:U=0:U50:Ll`:D/PJDTP:D/PBLd`:D/P:DTP:<D@:4
409kc`=c[P9kc`:4<0:<L@BDTP:<L@:<D@:4<0J440:<L@:Ld`:U50JU=0:]E@:U=0:U50:Ld`:<D@03
Q32448@@009kc`9cSP9S309:J@8ii`@ia`8YI@PYA@8YI@8aQP8aYPPia`8ii`922092:003F^][CF]=
00ABRP9Jb`9Jj`9[K@:4<0:<L@:DTP:4<09kk`:440:4<0:<D@:DTP:D/P:U=0:e]P:]E@:]M@:eUP:m
e`:mm`03aSS>NLii00;W70;_O@Coo`40007oo`005Ooo00<00?ooool00_oo0^mM0]kk0]Jj0/ii00?6
>;gg_OL00[Ff0[FF0ZDd0ZDD0YcC0YBB0Xaa0X@`0W__0W_?0W>>0V]]0V</0V<<0U[;0U:Z0TYY0U::
0V]]0X@@0YBB0Ycc00>U=:ee[GD02:ee0ZeE0ZDd0ZDD19cc0YcC3YBb0YBB0Xaa0X@`0W__0g>^0W_?
1X@`0X@@18aA0X@`0X@@17__0X@`0Xaa0YcC0ZDD2:Dd0ZDD0YcC0XaA0X@@00=kkg_?Nll00W>>0V<<
0U::0SWW0S6V0SW70RUU224T12U50RUU0S660TY90T8X136V0SW70SWW0T8800=2:6</Hb`00V<<0U::
0U:Z0V<<17__0W_?0Xaa0YcC0X@@0W__0X@@0XaA0Xaa0YBb0ZeE0/HH1:eE0Zee0[Ff0[gG00?66<iI
cUT00]Jj0^mM1?oo0@000Ooo0007ool40003ool20005ool00`00ooooo`02ool2ked2g_/2e[X2cWT0
0lHh_ONmm`02]KH2]IH2YC@2YA@2W=<2U982S742Q302Nnl2Nll2Lhh2Jfd2Hb`2H``2F//2DZX2BVT2
DXX2Jfd2Q102U982W?<00jDd[GF]M@08[GD2[ED2YC@2YA@4W?<2W=<>U;82U982S742Q302Nnl3Ljh2
Nll6Q302Q104S542Q302Q104Nnl2Q302S742W=<2YA@8YC@2YA@2W=<2S542Q1000g__Nlmkc`02Lhh2
H``2DXX2>NL2<JH2>LL2:FD88B@4:DD2:FD2<HH2BTT2@RP4<JH2>LL2>NL2@PP00d8XHbaS;002H``2
DXX2DZX2H``4Nnl2Nll2S742W=<2Q102Nnl2Q102S542S742U;82[ED2aQP4[ED2[GD2]KH2_ML00lHH
cUW>F@02e[X2ked4ool10001ool000Ooo`03003ooooo00?oo`04003ooooo0004ool00`00ooooo`02
ool2ia`2g]/2eYX2cUT00lHH_MNme`02]IH2[ED2YA@2W=<2U;82S742Q302Q102Nll2Ljh2Jfd2Hb`2
H``2F//2DZX2BVT4BTT2H``2Nll2Q302U9800iccYABU500:YC@4YA@4W?<4W=<:U;82U982S542Q102
Nll4Ljh00g__Q324<002S546Q102S542Q304Nnl2Nll2Nnl2Q102U982W?<4YA@2YC@4YA@2W=<2S742
Q102Nnl00g_?Jfe[K@02F^/2BVT2>NL4<JH2:FD28B@68@@68B@2:DD2<HH2BTT2<JH2<HH4<JH2>LL2
>NL00d88H`aS3002Hb`2BVT2DXX2Lhh2Ljh2H``2Jdd2Nnl2W=<2Nnl2Q102S742U;82W?<2YC@2]KH2
aQP4_ML2[GD2]IH2_ML00lHHaSS6>002cWT2ic`4ool10001ool000Soo`03003ooooo00;oo`04003o
oooo0004ool20003ool2ia`2g]/2eYX2cUT00lHH_MNme`02]IH2[ED2YA@2W=<2U;82S742Q302Q102
Nll2Ljh2Jfd2Hb`2H``2F//2DZX2BVT4BTT2H``2Nll2Q302U9800iccYABU500:YC@4YA@4W?<4W=<:
U;82U982S542Q102Nll4Ljh00g__Q324<002S546Q102S542Q304Nnl2Nll2Nnl2Q102U982W?<4YA@2
YC@4YA@2W=<2S742Q102Nnl00g_?Jfe[K@02F^/2BVT2>NL4<JH2:FD28B@68@@68B@2:DD2<HH2BTT2
<JH2<HH4<JH2>LL2>NL00d88H`aS3002Hb`2BVT2DXX2Lhh2Ljh2H``2Jdd2Nnl2W=<2Nnl2Q102S742
U;82W?<2YC@2]KH2aQP4_ML2[GD2]IH2_ML00lHHaSS6>002cWT2ic`3ool20001ool000Woo`05003o
ooooool00002ool00`00ooooo`02ool00`00ooooo`02ool2g_/2e[X2cWT2aSP00kgg]KJe]P02[GD2
YC@2W?<2U;82U982S542Q102Nnl2Ljh2Lhh2Jdd2H``2F^/2DZX2DXX2BVT2@RP2@PP2DXX2Jdd2Nll2
Q3000iBBW=>Ld`04W?<8YA@8W?<4W=<6U;82U982S742Q302Nnl4Nll2Nnl00h@`S56<D@02Q304Q102
Q302S542Q102Nnl6Nll2Q302U982W=<2W?<6YA@2W?<2U;82Q302Nnl2Nll00f]]F^]Jj`02BVT2>NL4
<JH2:FD68@@26><68@@48B@2:FD2BTT2<JH4:FD2<JH2@PP2>LL00cWWDXYBRP02Jdd2BTT2BVT2Jfd2
Ljh2H``2Hb`2Nll2U982Ljh2Q102YA@2[ED2[GD2]IH2_ML2aQP4_OL2[ED2[GD2]KH00kggaQS66002
cUT2g]/4ool10001ool000[oo`04003ooooo0002ool00`00ooooo`02ool00`00ooooo`02ool2g_/2
e[X2cWT2aSP00kgg]KJe]P02[GD2YC@2W?<2U;82U982S542Q102Nnl2Ljh2Lhh2Jdd2H``2F^/2DZX2
DXX2BVT2@RP2@PP2DXX2Jdd2Nll2Q3000iBBW=>Ld`04W?<8YA@8W?<4W=<6U;82U982S742Q302Nnl4
Nll2Nnl00h@`S56<D@02Q304Q102Q302S542Q102Nnl6Nll2Q302U982W=<2W?<6YA@2W?<2U;82Q302
Nnl2Nll00f]]F^]Jj`02BVT2>NL4<JH2:FD68@@26><68@@48B@2:FD2BTT2<JH4:FD2<JH2@PP2>LL0
0cWWDXYBRP02Jdd2BTT2BVT2Jfd2Ljh2H``2Hb`2Nll2U982Ljh2Q102YA@2[ED2[GD2]IH2_ML2aQP4
_OL2[ED2[GD2]KH00kggaQS66002cUT2g]/4ool10001ool000Ooo`04003ooooo0002ool01000oooo
o`001?oo00<00?ooool00_oo0]kK0]JJ0/iI0/HH00>mekFF]IH00ZeE0ZDD0YcC0YBB0Xaa0X@`0W__
0W_?0W>>0V]]0V</0V<<0U[;0U::0TYY0TY90T8X0T880SWW0U:Z0V]=0W_?00>4<8aaS7400YBb19cC
39cc19cC19Bb0YBB0Xaa0XaA0X@`17__0X@@0X@`0haA0X@`1X@@0XaA0X@`0W__0W_?17>^0W_?0X@`
0YBB0YcC29cc0YcC0XaA0X@@0W_?0V]]00=JjdYYBVT00SWW136V0RUU0R4431SS1R440RU50T8X0S66
0RU50RUU0T8X0U::0cW70TY90V</14Y90U[;0W>^17_?0X@`0W_?0W>>0W>^0YBB0ZDd19BB0ZeE0[gG
1:DD0ZDd0ZeE0[FF00>melHHaQP00/Hh0]JJ1?oo0@000Ooo0008ool20004ool20005ool00`00oooo
o`02ool2g]/2eYX2cUT2aQP00kgG]IJeUP02[ED2YA@2W=<2U982S742Q302Nnl2Nll2Lhh2Jfd2Hb`2
H``2F//2DXX2BVT2BTT2@RP2@PP2>NL2DZX2Jdd2Nll00h@`S76<L@02U;84W=<<W?<4W=<4U;82U982
S742S542Q304Nnl2Q102Q303S542Q306Q102S542Q302Nnl2Nll4Ljh2Nll2Q302U982W=<8W?<2W=<2
S542Q102Nll2Jfd00e[[BVU:J@02>NL4<JH2:FD28@@<6><68@@2:DD2@RP2<HH2:DD2:FD2@RP2DXX3
>LL2BTT2Hb`4BTT2F//2Ljh4Nll2Q302Nll2Lhh2Ljh2U982YC@4U982[ED2_ML4YA@2YC@2[ED2]IH0
0kgGaQS66002aSP2eYX4ool10001ool001Goo`03003ooooo00;oo`;F^P;>N@;6>0:mm`03]KJ]MJee
00:U=0:Ll`:D/P:DTP:<D@:4409kk`9c[P9cSP9[C@9S;09Jj`9Jb`9BRP9:J@92:092208ii`8ia`92
209BZP9[C@03Nln448@@00:<L@:DTPBD/PBLd`:Ll`JLd`BD/P:DTP:<L@:<D@:4<0B440:4<0:<D@B<
L@03S564<8@`00:4409kk`:4<0:<D@:4409kc`Ic[P9kk`:<D@:DTP:D/P:Ld`:Ll`BLd`:DTP:4<09k
c`9[K@9Jj`03BVU2248800@aYP8YI@8Q108Hh``H``HHh`8Q9092208YI@8Q908YI@9:B@8aYP8aQP03
<JI2:48X009S30A2:09:J@9[C@Akc`:4<0A[K@9cSP9kc`:DTP:U50:DTP:U50:e]P:Ld`:Ll`:U50:]
E@:]M@03]KJmmkgg00;660;>F@Coo`40007oo`005Ooo00<00?ooool00_oo0]Jj0/ii0/Hh0[gg00>e
]Zee[GD00ZDd0Ycc0YBb0YBB0XaA0X@@0W__0W>^0W>>0V]=0V</0U[[0U[;0U::0TYY0T8X0T880SWW
0SW70T880U:Z0V]=00=kch@@Q1000Xaa0YBB19Bb19cC0Ycc1YcC19Bb0YBB0Xaa0XaA0X@`18@@0X@`
0XaA18aa00><DH@`Q3000X@@0W__0X@`0XaA0X@@0W_?1W>^0W__0XaA0YBB0YBb0YcC0Ycc19cC0YBB
0X@`0W_?0V]]0U[[00=:JD88@PP0136V0RUU0R440QSS31S31QSS0R4T0T880RUU0R4T0RUU0TY90S6V
0S6600<aYT8X@RP00V<<148X0TYY0V]=17_?0X@`16]]0W>>0W_?0YBB0ZDD0YBB0ZDD0[Ff0YcC0Ycc
0ZDD0ZeE0Zee00>e][gg_OL00/HH0/iI1?oo0@000Ooo000Eool00`00ooooo`02ool2eYX2cUT2aQP2
_ML00kFF[EF]E@02YA@2W=<2U982S742Q302Nnl2Nll2Lhh2Jfd2Hb`2H``2F//2DZX2BVT2BTT2@RP2
>NL2>LL4<JH2@PP2DZX00f]=Ljic[P02Q102S542S742U982U;88W=<6U;82U982S746S546S744S540
0h@`Q1244002Nnl2Q102S542Q302Nnl2Nll4Ljh2Nll2Q102S542U986U;82W=<2U982S542Nnl2Lhh2
H``2DXX00d88>LLia`02<JH2:FD46><66<<64:866<<26><28@@2>NL2:FD28@@2:DD2BTT2<HH2:FD0
0c6VBVU:J@02F//4@PP2BTT2Jfd2H``2F^/2Nnl2Ljh2Jdd2Jfd2Lhh2Nll2U;84YC@2]IH2U;82W=<2
W?<2YC@2[GD00kFF_MNme`02aQP2aSP4ool10001ool001Goo`03003ooooo00;oo`;FVP;>F@;660:m
e`03]IJ]EJeE00:U50:Ld`:DTP:<L@:4<09kk`9kc`9cSP9[K@9S;09S309Jb`9BZP9:J@9:B@92:08i
i`8ia`@aYP92209BZP03Jdec[W>^00:440:<D@:<L@:DTP:D/PRLd`JD/P:DTP:<L@J<D@J<L@B<D@03
Q32448@@009kk`:440:<D@:4<09kk`9kc`Ac[P9kc`:440:<D@:DTPJD/P:Ld`:DTP:<D@9kk`9cSP9S
309BRP03@PPiacW7008aYP8YI@@Hh`HH``H@XPHH``8Hh`8Q108ii`8YI@8Q108YA@9:B@8aQP8YI@03
<JI:JDYY009Jb`A2209:B@9[K@9S309Jj`9kk`9c[P9[C@9[K@9cSP9kc`:D/PBU=0:eUP:D/P:Ld`:L
l`:U=0:]M@03]IJmekgG00;660;6>0Coo`40007oo`005Ooo00<00?ooool00_oo0/ii0/iI0[gg0[Ff
00>]MJDdYC@00Ycc0YBb0Xaa0XaA0X@@0W_?0W>^0V]]0V]=0V</0U[[0U[;0U::0TYY0T8X0T880SWW
0SW713660RUU0T8800=BZV</Hb`00W>^0W__0X@`0XaA19BB39Bb29BB1Xaa0XaA0X@`0h@@17__18@`
0X@@0W__0W_?17>^0W_?0X@@0XaA0Xaa19BB0YBb0YBB0Xaa0X@@0W>^0V]=0U[;0TY900<iac6V<JH0
0RUU0QSS11S3212R0Q221Q2R11S30QSS0SW70RU512440T880T8X0SW700=225:ZDZX00T8X0SW70SWW
0T8X16]=0V</0W__0V]]0V</0V]=0W>>0W>^0W__0YcC0Zee0[FF0YBb0YcC0Ycc0ZDD0ZeE00>]MKgG
_ML00[gg0/Hh1?oo0@000Ooo000Eool20003ool2cWT2cUT2_OL2]KH00jeeYCBU=002W?<2U;82S742
S542Q102Nll2Ljh2Jfd2Jdd2Hb`2F^/2F//2DXX2BVT2@RP2@PP2>NL2>LL4<HH2:FD2@PP00e:ZHbaS
;002Ljh2Nnl2Q302S544U98<U;88U986S742S542Q303Q104Nnl4Q302Q102Nnl2Nll4Ljh2Nll2Q102
S542S744U982U;82U982S742Q102Ljh2Jdd2F//2BTT00cW7<JHaYP02:FD26><46<<84:8248864:84
6<<26><2>LL2:DD48@@2@PP2@RP2>LL00d88DZYBZP02@RP2>LL2>NL2@RP4Jdd2Hb`2Nnl2Jfd2Hb`2
Jdd2Lhh2Ljh2Nnl2W=<2[GD2]IH2U;82W=<2W?<2YA@2[ED00jee_MNme`02_OL2aSP3ool20001ool0
01Goo`03003ooooo00;oo`;>N@;6>0:mm`:e]P03[GFU=:Dd00:Ll`:D/P:<L@:4<0:4409kc`9c[P9[
K@9[C@9S309Jj`9BZP9BRP9:B@92:092208ii`8aYP8aQP8YI@@YA@03>LMBRU::009S309cSP9kc`:4
40:4<0B<LA2DTPB<L@B<D@:4<0:440Ekk`:440:<D@:4<0:440Akc`Ac[P9kc`:440:<D@:<L@:<D@:<
L@:DTPB<L@:4<09cSP9S309BRP8ii`03<JHaQS66008Hh`@H``H@XP`@PP@@XP8H``@YI@@Hh`8Q108i
a`92:003BTU22488008aQP8aYP8ia`8ii`9:B@9S309[K@9cSPAJj`9S;09[C@9cSP9c[P:440:Ld`:]
E@:Ld`:D/P:Ld`:Ll`:U=003[EFeU[FF00:me`;660Coo`40007oo`005Ooo00<00?ooool00_oo0/ii
0/Hh0[gg0[Ff00>]MJDdYC@00Ycc0YBb0Xaa0X@`0X@@0W_?0W>^0V]]0V]=0V<<0U[[0U:Z0U::0TY9
0T8X0T880SWW0S6V0S660RUU12U500<iae::DXX00V<<0W>>0W_?0X@@0X@`18aa49BB18aa18aA0X@`
0X@@1G__0X@@0XaA0X@`0X@@17_?17>^0W_?0X@@0XaA0Xaa0XaA0Xaa0YBB18aa0X@`0W>>0V<<0U::
0SWW00<aYS66<HH00QSS11S31Q2R3122112R0QS312UU11SS0R440SW70T8X00=:BD88@PP00S660S6V
0SW70SWW0TY90V<<0V]]0W>>15[[0V</0V]=0W>>0W>^0X@@0YcC0ZeE0YcC0YBb0YcC0Ycc0ZDd00>]
EKFF]IH00[gG0/HH1?oo0@000Ooo000Eool00`00ooooo`02ool2cUT2aQP2_ML2[GD00jDdW?>Ll`02
U;82U982S542Q102Nll2Ljh2Lhh2Jdd2Hb`2F^/2F//2DXX2BVT2BTT2@PP2>NL2>LL2<JH2<HH2:FD4
8B@00bU5@PQ22002DZX2Hb`2Lhh2Nll2Nnl2Q302S546S744U986S744S542Q302Q102Nnl5Nll2Q102
S542Q302Q104Nll4Ljh2Nll2Nnl2Q306S542U984U;82S742Q102Hb`2DZX2@PP2<HH00bUU8B@Q9002
6<<64:864888264648824:826<<24:826<<46><28@@28B@00bU5:FDYI@02:FD2<HH2<JH2>LL2@PP2
@RP2BVT2DXX2DZX2F^/2H``2Jdd2Lhh2Ljh2Nnl2Q302S542S742U982U;82W?<2YA@00jeE]IJeUP02
]KH2_OL4ool10001ool001Goo`03003ooooo00;oo`;>F@;660:me`:]M@03YCBLlicc00:D/P:DTP:<
D@:4409kc`9c[P9cSP9[C@9S;09Jj`9Jb`9BRP9:J@9:B@92208ii`8ia`8aYP8aQP8YI@@Q9003:DE2
2488009BZP9S;09cSP9kc`9kk`:4<0:<D@J<L@BDTPJ<L@B<D@:4<0:4409kk`Ekc`:440:<D@:4<0:4
40Akc`Ac[P9kc`9kk`:4<0J<D@:DTPBD/P:<L@:4409S;09BZP92208aQP03:FDQ924T008H``H@XPH@
PPP8H@H@PP8@XP8H``8@XP8H``@Hh`8Q108Q9003:DDYIBUU008YI@8aQP8aYP8ia`922092:09:J@9B
RP9BZP9Jj`9S309[C@9cSP9c[P9kk`:4<0:<D@:<L@:DTP:D/P:Ll`:U5003[EFeU[FF00:e]P:mm`Co
o`40007oo`005Ooo00<00?ooool00_oo0/Hh0[gg0[Ff0Zee00>U=9ccW?<00YBb0Xaa0X@`0W__0W_?
0W>>0V]]0V</0V<<0U[[0U:Z0U::0TY90T8X0T880SWW0S6V0S660RUU0RU50R4T0R4400<HhbU5:DD0
0T8X0U:Z0V<<0V]]0W>^0W__0X@@18@`38aA18@`0X@@0W__1W_?00=kkh@`Q3000X@`0X@@17_?1W>^
0W_?0W__0X@@18@`0XaA1YBB0Xaa0X@`0V<<0U::0T8X0RU500<Hhb4T8B@00QS3112R11224PQQ1Q22
0Q2R11S30QSS0R4400<Q92U5:DD00RU50RUU0S6613W70T880T8X0TYY0U::0U[;0V<<0V</0V]]0W>>
0W_?0X@@0X@`0XaA0Xaa0YBb0YcC0Ycc00>U=:ee[GD00[Ff0[gG1?oo0@000Ooo000Eool00`00oooo
o`02ool2aSP2_OL2]KH2[GD00jDdW?>Ll`02U;82S742Q302Nnl2Nll2Lhh2Jfd2Hb`2H``2F^/2DZX2
DXX2BTT2@RP2@PP2>NL2<JH2<HH2:FD2:DD28B@28@@00aSS:DDYA@02@RP2DZX2H``2Jfd2Ljh2Nnl2
Q104Q30<S544Q302Q102Nnl6Nll00g__Q324<002Q302Q104Nll6Ljh2Nll2Nnl2Q104Q302S546U982
S742Q302H``2DXX2@RP2:DD00aSS8B@Q90026<<44:84488B264648824:846<<26><28@@00b4T:DDY
A@02:DD2:FD2<HH4>LL2@PP2@RP2BVT2DXX2F//2H``2Hb`2Jfd2Lhh2Nll2Q102Q302S542S742U;82
W=<2W?<00jDd[GF]M@02]KH2_ML4ool10001ool001Goo`03003ooooo00;oo`;6>0:me`:eUP:]E@03
YABLdicC00:DTP:<D@:4409kk`9c[P9[K@9[C@9S;09Jj`9Jb`9BZP9:J@9:B@92208ii`8ia`8aYP8a
QP8YI@8YA@8Q908Q10<Hh`8aQP9:B@9BZP9S309[C@9cSPAkc`9kk`:440Z4<0B4409kk`Ikc`9kk`>4
<0:4409kk`9kc`9c[P9cSPAc[P9kc`9kk`:440J4<0B<L@:4<0:<L@:4<09[K@9Jj`9BZP8ii`<Hh`8H
``H@PP@8H@`8@@P8H@@@PP8@XP@H``8Hh`038@@Q924T008YA@8YI@8aQP8aYP8ia`8ii`92209:B@9B
RP9BZP9Jj`9S309[C@9[K@9c[P9kk`:440:4<0:<L@:DTP:D/P:Ll`03YAB]EJeE00:eUP:me`Coo`40
007oo`005Ooo00<00?ooool00_oo0/Hh0[gG0[FF0ZeE00>U59cCW=<00YBB0XaA0X@@0W__0W>^0V]]
0V]=0V</0U[[0U[;0U:Z0TYY0TY90T880SWW0SW70S6V0S660RUU0RU50R4T0R440aSS0S660TY90U:Z
0V<<0V]=0W>>17_?0W__0X@@2X@`18@@0W__1W_?0W__0h@`0X@@0W__0W_?0W>^0W>>17>^0W_?0W__
0X@@1X@`18aa0X@`0Xaa0X@`0V]]0U[[0U:Z0SWW0aSS0QS31Q2210QQ30Q120QQ11220Q2R11S30QSS
00<Q124T8B@00RU50RUU0S660S6V0SW70SWW0T880TY90U::0U:Z0U[[0V<<0V]=0V]]0W>^0W__0X@@
0X@`0Xaa0YBB0YBb0Ycc00>U5:eE[ED00[FF0[gG1?oo0@000Ooo000Eool00`00ooooo`02ool2aQP2
_ML2[GD2YC@00iccU;:D/P02S742S542Q102Nll2Lhh2Jfd2Hb`2H``2F^/2DZX2DXX2BTT2@RP2@PP2
>NL2>LL2<JH2<HH2:FD2:DD48@@00aSS6<<H``026><2>LL2BTT2DZX2H``2Jdd2Lhh4Ljh2Nll4Nnl6
Q106Nnl4Nll2Q103Q302Q102Nnl2Nll2Ljh6Lhh2Ljh2Nll2Nnl8Q102S542S742S542S742Nnl2Jfd2
H``2F//2@PP00b4T6><Hh`028@@24:82488426462442020<2444264448824:846<<00aSS8@@Q1002
8B@2:DD2:FD2<HH2<JH2>LL2@PP2@RP2BVT2DXX2F//2H``2Hb`2Jfd2Lhh2Nll2Nnl2Q302S542S742
U;82W=<00jDDYCBU=002[GD2]KH4ool10001ool001Goo`8000?oo`;660:me`:]M@:U=003W?>D/YBb
00:<L@:<D@:4409kc`9cSP9[K@9S;09S309Jj`9BZP9BRP9:B@92:092208ii`8ia`8aYP8aQP8YI@8Y
A@@Q10036><H`aS3008Hh`8ia`9:B@9BZP9S309[C@9cSPAc[P9kc`Akk`J440Ikk`Akc`:440>4<0:4
409kk`9kc`9c[PIcSP9c[P9kc`9kk`R440:<D@:<L@:<D@:<L@9kk`9[K@9S309Jb`9220038B@HhaSS
008Q108@XP8@PP@8H@H8@@8080`8@@@8H@@@PP8@XP@H``036><Q1244008Q908YA@8YI@8aQP8aYP8i
a`922092:09:J@9BRP9Jb`9S309S;09[K@9cSP9kc`9kk`:4<0:<D@:<L@:D/P:Ld`03YABU=:Dd00:]
M@:e]P?oo`80007oo`005Ooo00<00?ooool00_oo0/HH0[Ff0Zee0ZDd00>LliBbU;800Xaa0X@`0X@@
0W_?0W>>0V]]0V</0V<<0U[;0U:Z0TYY0TY90T8X0T880SWW0SW70S6V12UU0R4T0R440QSS00<H`a2R
4:800Q2R0R440SW70TY90U:Z0U[[0V</0V]]17>>0W>^17_?17__27_?0W__18@`00>447__Nnl00W_?
0W>^27>>0W>^0W_?17__28@@0X@`0XaA0Xaa0W__0V]=0V<<0U[;0TY900<YAASS6><00QSS112210QQ
10Q13P0P10Q11PQQ0Q220Q2R0QS300<Hhb448@@00R440R4T0RU50RUU0S660S6V0SWW0T880TY90TYY
0U:Z0U[;0V<<0V]=0V]]0W>^0W_?0X@@0X@`0XaA0YBB0YBb00>LljDDYA@00ZeE0[FF1?oo0@000Ooo
000Eool00`00ooooo`02ool2aQP2]KH2[GD2YC@00iccU;:D/P02S742Q302Q102Nll2Lhh2Jfd2Hb`2
H``2F//2DZX2BVT2BTT2@RP2@PP2>NL2>LL2<JH4:FD28B@28@@26><00aS34:8@XP024:828@@2>LL2
BTT2DZX2F^/2Hb`2Jfd4Lhh2Ljh4Nll4Nnl8Nll2Nnl4Q3000h@@Nnmkk`02Nll2Ljh8Lhh2Ljh2Nll4
Nnl8Q102Q302S542S742Nnl2Jdd2H``2F//2BTT00bU56><Hh`026><448842644244>020424462642
48824:826<<00aSS8@@Q10028@@28B@2:DD2:FD2<HH2<JH2>NL2@PP2BTT2BVT2DZX2F//2H``2Jdd2
Jfd2Ljh2Nll2Q102Q302S542U982U;800iccYABU5002[ED2]IH4ool10001ool001Goo`03003ooooo
00;oo`:me`:eUP:]E@:U5003W=>DTYBB00:<D@:4409kc`9c[P9[K@9[C@9S309Jj`9BZP9BRP9:J@9:
B@92208ii`8ia`8aYP8aQP8YI@8YA@8Q908Q108Hh`036<<@XQ2R008@XP8H``8aQP92:09BRP9Jb`9S
309S;0A[K@9cSPIc[PQkc`9kk`B4<0:44003Nnmkcg_?009c[PAcSP9[K@AcSP9c[P9kc`Akk`:4409k
k`Ikc`:<D@:4<09c[P9S309Jb`9BRP8ia`<Hh`@@PP@8H@88@AH08088@@@8H@@@PP8@XP036<<HhaSS
008Q108Q908YA@8YI@8aQP8aYP8ii`922092:09:J@9BRP9Jb`9S309S;09[K@9cSP9kc`9kk`:4<0:<
D@:DTP:D/P03W?>U5:DD00:]E@:eUPCoo`40007oo`005Ooo00<00?ooool00_oo0[gG0[FF0ZeE0ZDD
00>LdiBBU9800XaA0X@@0W_?0W>^0V]]0V]=0V<<0U[;0U:Z0U::0TY90T8X0T880SWW0SW70S6V0S66
0RUU0RU50R4T0R440QSS00<H`a2R4:800Q2R0Q220QSS0S6V0T8X0U::0U[;0V<<0V</0V]=0V]]17>>
17>^17_?0W__1X@@0W__00=kcg>^Ljh017>>16]]17>>0W>^0W_?1W__0W_?17>^1W_?0V]=0U[;0U::
0T8X0RU50aSS0Q2210QQ10Q11P0P30001P0P10Q10PQQ0Q220a2R0QS30QSS0R440R4T0RU50RUU0S66
0SW70SWW0T880TY90TYY0U:Z0U[;0V<<0V</0V]]0W>^0W_?0X@@0X@`0Xaa0YBB00>LdiccW?<00ZDd
0ZeE1?oo0@000Ooo000Eool00`00ooooo`02ool2_ML2]IH2[ED2YA@00icCU9:DTP02S542Q102Nll2
Ljh2Jfd2Jdd2H``2F//2DZX2DXX2BTT2@RP2@PP2>NL2>LL2<JH2<HH2:FD2:DD28B@28@@26><00aS3
4:8@XP024:8248826><2<JH2@RP2DXX2F//2H``2Hb`2Jdd2Jfd4Lhh4Ljh4Nll2Nnl6Q102Nnl00g_?
Ljic[P04Lhh4Jfd4Lhh2Ljh2Nll6Nnl2Nll4Ljh6Nll2Jdd2F//2DXX2@RP2:DD36><2488426442446
020<000602042442264248834:826<<26><28@@28B@2:DD2:FD2<HH2>LL2>NL2@PP2BTT2BVT2DZX2
F//2H``2Hb`2Jfd2Ljh2Nll2Q102Q302S742U9800icCW?>Ll`02YC@2[ED4ool10001ool001Goo`03
003ooooo00;oo`:me`:]M@:U=0:Ll`03U;:<LHaa00:4<09kk`9kc`9cSP9[C@9S;09Jj`9Jb`9BZP9:
J@9:B@92:092208ii`8aYP8aQP8YI@8YA@8Q90@Q108Hh`036<<@XQ2R00@@PP8@XP8YI@8ii`9:J@9B
ZP9Jj`9S;09[C@9[K@AcSPAc[P9kc`9kk`B4409kk`Akc`03LjicSW>>009cSPI[K@9cSPAc[PAkc`9k
k`9c[PA[K@IcSP9[K@9S309:J@8ia`8Q90L@PP@8H@@8@@8081@000@08088@@@8H@8@PP034:8H`aS3
008Hh`@Q108YA@8YI@8aQP8aYP8ia`922092:09:J@9BRP9Jb`9Jj`9S;09[K@9cSP9kc`9kk`:4<0:<
D@:<L@03U;:Llicc00:U50:]E@Coo`40007oo`005Ooo00<00?ooool00_oo0[gG0Zee0ZDd0Ycc00>D
/XaaS7400X@`0W__0W_?0W>>0V]=0V</0U[[0U[;0U:Z0TYY0TY90T8X0T880SWW0S6V0S660RUU0RU5
0R4T12440QSS00<H`a2R4:8011220Q2R0RUU0SWW0TYY0U:Z0U[[0V</0V]=0V]]17>>17>^0W_?0W__
18@@0W__17_?00=c[W>>Lhh00W>>1V]]0W>>17>^17_?0W__0W>^16]]1W>>0V]]0V<<0TYY0SW70R4T
1a2210QQ10Q10P0P5000100P0PQ110QQ0Q2200<@XQS36<<00QSS12440RU50RUU0S660S6V0SW70T88
0T8X0TYY0U::0U[;0U[[0V</0V]]0W>>0W_?0W__0X@`0XaA0Xaa00>D/YccW?<00ZDD0ZeE1?oo0@00
0Ooo000Eool00`00ooooo`02ool2]KH2[GD2YC@2W?<00iBBS76<L@02Q302Nnl2Ljh2Jfd2Jdd2H``2
F^/2DZX2DXX2BVT2@RP2@PP2>NL2>LL2<JH2<HH2:FD2:DD28B@28@@46><00aS34:8@XP0648826><2
<JH2@RP2DXX2F//2H``2Jdd2Jfd4Lhh2Ljh2Nll8Nnl2Nll4Ljh00g>>Jfe[K@02Lhh4Jfd2Lhh4Ljh6
Nll2Ljh<Jfd2Jdd2H``2@RP2:FD24:85488626422444020D000602022442264348824:826<<26><2
8@@28B@2:DD2:FD2<HH2>LL2>NL2@PP2BTT2BVT2DZX2F^/2H``2Jdd2Lhh2Ljh2Nnl2Q102Q302S740
0iBbW=>Ld`02YA@2YC@4ool10001ool001Goo`03003ooooo00;oo`:e]P:]M@:U=0:Ll`03U9:<LHaa
00:4<09kk`9c[P9[K@9[C@9S309Jj`9BZP9BRP9:J@92:092208ii`8ia`8aYP8aQP8YI@8YA@8Q908Q
10@Hh`036<<@XQ2R00H@PP8Hh`8aYP92:09BRP9Jb`9S309[C@9[K@AcSP9c[P9kc`Qkk`9kc`Ac[P03
Lhi[KF]]009cSPA[K@9cSPAc[PIkc`9c[Pa[K@9[C@9S3092:08YI@8@XPD@PPH8H@88@@@081@000H0
8088@@88H@<@PP8@XP8H``8Hh`8Q108Q908YA@8YI@8aQP8ia`8ii`92209:B@9:J@9BZP9Jj`9S309[
C@9cSP9c[P9kk`:440:4<0:<L@03U;:LdicC00:U50:U=0Coo`40007oo`005Ooo0P000ooo0[FF0ZeE
0ZDD0YBb00><LHaAS5400X@@0W_?0W>>0V]=0V</0U[[0U[;0U::0TYY0TY90T8X0T880SW70S6V0S66
12UU0R4T12440QSS0QS300<@XQ2248800Q2210QQ0QS30S660T880TYY0U[;0V<<0V]=0V]]0W>>0W>^
0W_?1W__17_?0W>^17>>1f]]17>>0W>^1W_?0W>>2V]]16]=0U[[0TY90S660Q2R2`QQ0PQ11P0P6000
0P0P10Q10PQQ00<@PQ2R4:800Q2R0QS30R440R4T0RU50RUU0S660SW70SWW0T880TY90TYY0U:Z0U[;
0V<<0V]=0V]]0W>^0W_?0X@@0X@`0Xaa00>DTYcCW=<00Ycc0ZDd0ooo0P000Ooo000Eool00`00oooo
o`02ool2]IH2[ED2YA@2U;800haaS56<D@02Q102Nll2Lhh2Jdd2Hb`2F^/2F//2DXX2BVT2BTT2@RP2
@PP2>LL2<JH2<HH4:FD28B@48@@26><26<<00a2R488@PP02488426426<<2<HH2@PP2BVT2F//2H``2
Jdd2Jfd2Lhh2Ljh2Nll6Nnl4Nll2Ljh4Lhh7Jfd4Lhh2Ljh6Nll2Lhh:Jfd4Jdd2F^/2BTT2<HH24:8;
26422446020H00020204244226400a224:8@XP024:826<<28@@28B@2:DD2:FD2<HH2>LL2>NL2@PP2
BTT2BVT2DZX2F//2H``2Jdd2Jfd2Ljh2Nll2Q102Q302S7400iBBW=>Ld`02W?<2YC@4ool10001ool0
01Goo`03003ooooo00;oo`:]M@:U=0:Ll`:D/P03S764<8@`009kk`9c[P9[K@9[C@9S309Jj`9BZP9B
RP9:B@92:092208ii`8ia`8aYP8aQP8YI@8YA@8Q90@Q10@H``034:8@PQ22008@PP88H@88@@88H@8Q
108ia`9:B@9BZP9Jj`9S;09[K@9cSPAkc`9kk`Ikc`9c[PAcSPE[K@IcSPAc[P9kc`9c[P9cSP9[K@Y[
C@9S;09Jj`9:J@8ii`8Q10@8H@88@@<8H@H8@@@081X000@08088@@<8H@8@PP8@XP8H``8Hh`8Q108Q
908YA@8aQP8aYP8ia`922092:09:J@9BRP9Jb`9S309S;09[K@9cSP9kc`9kk`:4<0:<D@03U9:D/YBb
00:Ll`:U50Coo`40007oo`005Ooo00<00?ooool00_oo0Zee0ZDd0Ycc0YBb00><LH@`Q3000W__0W>^
0V]]0V]=0V<<0U[[0U:Z0U::0TY90T8X0T880SWW0SW70S6V0S660RUU0RU50R4T124411S300<@XQ22
48800Q220PQQ0PQ10PQQ0R440SW70TY90U:Z0U[[0V</0V]]0W>>17_?0W__1W_?0W>^17>>1F]]1W>>
17>^0W_?0W>^0W>>0V]]2V]=0V</0U[[0TYY0SWW0R4410QQ0PQ10`QQ1PQ1100P6P00100P0PQ10`QQ
0Q220Q2R0QS30QSS0R440R4T0RU50S660S6V0SW70T880T8X0TYY0U::0U[;0V<<0V</0V]]0W>>0W_?
0W__0X@`0XaA00>DTYBbU;800Ycc0ZDD1?oo0@000Ooo000Eool00`00ooooo`02ool2[GD2YA@2W=<2
U9800haAQ1244002Nnl2Ljh2Jfd2Hb`2H``2F//2DZX2BVT2BTT2@RP2@PP2>NL2>LL2<JH2<HH2:FD2
:DD28B@28@@26><46<<00a2R488@PP024884264224422642:DD2>NL2BVT2F//2Hb`2Jfd2Lhh2Ljh4
Nll4Ljh4Lhh7Jfd6Lhh8Ljh2Lhh2Jfd8Jdd4Hb`2F^/2DXX2BTT2>NL2:DD24:892446020N00040202
2443264248824:826<<26><28@@2:DD2:FD2<HH2<JH2>NL2@PP2BTT2DXX2DZX2F^/2Hb`2Jdd2Lhh2
Ljh2Nnl2Q102S5400haaU;:D/P02W=<2YA@4ool10001ool001Goo`03003ooooo00;oo`:]M@:U50:L
d`:DTP03S56448@@009kk`9c[P9[K@9S;09S309Jb`9BZP9:J@9:B@92:092208ii`8ia`8aYP8aQP8Y
I@8YA@8Q908Q108Hh`@H``034:8@PQ22008@PP@8H@88@@88H@8YA@8ii`9:J@9Jb`9S;09[K@9cSP9c
[PAkc`Ac[PAcSPM[K@IcSPQc[P9cSP9[K@Q[C@AS;09Jj`9BRP9:B@8ii`8YA@8@XPT8@@H081h000@0
8088@@<8H@8@PP8@XP8H``8Hh`8Q108YA@8YI@8aQP8aYP8ii`92209:B@9BRP9BZP9Jj`9S;09[C@9c
SP9c[P9kk`:440:<D@03S76D/YBb00:Ld`:U50Coo`40007oo`005Ooo00<00?ooool00_oo0ZeE0ZDD
0YcC0Xaa00>4<8@@Q1000W_?0W>>0V]=0V</0U[[0U[;0U::0TYY0T8X0T8813WW136V0S6612U50R4T
0R440QSS0QS31A2R11220PQQ10Q10Q220RUU0T880U:Z0V<<0V]=0V]]0W>>1W>^17>>26]]1G>>27>^
0V]]2V]=0V</0V<<0U[;0U::0TYY0TY90T880S6V0R4T0Q2R0PQ11`0P90000P0P0`Q10PQQ0Q220Q2R
0QS30QSS0R440R4T0RU50S660S6V0SW70T880TY90TYY0U:Z0U[;0V<<0V]=0V]]0W>^0W_?0X@@0X@`
00><LIBBU9800YcC0ZDD1?oo0@000Ooo0009ool00`00ooooo`02ool20005ool00`00ooooo`02ool2
[ED2YA@2W=<2S7400h@`Q1244002Nll2Lhh2Jdd2Hb`2F^/2F//2DXX2BVT2@RP2@PP4>NL4<JH2<HH4
:DD28B@28@@26><26<<54:844882264424424882:FD2@PP2DZX2H``2Jdd2Jfd2Lhh6Ljh4Lhh8Jfd5
Lhh8Ljh2Jfd:Jdd2Hb`2H``2F//2DXX2BVT2BTT2@PP2<JH28B@24:822447020T0002020324422642
48824:826<<26><28@@28B@2:DD2<HH2<JH2>LL2@PP2BTT2BVT2DZX2F//2H``2Jdd2Jfd2Ljh2Nll2
Q102Q3000haaU9:DTP02W=<2YA@4ool10001ool000Woo`05003oooooool00002ool00`00ooooo`02
ool00`00ooooo`02ool2[ED2YA@2W=<2U9800h@`Q1244002Nll2Lhh2Jdd2H``2F^/2F//2DXX2BVT2
BTT2@PP4>NL4<JH2<HH2:FD2:DD28B@2:DD28@@46<<34:826><26<<2264624424882<HH2BTT2DZX2
H``2Jdd2Jfd:Lhh8Jfd5Lhh4Ljh2Lhh2Jfd:Jdd2Hb`2F^/2DZX4BVT4BTT2@PP2>LL2<HH28B@22443
020Z000202032442264248824:826<<26><28@@28B@2:FD2<HH2<JH2>NL2@PP2BTT2DXX2DZX2F^/2
Hb`2Jdd2Lhh2Ljh2Nnl2Q1000haAS76<L@02U;82W?<4ool10001ool000Koo`D000;oo`04003ooooo
0004ool20003ool2[ED2YA@2W=<2U9800h@`Q1244002Nll2Lhh2Jdd2H``2F^/2F//2DXX2BVT2BTT2
@PP4>NL4<JH2<HH2:FD2:DD28B@2:DD28@@46<<34:826><26<<2264624424882<HH2BTT2DZX2H``2
Jdd2Jfd:Lhh8Jfd5Lhh4Ljh2Lhh2Jfd:Jdd2Hb`2F^/2DZX4BVT4BTT2@PP2>LL2<HH28B@22443020Z
000202032442264248824:826<<26><28@@28B@2:FD2<HH2<JH2>NL2@PP2BTT2DXX2DZX2F^/2Hb`2
Jdd2Lhh2Ljh2Nnl2Q1000haAS76<L@02U;82W?<3ool20001ool000Koo`04003ooooo0003ool01000
ooooo`001?oo00<00?ooool00_oo0ZDd0ZDD0Ycc0Xaa00><DIBBU9800XaA0W__0V]=15[[16]=0V<<
0TY90T880U::0T880S6V0T880SWW0RU5124T0SWW0RU50QS30a2R0QS30RUU0QSS0Q2210Q10P0P0PQ1
0R440SW70TYY0U[;0V<<0V</0V]=36]]1G>>17>^0W>>0V]]36]=0V<<0U:Z0TYY0TY90TYY14Y90T8X
0T880SW70S6V0R4T0PQQ00<080000000:P000`0P0PQ10PQQ0Q22112R0QSS0R440R4T0RUU0S660S6V
0SWW0T880TY90TYY0U:Z0U[;0V<<0V]=0V]]0W>^0W_?0X@@00>4<8aaS7400YBb0Ycc1?oo0@000Ooo
0007ool00`00ool00003ool01000ooooo`001?oo00<00?ooool00_oo0ZDd0ZDD0Ycc0Xaa00><DIBB
U9800XaA0W__0V]=15[[16]=0V<<0TY90T880U::0T880S6V0T880SWW0RU5124T0SWW0RU50QS30a2R
0QS30RUU0QSS0Q2210Q10P0P0PQ10R440SW70TYY0U[;0V<<0V</0V]=36]]1G>>17>^0W>>0V]]36]=
0V<<0U:Z0TYY0TY90TYY14Y90T8X0T880SW70S6V0R4T0PQQ00<080000000:P000`0P0PQ10PQQ0Q22
112R0QSS0R440R4T0RUU0S660S6V0SWW0T880TY90TYY0U:Z0U[;0V<<0V]=0V]]0W>^0W_?0X@@00>4
<8aaS7400YBb0Ycc1?oo0@000Ooo0008ool20003ool01000ooooo`001?oo00<00?ooool00_oo0Zee
0ZDD0[FF0YBB00>4<9ccW?<00X@`0W_?0W__0V<<0U[;0V]]0U[;0TYY0T8X0SWW0TYY0TY90S6V0T8X
0SWW0RU5124T0SW70S6V0QSS1A2R0R4T0RU50Q220PQQ0PQ11P0P0R440SW70TYY0U:Z0U[[0V<<0V</
0V]=2V]]0g>>0W>^0W>>3V]=0V</0U[;0TYY14Y914YY14Y90T8X0T880SW70RUU0QSS00<8H@0P0200
100P:0000`0P0PQ10PQQ0Q220Q2R0QS30QSS0R440R4T0RUU0S660SW70SWW0T8X0TY90U::0U[;0U[[
0V</0V]=0W>>0W_?0W__00>4<8aAS5400YBB0YcC1?oo0@000Ooo0009ool00`00ooooo`02ool20005
ool00`00ooooo`02ool2[GD2YA@2]IH2U9800h@`W?>Ll`02Q302Nll2Nnl2H``2F//2Jfd2F//2BVT2
@RP2>NL2BVT2BTT2<JH2@RP2>NL2:DD48B@2>LL2<JH26><54:828B@2:DD248822642244602028@@2
>LL2BVT2DZX2F^/2H``2Hb`2Jdd:Jfd3Lhh2Ljh2Lhh>Jdd2Hb`2F//2BVT4BTT4BVT4BTT2@RP2@PP2
>LL2:FD26><00`QQ02008004020X000302022442264248824:826<<26><28@@28B@2:FD2<HH2>LL2
>NL2@RP2BTT2DXX2F//2F^/2Hb`2Jdd2Lhh2Nll2Nnl00h@`S56<D@02U982W=<4ool10001ool001Go
o`03003ooooo00;oo`:U=0:Ll`:eUP:DTP03Q12LdicC009kk`9kc`:4409Jj`9BZP9[C@9Jj`9:J@92
208ii`9:J@9BRP9:B@9:J@8aQPHQ908ia`8aQP8H``<@XP8H``8Q908YA@8@PP88H@88@@H08088@@8Y
A@92209:J@9Jb`9Jj`AS;09[C@I[K@EcSP9[K@Q[C@9[K@A[C@9S309Jb`9BRQ1:J@92:08ia`8aQP8Q
90038@@HhaSS00PH``8@XP88@@8081l0008080@8@@88H@8@PP8@XP8H``8Q108Q908YA@8YI@8aYP8i
i`92209:B@9:J@9BZP9Jj`9S309[C@9cSP9c[P9kk`03Q12<DHaA00:<L@:D/PCoo`40007oo`005Ooo
00<00?ooool00_oo0ZDd0Ycc0[FF0YBB00>449cCW=<00W__0W_?0X@@0U[[0U:Z0V]=0U[[0TYY0T88
0SWW0TYY0U::0TY90TYY0S661R4T0SW70S660QS30a2R0QS30R4T0RU50Q220PQQ0PQ11P0P0PQ10RU5
0T880TYY0U[;0U[[16</0V]=1V]]1G>>0V]]26]=0V]]16]=0V<<0U[;0U::44YY0T8X0SW70S660R4T
00<Q11SS6><021S30Q2R0PQ10P0P7`000P0P10Q10PQQ0Q220Q2R0QS30R440R4T0RU50RUU0S6V0SWW
0T880TY90TYY0U:Z0U[[0V<<0V]=0W>>0W>^0W__00>448aAS5400Xaa0YBb1?oo0@000Ooo000Eool0
0`00ooooo`02ool4YA@2[GD2S5400h@`W=>Ld`02S742S542Jfd4DZX2Jfd2Jdd2DZX2>NL2>LL2DZX2
DXX4BVT2:FD28B@28@@28B@2>NL2:DD26<<34:826><2<JH2:FD2488226422444020400028@@2>LL2
BTT2DXX2F//2H``2Hb`2Jdd6Jfd2Lhh2Jfd00f]=HbaS;004Jdd4Jfd2Jdd2Hb`2H``2F//2DZX>BVT2
DXX2BVT2@RP2>NL2>LL2<JH00c66:FDYI@08:FD28B@26<<22642020M000402022442264248824:82
6<<26><28B@2:DD2:FD2<JH2>LL2@PP2BTT2BVT2DZX2F//2H``2Jdd2Jfd2Ljh2Nnl00h@@S56<D@02
U982U;84ool10001ool001Goo`03003ooooo00;oo`BU50:]M@:<D@03Q32LdicC00:<L@:<D@9[K@AB
ZP9[K@9[C@9BZP8ii`8ia`9BZP9BRPA:J@8YI@8Q908Q108Q908ii`8YA@8H``<@XP8Hh`8aYP8YI@8@
PP88H@88@@@080@0008Q108ia`9:B@9BRP9Jb`9S309S;09[C@I[K@9cSP9[K@03JdeS;6</00A[C@A[
K@9[C@9S;09S309Jb`9BZPi:J@9BRP9:J@92:08ii`8ia`8aYP03<HHYIBUU00PYI@8Q908H``88H@80
81d000@08088@@88H@8@PP8@XP8H``8Hh`8Q908YA@8YI@8aYP8ia`92209:B@9:J@9BZP9Jb`9S309[
C@9[K@9c[P9kk`03Q12<DHaA00:DTP:D/PCoo`40007oo`005Ooo00<00?ooool00_oo19cc0ZeE0X@`
00>449BbU;800W_?0W__0W>>0U:Z0U::0V]]0U::0T8X0SWW0SW70U::0T880S660TY90S6V124T0RU5
0SW70RUU0QS30a2R0RUU0RU50RUU0R4T0PQQ0PQ1100P10000PQQ0RUU0T880TYY0U:Z0U[[0V<<0V</
0V]=16]]0V]=0f</16]=16]]0V]=0V</0V<<0U[[0U[;0U::14YY3U::14YY0TY93D880SW70RUU0R44
0Q220P0P7@000P0P0PQ110QQ0Q2R0QS30QSS0R440R4T0RUU0S660SW70SWW0T8X0TYY0U::0U[;0V<<
0V]=0V]]0W>^0W_?00>448aAS5400Xaa0YBb1?oo0@000Ooo000Eool20003ool4W?<2[ED2Q3000h@@
U;:D/P02Nll2Nnl2Lhh2DZX2DXX2Jfd2DXX2@RP2>NL2>LL2DXX2@PP2<HH2BTT2<JH48B@2:DD2>LL2
:FD26<<34:82:FD2:DD2:FD28B@226422444020400022642:FD2@PP2BVT2DZX2F^/2H``2Hb`2Jdd4
Jfd2Jdd3Hb`4Jdd4Jfd2Jdd2Hb`2H``2F^/2F//2DXX4BVT>DXX4BVT2BTT=@PP2>LL2:FD28@@24882
020M00020202244426424:826<<26><28@@28B@2:FD2<HH2>LL2>NL2@RP2BVT2DXX2F//2H``2Jdd2
Jfd2Ljh2Nll00h@@S56<D@02S742U;83ool20001ool001Goo`03003ooooo00;oo`BLl`:]E@:4<003
Q12DTYBB009c[P9kc`9cSPABRP9[C@9Jb`9:J@8ii`8aYP9:J@92:092209:B@8YI@8Q108aYP8ii`8a
YP8ia`8aQP8H``038@@YIBUU00@@XP8YA@8@XP88@@@080H0008Q108aYP92:09BRP9Jb`9Jj`9S;0A[
C@9S;09S309S;003Jde[KF]]00A[K@9[C@9S;0AS309Jj`9BZP9BRP9:J@9BRPaBZPAJb`9Jj`9BZP]B
RP9:J@92208ia`8aQP8Hh`8081d0008080@8@@88H@8@PP8@XP8Hh`8Q108Q908YA@8aQP8ia`8ii`92
:09:B@9BRP9Jb`9Jj`9S;09[K@9cSP9kc`03Q124<8@`00:<L@:D/PCoo`40007oo`005Ooo00<00?oo
ool00_oo19cc0ZeE0X@`00>449BBU9800W>^0W_?0W>>15::0V]=0U[;0TYY0SWW0S6V0TYY0T8X0T88
0TY90RUU0R440S6V0SWW0S6V0SW70S660QS300<Q12UU:FD0112R0RU50Q2R0PQ1100P1P000R440S6V
0T8X0U::0U[;0U[[0V</16]=0V</0V<<0V</00=[CF]]Jfd016]]0V]=0V</16<<0U[[0U:Z0U::0TYY
0U::35:Z15[;0U[[0U:Z2e::0TYY0T880SW70S660QSS0P0P7@000P0P10Q10PQQ0Q220Q2R0QSS0R44
0R4T0RU50S660SW70SWW0T8X0TY90U::0U[;0U[[0V</0V]]0W>>0W_?00>448@`Q3000Xaa0YBb1?oo
0@000Ooo000Eool00`00ooooo`02ool4W?<2YC@2Q1000g__S76<L@02Q302Nll2F^/2DXX2BVT2H``2
F^/2DZX2>NL2<JH4@RP2@PP2<JH28B@28@@4:FD2:DD28B@28@@36<<24:8648822642244402060002
4882:FD2@PP2BVT2DZX2F//:H``2Hb`00f]=Jfe[K@04Jdd6Hb`2H``2F^/8DZX4F//4F^/2F//2F^/2
H``4Jdd2Hb`5H``2F^/4F//2DXX2BTT2@RP2>LL2:DD24882020K000402022442264248824:826<<2
6><28B@2:DD2:FD2<JH2>NL2@PP2BTT2DXX2DZX2F^/2Hb`2Jdd2Lhh2Nll00g__Q324<002S742U984
ool10001ool001Goo`03003ooooo00;oo`BLl`:U=0:44003Nnn<LHaa00:4<09kc`9Jj`9BRP9:J@9S
309Jj`9BZP8ii`8aYPA2:092208aYP8Q908Q10@YI@8YA@8Q908Q10<H``8@XPH@PP88H@88@@@080H0
008@PP8YI@92209:J@9BZP9Jb`YS309S;003Jde[KF]]00A[C@IS;09S309Jj`QBZPAJb`AJj`9Jb`9J
j`9S30A[C@9S;0ES309Jj`AJb`9BRP9:B@92:08ia`8YA@8@PP8081/000@08088@@88H@8@PP8@XP8H
``8Hh`8Q908YA@8YI@8aYP8ii`92209:B@9BRP9BZP9Jj`9S;09[C@9cSP9kc`03Nnn4<8@`00:<L@:D
TPCoo`40007oo`005Ooo00<00?ooool00_oo0Ycc0YBb0Xaa0X@@00=c[W>>Lhh00V]=0V<<0U:Z0U::
0TY90T8X0T880SWW0S6V0S6612UU0RU50R4T0R4411SS11S3112R0a221PQQ1PQ1100P20000QSS0S66
0T880TYY0U:Z15[;0U[[0V<<0V</1F]=2V</0V<<0U[[0U[;15:Z15[;0U[[0V</0V<<16</0V]]1W>>
0V]]0f]=0V</0V<<0U[[0U[;0U:Z0TYY0T880S660QSS0P0P7@000P0P10Q10PQQ0Q220QS30QSS0R44
0R4T0RUU0S660SW70SWW0T8X0TYY0U:Z0U[;0V<<0V]=0V]]0W>^00=kkh@@Q1000XaA0YBB1?oo0@00
0Ooo000Eool00`00ooooo`02ool2W?<2U;82S742Q1000g>^LhicSP02Jdd2H``2DZX2DXX2BTT2@RP2
@PP2>NL2<JH2<HH4:FD2:DD28B@28@@46><46<<44:83488626462444020800026><2<HH2@PP2BVT2
DZX4F//2F^/2H``2Hb`5Jdd:Hb`2H``2F^/2F//4DZX4F//2F^/2Hb`2H``4Hb`2Jfd6Lhh2Jfd3Jdd2
Hb`2H``2F^/2F//2DZX2BVT2@PP2<HH26><2020M000202042442264248826<<26><28@@28B@2:FD2
<HH2>LL2>NL2@RP2BVT2DZX2F//2H``2Jdd2Jfd2Ljh00g__Q1244002S542U984ool10001ool001Go
o`03003ooooo00;oo`:Ld`:DTP:4<09kk`03Lhi[CF]=009S309Jb`9BZP9:J@9:B@92208ii`8ia`@a
QP8YI@8YA@8Q908Q10@Hh`@H``@@XP@@PPD8H@@8@@H080X0008@XP8aQP8ii`A:B@9BRP9Jb`9Jj`]S
;0I[C@9S;09S309Jj`9Jb`9BZPAJb`9Jj`9S;0A[C@9[K@9cSPIc[P9cSP9[C@=[K@9[C@9S;09S309J
j`9Jb`9BRP92:08aQP8Hh`8081d000@08088@@88H@8@PP8@XP8Hh`8Q108Q908YI@8aQP8ia`8ii`92
:09:J@9BZP9Jb`9S309[C@9[K@9c[P03Nnn448@@00:<D@:DTPCoo`40007oo`005Ooo00<00?ooool0
0_oo0YcC0YBB0X@`0W__00=cSV]=Jdd00V<<0U[;0U:Z0TYY0TY90T880SWW0SW713660RUU0RU50R4T
0R4411SS11S3112R11221@QQ10Q11P0P2P000Q2R0S660SWW14Y90U::0U[;0U[[2f</1V]=0V</0V<<
0U[[0U[;0U:Z15[;0U[[0V</16]=0V]]0W>>1W>^0W>>0V]=0f]]0V]=0V</0V<<0U[[0U[;0U::0T8X
0S660QSS0P0P7@00100P0PQ10PQQ0Q220Q2R0QSS0R440R4T0RUU0S660SW70SWW0T8X0TYY0U:Z0U[;
0V<<0V]=0V]]0W>^00=kkh@@Q1000XaA0YBB1?oo0@000Ooo000Eool00`00ooooo`02ool2W=<2U982
Q302Nnl00g>>Jde[C@02H``2F//2DXX2BVT2@RP2@PP2>NL2<JH2<HH2:FD2:DD48B@28@@26><46<<2
4:84488526462448020:000224428B@2<HH2>LL2@RP2DXX2F//2F^/6H``3Hb`8Jdd2Hb`2H``2F^/6
F//2F^/2Hb`2Jdd2Jfd4Lhh2Ljh2Nll4Ljh2Jfd2Jdd5Jfd2Jdd2H``2F^/2DZX2BVT2@PP2<HH26<<2
020M000402022442264248824:826<<28@@28B@2:DD2<HH2<JH2>NL2@RP2BVT2DXX2F//2H``2Hb`2
Jfd2Ljh00g__Q1244002S542U984ool10001ool001Goo`8000?oo`:Ld`:DTP:4<09kc`03Lhi[CF]=
009S309Jb`9BRP9:J@92:092208ia`8aYP8aQP8YI@8YA@8Q908Q108Hh`@H``@@XP@@PP@8H@<8@@P0
8100008@XP8YA@8ia`92:09BRP9BZPAJb`9Jj`9S30=S;0Q[C@9S309Jj`IJb`9S309S;09[K@9cSPIc
[PAkc`9c[P9cSP9[C@9S;0E[C@9S;09Jj`9BZP9:J@92208aQP8Hh`80824000808088@@88H@8@PP8@
XP8H``8Hh`8Q908YA@8aQP8aYP8ii`92:09:B@9BRP9Jb`9Jj`9S;09[K@9c[P03Nln448@@00:<D@:D
TP?oo`80007oo`005Ooo00<00?ooool00_oo0YcC0YBB0X@`0W_?00=cSV]=Jdd00V<<0U[;0U::0TYY
0T8X0T880SW70S6V0S660RUU0RU50R4T0R440QSS11S3112R112210QQ0`Q1200P40000Q2R0RU50SW7
0T8X0U::0U:Z15[;0U[[0V<<0f</26]=0V<<0U[[1U[;0V<<0V</0V]]0W>>1W>^17_?0W>^0W>>0V]=
0V</1F]=0V</0U[[0U:Z0TYY0T880S660QSS0P0P8@000P0P0PQ10PQQ0Q220Q2R0QS30QSS0R4T0RU5
0S660S6V0SWW0T8X0TY90U::0U[;0U[[0V</0V]]0W>^00=kch@@Q1000XaA0YBB1?oo0@000Ooo000E
ool00`00ooooo`02ool2W=<2U982Q302Nnl00g>>Jde[C@02H``2F//2DXX2BTT2@RP2>NL2>LL2<JH2
:FD2:DD48B@28@@26><26<<44:84488426452448020@000202028B@2<JH2@RP2BTT2BVT2DZX2F//2
F^/2H``3Hb`6Jdd2Hb`2H``6F^/2H``2Jdd2Jfd4Lhh2Ljh8Nll2Lhh2Jfd2Hb`2H``5Hb`2H``2DZX2
BTT2>NL2<HH26><2020S000202022442264248824:826<<26><28@@2:DD2<HH2<JH2>NL2@RP2BTT2
DXX2F//2F^/2Hb`2Jfd2Lhh00g_?Q1244002S542S744ool10001ool001Goo`03003ooooo00;oo`:L
d`:DTP:4<09kk`03Lhi[CF]=009S309Jb`9BRP9:B@92:08ii`8ia`8aYP8YI@8YA@@Q908Q108Hh`8H
``@@XP@@PP@8H@D8@@P081000080808Q908aYP92:09:B@9:J@9BZP9Jb`9Jj`9S30=S;0I[C@9S;09S
30IJj`9S309[C@9[K@AcSP9c[PQkc`9cSP9[K@9S;09S30ES;09S309BZP9:B@8ii`8aQP8Hh`8082<0
00808088@@88H@8@PP8@XP8H``8Hh`8Q108YA@8aQP8aYP8ii`92:09:B@9BRP9Jb`9Jj`9S;09[K@9c
SP03Nln448@@00:<D@:<L@Coo`40007oo`005Ooo00<00?ooool00_oo0YcC0YBB0X@`0W__00=cSV]=
Jdd00V<<0U[;0U::0TY90T8X0SWW0SW70S660RUU0RU50R4T0R4411SS0QS30Q2R1Q220PQQ1@Q12P0P
4P000Q220RUU0SW70T8X0TYY0U::0U[;0U[[0V<<0f</16]=0V</0V<<1U[[0V</0V]=0V]]1W>>27_?
0W>^0W>>0V]=1F<<15[[0U:Z0TY90SWW0S660R440P0P9@000P0P10Q111220QS30QSS0R440RU50RUU
0S6V0SWW0T880TY90U::0U[;0U[[0V</0V]]0W>>00=kch@@Q1000X@`0Xaa1?oo0@000Ooo000Eool0
0`00ooooo`02ool2W=<2U982Q302Nnl00g>>Jde[C@02H``2F//2DXX2BTT2@RP2>NL2>LL2<HH2:FD2
:DD28B@28@@46><26<<24:8648822645244:020B00024882:FD2>LL2@RP2BVT2DXX2F//2F^/2H``3
Hb`4Jdd2Hb`2H``6F^/2Hb`2Jdd2Jfd6Lhh8Nll2Ljh2Lhh2Jdd5H``4F^/2DZX2BTT2>NL2<HH28@@2
020U00020204244448826<<26><28@@2:DD2:FD2<JH2>NL2@PP2BTT2DXX2F//2F^/2Hb`2Jfd2Lhh0
0g_?Q1244002Q302S744ool10001ool001Goo`03003ooooo00;oo`:Ll`:DTP:<D@9kk`03Lji[CF]=
009S309Jb`9BRP9:J@92:08ii`8ia`8aQP8YI@8YA@8Q908Q108Hh`@H``8@XP@@PP@8H@@8@@L08080
008081800080808Q908aYP92209:B@9BRP9BZP9Jb`9Jj`03H`aS;6</00IS;09S309Jj`9Jb`9S309[
C@9[K@9cSPAc[PYkc`9c[P9cSP9[K@9S309Jj`EJb`9BRP92:08ii`8aQP8@XP8082D0008080@8@@88
H@8@PP8@XP8Hh`8Q108Q908YI@8aYP8ia`92209:B@9:J@9BZP9Jj`9S309[C@9cSP03Ljikkg__00:4
<0:<L@Coo`40007oo`005Ooo00<00?ooool00_oo0Ycc0YBB0XaA0W__00=c[V]=Jdd00V<<0U[;0U::
0TYY0T8X0SWW0SW70S660RUU0RU50R4T0R440QSS11S30Q2R112210QQ10Q11`0P0P000P0P4P000P0P
0R4T0S6V0T880TY90U::0U:Z0U[;0U[[00=S36</Hb`01V</0V<<0U[[0U[;0V<<0V]=0V]]0W>>17>^
2W_?0W>^0W>>0V]]0V<<0U[[1E[;0U::0T8X0SWW0S660Q2R0P0P9@000P0P10Q10PQQ0Q220Q2R0QSS
0R440R4T0RUU0S6V0SW70T880TY90TYY0U:Z0U[[0V<<0V]=0W>>00=c[W__Nnl00X@`0Xaa1?oo0@00
0Ooo000Eool00`00ooooo`02ool2W=<2U982Q302Nnl00g>>Jde[C@02F^/2F//2DXX2BTT2@PP2>NL2
<JH2<HH2:DD28B@28@@46><26<<44:82488426442449020D000226426><2:FD2>NL2BTT2BVT2DXX2
DZX2F//2F^/00f<<HbaS;004Hb`2H``2F^/2F//2F^/2Jdd2Jfd2Lhh2Ljh:Nll4Ljh2Lhh2Jfd2Jdd2
F^/5F//2DZX2@RP2@PP2>NL2<HH24:82020U000202042442264248826<<26><28@@2:DD2:FD2<JH2
>NL2@PP2BTT2DXX2DZX2F^/2Hb`2Jfd2Lhh00g_?Q1244002Q302S744ool10001ool001Goo`03003o
oooo00;oo`:Ld`:DTP:4<09kk`03Lhi[CF]=009Jj`9Jb`9BRP9:B@92208ii`8aYP8aQP8YA@8Q908Q
10@Hh`8H``@@XP8@PP@8H@@8@@T081@00088H@8Hh`8YI@8ii`9:B@9:J@9BRP9BZP9Jb`9Jj`03H`aS
;6</00AS;09S309Jj`9Jb`9Jj`9[C@9[K@9cSP9c[PYkc`Ac[P9cSP9[K@9[C@9Jj`EJb`9BZP92:092
208ii`8aQP8@XP8082D0008080@8@@88H@8@PP8H``8Hh`8Q108YA@8YI@8aYP8ii`92209:B@9BRP9B
ZP9Jj`9S;09[K@9cSP03Nln448@@00:4<0:<L@Coo`40007oo`005Ooo0P000ooo0YcC0YBB0X@`0W__
00=cSV]=Jdd00V<<0U[;0U::0TY90T880SWW0S6V0RUU0RU50R4T0R440QSS11S30Q2R112210QQ10Q1
1`0P4P000P0P0Q2R0R440RUU0SW70T8X14YY0U::0U:Z0U[;0U[[00=S36</Hb`00V</16<<0U[[0U[;
0V<<0V]]17>>2W_?0W>^17>>0V]]0V]=0V</1e[[0U:Z14880SWW0S6V0RUU0Q2R0P0P8`000P0P10Q1
0PQQ0Q220QS30QSS0R440R4T0RUU0S6V0SW70T880TY90U::0U[;0U[[0V</0V]]0W>>00=kcg__Nnl0
0X@`0Xaa0ooo0P000Ooo000Eool00`00ooooo`02ool2W=<2U982Q302Nnl00g>>Jde[C@02H``2F//2
DXX2BTT2@PP2>NL2<JH2:FD2:DD28B@28@@26><46<<24:84488426442447020B000202024:828@@2
:FD2>LL2@RP4BVT2DXX2DZX2F//2F^/00f<<HbaS;002Hb`4H``2F^/2F//2H``2Jfd4Lhh:Nll2Ljh4
Lhh2Jfd2Jdd2Hb`7F^/2DZX4@PP2>NL2<JH2:FD24:82020S000202042442264248826<<26><28@@2
8B@2:FD2<JH2>LL2@PP2BTT2DXX2F//2F^/2Hb`2Jfd2Lhh00g_?Nnmkk`02Q302S744ool10001ool0
01Goo`03003ooooo00;oo`:Ll`:DTP:<D@9kk`03Lji[CF]=009S309Jb`9BRP9:B@92208ii`8aYP8a
QP8YA@8Q908Q108Hh`@H``8@XP@@PP@8H@@8@@D081@00088H@8Q108YA@8ia`9:B@A:J@ABRP9BZP9J
b`=Jj`IS309Jj`9Jb`9Jj`9S;09[K@9cSP9c[PIkk`Akc`9c[P9cSPA[K@9[C@9S;09Jj`9Jb`=S309J
b`9:B@Hii`8aYP8Q908082D000808088@@88H@8@PP8@XP8H``8Q108Q908YI@8aQP8ia`92209:B@9B
RP9BZP9Jj`9S;09[C@9cSP03Ljikkg__00:4<0:<L@Coo`40007oo`005Ooo00<00?ooool00_oo0Ycc
0YBB0XaA0W__00=c[V]=Jdd00V<<0U[;0U::0TY90T880SWW0S6V0S660RU50R4T0R440QSS11S30Q2R
112210QQ10Q11@0P50000PQQ0R440RU50SW70TY914YY15::0U:Z0U[;0e[[1V<<0U[[0U[;0U[[0V</
0V]]0W>>0W>^1W__17_?0W>^0W>>16]]0V]=0V</0U[[0U[;0f<<0U[;0TY91SWW0S6V0R4T0P0P9@00
0P0P0PQ10PQQ0Q220Q2R0QS30R440R4T0RUU0S660SW70T880TY90U::0U:Z0U[[0V</0V]=0W>>00=c
[W__Nnl00X@`0Xaa1?oo0@000Ooo000Eool00`00ooooo`02ool2W?<2U982Q302Nnl00g>>Jde[C@02
H``2F//2DXX2BTT2@PP2>LL2<JH2:FD2:DD28B@28@@26><26<<44:82488426442445020D00020202
8@@2:FD2>LL2BTT4DXX4DZX4F//;F^/2F//2F^/2Hb`2Jfd2Ljh4Nll6Nnl2Nll2Ljh4Lhh2Jfd2Jdd4
Hb`4F//3F^/2F//2BVT2>LL2<JH2<HH2:DD26><2020S000402022442264248826<<26><28@@2:DD2
:FD2<JH2>NL2@PP2BTT2DXX2F//2F^/2Hb`2Jfd2Lhh00g_?Q1244002S542S744ool10001ool001Go
o`03003ooooo00;oo`:Ll`:DTP:4<09kk`03Lhi[CF]=009S309Jb`9BRP9:B@92208ia`8aYP8YI@8Y
A@8Q908Q108Hh`8H``@@XP8@PP@8H@@8@@D081@00080808Q108YI@8ia`9:B@ABRPABZPAJb`]Jj`9J
b`9Jj`9S;09[K@9c[PAkc`Ikk`9kc`9c[PAcSP9[K@9[C@AS;0AJb`=Jj`9Jb`9:J@8ia`8aYP8aQP8Y
A@8Hh`8082<000@08088@@88H@8@PP8H``8Hh`8Q108YA@8YI@8aYP8ii`92209:B@9BRP9Jb`9Jj`9S
;09[K@9cSP03Nln448@@00:<D@:<L@Coo`40007oo`005Ooo00<00?ooool00_oo0Ycc0YBb0XaA0X@@
00=c[V]]Jfd00V<<0U[;0U::0TY90T880SWW0S6V0S660RU50R4T0R440QSS0QS3112R0Q2210QQ10Q1
1@0P50000PQ10R440S660SW70TY90U::0TYY0U:Z4E[[0U[;0U[[0V</0V]]0W>^17_?27__0W_?17>>
0V]]0V]=0V</0V<<0U[[0U:Z1E[;0U:Z0TY90SWW0SW70S6V0RUU0QSS0P0P8`000P0P0PQ10PQQ0Q22
0Q2R0QS30R440R4T0RUU0S660SW70T880TY90U::0U:Z0U[[0V</0V]=0W>>00=kcg__Nnl00X@`0Xaa
1?oo0@000Ooo0008ool20004ool20005ool00`00ooooo`02ool2W?<2U;82S542Q1000g>^Jfe[K@02
H``2F//2DXX2BTT2@PP2>NL2<JH2<HH2:DD28B@28@@26><26<<44:82488426442445020D00022442
8@@2<HH2>LL2BTT2DXX2BVT2DZXAF^/2F//2F^/2Hb`2Jfd2Ljh4Nll8Nnl2Nll4Lhh2Jfd2Jdd2Hb`2
H``2F^/2DZX5F//2DZX2BTT2>NL2>LL2<JH2:FD26><2020S000202022442264248824:826<<28@@2
8B@2:FD2<HH2>LL2@PP2BTT2DXX2DZX2F^/2Hb`2Jdd2Lhh00g_?Nnmkk`02Q302S744ool10001ool0
00Ooo`04003ooooo0002ool01000ooooo`001?oo00<00?ooool00_oo0Ycc0YBB0XaA0W__00=c[V]=
Jdd00V<<0U[;0U::0TY90T880SW70S6V0RUU0RU50R4T0R440QSS0QS3112R0Q220PQQ10Q1100P5`00
0QSS0R4T0SWW0T8814YY0U::15[[0U[;16<<0U[[1E[;0U:Z0U[[0V</0V]]0W>>0W>^17_?27__0W_?
17>^0W>>0V]=0V</0V<<0U[[0U::00=BZU[;F//015:Z0U::0TY90T8X0SWW0S6V0R4T0P0P8@000P0P
10Q10PQQ0Q220QS30QSS0R440RU50RUU0S6V0SWW0T8X0TY90U::0U[;0V<<0V</0V]]0W>>00=kch@@
Q1000XaA0Xaa1?oo0@000Ooo0007ool01000ooooo`000_oo00@00?ooool000Coo`8000?oo`:Ll`:D
TP:<D@9kk`03Lji[CF]=009S309Jb`9BRP9:B@92208ia`8aYP8YI@8YA@8Q908Q108Hh`8H``@@XP8@
PP88H@@8@@@081L0008Hh`8Q908ii`9220A:J@9BRPAJj`9Jb`AS309Jj`EJb`9BZP9Jj`9S;09[K@9c
SP9c[PAkc`Qkk`9kc`Ac[P9cSP9[C@9S;09S309Jj`9BRP03DZYJbe[;00ABZP9BRP9:B@92:08ii`8a
YP8Q90808240008080@8@@88H@8@PP8H``8Hh`8Q108YA@8YI@8aYP8ii`92:09:B@9BRP9Jb`9S309S
;09[K@9cSP03Nln448@@00:<D@:<L@?oo`80007oo`001ooo0`000ooo00@00?ooool000Coo`03003o
oooo00;oo`:Ll`:DTP:<D@9kk`03Lji[CF]=009S309Jb`9BRP9:B@92208ii`8aYP8YI@8YA@8Q908Q
108Hh`8H``8@XP@@PP88H@@8@@@081D00080808Q108YA@8ii`92:09BRP9BZP9Jj`9S;09S30AS;09S
309Jj`03F/]BZU:Z009BRP9BZP9Jj`9[C@9[K@9cSP9c[PAkc`Qkk`Akc`9c[P9cSP9[C@AS309Jj`=B
ZP9Jb`9Jj`9Jb`9BRP9:J@9:B@92208ia`8YA@808240008080@8@@8@PP8@XP8H``8Hh`8Q108YA@8a
QP8aYP8ii`92:09:B@9BRP9Jb`9S309S;09[K@9cSP03Nln448@@00:<D@:DTPCoo`40007oo`001ooo
00<00?ooool00ooo00@00?ooool000Coo`03003ooooo00;oo`:Ll`:DTP:<D@9kk`03Lji[CF]=009S
309Jb`9BRP9:B@92208ii`8aYP8YI@8YA@8Q908Q108Hh`8H``8@XP@@PP88H@@8@@@081D00080808Q
108YA@8ii`92:09BRP9BZP9Jj`9S;09S30AS;09S309Jj`03F/]BZU:Z009BRP9BZP9Jj`9[C@9[K@9c
SP9c[PAkc`Qkk`Akc`9c[P9cSP9[C@AS309Jj`=BZP9Jb`9Jj`9Jb`9BRP9:J@9:B@92208ia`8YA@80
8240008080@8@@8@PP8@XP8H``8Hh`8Q108YA@8aQP8aYP8ii`92:09:B@9BRP9Jb`9S309S;09[K@9c
SP03Nln448@@00:<D@:DTPCoo`40007oo`001ooo00<00?ooool00ooo00@00?ooool000Coo`03003o
oooo00;oo`:U50:D/P:<D@:44003Lji[KF]]009S309Jb`9BRP9:B@92208ii`8aYP8aQP8YA@8Q908Q
108Hh`8H``8@XP8@PP@8H@@8@@@081D00080808Q108YI@92209:J@9Jb`9S30AS;09S309[C@9S;0AJ
j`03DZYBRU::009:J@9BZP9S309S;09[K@9cSP9c[PAkc`Akk`9kc`9kk`Akc`9c[P9cSP9[K@9S;0AS
309Jj`=Jb`AJj`9BZP9:J@92:08ii`8ia`8YI@80824000808088@@88H@8@PP8@XP8H``8Hh`8Q908Y
A@8aQP8aYP8ii`92:09:J@9BRP9Jb`9S309S;09[K@9c[P03Nln448@@00:<D@:DTPCoo`40007oo`00
2?oo0`000ooo0P001Ooo00<00?ooool00_oo0ZDD0YBb0XaA0X@@00=c[V]]Jfd00V<<0U[;0U::0TY9
0T880SWW0S6V0S660RU50R4T0R440QSS0QS30Q2R0Q2210QQ10Q1100P5@000P0P0R440RUU0T880TYY
0U[;0V<<16</0V<<0V]=0V</15[[00=BZU::DXX00TYY0U:Z0V<<0V</0V]]0W>>0W>^17_?17__0W_?
0W__17_?0W>^0W>>0V]]0V</16<<0U[[0e[;15[[0U:Z0TYY0T8X0SWW0SW70RUU0P0P8@000P0P0PQ1
0PQQ0Q220Q2R0QS30QSS0R4T0RU50S660S6V0SWW0T8X0TYY0U::0U[;0V<<0V</0V]]0W>^00=kch@@
Q1000XaA0YBB1?oo0@000Ooo000Eool00`00ooooo`02ool2YA@2U;82S742Q1000g>^Jfe[K@02Hb`2
F//2DXX2BTT2@RP2>NL2<JH2<HH2:DD28B@28@@26><26<<24:82488426422444020G00022642:DD2
>LL2BTT2DZX2H``4Jdd4Hb`2Jdd2H``2F^/2F//00e:ZBVU:J@02BVT2F//2F^/2H``2Jdd2Lhh4Ljh>
Nll4Ljh2Jfd2Jdd2Hb`2Jdd2Hb`5H``2Hb`2F^/2BVT2@PP2>LL2<JH2:FD2264Q0002020224422642
48824:826<<26><28B@2:DD2<HH2>LL2>NL2@RP2BVT2DZX2F//2H``2Jdd2Jfd2Ljh00g__Q1244002
S542U984ool10001ool001Goo`03003ooooo00;oo`:U50:D/P:<L@:44003Lji[KF]]009S;09Jb`9B
RP9:B@92:08ii`8aYP8aQP8YA@8Q908Q108Hh`8H``8@XP8@PP@8H@88@@@081L00088H@8YA@8ia`9:
B@9BZP9S30A[C@AS;09[C@9S309Jj`9Jb`03DZY:JDYY009:J@9Jb`9Jj`9S309[C@9cSPAc[Pikc`Ac
[P9[K@9[C@9S;09[C@9S;0ES309S;09Jj`9:J@92208ia`8aYP8YI@88HB4000808088@@88H@8@PP8@
XP8H``8Hh`8Q908YA@8aQP8ia`8ii`92:09:J@9BZP9Jb`9S309[C@9[K@9c[P03Nnn448@@00:<D@:D
TPCoo`40007oo`005Ooo00<00?ooool00_oo0ZDD0YcC0Xaa0X@@00=kcf]]Jfd00V</0U[[0U:Z0TYY
0T8X0SWW0SW70S660RU50R4T0R440QSS0QS30Q2R0Q2210QQ0PQ1100P5`000R440S6V0T8X0TYY0U[;
0V</0V]=16]]0W>>0V]]0V</0U[[0V<<00=Jbe[[F^/017>>0V</0U[[0V]=17>>27>^27_?17>^0W>>
16]]0W>>0W>^0g>>16]]0V]=0U[[0T880SWW0SW70S6V0RUU0QSS0Q22100P5`00100P0PQ10PQQ0Q22
0Q2R0QSS0R440R4T0RUU0S660SW70T880T8X0TYY0U:Z0U[[0V<<0V]=0W>>0W>^00=kkh@`Q3000Xaa
0YBb1?oo0@000Ooo000Eool00`00ooooo`02ool2YA@2W=<2S742Q1000g_?Jfe[K@02Hb`2F^/2DZX2
BVT2@RP2>NL2>LL2<HH2:DD28B@28@@26><26<<24:82488426422444020G00028@@2<JH2@RP2BVT2
F//2Hb`2Jdd4Jfd2Lhh2Jfd2Hb`2F^/2H``00e[;F^]Jj`04Lhh2Hb`2F^/2Jdd4Lhh8Ljh8Nll4Ljh2
Lhh4Jfd2Lhh2Ljh3Lhh4Jfd2Jdd2F^/2@PP2>NL2>LL2<JH2:FD26><24884020G0004020224422642
48824:826><28@@28B@2:FD2<HH2>LL2@PP2@RP2BVT2DZX2F^/2H``2Jdd2Lhh2Ljh00g__Q324<002
S742U;84ool10001ool001Goo`03003ooooo00;oo`:U=0:Ld`:<L@:4<003NlmcSW>>009S;09Jj`9B
ZP9:J@92:08ii`8ia`8aQP8YI@8Q908Q108Hh`8H``8@XP8@PP@8H@88@@@081D00088H@8YI@8ia`92
209BRP9Jj`9S309[K@9cSPAc[P9cSP9[K@A[C@03Hbakcg_?00:<D@:4<09cSP9S309[C@9[K@IcSPAc
[P9kc`9kk`Ikc`9c[PAcSP9c[P9kc`Ekk`9kc`9c[P9[K@9S;09:B@9220A:B@92208ia`8aQP8Q908@
XP8081D000808088@@@8H@8@PP8H``8Hh`8Q108Q908YI@8aYP8ia`92209:B@9BRP9BZP9Jj`9S;09[
C@9cSP9c[P03Nnn4<8@`00:<L@:D/PCoo`40007oo`005Ooo0P000ooo0ZDd0YcC0Xaa0X@`00=kcg>>
Lhh00V</0U[[0U:Z0TYY0T8X0SWW0SW70S660RUU0R4T0R440QSS0QS30Q2R0Q2210QQ0PQ1100P5@00
0PQQ0RUU0SW70T880U::0U[[0V<<0V]]0W>>17>^0W>>0V]]16]=00=S;7_?Nll00XaA0X@`0W>>0V<<
0V]=0V]]1W>>17>^0W_?0W__1W_?0W>^17>>0W>^0W_?1G__0W_?0W>^0V]]0V</0TY90T8814Y90T88
0SW70S660R4T0Q2R0P0P5@000P0P0PQ110QQ0Q220QS30QSS0R440R4T0RUU0S6V0SW70T880TY90U::
0U:Z0U[[0V</0V]=0W>>0W>^00=kkh@`Q3000Xaa0YBb0ooo0P000Ooo000Eool00`00ooooo`02ool2
YC@2W?<2U982Q3000g__LhicSP02Jdd2F^/2DZX2BVT2@RP2@PP2>LL2<HH2:FD28B@28@@26><26<<2
4:82488426422444020E00026<<2<JH2>NL2@RP2F//2H``2Hb`2Lhh8Ljh6Lhh00g__S56<D@02S742
Q302Ljh2Hb`4Jdd8Lhh2Ljh4Nnl6Nll2Ljh2Lhh2Ljh2Q104Q3000haAQ324<002Q102Nll2Jfd2Hb`2
DXX2@RP2BTT2BVT2@RP2>NL2>LL2<HH28B@2020E000202022442264248824:826<<26><28@@2:DD2
:FD2<JH2>NL2@RP2BTT2DXX2F//2F^/2Hb`2Jdd2Lhh2Nll00h@@S56<D@02S742U;84ool10001ool0
01Goo`03003ooooo00;oo`:U=0:Ll`:DTP:4<003NnmcSW>>009[C@9Jj`9BZP9:J@92:092208ia`8a
QP8YI@8Q908Q108Hh`8H``8@XP8@PP@8H@88@@@081D0008H``8aYP8ii`92:09Jb`9S309S;09cSPQc
[PIcSP03Nnn<DHaA00:<L@:4<09c[P9S;0A[C@QcSP9c[PAkk`Ikc`9c[P9cSP9c[P:440B4<003S564
<8@`00:4409kc`9[K@9S;09BRP92:09:B@9:J@92:08ii`8ia`8aQP8Q908081D000808088@@88H@8@
PP8@XP8H``8Hh`8Q108YA@8YI@8aYP8ii`92:09:B@9BRP9Jb`9Jj`9S;09[C@9cSP9kc`03Q12<DHaA
00:<L@:D/PCoo`40007oo`005Ooo00<00?ooool00_oo0ZeE0Ycc0YBB0XaA00=kkg>^Ljh00V]=0V<<
0U[;0U::0TY90T880SW70S6V0RUU0RU50R440QSS0QS30Q2R0Q2210QQ0PQ1100P5@000R440SW70SWW
0TYY0V<<0V]=0W>>1W>^0V]]0W>>17_?0X@@00>4<8aAS5400XaA0W__0W>>1V]=0V]]1W>^0W_?1W__
0W_?17>^0W_?0X@@0XaA0Xaa0iBB0Xaa0X@`0W__0V]]0V</0U:Z0T8X0T880SWW0SW71S6V0R4T0P0P
4`00100P0PQ10PQQ0Q220Q2R0QS30QSS0R4T0RU50S660SW70SWW0T8X0TY90U::0U[;0V<<0V</0V]]
0W>>0W_?00>448aAS5400YBB0YcC1?oo0@000Ooo000Eool00`00ooooo`02ool2[ED2YA@2U;82S540
0h@@Ljic[P02Jfd2Hb`2F//2DXX2BTT2@PP2>NL2<JH2:FD2:DD28@@26><26<<24:82488426422444
020C000226428B@2>LL2@RP2DXX2Hb`2Lhh6Nll6Ljh2Nll2Q302S745Q302Nll2Jfd2Jdd2Hb`2Jdd2
Jfd2Lhh2Ljh2Nll2Nnl2Q104Nnl6Nll2Q102S544U985U;82S742Q102Lhh2H``2DZX2@RP2>NL4>LL4
<JH2<HH26<<2020C000402022442264248824:826<<28@@28B@2:FD2<HH2>LL2>NL2@RP2BVT2DXX2
F//2H``2Hb`2Jfd2Ljh2Nll00h@@S56<D@02U982W=<4ool10001ool001Goo`03003ooooo00;oo`:]
E@:U50:D/P:<D@03Q11c[W>^009[K@9S;09Jb`9BRP9:B@92208ii`8aYP8YI@8YA@8Q108Hh`8H``8@
XP8@PP@8H@88@@@081<00088H@8Q908ia`92:09BRP9S;09cSPIkc`Ic[P9kc`:4<0:<L@F4<09kc`9[
K@9[C@9S;09[C@9[K@9cSP9c[P9kc`9kk`:440Akk`Ikc`:440:<D@BDTPFD/P:<L@:4409cSP9S309B
ZP92:08ii`@ia`@aYP8aQP8H``8081<000@08088@@88H@8@PP8@XP8H``8Q108Q908YI@8aQP8ia`8i
i`92:09:J@9BRP9Jb`9S309S;09[K@9c[P9kc`03Q12<DHaA00:DTP:Ld`Coo`40007oo`005Ooo00<0
0?ooool00_oo0Zee0ZDD0YcC0Xaa00>447_?Nll00V]]0V</0U[[0U:Z0TYY0T8X0SWW0S6V0S660RU5
0R4T0QSS0QS3112R10QQ0PQ1100P4`000QS30RUU0SW70T880TYY0V</0W>^17__0X@@0W__1X@@0Xaa
0XaA00>448@`Q3000X@@17>>1V]=0V]]0W>^0W_?0W__0X@@1X@`0X@@0W__0X@@0XaA0YBB2IBb0YBB
0X@`0W>>0U[[0TYY0T880SWW1SW70S6V0RU50P0P5@000P0P0PQ10PQQ11220QS30QSS0R440RU50RUU
0S6V0SW70T880TY90TYY0U:Z0U[;0V<<0V]=0W>>0W>^0W__00>4<8aaS7400YBB0YcC1?oo0@000Ooo
000Eool00`00ooooo`02ool2[GD2YA@2W=<2S7400h@@Nlmkc`02Jfd2Hb`2F^/2DZX2BVT2@RP2>NL2
<JH2<HH2:DD28B@26><26<<44:8426422444020C00026<<2:FD2>LL2@PP2BVT2Hb`2Ljh4Nnl2Q102
Nnl6Q102S742S5400h@@Q324<002Q104Lhh6Jdd2Jfd2Ljh2Nll2Nnl2Q106Q302Q102Nnl2Q102S542
U989U;82U982Q302Lhh2F^/2BVT2@PP2>NL6>LL2<JH2:DD2020E000202022442264448826<<26><2
8@@2:DD2:FD2<JH2>LL2@PP2BTT2BVT2DZX2F//2H``2Jdd2Lhh2Ljh2Nnl00h@`S76<L@02U982W=<4
ool10001ool001Goo`03003ooooo00;oo`:]M@:U=0:Ld`:DTP03Q31kcg_?009cSP9[C@9Jj`9BZP9:
J@92:092208ia`8aQP8YA@8Q908Q108Hh`8H``8@XP8@PP88H@88@@@081400088H@8Q908aYP8ia`92
:09Jb`9S;09kc`Akk`B440B4<0:<D@:D/P:<L@03Q11c[W>^00A[K@9c[P9cSP9[K@AcSP9kc`9kk`:4
40:4<0:<D@:DTPB<L@:<D@:<L@:DTP:D/PVLd`:DTP:4<09c[P9BZP9:B@8ii`Hia`8aYP8aQP8HhaL0
00808088@@88H@8@PP8@XP8H``8Hh`8Q108YA@8YI@8aYP8ii`92209:B@9BRP9Jb`9Jj`9S;09[C@9c
SP9kc`9kk`03Q32<LHaa00:D/P:Ll`Coo`40007oo`005Ooo00<00?ooool00_oo0Zee0ZDd0YcC0YBB
00>4<7_?Nll00W>>0V]=0U[[0U:Z0TYY0T8X0T880SW70S660RU50R4T0R440QSS0QS30Q2R0Q220PQQ
0PQ1100P4@000PQQ0R4T0S6V0SW70T8X0U[;0V</0W_?17__18@@18@`0XaA0YBb0Xaa00>447>^Ljh0
16]]0W>^0W>>0V]]17>>0W_?0W__0X@@0X@`0XaA0YBB18aa0XaA0Xaa0YBB0YBb2IcC0YBB0X@`0W>^
0U:Z0TY90SWW1SW70S6V0S660QSS5`000P0P0PQ10PQQ0Q220Q2R0QS30QSS0R440RU50RUU0S6V0SWW
0T880TY90U::0U[;0U[[0V</0V]=0W>>0W_?0W__00>4<8aaS7400YBb0Ycc1?oo0@000Ooo000Eool2
0003ool2]IH2YC@2W?<2U9800haANnmkk`02Ljh2Jdd2H``2F//2DXX2BTT2@PP2>LL2<HH2:FD28B@2
8@@26><26<<24:82488226442442020A00024882:FD2>NL2@PP2F//2Hb`2Jfd2Nll4Nnl2Q102Nnl2
Q102S544U;82S7400g_?Jde[C@02Jdd2Nll2Nnl2Nll6Ljh2Nll2Q102Q302S542U984W=<6U;82W=<8
W?<3W=<2U982Q302Lhh2DZX2@RP2>NL4>LL4<JH2:DD2020E000202042442264248824:826<<28@@2
8B@2:DD2<HH2<JH2>NL2@RP2BTT2DXX2F//2F^/2Hb`2Jfd2Lhh2Nll2Q1000haAS76<L@02U;82W?<3
ool20001ool001Goo`03003ooooo00;oo`:eUP:U=0:Ll`:DTP03S55kkg__009c[P9[C@9S309Jb`9B
RP9:B@92208ia`8aQP8YI@8Q908Q108Hh`8H``8@XP8@PP88H@@8@@808140008@PP8YI@8ii`92209J
b`9S;09[K@9kc`Akk`:4409kk`:440:<D@BD/P:<L@03Nlm[CF]=009[C@9kc`9kk`9kc`Ic[P9kc`:4
40:4<0:<D@:DTPBLd`JD/P:Ld`RLl`>Ld`:DTP:4<09cSP9BZP92:08ii`@ia`@aYP8YA@8081D00080
80@8@@88H@8@PP8@XP8H``8Q108Q908YA@8aQP8aYP8ii`92:09:B@9BRP9Jb`9Jj`9S;09[K@9cSP9k
c`:44003S56<LHaa00:D/P:Ll`Coo`40007oo`005Ooo00<00?ooool00_oo0[Ff0ZeE0ZDD0YBb00><
DH@@Q1000W>^0V]]0V<<0U[[0U::0TY90T880SWW0S6V0RUU0RU50R4T0QSS0QS30Q2R0Q220PQQ10Q1
100P3`000QSS0S6V0T880U::0V</0V]]0W>^0W__0X@@18aA0X@@18aA0YcC0YBb0Xaa00=cSV</Hb`0
0V]=18@@27__0X@`0Xaa0YBB0YBb0YcC29cc0ZDD0Ycc0ZDD19cc0YcC00>D/YBBU9800XaA0X@@0W>^
0U:Z0SWW1SW70S6V0S660QS30P0P5@000P0P0PQ10PQQ0Q220Q2R0QS30QSS0R440R4T0RUU0S660SW7
0T880T8X0TYY0U:Z0U[;0V<<0V]=0V]]0W>^0W_?0X@@00><DIBBU9800YcC0ZDD1?oo0@000Ooo000E
ool00`00ooooo`02ool2]KH2[ED2YA@2U;800haAQ1244002Ljh2Jfd2H``2F^/2DXX2BTT2@PP2>NL2
<JH2:FD2:DD28B@26><26<<24:82488226442444020?00026><2<JH2@PP2DXX2Hb`2Jfd2Ljh2Nnl2
Q104S542Q104S542W=<2U;82S7400g>>HbaS;002Jdd4Q108Nnl2Q302S742U982U;82W=<8W?<2YA@2
W?<2YA@4W?<2W=<00iBbU9:DTP02S542Q102Ljh2DZX2>NL6>LL2<JH2<HH26<<2020E000202022442
264248824:826<<26><28@@28B@2:FD2<HH2>LL2@PP2@RP2BVT2DZX2F//2H``2Jdd2Jfd2Ljh2Nll2
Q1000haAU9:DTP02W=<2YA@4ool10001ool001Goo`03003ooooo00;oo`:me`:]M@:U50:Ld`03S764
<8@`009kc`9cSP9S;09Jj`9BZP9:J@92:08ii`8ia`8aQP8YA@8Q908Q108Hh`@@XP8@PP88H@88@@@0
80d00088H@8Q908ia`9:J@9Jb`9[C@9c[P9kc`:440:<D@:DTP:<L@:<D@:<L@:DTP:Ll`:Ld`:<D@03
JfeS;6</009[K@:4<0R440:4<0:DTP:D/PBLl`ZU50:U=0BU50BLl`:D/P03S76<DHaA00:4<0:4409c
[P9BRPXaYP8YA@8081H000030208@@Q10088@@88H@8@PP8@XP8H``8Hh`8Q108YA@8YI@8aYP8ia`92
209:B@9:J@9BZP9Jj`9S309[C@9cSP9c[P9kk`:44003S56D/YBb00:Ll`:U=0Coo`40007oo`005Ooo
00<00?ooool00_oo0[gG0Zee0ZDD0YcC00><LH@`Q3000W_?0W>>0V</0U[[0U:Z0TYY0T8X0SWW0SW7
0S660RU50R4T0R440QSS112R0Q220PQQ0PQ1100P3@000PQQ0R4T0SW70TYY0U[;0V]=0W>^0W_?0X@@
0XaA0YBB0Xaa0XaA0Xaa0YBB0Ycc0YcC0XaA00=[KF</Hb`00V]]0X@`28@@0X@`0YBB0YBb19cc2ZDD
0ZDd1:DD19cc0YBb00><LHaAS5400X@`0X@@0W>^0U::2S6V0RU50P0P5P0000<080Q124400PQ10PQQ
0Q220Q2R0QS30QSS0R440RU50RUU0S6V0SW70T880TY90TYY0U:Z0U[[0V<<0V]=0W>>0W>^0W__0X@@
00><DIBbU;800Ycc0ZDd1?oo0@000Ooo000Eool00`00ooooo`02ool2_OL2]IH2[ED2W?<00iBbS56<
D@02Q102Ljh2Jfd2H``2F//2DXX2BTT2@PP2>NL2<JH2:FD2:DD28@@26><26<<24:82488226442444
020;00024882:DD2>NL2BVT2F^/2Jdd2Ljh2Nnl2Q302S744U984S742W?<2YA@2W?<2S7400f]]Jde[
C@02Jdd2Ljh2Nll2Nnl2Q102Q302S542U982W=<2W?<<YA@2YC@4YA@2W?<2W=<2U;800haAQ1244004
Q102Ljh2F^/2<JH4<HH4<JH28B@2020F00000`0P2448@@04264248824:826<<26><28@@2:DD2:FD2
<JH2>LL2@PP2BTT2BVT2DZX2F^/2Hb`2Jdd2Lhh2Ljh2Nnl2Q3000haaU;:D/P02W?<2YC@4ool10001
ool001Goo`03003ooooo00;oo`:mm`:eUP:]E@:Ll`03U;:<DHaA00:4409c[P9[K@9S309Jb`9BRP9:
B@92208ii`8aYP8YI@8YA@8Q108Hh`8H``8@XP8@PP88H@@8@@@080/0008@PP8YA@8ii`9:J@9Jj`9[
C@9c[P9kk`:4<0:<L@BDTPB<L@:Ll`:U50:Ll`:<L@03Jfe[CF]=009[C@9c[P9kc`9kk`:440:4<0:<
D@:DTP:Ld`:Ll`bU50:U=0BU50:Ll`:Ld`:D/P03S56448@@00B4409c[P9Jj`8aYP@aQP@aYP8Q9080
81H000030208@@Q100@8H@8@PP8@XP8H``8Hh`8Q108YA@8YI@8aYP8ia`92209:B@9:J@9BZP9Jj`9S
;09[C@9cSP9c[P9kk`:4<003S76D/YBb00:Ll`:U=0Coo`40007oo`005Ooo00<00?ooool00_oo0[gg
0[Ff0ZeE0ZDD00>D/XaAS5400X@@0W>^0V]]0V</0U[[0U::0TY90T880SWW0S6V0S660RU50R4T0QSS
0QS30Q2R0Q2210QQ0PQ1100P2`000QSS0S6V0T8X0U:Z0V<<0V]]0W_?0X@`0XaA0Xaa0YBB0YBb0YcC
0ZDD0ZDd0ZDD0YcC0X@`00=[CF]]Jfd016]]0W>>0W>^0W__0X@`0Xaa0YBb0YcC0Ycc1ZDD0ZDd1ZDD
0Ycc0YcC19Bb0YBB00>4<7__Nnl00W__0W_?0W>>0TYY0S660RUU0S660S6V0RUU0P0P5P000P0P00<8
@@QQ26400PQQ0Q220Q2R0QS30QSS0R440R4T0RUU0S660SW70SWW0T8X0TYY0U::0U[;0V<<0V]=0V]]
0W>^0W_?0X@@0XaA00>DTYcCW=<00ZDD0ZeE1?oo0@000Ooo000Eool00`00ooooo`02ool2_OL2]KH2
[ED2YA@00iBbS56<D@02Q102Ljh2Jfd2Hb`2F^/2DXX2BTT2@PP2>NL2<JH2<HH2:DD28B@26><26<<2
4:82488426422444020;00026><2<JH2@RP2DZX2H``2Jfd2Nll2Q302S542S742U982U;82W=<2YA@2
YC@2YA@2W=<2Q3000f]=Jfe[K@04Jfd2Lhh2Ljh2Nnl2Q302S742U;82W=<2W?<6YA@2YC@6YA@2W?<2
W=<4U;82U9800h@`Nnmkk`02Nnl2Nll2Lhh2BVT2<HH2:FD2<HH2<JH2:FD2020F000202000`Q12648
H@02264248824:826<<26><28@@28B@2:FD2<HH2>LL2>NL2@RP2BVT2DXX2F//2H``2Jdd2Jfd2Ljh2
Nll2Q102S5400iBBW=>Ld`02YA@2[ED4ool10001ool001Goo`8000?oo`;660:me`:]M@:U5003W=><
LHaa00:4<09kc`9cSP9[C@9Jj`9BZP9:J@92:092208ia`8aQP8YI@8Q908Q108Hh`8H``8@XP8@PP88
H@@8@@8080/0008Q108ia`92:09BZP9S;09cSP9kk`:<D@B<L@:DTP:Ll`:U=0B]M@:U50:Ll`:<D@03
Lhi[CF]=009c[P9cSPA[K@9c[P9kk`:<L@:DTPBLd`:Ll`:U50:U=0:U50JLl`:Ld`RD/P03S76448@@
009kc`9c[P9cSP9:J@@aQP@ia`8Hh`8081@0008080<8@@88H@8@PP@@XP8H``8Q108Q908YA@8YI@8a
YP8ia`92209:B@9:J@9BZP9Jj`9S309[C@9cSP9c[P9kk`:4<0:<D@03U9:LdicC00:U50:]M@?oo`80
007oo`005Ooo00<00?ooool00_oo0/HH0[gG0Zee0ZDD00>LdhaaS7400X@`0W_?0W>>0V]=0U[[0U:Z
0TYY0T8X0T880SW70S660RUU0R4T0R440QSS0QS30Q2R0Q220PQQ10Q10P0P2`000R440SW70T8X0U:Z
0V</0W>>0W__0XaA18aa0YBB0Ycc0ZDd1:ee0ZDD0Ycc0XaA00=cSV]=Jdd00W>^0W>>16]]0W>^0W__
0Xaa0YBB19cC0Ycc0ZDD0ZDd0ZDD1Ycc0YcC29Bb00><LH@@Q1000W_?0W>^0W>>0TYY136613W70QSS
0P0P50000P0P0`Q10PQQ0Q22112R0QS30R440R4T0RU50RUU0S6V0SW70T880TY90TYY0U:Z0U[[0V<<
0V]=0W>>0W>^0W__0X@`0XaA00>DTYcCW=<00ZDD0Zee1?oo0@000Ooo000Eool00`00ooooo`02ool2
aSP2_OL2]IH2YC@00iccU9:DTP02S542Nnl2Ljh2Jdd2H``2F//2DXX2BTT2@PP2>NL2<JH2:FD2:DD2
8B@26><26<<24:84488226422443020:00026><2>NL2BTT2F//2Jdd2Ljh2Q102S544U982W=<2YC@6
[GD4W?<2S5400g_?LhicSP02Nnl2Nll2Jfd2Jdd2Jfd2Nnl2S746U;82W?<4YA@2W?<6W=<2U;84U985
W=<2U;82Q302Q102Nll2F^/2>NL2>LL2@PP2>LL24:82020D0002020224400`QQ488@PP0248824:82
6<<26><28@@28B@2:FD2<HH2<JH2>NL2@RP2BTT2DXX2DZX2F^/2Hb`2Jfd2Lhh2Nll2Nnl2Q302S740
0iBbW?>Ll`02YC@2[GD4ool10001ool001Goo`03003ooooo00;oo`;6>0:mm`:eUP:U=003W?>DTYBB
00:<D@9kk`9c[P9[C@9S309Jb`9BRP9:B@92208ii`8aYP8YI@8YA@8Q908Hh`8H``8@XP@@PP88H@88
@@<080X0008Hh`8ii`9:B@9Jb`9[C@9c[P:440:<D@BDTP:Ld`:U=0J]M@BLl`:<D@03NlmcSW>>009k
k`9kc`9[K@9[C@9[K@9kk`:<L@JD/P:Ll`BU50:Ll`JLd`:D/PBDTPFLd`:D/P:4<0:4409kc`9Jj`8i
i`8ia`92208ia`8@XP8081@000808088@@03264@PQ22008@PP8@XP8H``8Hh`8Q108Q908YI@8aQP8a
YP8ii`92:09:B@9BRP9BZP9Jj`9S;09[K@9cSP9kc`9kk`:4<0:<L@03U;:Llicc00:U=0:]M@Coo`40
007oo`005Ooo00<00?ooool00_oo0/iI0/HH0[Ff0Zee00>U59cCW=<00Xaa0X@`0W__0W>>0V]=0V<<
0U:Z0U::0TY90T880SW70S6V0RUU0RU50R440QSS0QS30Q2R0Q2210QQ0`Q1100P1P000Q2R0S6V0TY9
0U[;0V]]0W_?0X@@0XaA0YBB0YcC0Ycc0ZDd0ZeE0ZDd0ZeE19cc0YBB00=kkg_?Nll00W__0X@`0W_?
17>>0W__0XaA19BB0YBb0YcC1:DD0Ycc19Bb29BB0YcC0Ycc0jDd0ZDD0YBB0X@`0W>^0TYY148X0T88
0R440P0P4P000P0P10Q100<8HA2248800Q2R0QS311SS0R440RU50RUU0S660SW70SWW0T8X0TY90U::
0U[;0U[[0V</0V]]0W>>0W_?0X@@0X@`0Xaa00>D/YccW?<00ZDd0[FF1?oo0@000Ooo000Eool00`00
ooooo`02ool2cUT2aQP2]KH2[GD00jDDW=>Ld`02S742Q302Nnl2Lhh2Jdd2H``2DZX2DXX2BTT2@PP2
>LL2<JH2:FD2:DD28@@26><26<<24:82488426432444020600024:82<JH2BTT2F//2Jfd2Nll2Q102
S542U982W=<2W?<2YC@2[ED2YC@2[ED4W?<2U9800g__Nlmkc`02Nnl2Q302Nll4Lhh2Nnl2S544U982
U;82W=<4YA@2W?<4U;88U982W=<2W?<3YC@2YA@2U982Q302Ljh2BVT4@RP2@PP28@@2020B00020204
24400`QQ488@PP024:826<<46><28@@2:DD2:FD2<HH2>LL2>NL2@RP2BTT2DXX2F//2F^/2Hb`2Jfd2
Lhh2Nll2Q102Q302S7400iBbW?>Ll`02YC@2]IH4ool10001ool001Goo`03003ooooo00;oo`;>N@;6
60:me`:]M@03YCBLdicC00:DTP:<D@9kk`9c[P9[C@9S309Jb`9BRP9:B@92208ii`8aYP8aQP8YA@8Q
908Q108Hh`@@XP8@PP88H@<8@@H080@0008Hh`8ia`9:J@9S309c[P9kk`:440:<L@BLd`:Ll`:U=0BU
50:]M@:U50:Ll`:DTP03Nnmkcg_?00:<D@:<L@:4409kc`B440:<L@:DTP:D/P:Ld`:Ll`:U50BLl`:D
/PRDTP:D/P:Ld`:U5003[EF]MJee00:]E@:Ll`:<D@9S;0IBZP92:08Q9080810000@08088@@88H@03
488@XQ2R008H``@Hh`8Q108YA@8YI@8aQP8aYP8ii`92209:B@9:J@9BZP9Jj`9S;09[C@9cSP9kc`9k
k`:4<0:<L@:D/P03W?>U=:Dd00:]M@:me`Coo`40007oo`002?oo0P001?oo0P001Ooo00<00?ooool0
0_oo0/ii0/HH0[gG0Zee00>U=9cCW=<00YBB0XaA0W__0W>^0V]=0V<<0U[;0U::0TY90T880SWW0S6V
0S660RU50R4T0R440QSS112R0Q220PQQ0`Q11P0P10000QSS0SW70TYY0V<<0W>^0W__0X@@0Xaa19cC
0Ycc0ZDd1:DD0Zee0ZDD0Ycc0YBB00=kkg_?Nll00XaA0Xaa0X@@0W_?18@@0Xaa0YBB0YBb0YcC0Ycc
0ZDD19cc0YBb29BB0YBb0YcC0ZDD00>]EJee[GD00ZeE0Ycc0XaA0V</1U:Z0T8X0R4T0P0P4000100P
0PQ10PQQ00<@PQ2R4:800QS311SS0R440RU50RUU0S660S6V0SWW0T880TY90TYY0U:Z0U[[0V</0V]=
0W>>0W_?0W__0X@`0Xaa0YBb00>LljDdYC@00Zee0[gG1?oo0@000Ooo0007ool01000ooooo`000_oo
00@00?ooool000Coo`03003ooooo00;oo`;F^P;>F@;660:e]P03[EFU5:DD00:Ld`:<L@:4<09kc`9c
SP9[C@9S309BZP9BRP9:B@92208ia`8aYP8YI@8YA@8Q908Q108Hh`8H``8@XP8@PP88H@D8@@H08088
@@8aYP92:09S309c[P9kk`:4<0:DTP:Ld`:Ll`:U=0:]E@:U=0:U50:]E@:eUP:]E@:U5003U9:4<8@`
00:<D@:DTPJ<L@:<D@:<L@BD/P:Ld`:Ll`JU50:Ll`RD/PBLd`:Ll`03YCB]MJee00:eUP:]M@:U50:<
D@9c[P9cSP9[K@9Jj`8ia`88@@8080`000@08088@@88H@8@PP<@XP8H``8Hh`8Q108Q908YA@8YI@8a
QP8ia`8ii`92:09:B@9BRP9Jb`9Jj`9S;09[K@9cSP9kc`9kk`:4<0:<L@:D/P03W?>U=:Dd00:]M@:m
m`Coo`40007oo`001ooo00@00?ooool000;oo`04003ooooo0004ool20003ool2e[X2cUT2aQP2]KH0
0jeEYABU5002W=<2S742Q302Nll2Lhh2Jdd2H``2DZX2DXX2BTT2@PP2>LL2<JH2:FD2:DD28B@28@@2
6><26<<24:8248822645244602022442<JH2@RP2H``2Ljh2Nnl2Q302U982W=<2W?<2YC@2[ED2YC@2
YA@2[ED2]IH2[ED2YA@00iBBQ324<002S542U986S742S542S744U;82W=<2W?<6YA@2W?<8U;84W=<2
W?<00jDd[GF]M@02]IH2[GD2YA@2S542Ljh2Lhh2Jfd2F^/2>LL22442020<00040202244226424883
4:826<<26><28@@28B@2:DD2:FD2<HH2>LL2>NL2@RP2BTT2DXX2F//2F^/2Hb`2Jfd2Lhh2Nll2Nnl2
Q302S742U;800iccYCBU=002[GD2_OL3ool20001ool000Soo`8000?oo`04003ooooo0004ool00`00
ooooo`02ool2e[X2cUT2aQP2]KH00jeeYABU5002W=<2U982Q302Nnl2Ljh2Jdd2H``2F//2DXX2BTT2
@PP2>NL2>LL2<HH2:FD28B@28@@26><26<<24:8448800`QQ2448@@02244602024:82>NL2DZX2Jdd2
Nnl2Q302U982W=<2W?<2YA@2[ED2[GD4YA@2[GD2]KH2]IH2[GD00iccU;:D/P02W=<2U982U;82W=<6
U;84W=<4W?<2YC@2[ED2YC@2YA@2W?<6W=<2W?<4YA@00jeE]IJeUP02]KH2]IH2[ED2W?<2U982S542
Nnl2H``2<HH4020:000402022442264448800a2R6<<H``026><28@@28B@2:DD2:FD2<HH2<JH2>NL2
@RP2BTT2DXX2DZX2F^/2H``2Jdd2Lhh2Ljh2Nnl2Q302S742U982W=<00jDD[GF]M@02]KH2e[X4ool1
0001ool000Ooo`04003ooooo0002ool01000ooooo`001?oo00<00?ooool00_oo0]Jj0/iI0/HH0[Ff
00>]MJDDYA@00YcC0YBB0X@`0W__0W>^0V]=0V<<0U[;0U::0TY90T880SWW0SW70S660RUU0R4T0R44
0QSS0QS30Q2R112200<8H@Q124400PQ11P0P0Q2R0SWW0U:Z0V]=0W__0X@`0YBB0YcC0Ycc0ZDD0ZeE
0Zee1:DD0Zee0[Ff0[FF0Zee00>LliBbU;800YcC0YBB0YBb0YcC1YBb19cC19cc0ZDd0ZeE0ZDd0ZDD
0Ycc1YcC0Ycc1:DD00>]EKFF]IH00[Ff0[FF0ZeE0Ycc0YBB0XaA0W__0V<<0S66100P2P00100P0PQ1
0PQQ112200<@XQS36<<00QSS0R440R4T0RU50RUU0S660S6V0SWW0T8X0TY90U::0U:Z0U[[0V<<0V]=
0W>>0W>^0W__0X@`0Xaa0YBB0YcC00>U5:ee[GD00[Ff0]Jj1?oo0@000Ooo0007ool01000ooooo`00
0_oo00@00?ooool000Coo`03003ooooo00;oo`;Nf`;>N@;6>0:me`03]IJU=:Dd00:Ll`:D/P:<D@:4
409kc`9[K@9S;09Jj`9BZP9:J@9:B@92208ia`8aYP8aQP8YA@8Q908Q108Hh`8H``8@XP8@PP<8H@H8
@@80808H``92209Jb`9[K@:440:<L@:D/P:Ll`:U50:]E@:eUP:]M@:U50:U=0:]M@:e]P:me`:e]P03
[GFU=:Dd00:U50BLd`BU50:Ll`JU50BU=0:]E@:]M@:]E@:U=0RU50BU=0:]E@>]M@Be]P:eUP:]E@:U
50:Ld`:4<09S308YA@@080P000@08088@@@8H@8@PP8@XP036<<HhaSS008Q108Q908YA@8YI@8aQP8a
YP8ia`922092:09:J@9BRP9Jb`9S309S;09[K@9c[P9kc`:440:4<0:<L@:D/P:Ll`03YCBeU[FF00;6
60;Nn`Coo`40007oo`002?oo0P001?oo0P001Ooo00<00?ooool00_oo0]kK0/ii0/Hh0[gG00>eUZDd
YC@00Ycc0YBb0XaA0X@@0W_?0V]]0V</0U[[0U:Z0TYY0TY90T880SW70S6V0S660RU50R4T0R440QSS
0QS30Q2R0Q220`QQ1PQ10P0P0QS30T880U[;0V]]0X@@0Xaa0YBb0Ycc0ZDD0ZeE0[FF0Zee0ZDD0ZDd
0Zee0[Ff0[gG0[Ff00>]MJDdYC@00ZDD19cC1:DD0Ycc1ZDD1:Dd0ZeE0Zee0ZeE0ZDd2:DD1:Dd0ZeE
0jee1;Ff0[FF0ZeE0ZDD0YcC0X@`0V<<0RU5100P2000100P0PQ110QQ0Q220Q2R00<H`aSS6><00R44
0R4T0RU50RUU0S660S6V0SW70T880T8X0TYY0U::0U[;0V<<0V</0V]]0W>^0W_?0X@@0X@`0Xaa0YBb
0Ycc00>U=;FF]IH00/HH0]kk1?oo0@000Ooo000Eool00`00ooooo`02ool2ia`2e[X2cUT2_OL00kFf
[GF]M@02YA@2W=<2S742Q302Nnl2Lhh2Jdd2H``2F//2DXX2BVT2@RP2@PP2>LL2<HH2:FD2:DD28B@2
8@@46<<24:800a222648H@02264624426><2@PP2DXX2Jfd2Q102U982W=<2YA@2YC@2[GD2]IH2[GD2
YC@4[ED2[GD2]KH2_ML00kFf]IJeUP02[ED2YA@2W?<2YC@4[ED2[GD4[ED6[GD2]IH2[GD2[ED4YC@6
[ED2[GD5]IH4]KH2]IH2[ED2YA@2U;82Q102F//26><60202000602042442264248824:826<<36><2
8@@28B@2:FD2<HH2<JH2>LL2>NL2@RP2BTT2DXX2DZX2F^/2Hb`2Jdd2Lhh2Ljh2Nnl2Q302S542U982
W=<2YA@00jee]KJe]P02eYX2ia`4ool10001ool001Goo`03003ooooo00;oo`;W70;F^P;>F@:mm`03
]KJ]MJee00:U50:Ld`:<L@:4<09kk`9cSP9[C@9S309Jb`9BRP9:J@92:092208ia`8aQP8YI@8YA@8Q
908Q10@H``8@XP034888H@QQ0088H@H8@@8Hh`92209BRP9[K@:440:DTP:Ld`:U50:U=0:]M@:eUP:]
M@:U=0B]E@:]M@:e]P:me`03]KJeU[FF00:]E@:U50:Ll`:U=0B]E@:]M@B]E@J]M@:eUP:]M@:]E@BU
=0J]E@:]M@FeUPBe]P:eUP:]E@:U50:D/P:4409Jb`8Hh`H0808000H080@8@@88H@8@PP8@XP8H``<H
h`8Q108Q908YI@8aQP8aYP8ia`8ii`92:09:B@9BRP9BZP9Jj`9S;09[C@9cSP9c[P9kk`:4<0:<D@:D
TP:Ld`:U5003[GFe][Ff00;FVP;W70Coo`40007oo`005Ooo00<00?ooool00_oo0^Ll0]kK0/ii0/Hh
00>mekFF]IH00ZDd0Ycc0YBb0XaA0X@@0W_?0W>>0V</0V<<0U[;0U::0TY90T8X0SWW0S6V0S660RUU
0RU50R440QSS0QS30a2R0Q2210QQ10Q10QSS0SWW0U::0V]]0X@`0YBb0Ycc0ZDD0ZDd1;FF0Zee2:eE
0Zee0[FF0kgG0[FF1:eE0ZDd0ZeE0[FF1;Ff2;FF0[Ff0[FF0Zee1:eE1:ee0[FF2KFf0[FF0Zee0ZDd
0Ycc0YBB0W_?0TY90PQQ300P0PQ110QQ0Q220Q2R11S300<Hhb448@@00R4T0RU50RUU0S660S6V0SWW
0T880TY90TYY0U:Z0U[;0V<<0V</0V]]0W>^0W_?0X@@0X@`0Xaa0YBb0Ycc0ZDd00>eU[gg_OL00]kK
0^LL1?oo0@000Ooo000Eool00`00ooooo`02ool2ic`2g]/2cWT2aSP00kgG]IJeUP02YC@2W?<2U;82
S542Q102Nll2Lhh2Hb`2H``2F//2DXX2BTT2@RP2>NL2<JH2<HH2:FD2:DD28@@26><26<<34:824884
264424426><2>NL2DXX2Jfd2Q302U;82W?<2YA@2YC@4]IH2[GD8[ED2[GD2]IH3_ML2]IH4[ED2YC@2
[ED2]IH4]KH8]IH2]KH2]IH2[GD4[ED4[GD2]IH9]KH2]IH2[GD2YC@2W?<2U982Nll2BTT2264<0202
2444264248824:846<<00aSS8@@Q10028B@2:DD2:FD2<HH2<JH2>NL2@PP2BTT2BVT2DZX2F//2H``2
Hb`2Jfd2Ljh2Nll2Q102Q302S742U;82W?<2YC@00kFF_ONmm`02g]/2ia`4ool10001ool001Goo`03
003ooooo00;oo`;g_P;W70;FVP;>F@03_ONe][Ff00:]M@:U50:Ld`:DTP:<D@9kk`9c[P9[K@9S;09J
j`9BZP9:J@9:B@92208ia`8aYP8aQP8YI@8Q908Q108Hh`<H``8@XP@@PP@8H@8Hh`92209Jj`9c[P:4
<0:D/P:Ll`:U50:U=0JeUPZ]M@:eUP03]KJmmkgg00:me`:e]P:eUPB]M@:e]PBme`Je]PBme`:e]PJe
UPJe]PNme`:e]P:eUP:]E@:U50:Ld`:<D@9cSP8ii`@8@@@080H8@@@8H@8@PP@@XP8H``8Hh`038@@Q
924T008YA@8YI@8aQP8aYP8ia`8ii`92:09:J@9BRP9BZP9Jj`9S;09[C@9cSP9c[P9kk`:4<0:<D@:D
TP:Ld`:U50:]E@03]KK>NLii00CNn`Coo`40007oo`005Ooo0P001Ooo0^Ll0]kK0/ii00?6>;gG_ML0
0[FF0ZDd0Ycc0YBb0Xaa0X@`0W_?0W>>0V]=0V<<0U[;0U:Z0TYY0T8X0T880SW70S6V0S660RU50R4T
0R440QSS0aS30Q2R1Q220R440TY90V<<0W>>0X@`0YBb0Ycc0ZDd0ZeE1;FF1;Ff1;FF1[Ff00>eU[gG
_ML01;gG1[FF0[Ff0[gG0[Ff3;gG2;Ff1;gG1Kgg0[gG0[Ff0[FF0ZeE0Ycc0YBb0X@`0V]=0S6630Q1
10QQ0Q22112R0QS30QSS0R4400<Q92U5:DD012UU0S6V0SW70SWW0T880TY90TYY0U:Z0U[[0V<<0V]=
0V]]0W>^0W_?0X@@0XaA0Xaa0YBb0Ycc0ZDd0[FF00>mmmkKg]/00^LL0]kk0ooo0P000Ooo000Eool0
0`00ooooo`04ool2ic`2g]/2cWT00lHh_MNme`02]IH2YC@2W?<2U;82S742Q302Nll2Lhh2Jdd2H``2
F//2DZX2BVT2@RP2@PP2>LL2<JH2<HH2:DD28B@28@@26><36<<24:8648828@@2BTT2H``2Lhh2Q302
U;82W?<2YC@2[ED4]IH4]KH4]IH6]KH00kFF_MNme`04_ML6]IH2]KH2_ML2]KH<_ML8]KH4_ML5_OL2
_ML2]KH2]IH2[ED2W?<2U;82Q302Jdd2<HH<2444264248844:826<<26><28@@00b4T:DDYA@04:FD2
<JH2>LL2>NL2@PP2BTT2BVT2DZX2F^/2H``2Jdd2Jfd2Ljh2Nll2Q102S542S742U;82W?<2YC@2]IH0
0kggg]_Nf`02ia`2g_/4ool10001ool001Goo`03003ooooo00;oo`Cog`;W70;F^P03cWW66<HH00:e
]P:]M@:U=0:Ll`:D/P:<L@:4409kc`9cSP9[C@9S309Jb`9BRP9:J@92:092208ia`8aYP8aQP8YI@8Y
A@8Q90<Hh`8H``H@XP8Q1092:09Jb`9cSP:440:<L@:Ll`:U50:]M@BeUP:e]P:me`Re]P:]M@03[EF]
MJee00:eUPBe]PJ]M@:eUP:e]P:mm`:me`Rmm`Zme`Vmm`:me`:eUP:]E@:Ll`:DTP:4<09[C@8ia`88
H@H8@@H8H@8@PP@@XP8H``8Hh`@Q10038B@YABU5008YI@8aQP8aYP8ia`922092:09:J@9BRP9Jb`9J
j`9S;09[C@9cSP9c[P9kk`:440:<D@:DTP:Ld`:U50:]E@:eUP03aSSNnmkk00CNn`Coo`40007oo`00
5Ooo00<00?ooool00_oo1?oO0^LL0]Jj00?>NLHHaQP00[Ff0Zee0ZDd0Ycc0YBb0Xaa0X@@0W_?0W>>
0V]=0V<<0U[;0U::0TYY0T8X0T880SW70S6V0S660RUU0RU50R4T0aSS0QS31Q2R0R440T8X0U[;0W>>
0X@@0Xaa0Ycc0ZDD0Zee1;FF0[Ff0[gG2;Ff0Zee00>]EJee[GD00[FF1;Ff1Zee0[FF0[Ff0[gg0[gG
2;gg2[gG2Kgg0[gG0[FF0ZeE0Ycc0YBB0X@`0V]=0SW70PQQ1PQ11PQQ0Q22112R0QS30QSS124400<Q
92U5:DD00RUU0S660S6V0SW70T880T8X0TYY0U::0U[;0U[[0V</0V]=0W>>0W>^0W__0X@@0XaA0YBB
0YcC0ZDD0ZeE0[FF00?6>=kkg_/01=kk1?oo0@000Ooo000Eool00`00ooooo`02ool2mih2ool2ic`2
g]/00liiaSS6>002_ML2]IH2[ED2YA@2W=<2S742Q302Nnl2Ljh2Jfd2Hb`2F^/2DZX2DXX2BTT2@RP2
>NL2>LL2<JH4:FD38B@46><26<<44:82<HH2BVT2Hb`2Nll2Q302U;82W?<2YC@2[GD4]IH4_ML4_OL2
_ML2]IH5[GD2[ED2[GD2]IH2[GD4[ED2]IH6_ML:_OL2_ML:_OL3aQP2_OL2_ML2]IH2[ED2W?<2S742
Nll2F//26><:264448824:846<<26><28@@48B@00bU5:FDYI@02<HH2<JH2>NL2@PP2@RP2BTT2DXX2
DZX2F^/2Hb`2Jdd2Lhh2Ljh2Nnl2Q102S542U982U;82W?<2YC@2]IH2aQP00mkKg__Nn`04g_/4ool1
0001ool001Goo`03003ooooo00;oo`;gWP;oo`;W?0;Nf`03cWW6><Hh00:me`:eUP:]E@:U50:Ld`:<
L@:4<09kk`9c[P9[K@9S;09Jj`9BZP9BRP9:B@92:08ii`8ia`8aYP@YI@<Q90@Hh`8H``@@XP8aQP9:
J@9S;09kc`:4<0:D/P:Ll`:U=0:]M@BeUPBme`Bmm`:me`:eUPF]M@:]E@:]M@:eUP:]M@B]E@:eUPJm
e`Zmm`:me`Zmm`?660:mm`:me`:eUP:]E@:Ll`:<L@9kc`9Jb`8Hh`X8H@@@PP8@XP@H``8Hh`8Q10@Q
9003:DDYIBUU008aQP8aYP8ii`922092:09:B@9BRP9BZP9Jj`9S;09[C@9cSP9c[P9kk`:440:<D@:D
TP:D/P:Ll`:U=0:eUP;66003g]_Nnmkk00CNn`Coo`40007oo`005Ooo00<00?ooool00_oo0]JJ0_oo
0_Nn0^LL00?F^/iIcUT00/HH0[Ff0Zee0ZDd0Ycc0YBb0Xaa0X@`0W_?0W>>0V]=0V<<0U[[0U:Z0TYY
0TY90T8X0SWW0SW70S6V0S660RUU00<YAB4T8B@00R440QSS11S30S660TYY0V</0W_?0XaA0YBb0Ycc
0ZDd0Zee0[FF0[Ff1[gG0[gg0[gG1;Ff0kFF0Zee0ZeE2:ee1[Ff0[gG4;gg2LHH0[gg0[gG0[FF0ZeE
0Ycc0Xaa0W>^0U::0Q2R1PQQ1Q220Q2R11S30QSS0R44124T0RU500<YIC66<HH00S6V0SW70SWW0T8X
0TY90TYY0U:Z0U[;0V<<0V]=0V]]0W>^0W_?0X@@0X@`0Xaa0YBB0YcC0ZDd0Zee0[Ff0]JJ1Mkk0]kK
1?oo0@000Ooo000Eool00`00ooooo`02ool2eYX2ool2mkh2ia`00mJjcUW>F@02aQP2]KH2[GD2YC@2
W?<2U;82S742Q302Nll2Lhh2Jdd2H``2F^/2DZX2BVT2BTT2@RP2>NL2>LL2<JH2<HH2:FD00bU58B@Q
90028@@26><46<<2<HH2BVT2Hb`2Nll2S542U;82W?<2YC@2[GD2]IH2]KH6_ML2_OL2_ML4]KH3]IH2
[GD2[ED8[GD6]KH2_ML@_OL9aQP2_OL2_ML2]IH2[ED2W?<2S742Ljh2DXX24:86264648824:846<<2
6><28@@48B@2:DD00bUU<HHaQP02<JH2>LL2>NL2@RP2BTT2BVT2DZX2F//2H``2Jdd2Jfd2Ljh2Nll2
Q102Q302S742U982W=<2YC@2[GD2]KH2eYX5g_/2g]/4ool10001ool001Goo`03003ooooo00;oo`:U
50;W70;og`;gWP03g__FV]JJ00;>F@:mm`:e]P:]M@:U50:Ll`:D/P:<L@:4<09kc`9cSP9[C@9S309J
j`9BZP9:J@9:B@92:092208ia`8aYP8aQP03:FDYABU5008Q908Q10@Hh`8Q1092209Jj`9c[P:<D@:D
/P:Ll`:U=0:]E@:eUP:e]P:me`:mm`:me`Be]P;660:mm`03_MNe][Ff00:e]P:eUP:]M@:eUP:e]P:e
UPJe]P:mea2mm`S660>mm`:me`:e]P:]M@:U50:DTP9kc`9BRP8@XPH@PPH@XP@H``8Hh`@Q108Q908Y
A@8YI@03<HHaYS6V008ia`8ii`922092:09:J@9BRP9Jb`9Jj`9S;09[K@9cSP9c[P9kk`:440:<D@:<
L@:D/P:Ll`:U=0:]M@:mm`;Nf`GNn`;W70Coo`40007oo`005Ooo00<00?ooool00_oo0ZDD0^LL0_oO
0_NN00?NnmJJeYX00/iI0[gg0[Ff0Zee0ZDD0Ycc0YBb0Xaa0X@`0W_?0W>>0V]=0V<<0U[[0U:Z0TYY
0TY90T8X0T880SW70S6V0S6600<YIBU5:DD00R4T0R4411SS0R440T880U[[0W>^0XaA0YBb0Ycc0ZDd
0ZeE0[FF0[Ff0[gG0[gg0[gG1;Ff0/HH0[gg00>mekFf]KH00[Ff0[FF0Zee0[FF0[Ff0[FF1[Ff0[gG
4;gg2<HH0kgg0[gG0[Ff0Zee0ZDD0YBB0W_?0U::0Q2R1Q221Q2R11S30QSS12440R4T0RU50RUU00<a
QS6V<JH00SW70SWW0T880T8X0TYY0U::0U[;0U[[0V</0V]]0W>>0W>^0W__0X@@0XaA0Xaa0YBb0Ycc
0ZDd0Zee0[gg0]kK1Mkk0^LL1?oo0@000Ooo000Eool20003ool2S742cWT2mkh2oml00nLLe[[F^P02
cUT2aQP2_ML2[GD2YC@2YA@2W=<2U982S542Nnl2Ljh2Jfd2Hb`2H``2F//2DZX2BVT2BTT2@RP2@PP2
>LL2<JH00c66:FDYI@02:DD28B@28@@26><28@@2@RP2F//2Nll2S542U982YA@2YC@2[ED2]IH2]KH4
_OL2]KH2[GD2]KH4aSP00lHH_ONmm`04_OL6_ML4]KH2_ML6_OL2aQP<_OL4aQP5_OL2_ML2]KH2]IH2
[ED2W=<2Q302Hb`2:DD648844:846<<26><48@@28B@2:DD4:FD2<HH00c6V>LLia`02>NL2@PP2@RP2
BVT2DXX2F//2F^/2Hb`2Lhh2Q104Nnl2Q102S542S742U;82W?<2YC@2[GD2_ML2e[X5g_/2g]/2ic`3
ool20001ool001Goo`03003ooooo00;oo`:<L@;>N@;g_P;og`03iacF^]Jj00;>F@;660:me`:]M@:U
=0:U50:Ld`:DTP:<D@9kk`9c[P9[K@9S;09S309Jb`9BZP9:J@9:B@92:092208ia`8aYP03<HHYIBUU
008YA@8Q908Q108Hh`8Q1092:09Jb`9kc`:<D@:DTP:U50:U=0:]E@:eUP:e]PBmm`:e]P:]M@:e]PC6
>003aQRmmkgg00Bmm`Jme`Be]P:me`Jmm`;660bmm`C660Fmm`:me`:e]P:eUP:]E@:Ld`:4<09S;08Y
A@H@PP@@XP@H``8Hh`@Q108Q908YA@@YI@8aQP03<JHiacW7008ii`922092:09:J@9BRP9Jb`9Jj`9S
;09cSP:440Akk`:440:<D@:<L@:D/P:Ll`:U=0:]M@:me`;F^PGNn`;Nf`;W?0Coo`40007oo`005Ooo
00<00?ooool00_oo0V<<0ZDd0^LL0_Nn00?_OMkkg_/00]JJ0/Hh0[gg0[Ff0Zee0ZDd1ZDD0XaA0W__
0W>^0V]]0V</0U[[0U[;0U::0TYY0TY90T8X0T880SW700<aYS66<HH00RUU0RU50R4T0R440R4T0T88
0U[;0W>^0X@@0Xaa0Ycc0ZDd0ZeE0[Ff0[gG1;gg0[Ff0Zee0[gG1lHh1<HH0[gg1<HH0[gG0[Ff0[gG
0[gg0/HH5[gg1KgG0[Ff0[FF0ZDd0YBB0W_?0TYY0QS31Q2R11S311SS12440R4T0RU512UU0S660S6V
00<iacWW>NL00T880T8X0TYY0U::0U:Z0U[[0V<<0V]=0W>^0Xaa0YBb18aA0Xaa0YcC0Ycc0ZDD0ZeE
0[FF0/iI1mkk0^mM0/ii1?oo0@000Ooo000Eool00`00ooooo`02ool2H``2YC@2ia`2mkh00nmmg__N
n`02eYX2aSP2_OL2]KH2[GD2YC@6YA@2S542Nnl2Ljh2Jfd2Hb`2F^/2F//2DXX2BVT2BTT2@RP2@PP2
>LL00c6V<HHaQP02:FD2:DD28B@28@@28B@2@PP2F//2Ljh2Q102S742W?<2YC@2[ED2]KH2_ML4_OL2
]KH2[GD2_ML7aSP4aQP2_OL4aQP2_ML2]KH2_ML2_OL2aQPF_OL5_ML2]KH2]IH2YC@2U982Nll2BVT2
6<<64:846<<46><48@@28B@2:DD4:FD2<HH2<JH00cW7>NLii`02@PP2@RP2BVT2DXX2DZX2F^/2H``2
Jdd2Ljh2S742U;84S542S742W=<2W?<2YA@2[ED2]IH2cUT7g_/2ked2cWT4ool10001ool001Goo`03
003ooooo00;oo`8aYP9kk`:mm`?g_P;W?0;F^P;>N@;660:mm`:e]P:]M@:eUP:e]P:Ll`:<L@:4409k
c`9cSP9[K@9S;09Jj`9Jb`9BZP9:J@9:B@92:0922003>NLiacW7008aQP8YI@8YA@@Q908ii`9BZP9[
K@9kc`:<D@:DTP:Ll`:U=0:eUP:me`:mm`;660:mm`:me`Bmm`?6>0C660Bmm`C660:mm`:e]P:me`Zm
ma2me`Fe]P:eUP:]M@:Ll`:4<09S;08aQP8@XPHH``@Hh`@Q108Q90@YA@8YI@@aQP8aYP8ia`03>NM2
24880092:09:B@9BRP9BZP9Jb`9S309S;09[K@9c[P9kk`:DTP:U50:Ld`:U50:eUP:]E@:U=0:]M@;6
60;Nf`GNn`;W70;W?0:D/PCoo`40007oo`005Ooo00<00?ooool00_oo0S6V0W__0[gg0oNn0^Ll0]Jj
0/ii0/HH0[gg0[Ff0Zee0[FF0[Ff0Ycc0Xaa0X@@0W_?0W>>0V]]0V</0U[[0U[;0U:Z0TYY0TY90T8X
0T8800<iicW7>LL00S660RUU0RU5124T0SWW0U:Z0V]]0W_?0XaA0YBB0Ycc0ZDd0[FF0[gG0[gg0/HH
0[gg0[gG1;gg0lHh1<HH1;gg1<HH0[gg0[Ff0[gG2[gg4;gG1KFf0[FF0Zee0Ycc0X@`0V</0S660Q2R
1QS311SS12440R4T12U50RUU13660S6V0SW700<iid88@PP00T8X0TY90U::0U:Z0U[;0V<<0V</0V]]
0W>^0W__0YBB0ZDD0YcC0ZDD0[FF0ZeE0ZDd0Zee0/HH0]kK1Mkk0^LL0^Ll0YBb1?oo0@000Ooo000E
ool00`00ooooo`02ool20002DXX2W=<2eYX00ooOmkkg_P02g_/2eYX2cUT2aQP2_ML2_OL2aQP2[GD2
W=<2U982S542Q102Nll2Lhh2Jdd2Hb`2F^/2F//2DZX2BVT2BTT2@RP00d88>NLii`02>LL2<HH2:FD4
:DD2>LL2DXX2Hb`2Lhh2Q302S542U;82YC@2]KH2_ML2_OL6aQP2_ML2]KH2aQP00lHhaQS66008_OL4
aQP2_OL2_ML4_OL6_ML@]KH5]IH2[GD2YA@2S742Lhh2DXX28B@66<<46><28@@48B@2:DD4:FD2<HH4
<JH4>NL00d88@RQ2:002BTT2DXX2DZX2F//2H``2Hb`2Jfd2Lhh2Nll2Nnl2Q302W=<2[GD4]KH2YC@2
[GD2]KH2eYX6g_/00mkKkeg_G@02_OL2F//4ool10001ool001Goo`03003ooooo00;oo`80009BRP:L
d`;FVP03omog__Nn00;Nn`;FVP;>F@;660:me`:mm`;660:]M@:Ld`:DTP:<D@:4409kc`9cSP9[C@9S
;09Jj`9Jb`9BZP9:J@9:B@92:003@PPiicWW008ia`8aQP8YI@@YA@8ia`9BRP9S;09cSP:4<0:<D@:D
/P:U=0:e]P:me`:mm`K660:me`:e]P;66003aSS66<HH00Rmm`C660:mm`:me`Bmm`Jmea2e]PFeUP:]
M@:U50:<L@9cSP9BRP8Q90HH``@Hh`8Q10@Q908YA@@YI@8aQP@aYP@ii`03@PQ2:48X009:B@9BRP9B
ZP9Jb`9S309S;09[K@9cSP9kc`9kk`:4<0:Ld`:]M@Be]P:U=0:]M@:e]P;FVPKNn`03g]__GNmM00:m
m`9Jb`Coo`40007oo`005Ooo00<00?ooool00_oo0P000PQQ0U[;0Ycc00?NfooOoml00_NN0]kk0]JJ
1<iI0]JJ0/HH0ZeE0ZDD0YcC0YBb0YcC0X@`0W_?0W>>0V]]0V</0V<<0U[[0U:Z0U::0TYY00=:BD88
@PP00SWW0SW70S6V12UU0RU50T880U[[0V]]0W>^0X@`0Xaa0ZDD0[FF0[gG0[gg1/HH0[gG1;Ff0lHH
0[gg1;gG1;gg1/HH0[gg0[gG2;Ff0[FF1:ee0[FF2Jee0ZeE0ZDD0YBb0X@@0V]=0TY90S660R4411SS
12440R4T12U50RUU13660S6V0SW713WW0T8800=2:4Y9BTT00U::0U:Z0U[;0U[[0V</0V]=0V]]0W>^
0W_?0X@@0X@`0YBB0ZeE0[gG0ZDd0ZeE0[FF0/HH0]kK1=kk0]kK00?W7>Llic`00Ycc0S661?oo0@00
0Ooo000Eool00`00ooooo`02ool200022642F//2W?<00mkKomoog`02mih2g_/2eYX4cUT2eYX2aQP2
[ED2YA@2W=<2U;82W=<2Q302Nll2Lhh2Jfd2Hb`2H``2F^/2DZX2DXX2BVT00dY9@PQ22002>NL2>LL2
<JH4:FD2:DD2@PP2F^/2Jfd2Ljh2Q302S742YA@2]IH2_ML2_OL6aQP2_ML4]KH3aQP2_OL4_ML4_OL6
aQP2_OL2_ML8]KH2]IH4[GD2]IH9[GD2[ED2YA@2U;82Q102Jdd2BTT2<HH28@@46><48@@28B@4:DD2
:FD4<HH2<JH2>LL4>NL2@PP00d8XBTU:B@02DXX2DZX2F//2F^/2Hb`2Jdd2Jfd2Ljh2Nll2Q102Q302
U982[ED2_ML2YC@2[ED2]IH2aQP2g]/4g_/2g]/00nLLiccW?002W?<2<HH4ool10001ool001Goo`80
00?oo`@0008YA@9c[P03]IK_GNmM00;og`;_G@;Nf`C>N@;>F@:e]P:]M@:]E@:U=0:]M@:]E@:<D@:4
409kc`9cSP9[K@9[C@9S309Jj`9Jb`9BRP03BVU:BDY90092208ii`8ia`8aYP8aQP8YI@8aYP9BZP9S
;09cSP9kk`:<L@:Ll`:]M@:eUP:me`:mm`;660:mm`BeUP:me`?660Jmm`S660:mm`:me`:eUPZ]M@:]
E@fU=0:Ll`:D/P:4<09c[P9S;09:B@8ia`8aYP8YA@8Q10@Q90@YA@8YI@8aQP@aYP8ia`8ii`9220A2
:003BTU:JDYY009BZP9Jb`9Jj`9S;09[C@9cSP9c[P9kc`9kk`:4<0:<L@:Ld`:e]P:]M@:U=0:]M@:m
e`;F^PCNn`CNf`03kefmmkgg009S308000?oo`80007oo`005Ooo00<00?ooool00_oo10000RU50W>^
00>eU^mMked00_oO0^mM0]kK1<ii0/iI0[Ff0Zee0ZeE0ZDd0Zee0ZeE0XaA0X@@0W_?0W>>0V]]0V]=
0V<<0U[[0U[;0U::00=:JDY9BTT00T880SWW0SW70S6V0S660RUU0S6V0U:Z0V</0W>>0W__0Xaa0Ycc
0Zee0[FF0[gG0[gg0/HH0[gg1;FF0[gG0lHH1[gg2<HH0[gg0[gG0[FF2Zee0ZeE3JDd0Ycc0YBb0X@`
0W>^0V</0TY90SW70S6V0RU50R44124T12U50RUU0S66136V0SW70SWW0T88148X00=:BDYYBVT00U:Z
0U[;0U[[0V</0V]=0W>>0W>^0W_?0W__0X@`0Xaa0YcC0[Ff0Zee0ZDd0Zee0[gG0]Jj1=kk1=kK00?_
GKgg_OL00V<<0P001?oo0@000Ooo000Eool00`00ooooo`02ool60002@PP00haAaSS6>002kgd2oml2
ia`2e[X2cWT2aSP2_OL2]KH2]IH2_OL2_ML2W?<2U982S542Q102Nll2Ljh2Jfd2Jdd2H``2F^/2F//0
0e::BVU:J@02BTT2@PP2>NL2>LL2<JH4<HH2BTT2F//2Hb`2Ljh2Q302U;82W?<2YC@2[GD2]KH2_ML2
]KH2]IH2]KH2_OL00lHH_ONmm`02_ML2_OL:aQP2_OL2_ML2[GD2YC@2YA@6YC@6YA@2W=<6W?<00icC
U9:DTP02Q302Nll2Lhh2Jdd2F//2BVT2@PP2>NL2:FD4:DD2:FD4<HH2<JH4>LL2>NL2@PP2@RP2BTT2
BVT00e::DZYBZP02F//2F^/2Hb`2Lhh2Q102Q304Nnl2Q302S542U982W=<2[ED2YA@2[ED2]KH2cWT6
g_/2g]/2ic`00mJJQ124400226420004ool10001ool001Goo`03003ooooo00;oo`H000922003S576
><Hh00;_O@;og`;W70;F^P;>N@;6>0:mm`:e]P:eUP:mm`:me`:Ll`:DTP:<D@:4409kc`9c[P9[K@9[
C@9S309Jj`9Jb`03DXY:JDYY009:B@92208ii`8ia`8aYP@aQP9:B@9Jb`9S;09c[P:4<0:D/P:Ll`:U
=0:]M@:e]P:me`:e]P:eUP:e]P:mm`03aQRmmkgg00:me`:mm`[660:mm`:me`:]M@:U=0:U50JU=0JU
50:Ld`JLl`03W=>DTYBB00:4<09kc`9cSP9[C@9Jb`9:J@92208ii`8YI@@YA@8YI@@aQP8aYP@ia`8i
i`922092:09:B@9:J@03DXYBZU:Z009Jb`9Jj`9S;09cSP:440:4<0Akk`:4<0:<D@:DTP:Ld`:]E@:U
50:]E@:e]P;>N@KNn`;Nf`;W?003eYZ448@@0088H@8000Coo`40007oo`005Ooo00<00?ooool00_oo
1P000R4400=[KJee[GD00^LL0_oO0_NN0]kK0]JJ0/Hh0/HH0[gg0/ii0/iI0[gG0Zee0ZeE0ZDD0YBb
0W__0W_?0W>>0V]]0V</0V<<0U[[00=BZU::DXX00TY90T8X0T880SWW0S6V13660SWW0U::0U[[0V]=
0W__0Xaa0YcC1:DD0ZeE1[Ff0[gG0/HH00>mmkgG_ML01;gg2<HH0[gg0[gG0[FF0ZDD1Ycc0ZDD0Ycc
0YcC0Ycc19cC0YBB0YBb0YBB00><LHaAS5400X@@0W__0W>^0V]]0V]=0U[;0TY90T8X0S6V0RUU1366
136V0SW70SWW14880T8X0TY90TYY0U::00=BZU[;F//00V<<0V</0W>^18aA0YBb0XaA0X@`0XaA0YBB
0YBb0Ycc0ZDD0ZeE0[Ff0/ii1]kk0]kK0^Ll0]kK00>4<1S36<<010001?oo0@000Ooo000Eool00`00
ooooo`02ool600028@@00f]][GF]M@02ia`2oml2mih2g]/2eYX2aSP2aQP2_OL2cWT2cUT2_ML2[GD2
[ED2YA@2U;82Nnl2Nll2Lhh2Jfd2Hb`2H``2F^/00e:ZDXYBRP02BTT2@RP2@PP2>NL2<JH4<HH2>NL2
DXX2F^/2Jdd2Nnl2S742W=<4YA@2[ED6]KH2_ML2aQP00kgg_MNme`04_OL8aQP2_OL2_ML2]IH2YA@6
W?<2YA@2W?<2W=<2W?<4W=<2U982U;82U9800haaS56<D@02Q102Nnl2Ljh2Jfd2Jdd2F//2BTT2@RP2
<JH2:FD4<HH4<JH2>LL2>NL4@PP2@RP2BTT2BVT2DXX00e:ZF/]Jb`02H``2Hb`2Ljh4S542U;82S542
Q302S542U982U;82W?<2YA@2[ED2]KH2cWT6g_/2g]/2ic`2g]/00h@`6<<H``040004ool10001ool0
01Goo`03003ooooo00;oo`P00003>NN448@@00:mm`;_G@;og`;_G@;F^P;>N@;6>0;FVP;Nf`;FVP;6
60:me`Be]P:U50:4<09kk`9kc`9cSP9[K@9S;09S3003F/]BZU:Z009BRP9:B@92:08ii`8ia`@aYP8a
QP8ia`9:J@9Jj`9[K@:4<0:DTP:Ld`:Ll`:Ld`:]M@:eUP:e]P:me`:mm`>me`Zmm`:me`BeUP:]E@:L
d`JD/PBLd`:DTPBD/PJ<L@:DTPF<L@:<D@B4409kc`9S309BRP9:B@8ii`8aQP@aYP8ia`@ii`922092
:09:B@A:J@9BRP9BZP03F/]S36<<009S;09[K@:440:4<09kk`:Ll`:DTP:<D@:<L@:D/P:Ld`:U50:]
E@:]M@;>F@KNn`;Nf`CW70:Ll`03>NL0800P00@000Coo`40007oo`0000?oo`0000000P000ooo0P00
1?oo0P001Ooo00<00?ooool00_oo200000<iih@@Q1000[gg0^mM0_oO0^mM0]Jj0/ii0/Hh0]JJ0]kK
0]JJ0/HH0[gG1;Ff0ZDD0X@`0W__0W_?0W>>0V]]0V</0V<<00=Jbe:ZDZX00U::0TY90T8X0SWW0SW7
136V0S660SW70TYY0U[[0V]]0X@`0YBB0YcC0Ycc0YcC0Zee0[FF0[Ff0[gG0[gg0kgG2[gg0[gG1;FF
0ZeE0YcC1YBb19cC0YBB19Bb1Xaa0YBB1Haa0XaA18@@0W_?0V<<0U::0TY90SWW0S66136V0SW713WW
0T880T8X0TY914YY0U::0U:Z00=Jbf<<H``00V</0V]]0X@@0X@`0W__0Ycc0YBB0XaA0Xaa0YBb0YcC
0ZDD0ZeE0Zee0/iI1]kk0]kK1>LL0Ycc00<ii`0P020010001?oo0@000Ooo0003ool01@00oooooooo
00000_oo00@00?ooool000;oo`03003ooooo00;oo`03003ooooo00;oo`T0009220:440:mm`;_G@;o
g`;_O@;F^P;>N@;6>0;660:me`:eUP:]M@Bme`:D/P:<L@:4<09kk`9kc`9c[P9[K@9S;003H`aJje[[
009BZP9BRP9:B@92:092208ii`8ia`8aYP8aQP8ia`9:B@9Jb`9cSP:<D@:DTPBD/P:Ld`:]E@Be]P>m
m`:me`Jmm`Jme`:eUP:]E@:U=0:Ll`R<L@BD/P:DTP:D/P:<D@:4<0:<D@:DTP>D/PBLd`:D/P:DTP:<
D@9[K@9Jb`9BZP92:08aYP@ia`@ii`922092:09:B@A:J@9BZPAJb`03H`aS;6</009[C@9[K@9kk`:4
<0:440:Ll`:Ld`:DTP:D/P:Ld`:Ll`:U=0:]E@:mm`;F^PKNn`;Nf`;W?0;6>09cSP030200000000@0
00Coo`40007oo`000ooo00D00?ooooooo`0000;oo`04003ooooo0002ool00`00ooooo`02ool20003
ool90002@PP2Q102_OL2ked2oml2kgd2e[X2cWT2aSP2aQP2_ML2]IH2[GD4_ML2U;82S742Q302Nnl2
Nll2Ljh2Jfd2Hb`00f<<F^]Jj`02DZX2DXX2BTT2@RP2@PP2>NL2>LL2<JH2<HH2>LL2BTT2F//2Lhh2
S542U984U;82W=<2[ED4]KH3_OL2_ML6_OL6_ML2]IH2[ED2YC@2W?<8S744U;82U982U;82S542Q302
S542U983U;84W=<2U;82U982S542Jfd2F//2DZX2@RP2<JH4>LL4>NL2@PP2@RP2BTT4BVT2DZX4F//0
0f<<HbaS;002Jdd2Jfd2Nnl2Q302Q102W?<2W=<2U982U;82W=<2W?<2YC@2[ED2_OL2e[X6g_/2g]/2
ic`2aSP2Lhh00`0P000000040003ool20001ool000?oo`05003oooooool00002ool01000ooooo`00
0_oo00<00?ooool00_oo00<00?ooool00_oo2@000Q2R0V<<0ZDD0]kK1?Nn0^LL0]JJ0/iI0/HH0[gg
0[Ff0/HH0[gg0ZDD0YBb0Xaa0XaA0X@@0W__0W>^0W>>0V]=00=S;6<<H``00U[;0U:Z0TYY0TY90T8X
0T880SWW0SW7136V0T8X0U:Z0V]]0X@@0Xaa0YBB0YBb0YcC0ZDd0[FF0[Ff3kgG0[Ff0[FF0ZeE0ZDd
0YBb0XaA18@`0Xaa0YBB0YBb19cC0YBB18aa0YBb1icc0YcC0Xaa0W_?0V]=0V<<0U::0SWW0SW713WW
0T880T8X0TY914YY0U::0U:Z0U[;0U[[0V<<00=S;6]=Jdd00W>>0W>^0W_?0X@@0XaA0ZDd0YBb0ZDD
0ZeE0ZDD0ZDd0Zee0[gg0]Jj1=kk1=kK0^LL0/Hh0V]]0P0P1`001?oo0@000Ooo0003ool01@00oooo
oooo00000_oo00@00?ooool000;oo`03003ooooo00;oo`03003ooooo00;oo`T0008@XP9S30:U50;N
f`Cg_P;W70;FVP;>F@;660:mm`:e]P;660:mm`:U50:D/P:<L@:<D@:4409kk`9c[P9cSP9[C@03HbaS
36<<009Jb`9BZP9:J@9:B@92:092208ii`8ia`@aYP92:09BZP9[K@:440:<L@:DTP:D/P:Ld`:U=0:e
UP:e]Pnme`:e]P:eUP:]E@:U=0:D/P:<D@B4<0:<L@:DTP:D/PBLd`:DTPB<L@:D/PNLl`:Ld`:<L@9k
c`9[C@9S309BRP8ii`8ia`@ii`922092:09:B@A:J@9BRP9BZP9Jb`9Jj`9S3003Hba[CF]=009cSP9c
[P9kc`:440:<D@:U=0:D/P:U50:]E@:U50:U=0:]M@:mm`;F^PCNn`CNf`;W70;6>09[K@8080L000Co
o`40007oo`0000Coo`00000000?oo`04003ooooo0002ool01000ooooo`001?oo00<00?ooool00_oo
2`000RU50W>>0Zee0^LL0_oO0_Nn0]kk0/ii0/Hh0/HH1<iI0Zee0ZDd0YcC0YBb0Xaa0XaA0X@@0W__
0W_?0W>>00=[CF</Hb`00V<<0U[;0U:Z0TYY0TY90T8X0T880SWW0SW7136V0TY90U[[0W>>0W__18@`
0Xaa0YBb0ZDD0ZeE1kFF2;Ff1;FF0ZeE0ZDD0YBB0XaA0X@`0XaA0Xaa19BB0YBb0Ycc1YBb0YcC00>L
ljDDYA@00Ycc0YcC0YBB0X@@0W>>0V</0U[;0U::0T880SWW0T88148X0TY90TYY0U::0U:Z0U[;0U[[
0V<<0V</0V]=00=[KG>>Lhh00W>^0W_?0W__0X@`0Xaa1:eE0[Ff1:eE0Zee0[gG0]Jj1=kk1=kK0^Ll
0]JJ0X@@0QSS2@001?oo0@000Ooo0003ool00`00ooooo`02ool20004ool20005ool00`00ooooo`02
ool=0002>LL2Q102_ML2ked2ool2mkh2g]/2cWT2aSP2aQP2_ML2]IH2[ED2YA@2W=<2U;82S742S542
Q302Nnl2Nll00g>>Jfe[K@02Hb`2H``2F^/2DZX2DXX2BVT2BTT2@PP2>NL2>LL2<JH2<HH2<JH2@RP2
F^/2Jfd2Lhh2Nll2Nnl2S542U;82YA@3YC@2YA@2[ED2[GD2]IH4[GD4[ED2W?<2S542Q102Q302S542
S742U984U;82W=<2U982Q302S542U9800iBbW?>Ll`02W?<2U982Q102Lhh2H``2F//2DZX2@RP2@PP4
@RP2BTT2BVT2DXX4DZX2F//2F^/2H``2Jdd2Nll3Q302Nnl2Nll2Q102Q302S542U982W?<2[GD4[ED2
[GD2_OL2eYX6g_/2g]/2ia`2e[X2S742:FD;0004ool10001ool001Goo`03003ooooo00;oo`d0008i
a`:440:me`;_G@;oo`;g_P;Nf`;>N@;6>0;660:me`:eUP:]E@:U50:Ld`:D/P:<L@:<D@:4<09kk`9k
c`03Lhi[KF]]009S;09S309Jj`9BZP9BRP9:J@9:B@92208ii`8ia`8aYP8aQP8aYP92:09Jj`9[K@9c
SP9kc`9kk`:<D@:D/P:U50>U=0:U50:]E@:]M@:eUPB]M@B]E@:Ll`:<D@:440:4<0:<D@:<L@:DTPBD
/P:Ld`:DTP:4<0:<D@:DTP03U;:Llicc00:Ll`:DTP:4409cSP9S309Jb`9BZP92:09220A2:09:B@9:
J@9BRPABZP9Jb`9Jj`9S309[C@9kc`>4<09kk`9kc`:440:4<0:<D@:DTP:Ll`:]M@B]E@:]M@:mm`;F
VPKNn`;Nf`;W70;F^P:<L@8YI@/000Coo`40007oo`005Ooo00<00?ooool00_oo3`000S6V0W__0[Ff
0^mM0_oo0_oO0^LL0/ii0/Hh0[gg0[gG0[FF0ZeE0ZDD0YcC0YBb0YBB0Xaa0XaA0X@`00>447_?Nll0
0V]]0V]=0V<<0U[[0U[;0U:Z0TYY0TY90T8X0T880SW7136V0S660SW70TYY0U[;0V<<0V</0W>>0W__
0X@`00>DTYcCW=<019cC0ZDd1:eE0ZDD1:Dd0Ycc0Xaa28@@0X@`0YBb19cC0YBb0XaA0W__0X@`00><
DIBbU;800YBb0Xaa0W_?0V]]0U[[0U:Z0T8X0T88148X0TY90TYY0U::0U:Z0U[;15[[0V</0V]=0W>>
0XaA0W__00>449BbU;800Xaa0X@`0XaA0Xaa0YBB0YcC0Ycc0ZDd0ZeE0[Ff0/ii1]kk1=kK0]kk0ZeE
0U[;0P0P2`001?oo0@000Ooo000Eool00`00ooooo`02ool?0002<JH2Nnl2]KH2ked2ool2oml2ia`2
cWT2aSP2_OL2_ML2]IH2[ED2YA@2W=<2U;82U982S742S542Q3000h@@Nlmkc`02Jfd2Jdd2H``2F^/2
F//2DZX2BVT2BTT2@RP2@PP2>LL4<JH2<HH2>LL2BVT2F//2H``2Hb`2Lhh2Nnl2Q3000iBBW=>Ld`04
W=<2YC@4[ED2YA@4YC@2W?<2S748Q102Q302U;84W=<2U;82S542Nnl2Q3000haAU;:D/P02U;82S742
Nll2Jfd2F^/2DZX2@RP2@PP4@RP2BTT2BVT2DXX2DZX2F//4F^/2Hb`2Jdd2Lhh2S542Nnl00h@@U;:D
/P02S742Q302S542S742U982W=<2W?<2YC@2[ED2]KH2cWT6g_/4g]/2g_/2[ED2F//2020;0004ool1
0001ool001Goo`03003ooooo00;ooa40009220:4<0:mm`;_O@;oo`;og`;Nn`;>N@;6>0:mm`:e]P:]
M@:]E@:U50:Ll`BD/P:Ll`:U5003W?>DTYBB009kk`9cSP9[C@9S;09S309Jb`9BZP9BRP9:B@92:092
208ii`8ia`8aYP@aQP92:09:J@9Jb`9Jj`9[K@9c[P03Nnn448@@00:<D@:<L@:Ld`BU50:Ll`BU50:L
d`:DTP:<L@:<D@:4<0:4409kk`:<D@JD/P:<L@:4409kk`03Q12<DHaA00:<D@:4409c[P9S309BZP9:
B@A2:09:B@A:J@9BRP9BZP9Jb`9Jj`9S309S;09[C@9[K@9kk`:<L@=kk`:4<0:Ll`:DTP:<L@:D/P:L
d`:Ll`:U50:]E@:e]P;>N@KNn`CNf`;Nn`:]M@9Jj`8080d000Coo`40007oo`005Ooo00<00?ooool0
0_oo4@000T880X@`0[gg0^mm0_oo0_oO0]kk0/ii0/Hh0[gg0[Ff0Zee0ZeE0ZDD0Ycc19Bb0Ycc0ZDD
00>LliBBU9800W__0W>>0V]=0V</0V<<0U[;0U:Z0U::0TY90T8X0T880SWW0SW70S6V13660T8X0TYY
0U[;0U[[0V]]0W>^00=kkh@@Q1000XaA0Xaa0YcC1:DD0Ycc1:DD0YcC0YBB0Xaa0XaA0X@`0X@@0W__
0XaA1YBb0Xaa0X@@0W__00>448aAS5400XaA0X@@0W>^0V<<0U:Z0TY9148X0TY914YY0U::0U:Z0U[;
0U[[0V<<0V</0V]=0V]]0W__0Xaa0g__0X@`0Ycc0YBB0Xaa0YBb0YcC0Ycc0ZDD0ZeE0[Ff0/ii1]kk
1=kK0]kk0Zee0U[[0P0P3@001?oo0@000Ooo000Eool20003oolC0002DXX2S742aQP2mih2ool2mkh2
g_/2cWT2aSP2_OL2]KH2[GD2[ED2YA@2W?<2[ED2[GD2U;800haaW=>Ld`02U;82Nll2Lhh2Jdd2Hb`2
H``2F^/2DZX2DXX2BVT2@RP2@PP4>NL2>LL4<JH2@RP2DZX2F//2H``2Jdd00f]]LhicSP02Ljh2Q102
U986W=<4W?<2W=<2U;84U982S742Q304Q102S744U982S542Nnl3Ljh4Nnl2Ljh2Jfd2F^/2BVT2@RP4
BTT2BVT2DXX2DZX2F//2F^/2H``4Hb`4Jfd2Lhh2Nnl2U;82Q3000h@@Q324<002U;82YC@2U;82W=<2
W?<2YA@2[ED2]IH2cWT8g_/2g]/2g_/2]KH2Jdd2244?0003ool20001ool001Goo`03003ooooo00;o
oa<0009BRP:<L@;660;gWP;oo`;g_P;Nn`;>N@;6>0:mm`:e]P:]M@:]E@:U50:Ll`:]E@:]M@:D/P03
S76LdicC00:D/P9kc`9cSP9[C@9S;09S309Jj`9BZP9BRP9:J@92:09220@ii`8ia`@aYP92:09BZP9J
b`9S309[C@03JfecSW>>009c[P:440:DTPJLd`BLl`:Ld`:D/PBDTP:<L@:4<0B440:<L@BDTP:<D@9k
k`=c[PAkk`9c[P9[K@9Jj`9:J@92:0A:B@9:J@9BRP9BZP9Jb`9Jj`9S30AS;0A[K@9cSP9kk`:D/P:4
<003Q124<8@`00:D/P:U=0:D/P:Ld`:Ll`:U50:]E@:eUP;>N@SNn`;Nf`;Nn`:e]P9[C@88@@l000Co
o`40007oo`005Ooo00<00?ooool00_oo4`000P0P0U::0Xaa0/Hh0_NN0_oo0_Nn0]kk0/ii0/Hh0[gg
0[Ff0Zee1:eE0[gG0ZDD0YBb00>LdjDdYC@00ZDD0X@@0W_?0W>>0V]]0V]=0V<<0U[[0U:Z0U::0TYY
0TY90T8X0T880SWW1SW70T880U[;0V<<1F</0V]]0W_?0X@`0Xaa1YBB19Bb1YBB0Xaa0XaA0X@`0X@@
18@`0X@@0W_?0V]]0V]=00=S;5[[F^/00U::0TYY24Y90TYY15::0U:Z0U[;0U[[0V<<0V</0V]]0W>^
0W>>0W>^0W_?0W__19Bb00><DHaaS7400YBB0ZDd0ZeE0Ycc0ZDd0ZeE0[Ff0/ii0]kK1]kk0]kK0]kk
0[gG0W>>0Q224@001?oo0@000Ooo000Eool00`00ooooo`02oolC00020202DXX2S742aSP2mih2ool2
mkh2g_/2cWT2aSP2_OL2]KH2[GD4[ED2_ML2YA@2U;800icCYCBU=002YA@2Q102Nll2Lhh2Jfd2Jdd2
H``2F^/2DZX2DXX2BVT2BTT2@RP2@PP2>NL6>LL2@PP2F//2H``5Hb`2Jfd2Nll2Q302S746U984U;86
U982S742S542Q302Q104Q302Q102Nll2Jfd2Jdd00f</F^]Jj`02DXX2BVT8BTT2BVT4DXX2DZX2F//2
F^/2H``2Hb`2Jfd2Ljh2Lhh2Ljh2Nll2Nnl4U;800haAS76<L@02U982YC@2[ED2W?<2YC@2[ED2]KH2
cWT2g]/6g_/2g]/2g_/2_ML2Lhh2488A0004ool10001ool001Goo`03003ooooo00;ooaD0008Hh`9S
;0:Ll`;FVP;g_P;oo`;gWP;Nf`;>N@;6>0:mm`:e]P:eUPBmm`:U50:Ld`03[EFeU[FF00:<L@:4<09k
k`9kc`9c[P9cSP9[C@9S309Jj`9Jb`ABRP9:J@9:B@92:09220Hii`92:09BZPEJb`9S;09cSP9kc`9k
k`:440:4<0B440:<D@:4<0:440:<D@B4<0:4409kk`9kc`9c[P9cSP9[C@9S309Jb`03BVU2:48X0092
:0A:B@A:J@9BRPABZP9Jb`9Jj`9S309S;09[C@9[K@:440:4<09kc`Akk`:4<0:<L@:U50>D/P:Ld`:L
l`:U50:U=0:]M@:mm`;F^PKNn`;Nf`;Nn`;Nf`:]E@9S3088@A<000Coo`40007oo`005Ooo00<00?oo
ool00_oo5@000QSS0V</0Ycc0]JJ0_Nn0_oo0_NN0]kK0/ii0/Hh0[gg0[Ff0[FF1;gg0ZDD0YcC00>]
EKFF]IH00Xaa0X@`0W__0W_?0W>^0W>>0V]=0V<<0U[[0U[;15::0TYY0TY90T8X0T881SWW0T8X0U:Z
1E[;0V</0W>>0W_?0W__0X@@0X@`18@@0XaA0X@`0X@@0XaA18@`0X@@0W__0W_?0W>^0W>>0V]=0V<<
0U[;00=:JD8X@RP00T8X14Y914YY0U::15:Z0U[;0U[[0V<<0V</0V]=0V]]0X@@0X@`0W_?17__0X@`
0Xaa0ZDD0iBb0YcC0Ycc0ZDD0ZDd0Zee0[gg0]Jj1]kk0]kK0]kk0]kK0ZeE0V<<0PQ14`001?oo0@00
0Ooo000Eool00`00ooooo`02oolG00028@@2H``2W?<2cWT2mkh2oml2mkh2g_/2cWT2aSP2_OL2_ML2
_OL2aSP2[ED2YA@3W?<2U982S544Q304S742Q302Lhh2Hb`2H``4F//2DZX4BVT2BTT4@RP6@PP2@RP0
0e::F/]Jb`02F^/2Hb`2Jdd2Jfd6Lhh2Ljh2Nll2Ljh2Jfd2Jdd2Lhh4Nll2Lhh2Jdd4Hb`2H``2DXX2
@RP5BTT4BVT2DXX4DZX2F//2F^/2H``2Hb`2Jdd6Ljh2S542S742Nnl2Q102Q302S542S742YA@00jDd
W=>Ld`02W?<2YA@2YC@2[GD2aQP2e[X6g_/6g]/2[ED2H``2244E0004ool10001ool001Goo`03003o
oooo00;ooaL0008Q109S30:Ll`;>N@;g_P;og`;g_P;Nn`;>N@;6>0:mm`:me`:mm`;6>0:]E@:U50>L
l`:DTP:<D@B4<0B<L@:4<09cSP9S;09S30AJb`9BZPA:J@9:B@A2:0I22092:003DXYJbe[;009Jj`9S
;09[C@9[K@IcSP9c[P9kc`9c[P9[K@9[C@9cSPAkc`9cSP9[C@AS;09S309BRP92:0E:B@A:J@9BRPAB
ZP9Jb`9Jj`9S309S;09[C@Ic[P:<D@:<L@9kk`:440:4<0:<D@:<L@:U5003YCBLdicC00:Ll`:U50:U
=0:]M@;660;F^PKNn`KNf`:]E@9S3088@AD000Coo`40007oo`005Ooo00<00?ooool00_oo6`000U::
0Xaa0/HH0^mM1?oO0^mM0]JJ0/iI0/HH0[gg1<Hh0[Ff00>]EIccW?<00YcC0YBb0Xaa0YcC0ZDD18aa
0YBB0W>>0V]=0V</0V<<0U[[0U[;0U:Z0U::0TYY1TY91D8X0TY90U::15[;0U[[0V<<0U[[0V</0V]=
16]]0V</16<<16]=0V]]0V]=16<<0U[;0TY91DYY15::0U:Z15[;0U[[16<<0V</0V]=0W>>0X@@0XaA
0W__0Xaa0YcC18@`0XaA0Xaa0YBB0YBb00>]EJDDYA@00ZDD0ZeE0Zee0/HH0]Jj1]kk1=kK0]kk0[Ff
0V]]0QSS5`001?oo0@000Ooo000Eool00`00ooooo`02oolK0002DXX2S742aQP2ked4oml2ked2eYX2
cUT2aQP2_OL4aSP2]KH00jeEW?>Ll`02W=<2U;82S742W=<2YA@4S742U982Lhh2Jdd2Hb`2H``2F^/2
F//2DZX2DXX2BVT6BTT5@RP2BTT2DXX4F//2F^/2H``2F^/2Hb`2Jdd4Jfd2Hb`4H``4Jdd2Jfd2Jdd4
H``2F//2BTT5BVT4DXX2DZX4F//2F^/4H``2Hb`2Jdd2Lhh2Q102S542Nnl2S742W=<4Q302S542S742
U982U;800jeEYABU5002YA@2[ED2[GD2aQP2e[X6g_/4g]/2g_/2]KH2Jfd26><G0004ool10001ool0
01Goo`8000?ooa/0008@XP9Jb`:DTP;6>0;gWPCog`;_G@;FVP;>F@;6>0;660C6>003[GFU=:Dd00:L
l`:Ld`:U50:]M@:<L@:4<0:<D@:Ld`9kc`9cSP9[K@9[C@9S;09S309Jj`9Jb`ABZPABRP9:J@]:B@9B
ZP9Jb`9Jj`9S30AS;0QJj`9Jb`9BRP9:J@9BRP9BZPQBRP=BZPAJb`AJj`9S309S;0A[C@9[K@9cSP9k
c`:440:D/P:Ld`BU50:Ld`:<L@:DTP:D/P:Ld`:Ll`03YABU=:Dd00:]M@:me`;>N@;Nf`KNn`;Nf`;N
n`;>N@:D/P9BRP8081T000?oo`80007oo`005Ooo00<00?ooool00_oo6`000Q2R0U[;0YBB0/Hh0_NN
1?oO0^mM0]JJ0/iI0/Hh0/HH1<Hh00>]MJDdYC@00Ycc0YcC0ZDD0Zee0Xaa0X@`0XaA0YcC0W_?0W>>
0V]]0V]=0V</0V<<0U[[0U[;15:Z15::0TYY2dY90U:Z0U[;0U[[0V<<16</25[[0U[;0U::0TYY0U::
0U:Z25::0e:Z15[;15[[0V<<0V</16]=0V]]0W>>0W_?0X@@0YBb0YcC1:DD0YcC0Xaa0YBB0YBb0YcC
0Ycc00>U5:DdYC@00Zee0[gG0/ii0]kK1]kk0]kK0]kk0/ii0YBb0U::0P0P6@001?oo0@000Ooo000E
ool00`00ooooo`02oolM00020202DXX2S542_ML2ic`2oml2mkh2kgd2g]/2cWT2aSP2aQP2_ML00kFF
[GF]M@02YC@2YA@2]KH2[GD2U;82S742U982YA@2Q102Nll4Ljh4Nnl2Jfd2Hb`2H``2F^/4F//2DZX3
DXX6BVT2BTT4BVT2DXX2DZX4F//2DXX<BVT6DXX4DZX3F//4F^/2H``2Hb`2Jdd4Ljh4Lhh2Ljh2Nll2
Nnl2Q102W?<2YA@2S742U982[ED4W=<4W?<2YC@00jeE[GF]M@02aQP2eYX8g_/4g]/2_OL2Q302@PP2
020K0004ool10001ool001Goo`03003ooooo00;ooad00080809BRP:<D@:me`;W?0;og`;g_P;_O@;N
f`;>N@;6>0;660:me`03]IJ]MJee00:U=0:U50:e]P:]M@:D/P:<L@:DTP:U50:4409kc`Ac[PAkk`9[
K@9S;09S309Jj`AJb`9BZP=BRPI:J@9:B@A:J@9BRP9BZPAJb`9BRPa:J@IBRPABZP=Jb`AJj`9S309S
;09[C@Ac[PAcSP9c[P9kc`9kk`:440:Ll`:U50:<L@:DTP:]E@BLd`BLl`:U=003[EF]MJee00;660;F
VPSNn`CNf`:mm`:4<092208081/000Coo`40007oo`005Ooo00<00?ooool00_oo8@000T880W__0Zee
0]kK1?oO0_Nn0^Ll0]JJ0/iI0/HH00>mekFf]KH00Zee0ZeE0/HH0Zee0Ycc0YBb0ZDD0ZDd0X@`0X@@
17__19Bb0Xaa0W_?0V]=0V</16<<0U[[0e[;1U:Z6U::15:Z15[;15[[0f<<16</16]=0W>>0W_?0XaA
17_?0W__18@@0X@`0YBB0ZeE0YcC0ZDD0[FF0ZDD0Ycc0ZDD0ZDd0Zee00>e]/iIcUT00]kK1]kk1]kK
0[Ff0W_?0S6V0P0P7@001?oo0@000Ooo000Eool00`00ooooo`02oolQ0002@PP2Nnl2[GD2g]/4oml2
mkh2ic`2eYX2cUT2aQP00kgG]KJe]P02[GD2[ED2aQP2[GD2W?<2U;82YA@2YC@2Q302Q104Nnl4U;82
S742Nll2Jdd2Hb`4H``2F^/3F//6DZXJDXX4DZX4F//4F^/3H``4Hb`4Jdd2Lhh2Nll2S544Nll2Nnl4
Q102Q302U982[ED2W=<2YA@2]IH2YA@2W?<2YA@2YC@2[GD00kFfcUW>F@02g]/6g_/6g]/2]KH2Nll2
<JH2020M0004ool10001ool001Goo`03003ooooo00;oob<0008ia`9cSP:U50;>N@;gWP;og`;g_P;_
O@;Nf`;>F@03aQRmmkgg00:e]P:eUP;660:me`B]E@:e]P:Ll`:<L@B<D@:<L@:U50:<D@:4<0:<L@9c
[PA[K@9[C@9S;0ES30YJj`YJb`9BZPQJb`AJj`AS30AS;0=[C@A[K@AcSP9c[P9kc`:DTP:4<0:440B4
<0:<D@:<L@:DTP:]M@:eUP:e]P:]M@BU=0:]E@:eUP;66003eY[Nnmkk00[Nn`;F^P:U=09S;08H``80
81l000Coo`40007oo`005Ooo00<00?ooool00_oo8`000SW70W>>0ZDD0/ii0_NN0_oO0_Nn0^mm0]kK
0/iI00?66;gg_OL00[Ff0[FF0/HH0[gG1:eE0[Ff0Ycc0Xaa18aA0Xaa0ZDD0XaA0X@`0Xaa0W>^16]]
0V]=0V</1F<<2U[[2U[;0U:Z25[;15[[16<<16</0f]=16]]17>>0W>^0W_?0YBB0X@`0X@@18@`0XaA
0Xaa0YBB0Zee0[FF0[Ff0Zee1:Dd0ZeE0[FF0/HH00?FV]kkg_/02]kk0]Jj0ZDd0V</0QS30P0P7`00
1?oo0@000Ooo000Eool00`00ooooo`02oolU00028B@2H``2U982_ML2ia`4mkh2mih2ic`00liiaSS6
>002_OL4_ML2cUT4aQP2]KH2W?<2U;84U982W?<2YC@4S542W=<2Q102Nll2Ljh2Lhh4Jfd;Jdd2Jfd6
Hb`8H``2Jdd2Jfd2Lhh2Jfd6Jdd4Jfd3Lhh4Ljh2Nll4Nnl2Q104U;82S544S742U984U;82YC@2[GD4
[ED4[GD2_ML2cUT2g]/7g_/4g]/2cUT2S742BVT2020S0004ool10001ool001Goo`03003ooooo00;o
obD0008Q909S30:DTP:me`;W70Cg_P;gWP;W?003cWW6><Hh00:mm`Bme`;>F@C660:e]P:Ll`:D/PBD
TP:Ll`:U=0B<D@:Ld`:4409kc`9c[P9cSPA[K@][C@9[K@IS;0QS309[C@9[K@9cSP9[K@I[C@A[K@=c
SPAc[P9kc`Akk`:440BD/P:<D@B<L@:DTPBD/P:U=0:]M@B]E@B]M@:me`;>F@;Nf`ONn`CNf`;>F@:<
L@9:J@8082<000Coo`40007oo`005Ooo0P000ooo9`000PQQ0TY90W__0ZDd0]JJ0^mM0_Nn0^mm00?_
GMkkg_/00/iI0/HH0[gg1;gG0[Ff0ZeE0ZDD19cc0YcC0Zee0ZDd0Xaa0YBB0ZDd0XaA0X@@0W__17_?
0g>^27>>0W__0XaA0W>^0W>>0X@`0W>^16]=0V]]0X@`0XaA0X@`0X@@1W>>17>^0g_?17__18@@0X@`
0XaA0YBB0ZDd0YBB0YBb1YcC0Ycc0ZDD0ZeE0Zee0[FF0[Ff0/Hh0]Jj0]kk0^LL1Mkk0]kK0]JJ0[FF
0W>^0S6V0P0P9@000ooo0P000Ooo000Eool00`00ooooo`02oolW00022642BTT2Nnl2YC@2eYX2ked2
mkh2kgd00nmMg__Nn`02cUT2aQP2_OL4_ML2]KH2[ED2YA@4W?<2W=<2[GD2YC@2S742U982YC@2S542
Q102Nnl4Nll3Ljh8Lhh2Nnl2S542Ljh2Lhh2Q302Ljh4Jdd2Jfd2Q302S542Q302Q106Lhh4Ljh3Nll4
Nnl4Q102Q302S542U982YC@2U982U;86W=<2W?<2YA@2[ED2[GD2]IH2]KH2aSP2e[X2g_/2ia`5g_/2
g]/2eYX2]IH2Ljh2<JH2020U0004ool10001ool001Goo`03003ooooo00;oob/0008Q109BZP:4<0:]
M@;FVP;W?003kgg_GNmM00;_G@;Nn`;>N@;6>0:mm`:me`:eUP:]M@:]E@BU=0:mm`:]M@:Ll`:U50:e
UP:DTP:<D@B4<0B440Ukk`:<D@:Ll`:DTP:440:Ld`:DTPIc[PB<D@Ykc`Akk`>440B4<0B<D@:<L@:D
TP:D/P:]M@BeUP:]M@BU50:U=0:]E@:]M@:e]P;660;FVP;Nn`;W70ONn`;Nf`;6>0:Ll`9S;08Q9080
82L000Coo`40007oo`005Ooo00<00?ooool00_oo:`000R440U:Z0X@`0Zee0]JJ0^Ll00?_ONmMked0
0^mM0]kk0/ii0/Hh0[gg0[gG0[FF0Zee0ZeE1:Dd0[gg0Zee0Ycc0ZDD0[FF0YBB0XaA18@`18@@2G__
0XaA0Ycc0YBB0X@@0YcC0YBB1W>^18aA2W_?17__0h@@18@`18aA0Xaa0YBB0YBb0Zee1;FF0Zee1:DD
0ZDd0ZeE0Zee0[Ff0/HH0]JJ0]kk0^LL1mkk0]kK0/Hh0Ycc0V</0R4T0P0P9`001?oo0@000Ooo000E
ool00`00ooooo`02ool]00024:82@RP2Lhh2W=<2aQP00mkkiccW?002ic`2ked2ic`2e[X2cUT2aQP2
_ML2]KH2]IH2[GD2]KH2aSP2_OL2]KH2_OL2YA@2U;82U984S744S547Q302S542YA@2YC@4W?<2YC@2
W=<2Q104Nnl2U;82S742S546Q104Q304S543S744U984U;82YC@2]IH2]KH2[GD2YC@4[ED2[GD2]IH2
]KH2aQP2eYX2g_/4ia`6g_/00mkKcWW>N@02YC@2Lhh2<JH2020[0004ool10001ool001Goo`03003o
oooo00;oobd0008@XP92:09cSP:Ld`;66003g__W?>Ll00;W?0;_G@;W?0;F^P;>F@;660:me`:e]P:e
UP:]M@:e]P;6>0:mm`:e]P:mm`:U50:D/P:DTPB<L@B<D@N4<0:<D@:U50:U=0BLl`:U=0:Ld`:440Ak
k`:D/P:<L@:<D@J440B4<0B<D@><L@BDTPBD/P:U=0:eUP:e]P:]M@:U=0B]E@:]M@:eUP:e]P;660;F
VP;Nn`CW70KNn`03g]_>NLii00:U=09cSP8aYP8082/000Coo`40007oo`005Ooo00<00?ooool00_oo
<@000RU50U::0W__00>U5<HhaSP00]kk1>Ll0^mM0^Ll0]kK0/iI0[gg0[gG1[Ff1;gG0Zee0ZDD0Ycc
19cC19Bb2IBB0YcC0Zee0Ycc1:ee1:eE0Xaa18aA0Ycc0ZDd0ZDD0Xaa18aA18aa19BB1IBb0YcC0Ycc
0ZDD1ZeE1:ee1;FF0[gG0/Hh0]JJ0]kk2>LL1=kk0]Jj00>e]X@@Q1000U::0PQQ;`001?oo0@000Ooo
00000ooo000000020002ool40003ool20005ool00`00ooooo`02oola0002:DD2DXX2Nnl00jDDaSS6
>002g_/4ic`2ked2ic`2g]/2cUT2_OL2_ML6]KH4_ML2[GD2YA@2W?<4W=<4U;89U982W=<2[GD2W?<4
[GD4[ED2S744S542W?<2YC@2YA@2S744S544S744U985U;82W=<2W?<2YA@6[ED4[GD4]IH2_ML2aSP2
eYX2g_/8ia`4g_/2e[X00kFfQ1244002DXX2264_0004ool10001ool000?oo`05003oooooool00005
ool01000ooooo`001?oo00<00?ooool00_oo<`000P0P0RUU00=Jbh@@Q1000ZDd0/iI0]kk0^Ll1^mM
0]kK0/ii0/HH0[gg0[gG0[Ff0[FF0Zee0ZeE1:Dd1:DD19cc1icC0ZeE0[FF0Ycc1;gG0ZDD0Zee0Ycc
19Bb0ZDd0ZeE0YcC0YBb0YBB1YBb0YcC1Icc1:DD0ZDd0ZeE1:ee0[FF0[Ff0[gG0/HH0/ii0]kK0]kk
2>LL1=kk0]Jj0[gg0Xaa00=Jbb448@@00P0P<@001?oo0@000Ooo0003ool00`00ooooo`02ool00`00
ooooo`02ool01000ooooo`001?oo0P000ooo=`0000<8HC66<HH00U[;0X@@0ZDd0/iI0]kk0^Ll1>mM
0^mm0^LL0]Jj0/iI0/HH0[gg0[gG0[Ff0[FF1:ee1:eE1JDd0ZDD0ZDd0[gg0[FF0ZDD0[gG0[gg0ZDD
0[FF0Zee19cc0Zee0[Ff0Zee0ZeE0ZDD19cc1:DD0ZDd1JeE0Zee1;FF0[Ff0[gG0/HH0/iI0]Jj0]kk
2^LL1=kk0]JJ0[gg0YBB0V</0S6600<080000000<`000ooo0P000Ooo0003ool00`00ooooo`03ool0
1@00oooooooo00000_oo00<00?ooool00_oo00<00?ooool00_oo=`0000<8HC66<HH00U[;0X@@0ZDd
0/iI0]kk0^Ll1>mM0^mm0^LL0]Jj0/iI0/HH0[gg0[gG0[Ff0[FF1:ee1:eE1JDd0ZDD0ZDd0[gg0[FF
0ZDD0[gG0[gg0ZDD0[FF0Zee19cc0Zee0[Ff0Zee0ZeE0ZDD19cc1:DD0ZDd1JeE0Zee1;FF0[Ff0[gG
0/HH0/iI0]Jj0]kk2^LL1=kk0]JJ0[gg0YBB0V</0S6600<080000000<`001?oo0@000Ooo0003ool0
0`00ooooo`04ool01000ooooo`000_oo00<00?ooool00_oo00<00?ooool00_oo>P000PQ10S6V0U[[
0X@@0ZDd0/iI0]kk0^Ll0^mM1>mm0^mM0^LL0]Jj0/iI0/HH0[gg0[gG1;Ff1;FF1jee0[Ff0Zee0ZeE
0[FF0[Ff0ZeE0Zee0[gG1:eE0[FF0[Ff1;FF0Zee1ZeE0Zee1KFF0[Ff0[gG0[gg0/HH0/iI0]Jj0]kk
0^LL0^Ll2>LL0]kk0]kK0]JJ0[gG0YBB0V</0S6V0P0P>0001?oo0@000Ooo00001?oo000000000ooo
00@00?ooool000;oo`04003ooooo0004ool00`00ooooo`02oolj00022442<JH2F^/2Q102YC@2cUT2
g_/2ic`2ked4kgd2ked2ia`2e[X2cUT2aQP2_OL2_ML4]KH4]IH7[GD2]KH2[GD2[ED2]IH2]KH2[ED2
[GD2_ML4[ED2]IH2]KH4]IH2[GD6[ED2[GD5]IH2]KH2_ML2_OL2aQP2cUT2e[X2g_/2ia`2ic`8ia`2
g_/2g]/2eYX2_ML2U982Hb`2<JH2020h0004ool10001ool000?oo`03003ooooo00;oo`8000Coo`80
00Goo`03003ooooo00;ooch00088@@8aYP9Jj`:440:U=0;6>0;Nf`;W70C_G@C_O@;_G@;W70;F^P;>
N@;6>0;660:mm`Fme`Re]PJeUP:e]PReUPJe]PJeUPBe]PBme`03_OO66<HH00;>F@;FVP;Nf`;Nn`;W
70KW?0KW70;Nn`;Nf`;>N@:]M@:4<09S308aYP8083`000Coo`40007oo`005Ooo00<00?ooool00_oo
?P000PQ10S6V0U[[0X@@0ZDd0/Hh0]kK0^LL1>mM1>mm0^mM0^LL0]Jj0/ii0/Hh0/HH0[gg1KgG2;Ff
1[FF0[Ff2;FF1[Ff1[FF1;Ff1;gG00>mmlHHaQP00/iI0]JJ0]kK0]kk0^LL1^Ll1^LL0]kk0]kK0/ii
0Zee0X@`0V<<0S6V0P0P?0001?oo0@000Ooo000Eool00`00ooooo`02oom400028@@2BTT2Jfd2S742
[GD2cUT2g]/2ia`6ked4kgd2ked2ic`2g_/2e[X00mJJcUW>F@04aSP6aQPB_OL8aQP2aSP2cUT2cWT2
e[X00mkKg__Nn`02ia`8ic`6ia`4g_/2e[X2aSP2YC@2Nnl2F//2<HH4020n0004ool10001ool001Go
o`03003ooooo00;ood@0008Q109:B@9[K@:<L@:]M@;>F@;Nf`;W70K_G@C_O@;_G@;W?0;Nn`;F^P03
eY[>FLiI00C6>0K661:mm`S660;6>0;>F@;>N@;F^P03g]_Nnmkk00;W70SW?0KW70CNn`;F^P;6>0:U
=09kk`9Jb`8aQP@083h000Coo`40007oo`005Ooo00<00?ooool00_ooB0000QS30T880V<<0X@@0ZDD
0[gG0/ii0]kK0^LL1>Ll1>mM1>mm1NmM0^Ll0^LL0]kk2=kK1]Jj1=kK1]kk0^LL4nLl1>LL0]kk0]kK
0]JJ0[gg0Ycc0X@@0V<<0SW70PQQ0P0PA0001?oo0@000Ooo000Eool00`00ooooo`02oom800026<<2
@PP2H``2Q102YA@2_ML2cWT2g]/2ia`4ic`4ked4kgd5ked2ic`2ia`2g_/8g]/6e[X4g]/6g_/2ia`C
ic`4ia`2g_/2g]/2eYX2_OL2W?<2Q102H``2>LL2264202140004ool10001ool001Goo`8000?ood`0
0088@@8YI@9:J@9[C@:440:Ll`:e]P;>F@;F^P;Nn`CW70?W?2K_G@;W?0;_G@GW?0CW70CNn`;F^P;>
F@:e]P:Ll`:4409S;092:08Q108084X000?oo`80007oo`005Ooo00<00?ooool00_ooC0000PQ10RUU
0TYY0V]=0X@@0Ycc0[Ff0/iI0]Jj0]kk1>LL0nLl9^mM0^Ll0^mM1NLl1>LL1=kk0]Jj0/iI0[Ff0Ycc
0X@@0V</0T8X0R440P0PBP001?oo0@000Ooo000Eool00`00ooooo`02oomB000202028@@2>NL2F//2
Jfd2Q302W=<2[GD2_OL2aSP00mJJe[[F^P02g]/2g_/6ia`Fic`6ia`2g_/4g]/00liiaSS6>002_OL2
[ED2U;82Q102Jdd2DXX2<JH24:82021@0004ool10001ool001Goo`03003ooooo00;ooe800080808Q
108ii`9Jb`9[K@:4<0:Ld`:]M@:mm`;6>003eY[F^]Jj00;Nf`;Nn`KW71KW?0KW70;Nn`CNf`03cWW6
><Hh00:mm`:]E@:D/P:4409[C@9BRP8aYP8@XP80850000Coo`40007oo`005Ooo00<00?ooool00_oo
FP000Q220RU50T8X0U[;0V]=0W_?00>4<9BbU;800ZDD0Zee0[Ff0/HH0/Hh0/iI0/ii1=JJ2=Jj1=JJ
0/ii0/iI0/HH0[Ff0[FF0ZDD0YBb00>447>^Ljh00V<<0U::0SWW0R44100PEP001?oo0@000Ooo000E
ool00`00ooooo`02oomJ00024882:DD2@RP2F//2Jdd2Nll00h@`U;:D/P02YA@2[GD2]KH2aQP2aSP2
cUT2cWT4eYX8e[X4eYX2cWT2cUT2aQP2]KH2]IH2YA@2U;800h@@Ljic[P02H``2DXX2>NL28@@4021F
0004ool10001ool001Goo`03003ooooo0?ooo`7oo`40007oo`005Ooo00<00?ooool0oooo0Ooo0@00
0Ooo000Eool00`00ooooo`3oool1ool10001ool001Goo`03003ooooo00;oo`03003ooooo02Coo`03
003ooooo02Coo`03003ooooo02Coo`03003ooooo02Coo`03003ooooo02Coo`03003ooooo02Coo`03
003ooooo017oo`40007oo`005Ooo0P000ooo00<00?ooool01_oo00<00?ooool01ooo00<00?ooool0
1ooo00<00?ooool01ooo00<00?ooool01_oo00<00?ooool01ooo00<00?ooool01ooo00<00?ooool0
1ooo00<00?ooool01ooo00<00?ooool01_oo00<00?ooool01ooo00<00?ooool01ooo00<00?ooool0
1ooo00<00?ooool01_oo00<00?ooool01ooo00<00?ooool01ooo00<00?ooool01ooo00<00?ooool0
1_oo00<00?ooool01ooo00<00?ooool01ooo00<00?ooool01ooo00<00?ooool01_oo00<00?ooool0
1ooo00<00?ooool01ooo00<00?ooool01ooo00<00?ooool01_oo0P000Ooo000Eoooo00050001ool0
0?oooa_oo`00oooo6ooo003ooolKool00?oooa_oo`00\
\>"],
  ImageRangeCache->{{{0, 281}, {281, 0}} -> {-13.4539, -11.1787, 0.512735, \
0.512735}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListContourPlot[penny];\)\)], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0116596 0.00757117 0.0116596 0.00757117 [
[.01166 -0.0125 -3 -9 ]
[.01166 -0.0125 3 0 ]
[.16308 -0.0125 -6 -9 ]
[.16308 -0.0125 6 0 ]
[.31451 -0.0125 -6 -9 ]
[.31451 -0.0125 6 0 ]
[.46593 -0.0125 -6 -9 ]
[.46593 -0.0125 6 0 ]
[.61735 -0.0125 -6 -9 ]
[.61735 -0.0125 6 0 ]
[.76878 -0.0125 -9 -9 ]
[.76878 -0.0125 9 0 ]
[.9202 -0.0125 -9 -9 ]
[.9202 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01166 -6 -4.5 ]
[-0.0125 .01166 0 4.5 ]
[-0.0125 .16308 -12 -4.5 ]
[-0.0125 .16308 0 4.5 ]
[-0.0125 .31451 -12 -4.5 ]
[-0.0125 .31451 0 4.5 ]
[-0.0125 .46593 -12 -4.5 ]
[-0.0125 .46593 0 4.5 ]
[-0.0125 .61735 -12 -4.5 ]
[-0.0125 .61735 0 4.5 ]
[-0.0125 .76878 -18 -4.5 ]
[-0.0125 .76878 0 4.5 ]
[-0.0125 .9202 -18 -4.5 ]
[-0.0125 .9202 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01166 0 m
.01166 .00625 L
s
[(0)] .01166 -0.0125 0 1 Mshowa
.16308 0 m
.16308 .00625 L
s
[(20)] .16308 -0.0125 0 1 Mshowa
.31451 0 m
.31451 .00625 L
s
[(40)] .31451 -0.0125 0 1 Mshowa
.46593 0 m
.46593 .00625 L
s
[(60)] .46593 -0.0125 0 1 Mshowa
.61735 0 m
.61735 .00625 L
s
[(80)] .61735 -0.0125 0 1 Mshowa
.76878 0 m
.76878 .00625 L
s
[(100)] .76878 -0.0125 0 1 Mshowa
.9202 0 m
.9202 .00625 L
s
[(120)] .9202 -0.0125 0 1 Mshowa
.125 Mabswid
.04952 0 m
.04952 .00375 L
s
.08737 0 m
.08737 .00375 L
s
.12523 0 m
.12523 .00375 L
s
.20094 0 m
.20094 .00375 L
s
.23879 0 m
.23879 .00375 L
s
.27665 0 m
.27665 .00375 L
s
.35236 0 m
.35236 .00375 L
s
.39022 0 m
.39022 .00375 L
s
.42807 0 m
.42807 .00375 L
s
.50379 0 m
.50379 .00375 L
s
.54164 0 m
.54164 .00375 L
s
.5795 0 m
.5795 .00375 L
s
.65521 0 m
.65521 .00375 L
s
.69306 0 m
.69306 .00375 L
s
.73092 0 m
.73092 .00375 L
s
.80663 0 m
.80663 .00375 L
s
.84449 0 m
.84449 .00375 L
s
.88234 0 m
.88234 .00375 L
s
.95806 0 m
.95806 .00375 L
s
.99591 0 m
.99591 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01166 m
.00625 .01166 L
s
[(0)] -0.0125 .01166 1 0 Mshowa
0 .16308 m
.00625 .16308 L
s
[(20)] -0.0125 .16308 1 0 Mshowa
0 .31451 m
.00625 .31451 L
s
[(40)] -0.0125 .31451 1 0 Mshowa
0 .46593 m
.00625 .46593 L
s
[(60)] -0.0125 .46593 1 0 Mshowa
0 .61735 m
.00625 .61735 L
s
[(80)] -0.0125 .61735 1 0 Mshowa
0 .76878 m
.00625 .76878 L
s
[(100)] -0.0125 .76878 1 0 Mshowa
0 .9202 m
.00625 .9202 L
s
[(120)] -0.0125 .9202 1 0 Mshowa
.125 Mabswid
0 .04952 m
.00375 .04952 L
s
0 .08737 m
.00375 .08737 L
s
0 .12523 m
.00375 .12523 L
s
0 .20094 m
.00375 .20094 L
s
0 .23879 m
.00375 .23879 L
s
0 .27665 m
.00375 .27665 L
s
0 .35236 m
.00375 .35236 L
s
0 .39022 m
.00375 .39022 L
s
0 .42807 m
.00375 .42807 L
s
0 .50379 m
.00375 .50379 L
s
0 .54164 m
.00375 .54164 L
s
0 .5795 m
.00375 .5795 L
s
0 .65521 m
.00375 .65521 L
s
0 .69306 m
.00375 .69306 L
s
0 .73092 m
.00375 .73092 L
s
0 .80663 m
.00375 .80663 L
s
0 .84449 m
.00375 .84449 L
s
0 .88234 m
.00375 .88234 L
s
0 .95806 m
.00375 .95806 L
s
0 .99591 m
.00375 .99591 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01166 .99375 m
.01166 1 L
s
.16308 .99375 m
.16308 1 L
s
.31451 .99375 m
.31451 1 L
s
.46593 .99375 m
.46593 1 L
s
.61735 .99375 m
.61735 1 L
s
.76878 .99375 m
.76878 1 L
s
.9202 .99375 m
.9202 1 L
s
.125 Mabswid
.04952 .99625 m
.04952 1 L
s
.08737 .99625 m
.08737 1 L
s
.12523 .99625 m
.12523 1 L
s
.20094 .99625 m
.20094 1 L
s
.23879 .99625 m
.23879 1 L
s
.27665 .99625 m
.27665 1 L
s
.35236 .99625 m
.35236 1 L
s
.39022 .99625 m
.39022 1 L
s
.42807 .99625 m
.42807 1 L
s
.50379 .99625 m
.50379 1 L
s
.54164 .99625 m
.54164 1 L
s
.5795 .99625 m
.5795 1 L
s
.65521 .99625 m
.65521 1 L
s
.69306 .99625 m
.69306 1 L
s
.73092 .99625 m
.73092 1 L
s
.80663 .99625 m
.80663 1 L
s
.84449 .99625 m
.84449 1 L
s
.88234 .99625 m
.88234 1 L
s
.95806 .99625 m
.95806 1 L
s
.99591 .99625 m
.99591 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01166 m
1 .01166 L
s
.99375 .16308 m
1 .16308 L
s
.99375 .31451 m
1 .31451 L
s
.99375 .46593 m
1 .46593 L
s
.99375 .61735 m
1 .61735 L
s
.99375 .76878 m
1 .76878 L
s
.99375 .9202 m
1 .9202 L
s
.125 Mabswid
.99625 .04952 m
1 .04952 L
s
.99625 .08737 m
1 .08737 L
s
.99625 .12523 m
1 .12523 L
s
.99625 .20094 m
1 .20094 L
s
.99625 .23879 m
1 .23879 L
s
.99625 .27665 m
1 .27665 L
s
.99625 .35236 m
1 .35236 L
s
.99625 .39022 m
1 .39022 L
s
.99625 .42807 m
1 .42807 L
s
.99625 .50379 m
1 .50379 L
s
.99625 .54164 m
1 .54164 L
s
.99625 .5795 m
1 .5795 L
s
.99625 .65521 m
1 .65521 L
s
.99625 .69306 m
1 .69306 L
s
.99625 .73092 m
1 .73092 L
s
.99625 .80663 m
1 .80663 L
s
.99625 .84449 m
1 .84449 L
s
.99625 .88234 m
1 .88234 L
s
.99625 .95806 m
1 .95806 L
s
.99625 .99591 m
1 .99591 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.6 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.7 g
.01923 .49928 m
.01993 .50379 L
.02082 .51136 L
.02237 .51893 L
.02392 .5265 L
.02526 .53407 L
.02679 .54164 L
.0268 .54168 L
.02903 .54921 L
.03134 .55678 L
.03361 .56435 L
.03437 .56562 L
.03774 .57193 L
.03891 .5795 L
.04117 .58707 L
.04194 .58923 L
.04421 .59464 L
.04877 .60221 L
.04951 .60978 L
.04952 .6098 L
.05475 .61735 L
.05622 .62492 L
.05709 .62757 L
.05959 .6325 L
.06312 .64007 L
.06466 .64326 L
.06687 .64764 L
.07069 .65521 L
.07223 .65836 L
.07465 .66278 L
.0798 .66905 L
.08059 .67035 L
.08399 .67792 L
.08737 .68415 L
.08816 .68549 L
.09401 .69306 L
.09494 .69482 L
.09812 .70064 L
.10251 .70547 L
.1053 .70821 L
.11008 .71098 L
.11766 .70888 L
.12373 .71578 L
.12004 .72335 L
.12393 .73092 L
.12523 .73217 L
.13218 .73849 L
.1328 .7385 L
.13281 .73849 L
.14037 .7349 L
.14794 .73567 L
.15033 .73849 L
.14794 .74137 L
.14612 .74606 L
.14794 .74978 L
.15551 .7528 L
.16207 .75363 L
.16308 .75397 L
.16945 .76121 L
.16772 .76878 L
.16308 .77523 L
.16227 .77635 L
.16306 .78392 L
.16308 .78394 L
.16735 .79149 L
.17065 .79437 L
.17524 .79906 L
.17823 .80232 L
.1831 .80663 L
.1858 .80916 L
.19178 .8142 L
.19337 .81551 L
.20094 .81916 L
.20539 .8142 L
.20851 .81262 L
.21608 .80889 L
.21905 .8142 L
.21608 .82057 L
.21555 .82177 L
.21523 .82935 L
.21608 .83335 L
.22156 .83692 L
.22365 .83758 L
.23122 .84124 L
.23466 .84449 L
.23879 .85168 L
.23958 .85206 L
.24637 .858 L
.2482 .85963 L
.25394 .86129 L
.25478 .85963 L
.26151 .85238 L
.262 .85206 L
.26908 .84837 L
.27142 .85206 L
.27105 .85963 L
.27132 .8672 L
.27665 .87269 L
.28422 .87354 L
.29179 .86755 L
.29749 .87477 L
.29337 .88234 L
.29658 .88992 L
.29936 .89142 L
.30694 .89418 L
.31451 .89662 L
.3158 .89749 L
.32208 .89749 L
.32208 .89749 L
.32574 .88992 L
.32965 .88507 L
.33292 .88234 L
.33722 .87897 L
.33788 .88234 L
.33788 .88992 L
.3409 .89749 L
.34479 .89967 L
.35236 .898 L
.35937 .90506 L
.35882 .91263 L
.35993 .91392 L
.3675 .91781 L
.37501 .9202 L
.37508 .92021 L
.38265 .92104 L
.39022 .92324 L
.39779 .92475 L
.40536 .9256 L
.41293 .92567 L
.42047 .92777 L
.4205 .92778 L
.42807 .92856 L
.43565 .92778 L
.43565 .92777 L
.44024 .9202 L
.44322 .91712 L
.44667 .91263 L
.45079 .90577 L
.4556 .91263 L
.45553 .9202 L
.45698 .92777 L
.45836 .92895 L
.45889 .92777 L
.46057 .9202 L
.4614 .91263 L
.45836 .90862 L
.45206 .90506 L
.45836 .90193 L
.4617 .90506 L
.46593 .90742 L
.4735 .90788 L
.47908 .90506 L
.48107 .9033 L
.48391 .90506 L
.48864 .91001 L
.48996 .91263 L
.49429 .9202 L
.49621 .92212 L
.5013 .92777 L
.50379 .9311 L
.51136 .93153 L
.51466 .92777 L
.51847 .9202 L
.51893 .91895 L
.52252 .91263 L
.5265 .9119 L
.53173 .91263 L
.52945 .9202 L
.53407 .92422 L
.54164 .92459 L
.54364 .92777 L
.54921 .92933 L
.55678 .93153 L
.56435 .93166 L
.57193 .93008 L
.5795 .92848 L
.58212 .92777 L
.58707 .92627 L
.59464 .92508 L
.60221 .92358 L
.60978 .92251 L
.61735 .92101 L
.62167 .9202 L
.62492 .9193 L
.6325 .916 L
.63545 .91263 L
.63957 .90506 L
.64007 .90406 L
.64764 .90121 L
.6522 .89749 L
.65454 .88992 L
.65521 .88919 L
.65592 .88992 L
.66278 .894 L
.67035 .89365 L
.67792 .8937 L
.68388 .89749 L
.68549 .89938 L
.69306 .89834 L
.69532 .89749 L
.70064 .89471 L
.70821 .89147 L
.70957 .88992 L
.70821 .8851 L
.70723 .88234 L
.70533 .87477 L
.70619 .8672 L
.70821 .86094 L
.71096 .8672 L
.71578 .87003 L
.72335 .86808 L
.72443 .8672 L
.72845 .85963 L
.73092 .85636 L
.73428 .85963 L
.73702 .8672 L
.73847 .87477 L
.73849 .87479 L
.7398 .87477 L
.74606 .87211 L
.75363 .86824 L
.75643 .8672 L
.76121 .86521 L
.76878 .85965 L
.7688 .85963 L
.77635 .85615 L
.78189 .85206 L
.77635 .84984 L
.77358 .84449 L
.7701 .83692 L
.77635 .83553 L
.77845 .83692 L
.78242 .84449 L
.78392 .85014 L
.79149 .84568 L
.79349 .84449 L
.79906 .83921 L
.80119 .83692 L
.80663 .8328 L
.80925 .82935 L
.80663 .82812 L
.79906 .8236 L
.7982 .82177 L
.79765 .8142 L
.79906 .81324 L
.80061 .8142 L
.80663 .81958 L
.80989 .82177 L
.8142 .82727 L
.82177 .82179 L
.8218 .82177 L
.82935 .81672 L
.8321 .8142 L
.83692 .80867 L
.83849 .80663 L
.8434 .79906 L
.83692 .79567 L
.83241 .79149 L
.82935 .78801 L
.82743 .78392 L
.82856 .77635 L
.82935 .7749 L
.83077 .77635 L
.83692 .78175 L
.84449 .77698 L
.84577 .77635 L
.85206 .77383 L
.85765 .77635 L
.85963 .7788 L
.86393 .77635 L
.8672 .77378 L
.87477 .76879 L
.87479 .76878 L
.87869 .76121 L
.88234 .75603 L
.88348 .75363 L
.88234 .75113 L
.8795 .74606 L
.87748 .73849 L
.88138 .73092 L
.87739 .72335 L
.88234 .71883 L
.88992 .71677 L
.89118 .71578 L
.89749 .71162 L
.90506 .71188 L
.91263 .71125 L
.91525 .70821 L
.9202 .70065 L
.92021 .70064 L
.92619 .69306 L
.92777 .68553 L
.92778 .68549 L
.93256 .67792 L
.93534 .67478 L
.93823 .67035 L
.94115 .66278 L
.94291 .65765 L
.94387 .65521 L
.94802 .64764 L
.95048 .64198 L
.95135 .64007 L
.95523 .6325 L
.95806 .62682 L
.95894 .62492 L
.96379 .61735 L
.96563 .60982 L
.96564 .60978 L
.97042 .60221 L
.97067 .59464 L
.9732 .5889 L
.97409 .58707 L
.97609 .5795 L
.98077 .57195 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .49928 m
.01993 .50379 L
.02082 .51136 L
.02237 .51893 L
.02392 .5265 L
.02526 .53407 L
.02679 .54164 L
.0268 .54168 L
.02903 .54921 L
.03134 .55678 L
.03361 .56435 L
.03437 .56562 L
.03774 .57193 L
.03891 .5795 L
.04117 .58707 L
.04194 .58923 L
.04421 .59464 L
.04877 .60221 L
.04951 .60978 L
.04952 .6098 L
.05475 .61735 L
.05622 .62492 L
.05709 .62757 L
.05959 .6325 L
.06312 .64007 L
.06466 .64326 L
.06687 .64764 L
.07069 .65521 L
.07223 .65836 L
.07465 .66278 L
.0798 .66905 L
.08059 .67035 L
.08399 .67792 L
.08737 .68415 L
.08816 .68549 L
.09401 .69306 L
.09494 .69482 L
.09812 .70064 L
.10251 .70547 L
.1053 .70821 L
.11008 .71098 L
.11766 .70888 L
.12373 .71578 L
.12004 .72335 L
.12393 .73092 L
.12523 .73217 L
.13218 .73849 L
.1328 .7385 L
.13281 .73849 L
.14037 .7349 L
Mistroke
.14794 .73567 L
.15033 .73849 L
.14794 .74137 L
.14612 .74606 L
.14794 .74978 L
.15551 .7528 L
.16207 .75363 L
.16308 .75397 L
.16945 .76121 L
.16772 .76878 L
.16308 .77523 L
.16227 .77635 L
.16306 .78392 L
.16308 .78394 L
.16735 .79149 L
.17065 .79437 L
.17524 .79906 L
.17823 .80232 L
.1831 .80663 L
.1858 .80916 L
.19178 .8142 L
.19337 .81551 L
.20094 .81916 L
.20539 .8142 L
.20851 .81262 L
.21608 .80889 L
.21905 .8142 L
.21608 .82057 L
.21555 .82177 L
.21523 .82935 L
.21608 .83335 L
.22156 .83692 L
.22365 .83758 L
.23122 .84124 L
.23466 .84449 L
.23879 .85168 L
.23958 .85206 L
.24637 .858 L
.2482 .85963 L
.25394 .86129 L
.25478 .85963 L
.26151 .85238 L
.262 .85206 L
.26908 .84837 L
.27142 .85206 L
.27105 .85963 L
.27132 .8672 L
.27665 .87269 L
.28422 .87354 L
.29179 .86755 L
Mistroke
.29749 .87477 L
.29337 .88234 L
.29658 .88992 L
.29936 .89142 L
.30694 .89418 L
.31451 .89662 L
.3158 .89749 L
.32208 .89749 L
.32208 .89749 L
.32574 .88992 L
.32965 .88507 L
.33292 .88234 L
.33722 .87897 L
.33788 .88234 L
.33788 .88992 L
.3409 .89749 L
.34479 .89967 L
.35236 .898 L
.35937 .90506 L
.35882 .91263 L
.35993 .91392 L
.3675 .91781 L
.37501 .9202 L
.37508 .92021 L
.38265 .92104 L
.39022 .92324 L
.39779 .92475 L
.40536 .9256 L
.41293 .92567 L
.42047 .92777 L
.4205 .92778 L
.42807 .92856 L
.43565 .92778 L
.43565 .92777 L
.44024 .9202 L
.44322 .91712 L
.44667 .91263 L
.45079 .90577 L
.4556 .91263 L
.45553 .9202 L
.45698 .92777 L
.45836 .92895 L
.45889 .92777 L
.46057 .9202 L
.4614 .91263 L
.45836 .90862 L
.45206 .90506 L
.45836 .90193 L
.4617 .90506 L
.46593 .90742 L
Mistroke
.4735 .90788 L
.47908 .90506 L
.48107 .9033 L
.48391 .90506 L
.48864 .91001 L
.48996 .91263 L
.49429 .9202 L
.49621 .92212 L
.5013 .92777 L
.50379 .9311 L
.51136 .93153 L
.51466 .92777 L
.51847 .9202 L
.51893 .91895 L
.52252 .91263 L
.5265 .9119 L
.53173 .91263 L
.52945 .9202 L
.53407 .92422 L
.54164 .92459 L
.54364 .92777 L
.54921 .92933 L
.55678 .93153 L
.56435 .93166 L
.57193 .93008 L
.5795 .92848 L
.58212 .92777 L
.58707 .92627 L
.59464 .92508 L
.60221 .92358 L
.60978 .92251 L
.61735 .92101 L
.62167 .9202 L
.62492 .9193 L
.6325 .916 L
.63545 .91263 L
.63957 .90506 L
.64007 .90406 L
.64764 .90121 L
.6522 .89749 L
.65454 .88992 L
.65521 .88919 L
.65592 .88992 L
.66278 .894 L
.67035 .89365 L
.67792 .8937 L
.68388 .89749 L
.68549 .89938 L
.69306 .89834 L
.69532 .89749 L
Mistroke
.70064 .89471 L
.70821 .89147 L
.70957 .88992 L
.70821 .8851 L
.70723 .88234 L
.70533 .87477 L
.70619 .8672 L
.70821 .86094 L
.71096 .8672 L
.71578 .87003 L
.72335 .86808 L
.72443 .8672 L
.72845 .85963 L
.73092 .85636 L
.73428 .85963 L
.73702 .8672 L
.73847 .87477 L
.73849 .87479 L
.7398 .87477 L
.74606 .87211 L
.75363 .86824 L
.75643 .8672 L
.76121 .86521 L
.76878 .85965 L
.7688 .85963 L
.77635 .85615 L
.78189 .85206 L
.77635 .84984 L
.77358 .84449 L
.7701 .83692 L
.77635 .83553 L
.77845 .83692 L
.78242 .84449 L
.78392 .85014 L
.79149 .84568 L
.79349 .84449 L
.79906 .83921 L
.80119 .83692 L
.80663 .8328 L
.80925 .82935 L
.80663 .82812 L
.79906 .8236 L
.7982 .82177 L
.79765 .8142 L
.79906 .81324 L
.80061 .8142 L
.80663 .81958 L
.80989 .82177 L
.8142 .82727 L
.82177 .82179 L
Mistroke
.8218 .82177 L
.82935 .81672 L
.8321 .8142 L
.83692 .80867 L
.83849 .80663 L
.8434 .79906 L
.83692 .79567 L
.83241 .79149 L
.82935 .78801 L
.82743 .78392 L
.82856 .77635 L
.82935 .7749 L
.83077 .77635 L
.83692 .78175 L
.84449 .77698 L
.84577 .77635 L
.85206 .77383 L
.85765 .77635 L
.85963 .7788 L
.86393 .77635 L
.8672 .77378 L
.87477 .76879 L
.87479 .76878 L
.87869 .76121 L
.88234 .75603 L
.88348 .75363 L
.88234 .75113 L
.8795 .74606 L
.87748 .73849 L
.88138 .73092 L
.87739 .72335 L
.88234 .71883 L
.88992 .71677 L
.89118 .71578 L
.89749 .71162 L
.90506 .71188 L
.91263 .71125 L
.91525 .70821 L
.9202 .70065 L
.92021 .70064 L
.92619 .69306 L
.92777 .68553 L
.92778 .68549 L
.93256 .67792 L
.93534 .67478 L
.93823 .67035 L
.94115 .66278 L
.94291 .65765 L
.94387 .65521 L
.94802 .64764 L
Mistroke
.95048 .64198 L
.95135 .64007 L
.95523 .6325 L
.95806 .62682 L
.95894 .62492 L
.96379 .61735 L
.96563 .60982 L
.96564 .60978 L
.97042 .60221 L
.97067 .59464 L
.9732 .5889 L
.97409 .58707 L
.97609 .5795 L
.98077 .57195 L
Mfstroke
.8 g
.01923 .56958 m
.02025 .57193 L
.02137 .5795 L
.02367 .58707 L
.02654 .59464 L
.0268 .59507 L
.03037 .60221 L
.03137 .60978 L
.03437 .61382 L
.03697 .61735 L
.03758 .62492 L
.04081 .6325 L
.04194 .63504 L
.04391 .64007 L
.04709 .64764 L
.04952 .65205 L
.05148 .65521 L
.05465 .66278 L
.05709 .6639 L
.0608 .67035 L
.06352 .67792 L
.06466 .68018 L
.0673 .68549 L
.07223 .68953 L
.07425 .69306 L
.0765 .70064 L
.0798 .70743 L
.08038 .70821 L
.08699 .71578 L
.08737 .7163 L
.09232 .72335 L
.09494 .72366 L
.09869 .72335 L
.10251 .7227 L
.11008 .7198 L
.11288 .72335 L
.11086 .73092 L
.11008 .73369 L
.10808 .73849 L
.10976 .74606 L
.11008 .74672 L
.11766 .75211 L
.12523 .75039 L
.13231 .74606 L
.1328 .74581 L
.13884 .74606 L
.13918 .75363 L
.14037 .75625 L
.14447 .76121 L
.14037 .76463 L
.1328 .76824 L
.13215 .76878 L
.1328 .77554 L
.13332 .77635 L
.14037 .77893 L
.14483 .77635 L
.14794 .77477 L
.15551 .77122 L
.15603 .77635 L
.15551 .77716 L
.15156 .78392 L
.14794 .79073 L
.14689 .79149 L
.14794 .7963 L
.15132 .79906 L
.15551 .80402 L
.15728 .80663 L
.16308 .81242 L
.1649 .8142 L
.17065 .81989 L
.17223 .82177 L
.17787 .82935 L
.17823 .82974 L
.1858 .83572 L
.18737 .83692 L
.19337 .83994 L
.19936 .83692 L
.20094 .82968 L
.20123 .82935 L
.20851 .82413 L
.20873 .82935 L
.21104 .83692 L
.21608 .84186 L
.22108 .84449 L
.22365 .84678 L
.22663 .85206 L
.22365 .85845 L
.22209 .85963 L
.22365 .86284 L
.22839 .8672 L
.23122 .86939 L
.23838 .87477 L
.23879 .8751 L
.24637 .88025 L
.24973 .88234 L
.25394 .88508 L
.26151 .88759 L
.26604 .88992 L
.26908 .89266 L
.27665 .89437 L
.27956 .89749 L
.28422 .90217 L
.2901 .90506 L
.29179 .90607 L
.29936 .91139 L
.30225 .91263 L
.30694 .91486 L
.31451 .91774 L
.32208 .91989 L
.32364 .9202 L
.32965 .9218 L
.33722 .92516 L
.34479 .92748 L
.3464 .92777 L
.35236 .92916 L
.35993 .93317 L
.36679 .93534 L
.3675 .93554 L
.37508 .93719 L
.38265 .93839 L
.39022 .94098 L
.39779 .94158 L
.40048 .94291 L
.40536 .94358 L
.41293 .94411 L
.4205 .94363 L
.42807 .94598 L
.43565 .94688 L
.44322 .94768 L
.45079 .94821 L
.45836 .94883 L
.46593 .94981 L
.4735 .94981 L
.48107 .95012 L
.48549 .95048 L
.48864 .9507 L
.49621 .9507 L
.49937 .95048 L
.50379 .95016 L
.51136 .94967 L
.51893 .94925 L
.5265 .94934 L
.53407 .94854 L
.54164 .94904 L
.54921 .94877 L
.55678 .94809 L
.56435 .94716 L
.57193 .94606 L
.5795 .94517 L
.58707 .94411 L
.59232 .94291 L
.59464 .94218 L
.60221 .94047 L
.60978 .93856 L
.61735 .93681 L
.62492 .93549 L
.62561 .93534 L
.6325 .93332 L
.64007 .93115 L
.64764 .92939 L
.65237 .92777 L
.65521 .92632 L
.66278 .92469 L
.67035 .92164 L
.67437 .9202 L
.67792 .9191 L
.68549 .91694 L
.69306 .91338 L
.69492 .91263 L
.70064 .91053 L
.70821 .90753 L
.71294 .90506 L
.71578 .90292 L
.72335 .90123 L
.72877 .89749 L
.73092 .89647 L
.73849 .8922 L
.74212 .88992 L
.74606 .88825 L
.75363 .88324 L
.75546 .88234 L
.76121 .87955 L
.76825 .87477 L
.76878 .87396 L
.77635 .86982 L
.78054 .8672 L
.78392 .86466 L
.79058 .85963 L
.79149 .85879 L
.79906 .85316 L
.80089 .85206 L
.80663 .84989 L
.81318 .84449 L
.8142 .84317 L
.82055 .83692 L
.82177 .836 L
.82927 .82935 L
.82935 .82927 L
.83692 .82358 L
.83961 .82177 L
.84449 .81794 L
.84804 .8142 L
.85206 .80932 L
.85454 .80663 L
.85963 .80251 L
.86227 .79906 L
.8672 .79166 L
.86732 .79149 L
.87477 .78431 L
.87519 .78392 L
.88205 .77635 L
.88234 .77548 L
.88966 .76878 L
.88992 .76813 L
.89616 .76121 L
.89749 .75724 L
.90067 .75363 L
.90506 .74996 L
.9084 .74606 L
.91263 .73966 L
.91316 .73849 L
.91859 .73092 L
.9202 .72761 L
.92259 .72335 L
.92698 .71578 L
.92777 .71513 L
.93268 .70821 L
.93534 .70254 L
.93615 .70064 L
.9423 .69306 L
.94291 .69206 L
.9456 .68549 L
.94923 .67792 L
.95048 .67623 L
.95542 .67035 L
.95733 .66278 L
.95806 .66161 L
.96126 .65521 L
.96463 .64764 L
.96563 .64692 L
.96976 .64007 L
.97155 .6325 L
.9732 .62983 L
.97589 .62492 L
.9802 .61735 L
.98077 .61588 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .56958 m
.02025 .57193 L
.02137 .5795 L
.02367 .58707 L
.02654 .59464 L
.0268 .59507 L
.03037 .60221 L
.03137 .60978 L
.03437 .61382 L
.03697 .61735 L
.03758 .62492 L
.04081 .6325 L
.04194 .63504 L
.04391 .64007 L
.04709 .64764 L
.04952 .65205 L
.05148 .65521 L
.05465 .66278 L
.05709 .6639 L
.0608 .67035 L
.06352 .67792 L
.06466 .68018 L
.0673 .68549 L
.07223 .68953 L
.07425 .69306 L
.0765 .70064 L
.0798 .70743 L
.08038 .70821 L
.08699 .71578 L
.08737 .7163 L
.09232 .72335 L
.09494 .72366 L
.09869 .72335 L
.10251 .7227 L
.11008 .7198 L
.11288 .72335 L
.11086 .73092 L
.11008 .73369 L
.10808 .73849 L
.10976 .74606 L
.11008 .74672 L
.11766 .75211 L
.12523 .75039 L
.13231 .74606 L
.1328 .74581 L
.13884 .74606 L
.13918 .75363 L
.14037 .75625 L
.14447 .76121 L
.14037 .76463 L
Mistroke
.1328 .76824 L
.13215 .76878 L
.1328 .77554 L
.13332 .77635 L
.14037 .77893 L
.14483 .77635 L
.14794 .77477 L
.15551 .77122 L
.15603 .77635 L
.15551 .77716 L
.15156 .78392 L
.14794 .79073 L
.14689 .79149 L
.14794 .7963 L
.15132 .79906 L
.15551 .80402 L
.15728 .80663 L
.16308 .81242 L
.1649 .8142 L
.17065 .81989 L
.17223 .82177 L
.17787 .82935 L
.17823 .82974 L
.1858 .83572 L
.18737 .83692 L
.19337 .83994 L
.19936 .83692 L
.20094 .82968 L
.20123 .82935 L
.20851 .82413 L
.20873 .82935 L
.21104 .83692 L
.21608 .84186 L
.22108 .84449 L
.22365 .84678 L
.22663 .85206 L
.22365 .85845 L
.22209 .85963 L
.22365 .86284 L
.22839 .8672 L
.23122 .86939 L
.23838 .87477 L
.23879 .8751 L
.24637 .88025 L
.24973 .88234 L
.25394 .88508 L
.26151 .88759 L
.26604 .88992 L
.26908 .89266 L
.27665 .89437 L
Mistroke
.27956 .89749 L
.28422 .90217 L
.2901 .90506 L
.29179 .90607 L
.29936 .91139 L
.30225 .91263 L
.30694 .91486 L
.31451 .91774 L
.32208 .91989 L
.32364 .9202 L
.32965 .9218 L
.33722 .92516 L
.34479 .92748 L
.3464 .92777 L
.35236 .92916 L
.35993 .93317 L
.36679 .93534 L
.3675 .93554 L
.37508 .93719 L
.38265 .93839 L
.39022 .94098 L
.39779 .94158 L
.40048 .94291 L
.40536 .94358 L
.41293 .94411 L
.4205 .94363 L
.42807 .94598 L
.43565 .94688 L
.44322 .94768 L
.45079 .94821 L
.45836 .94883 L
.46593 .94981 L
.4735 .94981 L
.48107 .95012 L
.48549 .95048 L
.48864 .9507 L
.49621 .9507 L
.49937 .95048 L
.50379 .95016 L
.51136 .94967 L
.51893 .94925 L
.5265 .94934 L
.53407 .94854 L
.54164 .94904 L
.54921 .94877 L
.55678 .94809 L
.56435 .94716 L
.57193 .94606 L
.5795 .94517 L
.58707 .94411 L
Mistroke
.59232 .94291 L
.59464 .94218 L
.60221 .94047 L
.60978 .93856 L
.61735 .93681 L
.62492 .93549 L
.62561 .93534 L
.6325 .93332 L
.64007 .93115 L
.64764 .92939 L
.65237 .92777 L
.65521 .92632 L
.66278 .92469 L
.67035 .92164 L
.67437 .9202 L
.67792 .9191 L
.68549 .91694 L
.69306 .91338 L
.69492 .91263 L
.70064 .91053 L
.70821 .90753 L
.71294 .90506 L
.71578 .90292 L
.72335 .90123 L
.72877 .89749 L
.73092 .89647 L
.73849 .8922 L
.74212 .88992 L
.74606 .88825 L
.75363 .88324 L
.75546 .88234 L
.76121 .87955 L
.76825 .87477 L
.76878 .87396 L
.77635 .86982 L
.78054 .8672 L
.78392 .86466 L
.79058 .85963 L
.79149 .85879 L
.79906 .85316 L
.80089 .85206 L
.80663 .84989 L
.81318 .84449 L
.8142 .84317 L
.82055 .83692 L
.82177 .836 L
.82927 .82935 L
.82935 .82927 L
.83692 .82358 L
.83961 .82177 L
Mistroke
.84449 .81794 L
.84804 .8142 L
.85206 .80932 L
.85454 .80663 L
.85963 .80251 L
.86227 .79906 L
.8672 .79166 L
.86732 .79149 L
.87477 .78431 L
.87519 .78392 L
.88205 .77635 L
.88234 .77548 L
.88966 .76878 L
.88992 .76813 L
.89616 .76121 L
.89749 .75724 L
.90067 .75363 L
.90506 .74996 L
.9084 .74606 L
.91263 .73966 L
.91316 .73849 L
.91859 .73092 L
.9202 .72761 L
.92259 .72335 L
.92698 .71578 L
.92777 .71513 L
.93268 .70821 L
.93534 .70254 L
.93615 .70064 L
.9423 .69306 L
.94291 .69206 L
.9456 .68549 L
.94923 .67792 L
.95048 .67623 L
.95542 .67035 L
.95733 .66278 L
.95806 .66161 L
.96126 .65521 L
.96463 .64764 L
.96563 .64692 L
.96976 .64007 L
.97155 .6325 L
.9732 .62983 L
.97589 .62492 L
.9802 .61735 L
.98077 .61588 L
Mfstroke
.9 g
.01923 .62285 m
.01946 .62492 L
.02322 .6325 L
.02635 .64007 L
.0268 .641 L
.03039 .64764 L
.03325 .65521 L
.03437 .65755 L
.03721 .66278 L
.04194 .66895 L
.04288 .67035 L
.04553 .67792 L
.04952 .68526 L
.04972 .68549 L
.05587 .69306 L
.05709 .69705 L
.05793 .70064 L
.06214 .70821 L
.06466 .71293 L
.06633 .71578 L
.07029 .72335 L
.07223 .72615 L
.07691 .73092 L
.0798 .73497 L
.08194 .73849 L
.08737 .74293 L
.08839 .74606 L
.08964 .75363 L
.09494 .761 L
.09514 .76121 L
.10251 .76808 L
.10327 .76878 L
.1074 .77635 L
.11008 .77973 L
.11391 .78392 L
.11766 .78848 L
.12037 .79149 L
.12523 .79622 L
.12883 .79906 L
.1328 .8032 L
.13536 .80663 L
.14037 .81164 L
.14325 .8142 L
.14794 .81896 L
.15163 .82177 L
.15551 .82717 L
.15791 .82935 L
.16308 .83408 L
.16615 .83692 L
.17065 .84043 L
.17682 .84449 L
.17823 .84553 L
.18381 .85206 L
.1858 .85376 L
.19337 .85902 L
.19494 .85963 L
.20094 .86396 L
.20691 .8672 L
.20851 .86818 L
.21608 .87361 L
.21761 .87477 L
.22365 .87813 L
.22851 .88234 L
.23122 .88386 L
.23879 .88732 L
.24151 .88992 L
.24637 .89225 L
.25394 .89585 L
.25768 .89749 L
.26151 .89936 L
.26908 .90443 L
.26986 .90506 L
.27665 .90834 L
.28422 .9119 L
.28578 .91263 L
.29179 .91535 L
.29936 .91871 L
.30243 .9202 L
.30694 .92211 L
.31451 .92431 L
.32208 .92757 L
.32284 .92777 L
.32965 .93018 L
.33722 .93204 L
.3444 .93534 L
.34479 .93552 L
.35236 .9379 L
.35993 .9396 L
.3675 .94268 L
.36851 .94291 L
.37508 .94462 L
.38265 .94587 L
.39022 .94441 L
.39779 .94834 L
.40536 .95023 L
.4069 .95048 L
.41293 .95163 L
.4205 .95265 L
.42807 .95349 L
.43565 .95422 L
.44322 .95353 L
.45079 .9558 L
.45836 .95633 L
.46593 .95676 L
.4735 .95725 L
.48107 .95763 L
.48864 .95783 L
.49621 .95782 L
.50379 .95755 L
.51136 .95727 L
.51893 .95674 L
.5265 .95605 L
.53407 .95538 L
.54164 .95411 L
.54921 .95484 L
.55678 .95448 L
.56435 .95399 L
.57193 .95332 L
.5795 .95228 L
.58671 .95048 L
.58707 .95042 L
.59464 .94882 L
.60221 .94519 L
.60978 .94624 L
.61735 .94406 L
.62061 .94291 L
.62492 .94154 L
.6325 .9376 L
.64007 .93809 L
.64764 .93558 L
.6481 .93534 L
.65521 .93122 L
.66278 .9308 L
.67012 .92777 L
.67035 .92768 L
.67792 .92229 L
.68549 .92289 L
.69052 .9202 L
.69306 .91885 L
.70064 .91671 L
.70821 .9136 L
.70887 .91263 L
.71578 .90972 L
.72335 .90563 L
.72429 .90506 L
.73092 .90236 L
.73849 .89912 L
.73968 .89749 L
.74606 .89458 L
.75273 .88992 L
.75363 .88926 L
.76121 .88581 L
.76537 .88234 L
.76878 .87936 L
.77635 .87581 L
.77781 .87477 L
.78392 .87106 L
.7887 .8672 L
.79149 .86483 L
.79906 .86037 L
.79999 .85963 L
.80663 .8549 L
.81022 .85206 L
.8142 .84995 L
.82158 .84449 L
.82177 .84431 L
.82847 .83692 L
.82935 .83603 L
.83692 .82963 L
.83727 .82935 L
.84449 .82472 L
.84795 .82177 L
.85206 .81796 L
.8555 .8142 L
.85963 .81016 L
.86316 .80663 L
.8672 .80249 L
.87044 .79906 L
.87477 .79239 L
.87561 .79149 L
.88234 .78429 L
.88268 .78392 L
.88891 .77635 L
.88992 .77536 L
.8973 .76878 L
.89749 .76854 L
.90174 .76121 L
.90506 .75613 L
.90756 .75363 L
.91263 .74875 L
.91481 .74606 L
.91936 .73849 L
.9202 .73764 L
.92572 .73092 L
.92777 .72465 L
.92848 .72335 L
.93191 .71578 L
.93534 .71187 L
.93922 .70821 L
.94271 .70064 L
.94291 .70046 L
.94819 .69306 L
.95048 .68936 L
.95237 .68549 L
.9563 .67792 L
.95806 .67288 L
.96273 .67035 L
.96169 .66278 L
.96563 .65892 L
.96803 .65521 L
.97129 .64764 L
.9732 .6417 L
.97439 .64007 L
.97785 .6325 L
.98077 .62528 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .62285 m
.01946 .62492 L
.02322 .6325 L
.02635 .64007 L
.0268 .641 L
.03039 .64764 L
.03325 .65521 L
.03437 .65755 L
.03721 .66278 L
.04194 .66895 L
.04288 .67035 L
.04553 .67792 L
.04952 .68526 L
.04972 .68549 L
.05587 .69306 L
.05709 .69705 L
.05793 .70064 L
.06214 .70821 L
.06466 .71293 L
.06633 .71578 L
.07029 .72335 L
.07223 .72615 L
.07691 .73092 L
.0798 .73497 L
.08194 .73849 L
.08737 .74293 L
.08839 .74606 L
.08964 .75363 L
.09494 .761 L
.09514 .76121 L
.10251 .76808 L
.10327 .76878 L
.1074 .77635 L
.11008 .77973 L
.11391 .78392 L
.11766 .78848 L
.12037 .79149 L
.12523 .79622 L
.12883 .79906 L
.1328 .8032 L
.13536 .80663 L
.14037 .81164 L
.14325 .8142 L
.14794 .81896 L
.15163 .82177 L
.15551 .82717 L
.15791 .82935 L
.16308 .83408 L
.16615 .83692 L
.17065 .84043 L
Mistroke
.17682 .84449 L
.17823 .84553 L
.18381 .85206 L
.1858 .85376 L
.19337 .85902 L
.19494 .85963 L
.20094 .86396 L
.20691 .8672 L
.20851 .86818 L
.21608 .87361 L
.21761 .87477 L
.22365 .87813 L
.22851 .88234 L
.23122 .88386 L
.23879 .88732 L
.24151 .88992 L
.24637 .89225 L
.25394 .89585 L
.25768 .89749 L
.26151 .89936 L
.26908 .90443 L
.26986 .90506 L
.27665 .90834 L
.28422 .9119 L
.28578 .91263 L
.29179 .91535 L
.29936 .91871 L
.30243 .9202 L
.30694 .92211 L
.31451 .92431 L
.32208 .92757 L
.32284 .92777 L
.32965 .93018 L
.33722 .93204 L
.3444 .93534 L
.34479 .93552 L
.35236 .9379 L
.35993 .9396 L
.3675 .94268 L
.36851 .94291 L
.37508 .94462 L
.38265 .94587 L
.39022 .94441 L
.39779 .94834 L
.40536 .95023 L
.4069 .95048 L
.41293 .95163 L
.4205 .95265 L
.42807 .95349 L
.43565 .95422 L
Mistroke
.44322 .95353 L
.45079 .9558 L
.45836 .95633 L
.46593 .95676 L
.4735 .95725 L
.48107 .95763 L
.48864 .95783 L
.49621 .95782 L
.50379 .95755 L
.51136 .95727 L
.51893 .95674 L
.5265 .95605 L
.53407 .95538 L
.54164 .95411 L
.54921 .95484 L
.55678 .95448 L
.56435 .95399 L
.57193 .95332 L
.5795 .95228 L
.58671 .95048 L
.58707 .95042 L
.59464 .94882 L
.60221 .94519 L
.60978 .94624 L
.61735 .94406 L
.62061 .94291 L
.62492 .94154 L
.6325 .9376 L
.64007 .93809 L
.64764 .93558 L
.6481 .93534 L
.65521 .93122 L
.66278 .9308 L
.67012 .92777 L
.67035 .92768 L
.67792 .92229 L
.68549 .92289 L
.69052 .9202 L
.69306 .91885 L
.70064 .91671 L
.70821 .9136 L
.70887 .91263 L
.71578 .90972 L
.72335 .90563 L
.72429 .90506 L
.73092 .90236 L
.73849 .89912 L
.73968 .89749 L
.74606 .89458 L
.75273 .88992 L
Mistroke
.75363 .88926 L
.76121 .88581 L
.76537 .88234 L
.76878 .87936 L
.77635 .87581 L
.77781 .87477 L
.78392 .87106 L
.7887 .8672 L
.79149 .86483 L
.79906 .86037 L
.79999 .85963 L
.80663 .8549 L
.81022 .85206 L
.8142 .84995 L
.82158 .84449 L
.82177 .84431 L
.82847 .83692 L
.82935 .83603 L
.83692 .82963 L
.83727 .82935 L
.84449 .82472 L
.84795 .82177 L
.85206 .81796 L
.8555 .8142 L
.85963 .81016 L
.86316 .80663 L
.8672 .80249 L
.87044 .79906 L
.87477 .79239 L
.87561 .79149 L
.88234 .78429 L
.88268 .78392 L
.88891 .77635 L
.88992 .77536 L
.8973 .76878 L
.89749 .76854 L
.90174 .76121 L
.90506 .75613 L
.90756 .75363 L
.91263 .74875 L
.91481 .74606 L
.91936 .73849 L
.9202 .73764 L
.92572 .73092 L
.92777 .72465 L
.92848 .72335 L
.93191 .71578 L
.93534 .71187 L
.93922 .70821 L
.94271 .70064 L
Mistroke
.94291 .70046 L
.94819 .69306 L
.95048 .68936 L
.95237 .68549 L
.9563 .67792 L
.95806 .67288 L
.96273 .67035 L
.96169 .66278 L
.96563 .65892 L
.96803 .65521 L
.97129 .64764 L
.9732 .6417 L
.97439 .64007 L
.97785 .6325 L
.98077 .62528 L
Mfstroke
.8 g
.01923 .68517 m
.0194 .68549 L
.025 .69306 L
.0268 .69759 L
.028 .70064 L
.03096 .70821 L
.03437 .71166 L
.03727 .71578 L
.04194 .72289 L
.04234 .72335 L
.04877 .73092 L
.04952 .73184 L
.05264 .73849 L
.05709 .74298 L
.05822 .74606 L
.06222 .75363 L
.06466 .75659 L
.06618 .76121 L
.07223 .76679 L
.07567 .76878 L
.07893 .77635 L
.0798 .77763 L
.08468 .78392 L
.08737 .78712 L
.08966 .79149 L
.09494 .79777 L
.09726 .79906 L
.10251 .80428 L
.10435 .80663 L
.11008 .81261 L
.11274 .8142 L
.11766 .82112 L
.12 .82177 L
.12523 .82907 L
.12566 .82935 L
.1328 .8361 L
.13372 .83692 L
.14037 .84179 L
.14272 .84449 L
.14794 .84968 L
.15034 .85206 L
.15551 .85623 L
.15899 .85963 L
.16308 .86387 L
.1698 .8672 L
.17065 .86799 L
.17823 .87359 L
.17972 .87477 L
.1858 .87926 L
.18976 .88234 L
.19337 .88553 L
.20094 .88955 L
.20114 .88992 L
.20851 .89295 L
.21608 .89721 L
.21653 .89749 L
.22365 .90199 L
.22768 .90506 L
.23122 .90632 L
.23879 .91021 L
.24212 .91263 L
.24637 .91403 L
.25394 .9179 L
.25682 .9202 L
.26151 .92192 L
.26908 .92601 L
.27153 .92777 L
.27665 .92938 L
.28422 .93306 L
.28714 .93534 L
.29179 .93688 L
.29936 .94017 L
.30444 .94291 L
.30694 .94346 L
.31451 .94539 L
.32208 .94862 L
.32707 .95048 L
.32965 .95126 L
.33722 .95396 L
.34479 .95686 L
.34855 .95806 L
.35236 .95903 L
.35993 .9613 L
.3675 .96347 L
.37412 .96563 L
.37508 .96579 L
.38265 .96695 L
.39022 .96795 L
.39779 .9695 L
.40536 .97085 L
.41293 .97248 L
.41714 .9732 L
.4205 .97366 L
.42807 .97451 L
.43565 .97528 L
.44322 .97591 L
.45079 .97666 L
.45836 .97715 L
.46593 .97832 L
.4735 .97895 L
.48107 .98012 L
.48864 .97972 L
.49621 .98051 L
.50107 .98077 L
.01923 .98077 L
F
0 g
.01923 .68517 m
.0194 .68549 L
.025 .69306 L
.0268 .69759 L
.028 .70064 L
.03096 .70821 L
.03437 .71166 L
.03727 .71578 L
.04194 .72289 L
.04234 .72335 L
.04877 .73092 L
.04952 .73184 L
.05264 .73849 L
.05709 .74298 L
.05822 .74606 L
.06222 .75363 L
.06466 .75659 L
.06618 .76121 L
.07223 .76679 L
.07567 .76878 L
.07893 .77635 L
.0798 .77763 L
.08468 .78392 L
.08737 .78712 L
.08966 .79149 L
.09494 .79777 L
.09726 .79906 L
.10251 .80428 L
.10435 .80663 L
.11008 .81261 L
.11274 .8142 L
.11766 .82112 L
.12 .82177 L
.12523 .82907 L
.12566 .82935 L
.1328 .8361 L
.13372 .83692 L
.14037 .84179 L
.14272 .84449 L
.14794 .84968 L
.15034 .85206 L
.15551 .85623 L
.15899 .85963 L
.16308 .86387 L
.1698 .8672 L
.17065 .86799 L
.17823 .87359 L
.17972 .87477 L
.1858 .87926 L
.18976 .88234 L
Mistroke
.19337 .88553 L
.20094 .88955 L
.20114 .88992 L
.20851 .89295 L
.21608 .89721 L
.21653 .89749 L
.22365 .90199 L
.22768 .90506 L
.23122 .90632 L
.23879 .91021 L
.24212 .91263 L
.24637 .91403 L
.25394 .9179 L
.25682 .9202 L
.26151 .92192 L
.26908 .92601 L
.27153 .92777 L
.27665 .92938 L
.28422 .93306 L
.28714 .93534 L
.29179 .93688 L
.29936 .94017 L
.30444 .94291 L
.30694 .94346 L
.31451 .94539 L
.32208 .94862 L
.32707 .95048 L
.32965 .95126 L
.33722 .95396 L
.34479 .95686 L
.34855 .95806 L
.35236 .95903 L
.35993 .9613 L
.3675 .96347 L
.37412 .96563 L
.37508 .96579 L
.38265 .96695 L
.39022 .96795 L
.39779 .9695 L
.40536 .97085 L
.41293 .97248 L
.41714 .9732 L
.4205 .97366 L
.42807 .97451 L
.43565 .97528 L
.44322 .97591 L
.45079 .97666 L
.45836 .97715 L
.46593 .97832 L
.4735 .97895 L
Mistroke
.48107 .98012 L
.48864 .97972 L
.49621 .98051 L
.50107 .98077 L
Mfstroke
.7 g
.01923 .68855 m
.02188 .69306 L
.02479 .70064 L
.0268 .70452 L
.02788 .70821 L
.03437 .71572 L
.03441 .71578 L
.03874 .72335 L
.04194 .7268 L
.0452 .73092 L
.04952 .73672 L
.05004 .73849 L
.05575 .74606 L
.05709 .74879 L
.05866 .75363 L
.06466 .76115 L
.06466 .76121 L
.07214 .76878 L
.07223 .76895 L
.0751 .77635 L
.0798 .78228 L
.08123 .78392 L
.08737 .7912 L
.08749 .79149 L
.09494 .79906 L
.0952 .79906 L
.10242 .80663 L
.10251 .80674 L
.10924 .8142 L
.11008 .81505 L
.11634 .82177 L
.11766 .82348 L
.12179 .82935 L
.12523 .83303 L
.12978 .83692 L
.1328 .83934 L
.13977 .84449 L
.14037 .8451 L
.14655 .85206 L
.14794 .85345 L
.15551 .85923 L
.15584 .85963 L
.16308 .86651 L
.16559 .8672 L
.17065 .87167 L
.17537 .87477 L
.17823 .87699 L
.1858 .88219 L
.18597 .88234 L
.19337 .88865 L
.1967 .88992 L
.20094 .89275 L
.20851 .89572 L
.21102 .89749 L
.21608 .9011 L
.22237 .90506 L
.22365 .90593 L
.23122 .90971 L
.23607 .91263 L
.23879 .91444 L
.24637 .91757 L
.25071 .9202 L
.25394 .92258 L
.26151 .92531 L
.26532 .92777 L
.26908 .93038 L
.27665 .93268 L
.28126 .93534 L
.28422 .93739 L
.29179 .94026 L
.29724 .94291 L
.29936 .94415 L
.30694 .9461 L
.31451 .94878 L
.31766 .95048 L
.32208 .95282 L
.32965 .95481 L
.33722 .95775 L
.33791 .95806 L
.34479 .96135 L
.35236 .96248 L
.35993 .96499 L
.36212 .96563 L
.3675 .96771 L
.37508 .96841 L
.38265 .96974 L
.39022 .97133 L
.39676 .9732 L
.39779 .97341 L
.40536 .97464 L
.41293 .97617 L
.4205 .97717 L
.42807 .97808 L
.43565 .97895 L
.44322 .97975 L
.447 .98077 L
.01923 .98077 L
F
0 g
.01923 .68855 m
.02188 .69306 L
.02479 .70064 L
.0268 .70452 L
.02788 .70821 L
.03437 .71572 L
.03441 .71578 L
.03874 .72335 L
.04194 .7268 L
.0452 .73092 L
.04952 .73672 L
.05004 .73849 L
.05575 .74606 L
.05709 .74879 L
.05866 .75363 L
.06466 .76115 L
.06466 .76121 L
.07214 .76878 L
.07223 .76895 L
.0751 .77635 L
.0798 .78228 L
.08123 .78392 L
.08737 .7912 L
.08749 .79149 L
.09494 .79906 L
.0952 .79906 L
.10242 .80663 L
.10251 .80674 L
.10924 .8142 L
.11008 .81505 L
.11634 .82177 L
.11766 .82348 L
.12179 .82935 L
.12523 .83303 L
.12978 .83692 L
.1328 .83934 L
.13977 .84449 L
.14037 .8451 L
.14655 .85206 L
.14794 .85345 L
.15551 .85923 L
.15584 .85963 L
.16308 .86651 L
.16559 .8672 L
.17065 .87167 L
.17537 .87477 L
.17823 .87699 L
.1858 .88219 L
.18597 .88234 L
.19337 .88865 L
Mistroke
.1967 .88992 L
.20094 .89275 L
.20851 .89572 L
.21102 .89749 L
.21608 .9011 L
.22237 .90506 L
.22365 .90593 L
.23122 .90971 L
.23607 .91263 L
.23879 .91444 L
.24637 .91757 L
.25071 .9202 L
.25394 .92258 L
.26151 .92531 L
.26532 .92777 L
.26908 .93038 L
.27665 .93268 L
.28126 .93534 L
.28422 .93739 L
.29179 .94026 L
.29724 .94291 L
.29936 .94415 L
.30694 .9461 L
.31451 .94878 L
.31766 .95048 L
.32208 .95282 L
.32965 .95481 L
.33722 .95775 L
.33791 .95806 L
.34479 .96135 L
.35236 .96248 L
.35993 .96499 L
.36212 .96563 L
.3675 .96771 L
.37508 .96841 L
.38265 .96974 L
.39022 .97133 L
.39676 .9732 L
.39779 .97341 L
.40536 .97464 L
.41293 .97617 L
.4205 .97717 L
.42807 .97808 L
.43565 .97895 L
.44322 .97975 L
.447 .98077 L
Mfstroke
.6 g
.01923 .69282 m
.01933 .69306 L
.02188 .70064 L
.0267 .70821 L
.0268 .70879 L
.03133 .71578 L
.03437 .72091 L
.03571 .72335 L
.04194 .73021 L
.04245 .73092 L
.04759 .73849 L
.04952 .74112 L
.05246 .74606 L
.05605 .75363 L
.05709 .75545 L
.06142 .76121 L
.06466 .76432 L
.06881 .76878 L
.07223 .77555 L
.07251 .77635 L
.07858 .78392 L
.0798 .7855 L
.08434 .79149 L
.08737 .79458 L
.09246 .79906 L
.09494 .80196 L
.09886 .80663 L
.10251 .81059 L
.10576 .8142 L
.11008 .81861 L
.11286 .82177 L
.11766 .82823 L
.11844 .82935 L
.12523 .83608 L
.12629 .83692 L
.1328 .84201 L
.13601 .84449 L
.14037 .84924 L
.14283 .85206 L
.14794 .85673 L
.15212 .85963 L
.15551 .86241 L
.16172 .8672 L
.16308 .86828 L
.17065 .87446 L
.17116 .87477 L
.17823 .88006 L
.18167 .88234 L
.1858 .88527 L
.193 .88992 L
.19337 .89012 L
.20094 .89502 L
.20696 .89749 L
.20851 .89854 L
.21608 .90403 L
.21776 .90506 L
.22365 .90906 L
.23122 .91252 L
.23139 .91263 L
.23879 .91747 L
.24596 .9202 L
.24637 .92043 L
.25394 .92562 L
.26087 .92777 L
.26151 .92812 L
.26908 .93323 L
.27643 .93534 L
.27665 .93546 L
.28422 .94045 L
.29179 .94291 L
.2918 .94291 L
.29936 .94711 L
.30694 .94837 L
.31222 .95048 L
.31451 .95167 L
.32208 .95569 L
.32965 .95763 L
.3307 .95806 L
.33722 .96083 L
.34479 .96407 L
.35236 .96514 L
.35375 .96563 L
.35993 .96787 L
.3675 .97067 L
.37508 .97059 L
.38265 .9721 L
.38714 .9732 L
.39022 .97404 L
.39779 .97616 L
.40536 .97726 L
.41293 .97858 L
.4205 .97957 L
.42807 .98059 L
.42945 .98077 L
.01923 .98077 L
F
0 g
.01923 .69282 m
.01933 .69306 L
.02188 .70064 L
.0267 .70821 L
.0268 .70879 L
.03133 .71578 L
.03437 .72091 L
.03571 .72335 L
.04194 .73021 L
.04245 .73092 L
.04759 .73849 L
.04952 .74112 L
.05246 .74606 L
.05605 .75363 L
.05709 .75545 L
.06142 .76121 L
.06466 .76432 L
.06881 .76878 L
.07223 .77555 L
.07251 .77635 L
.07858 .78392 L
.0798 .7855 L
.08434 .79149 L
.08737 .79458 L
.09246 .79906 L
.09494 .80196 L
.09886 .80663 L
.10251 .81059 L
.10576 .8142 L
.11008 .81861 L
.11286 .82177 L
.11766 .82823 L
.11844 .82935 L
.12523 .83608 L
.12629 .83692 L
.1328 .84201 L
.13601 .84449 L
.14037 .84924 L
.14283 .85206 L
.14794 .85673 L
.15212 .85963 L
.15551 .86241 L
.16172 .8672 L
.16308 .86828 L
.17065 .87446 L
.17116 .87477 L
.17823 .88006 L
.18167 .88234 L
.1858 .88527 L
.193 .88992 L
Mistroke
.19337 .89012 L
.20094 .89502 L
.20696 .89749 L
.20851 .89854 L
.21608 .90403 L
.21776 .90506 L
.22365 .90906 L
.23122 .91252 L
.23139 .91263 L
.23879 .91747 L
.24596 .9202 L
.24637 .92043 L
.25394 .92562 L
.26087 .92777 L
.26151 .92812 L
.26908 .93323 L
.27643 .93534 L
.27665 .93546 L
.28422 .94045 L
.29179 .94291 L
.2918 .94291 L
.29936 .94711 L
.30694 .94837 L
.31222 .95048 L
.31451 .95167 L
.32208 .95569 L
.32965 .95763 L
.3307 .95806 L
.33722 .96083 L
.34479 .96407 L
.35236 .96514 L
.35375 .96563 L
.35993 .96787 L
.3675 .97067 L
.37508 .97059 L
.38265 .9721 L
.38714 .9732 L
.39022 .97404 L
.39779 .97616 L
.40536 .97726 L
.41293 .97858 L
.4205 .97957 L
.42807 .98059 L
.42945 .98077 L
Mfstroke
.5 g
.01923 .70098 m
.02568 .70821 L
.0268 .71334 L
.02839 .71578 L
.03295 .72335 L
.03437 .72513 L
.03972 .73092 L
.04194 .73431 L
.04464 .73849 L
.04952 .74571 L
.04969 .74606 L
.05308 .75363 L
.05709 .75968 L
.05844 .76121 L
.06466 .76734 L
.0658 .76878 L
.06962 .77635 L
.07223 .78033 L
.07539 .78392 L
.0798 .78964 L
.08122 .79149 L
.08737 .79745 L
.08923 .79906 L
.09494 .80589 L
.09555 .80663 L
.10247 .8142 L
.10251 .81425 L
.10965 .82177 L
.11008 .82239 L
.11508 .82935 L
.11766 .83207 L
.12304 .83692 L
.12523 .83866 L
.13262 .84449 L
.1328 .84469 L
.13932 .85206 L
.14037 .85308 L
.14794 .85936 L
.14834 .85963 L
.15551 .86552 L
.15767 .8672 L
.16308 .87151 L
.1671 .87477 L
.17065 .8774 L
.1775 .88234 L
.17823 .88283 L
.1858 .88818 L
.18856 .88992 L
.19337 .89246 L
.20094 .89689 L
.20234 .89749 L
.20851 .90175 L
.21334 .90506 L
.21608 .9067 L
.22365 .91142 L
.2265 .91263 L
.23122 .91516 L
.23879 .91945 L
.24107 .9202 L
.24637 .9231 L
.25394 .92733 L
.25572 .92777 L
.26151 .93082 L
.26908 .93489 L
.27098 .93534 L
.27665 .93819 L
.28422 .94232 L
.28647 .94291 L
.29179 .94524 L
.29936 .94897 L
.30685 .95048 L
.30694 .95052 L
.31451 .9543 L
.32208 .95747 L
.32462 .95806 L
.32965 .96015 L
.33722 .96314 L
.34479 .96535 L
.34729 .96563 L
.35236 .9673 L
.35993 .97005 L
.3675 .97226 L
.37508 .97259 L
.37796 .9732 L
.38265 .97429 L
.39022 .97641 L
.39779 .97835 L
.40536 .97934 L
.41293 .98045 L
.4154 .98077 L
.01923 .98077 L
F
0 g
.01923 .70098 m
.02568 .70821 L
.0268 .71334 L
.02839 .71578 L
.03295 .72335 L
.03437 .72513 L
.03972 .73092 L
.04194 .73431 L
.04464 .73849 L
.04952 .74571 L
.04969 .74606 L
.05308 .75363 L
.05709 .75968 L
.05844 .76121 L
.06466 .76734 L
.0658 .76878 L
.06962 .77635 L
.07223 .78033 L
.07539 .78392 L
.0798 .78964 L
.08122 .79149 L
.08737 .79745 L
.08923 .79906 L
.09494 .80589 L
.09555 .80663 L
.10247 .8142 L
.10251 .81425 L
.10965 .82177 L
.11008 .82239 L
.11508 .82935 L
.11766 .83207 L
.12304 .83692 L
.12523 .83866 L
.13262 .84449 L
.1328 .84469 L
.13932 .85206 L
.14037 .85308 L
.14794 .85936 L
.14834 .85963 L
.15551 .86552 L
.15767 .8672 L
.16308 .87151 L
.1671 .87477 L
.17065 .8774 L
.1775 .88234 L
.17823 .88283 L
.1858 .88818 L
.18856 .88992 L
.19337 .89246 L
.20094 .89689 L
Mistroke
.20234 .89749 L
.20851 .90175 L
.21334 .90506 L
.21608 .9067 L
.22365 .91142 L
.2265 .91263 L
.23122 .91516 L
.23879 .91945 L
.24107 .9202 L
.24637 .9231 L
.25394 .92733 L
.25572 .92777 L
.26151 .93082 L
.26908 .93489 L
.27098 .93534 L
.27665 .93819 L
.28422 .94232 L
.28647 .94291 L
.29179 .94524 L
.29936 .94897 L
.30685 .95048 L
.30694 .95052 L
.31451 .9543 L
.32208 .95747 L
.32462 .95806 L
.32965 .96015 L
.33722 .96314 L
.34479 .96535 L
.34729 .96563 L
.35236 .9673 L
.35993 .97005 L
.3675 .97226 L
.37508 .97259 L
.37796 .9732 L
.38265 .97429 L
.39022 .97641 L
.39779 .97835 L
.40536 .97934 L
.41293 .98045 L
.4154 .98077 L
Mfstroke
.4 g
.01923 .70582 m
.02305 .70821 L
.0256 .71578 L
.0268 .71768 L
.03029 .72335 L
.03437 .728 L
.03708 .73092 L
.04188 .73849 L
.04194 .73859 L
.04702 .74606 L
.04952 .75182 L
.05032 .75363 L
.05567 .76121 L
.05709 .76275 L
.06294 .76878 L
.06466 .77203 L
.0668 .77635 L
.07223 .78375 L
.07239 .78392 L
.07841 .79149 L
.0798 .79299 L
.08633 .79906 L
.08737 .80031 L
.09266 .80663 L
.09494 .80951 L
.09926 .8142 L
.10251 .8174 L
.10656 .82177 L
.11008 .82693 L
.11179 .82935 L
.11766 .83505 L
.11992 .83692 L
.12523 .84105 L
.12943 .84449 L
.1328 .8484 L
.13594 .85206 L
.14037 .85616 L
.14474 .85963 L
.14794 .86204 L
.15401 .8672 L
.15551 .86835 L
.16308 .87461 L
.16328 .87477 L
.17065 .88023 L
.17358 .88234 L
.17823 .88546 L
.18442 .88992 L
.1858 .89038 L
.19337 .89467 L
.19812 .89749 L
.20094 .89951 L
.20851 .90489 L
.20876 .90506 L
.21608 .9093 L
.22191 .91263 L
.22365 .91341 L
.23122 .9176 L
.23635 .9202 L
.23879 .92128 L
.24637 .92548 L
.25097 .92777 L
.25394 .92914 L
.26151 .93326 L
.26586 .93534 L
.26908 .93669 L
.27665 .94069 L
.28137 .94291 L
.28422 .94356 L
.29179 .94728 L
.29936 .95023 L
.30069 .95048 L
.30694 .95284 L
.31451 .95662 L
.31859 .95806 L
.32208 .95902 L
.32965 .9624 L
.33722 .96491 L
.34056 .96563 L
.34479 .96616 L
.35236 .96914 L
.35993 .97172 L
.3675 .97309 L
.36905 .9732 L
.37508 .97452 L
.38265 .97643 L
.39022 .97858 L
.39779 .98019 L
.40262 .98077 L
.01923 .98077 L
F
0 g
.01923 .70582 m
.02305 .70821 L
.0256 .71578 L
.0268 .71768 L
.03029 .72335 L
.03437 .728 L
.03708 .73092 L
.04188 .73849 L
.04194 .73859 L
.04702 .74606 L
.04952 .75182 L
.05032 .75363 L
.05567 .76121 L
.05709 .76275 L
.06294 .76878 L
.06466 .77203 L
.0668 .77635 L
.07223 .78375 L
.07239 .78392 L
.07841 .79149 L
.0798 .79299 L
.08633 .79906 L
.08737 .80031 L
.09266 .80663 L
.09494 .80951 L
.09926 .8142 L
.10251 .8174 L
.10656 .82177 L
.11008 .82693 L
.11179 .82935 L
.11766 .83505 L
.11992 .83692 L
.12523 .84105 L
.12943 .84449 L
.1328 .8484 L
.13594 .85206 L
.14037 .85616 L
.14474 .85963 L
.14794 .86204 L
.15401 .8672 L
.15551 .86835 L
.16308 .87461 L
.16328 .87477 L
.17065 .88023 L
.17358 .88234 L
.17823 .88546 L
.18442 .88992 L
.1858 .89038 L
.19337 .89467 L
.19812 .89749 L
Mistroke
.20094 .89951 L
.20851 .90489 L
.20876 .90506 L
.21608 .9093 L
.22191 .91263 L
.22365 .91341 L
.23122 .9176 L
.23635 .9202 L
.23879 .92128 L
.24637 .92548 L
.25097 .92777 L
.25394 .92914 L
.26151 .93326 L
.26586 .93534 L
.26908 .93669 L
.27665 .94069 L
.28137 .94291 L
.28422 .94356 L
.29179 .94728 L
.29936 .95023 L
.30069 .95048 L
.30694 .95284 L
.31451 .95662 L
.31859 .95806 L
.32208 .95902 L
.32965 .9624 L
.33722 .96491 L
.34056 .96563 L
.34479 .96616 L
.35236 .96914 L
.35993 .97172 L
.3675 .97309 L
.36905 .9732 L
.37508 .97452 L
.38265 .97643 L
.39022 .97858 L
.39779 .98019 L
.40262 .98077 L
Mfstroke
.7 g
.01923 .33945 m
.01955 .33722 L
.02075 .32965 L
.02174 .32208 L
.02416 .31451 L
.02427 .30694 L
.02597 .29936 L
.0268 .29674 L
.02844 .29179 L
.03058 .28422 L
.03436 .27665 L
.03437 .27661 L
.03617 .26908 L
.03903 .26151 L
.03905 .25394 L
.04194 .24952 L
.04358 .24637 L
.04408 .23879 L
.04687 .23122 L
.0495 .22365 L
.04952 .22362 L
.05234 .21608 L
.05708 .20851 L
.05709 .20846 L
.05814 .20094 L
.06173 .19337 L
.06466 .18755 L
.06573 .1858 L
.0701 .17823 L
.07223 .17313 L
.07327 .17065 L
.07762 .16308 L
.0798 .15989 L
.08352 .15551 L
.08736 .14794 L
.08737 .1479 L
.09055 .14037 L
.09494 .13404 L
.09704 .1328 L
.1025 .12523 L
.10251 .12521 L
.10682 .11766 L
.11008 .11269 L
.11226 .11008 L
.11766 .10385 L
.11878 .10251 L
.12303 .09494 L
.12523 .09233 L
.12945 .08737 L
.1328 .08163 L
.13375 .0798 L
.14036 .07223 L
.14037 .07221 L
.14542 .06466 L
.14794 .06172 L
.14841 .05709 L
.15179 .04952 L
.15551 .04593 L
.1599 .04952 L
.16308 .05173 L
.16614 .05709 L
.1682 .06466 L
.16998 .07223 L
.17008 .0798 L
.17065 .08121 L
.17457 .08737 L
.17572 .09494 L
.17823 .10124 L
.17914 .10251 L
.18363 .11008 L
.1858 .11337 L
.18805 .11766 L
.19337 .12345 L
.19548 .12523 L
.20094 .13093 L
.20252 .1328 L
.20851 .14036 L
.20852 .14037 L
.21608 .14676 L
.21812 .14794 L
.22365 .15196 L
.22923 .15551 L
.23122 .15697 L
.23879 .16156 L
.2431 .16308 L
.24637 .16398 L
.25394 .16516 L
.26151 .16618 L
.26908 .16465 L
.27658 .16308 L
.27665 .16306 L
.28422 .15848 L
.29008 .15551 L
.29179 .15383 L
.29936 .15017 L
.30303 .14794 L
.30694 .14497 L
.31451 .1408 L
.3156 .14037 L
.32208 .13658 L
.32736 .1328 L
.32965 .13086 L
.3372 .12523 L
.33722 .12521 L
.34133 .11766 L
.34477 .11008 L
.34478 .10251 L
.34479 .09494 L
.34479 .0949 L
.35082 .08737 L
.35236 .08528 L
.35816 .0798 L
.35993 .07353 L
.36413 .07223 L
.3675 .07051 L
.3717 .06466 L
.37371 .05709 L
.37464 .04952 L
.37508 .04769 L
.3802 .04194 L
.38265 .03667 L
.386 .03437 L
.3888 .0268 L
.39022 .02429 L
.3935 .01923 L
.01923 .01923 L
F
0 g
.01923 .33945 m
.01955 .33722 L
.02075 .32965 L
.02174 .32208 L
.02416 .31451 L
.02427 .30694 L
.02597 .29936 L
.0268 .29674 L
.02844 .29179 L
.03058 .28422 L
.03436 .27665 L
.03437 .27661 L
.03617 .26908 L
.03903 .26151 L
.03905 .25394 L
.04194 .24952 L
.04358 .24637 L
.04408 .23879 L
.04687 .23122 L
.0495 .22365 L
.04952 .22362 L
.05234 .21608 L
.05708 .20851 L
.05709 .20846 L
.05814 .20094 L
.06173 .19337 L
.06466 .18755 L
.06573 .1858 L
.0701 .17823 L
.07223 .17313 L
.07327 .17065 L
.07762 .16308 L
.0798 .15989 L
.08352 .15551 L
.08736 .14794 L
.08737 .1479 L
.09055 .14037 L
.09494 .13404 L
.09704 .1328 L
.1025 .12523 L
.10251 .12521 L
.10682 .11766 L
.11008 .11269 L
.11226 .11008 L
.11766 .10385 L
.11878 .10251 L
.12303 .09494 L
.12523 .09233 L
.12945 .08737 L
.1328 .08163 L
Mistroke
.13375 .0798 L
.14036 .07223 L
.14037 .07221 L
.14542 .06466 L
.14794 .06172 L
.14841 .05709 L
.15179 .04952 L
.15551 .04593 L
.1599 .04952 L
.16308 .05173 L
.16614 .05709 L
.1682 .06466 L
.16998 .07223 L
.17008 .0798 L
.17065 .08121 L
.17457 .08737 L
.17572 .09494 L
.17823 .10124 L
.17914 .10251 L
.18363 .11008 L
.1858 .11337 L
.18805 .11766 L
.19337 .12345 L
.19548 .12523 L
.20094 .13093 L
.20252 .1328 L
.20851 .14036 L
.20852 .14037 L
.21608 .14676 L
.21812 .14794 L
.22365 .15196 L
.22923 .15551 L
.23122 .15697 L
.23879 .16156 L
.2431 .16308 L
.24637 .16398 L
.25394 .16516 L
.26151 .16618 L
.26908 .16465 L
.27658 .16308 L
.27665 .16306 L
.28422 .15848 L
.29008 .15551 L
.29179 .15383 L
.29936 .15017 L
.30303 .14794 L
.30694 .14497 L
.31451 .1408 L
.3156 .14037 L
.32208 .13658 L
Mistroke
.32736 .1328 L
.32965 .13086 L
.3372 .12523 L
.33722 .12521 L
.34133 .11766 L
.34477 .11008 L
.34478 .10251 L
.34479 .09494 L
.34479 .0949 L
.35082 .08737 L
.35236 .08528 L
.35816 .0798 L
.35993 .07353 L
.36413 .07223 L
.3675 .07051 L
.3717 .06466 L
.37371 .05709 L
.37464 .04952 L
.37508 .04769 L
.3802 .04194 L
.38265 .03667 L
.386 .03437 L
.3888 .0268 L
.39022 .02429 L
.3935 .01923 L
Mfstroke
.3 g
.01923 .70942 m
.02297 .71578 L
.0268 .72179 L
.02779 .72335 L
.03437 .73069 L
.03457 .73092 L
.0397 .73849 L
.04194 .74209 L
.04446 .74606 L
.04824 .75363 L
.04952 .75678 L
.05299 .76121 L
.05709 .76547 L
.06016 .76878 L
.06453 .77635 L
.06466 .77719 L
.07005 .78392 L
.07223 .78714 L
.07581 .79149 L
.0798 .79547 L
.0838 .79906 L
.08737 .80345 L
.09001 .80663 L
.09494 .81281 L
.09624 .8142 L
.10251 .82047 L
.10365 .82177 L
.10923 .82935 L
.11008 .83058 L
.11707 .83692 L
.11766 .83737 L
.12523 .84339 L
.12648 .84449 L
.1328 .85206 L
.1328 .85206 L
.14037 .85882 L
.1414 .85963 L
.14794 .86465 L
.15083 .8672 L
.15551 .87092 L
.15997 .87477 L
.16308 .87664 L
.17004 .88234 L
.17065 .88277 L
.17823 .88798 L
.18083 .88992 L
.1858 .89157 L
.19337 .89691 L
.19428 .89749 L
.20094 .90256 L
.20436 .90506 L
.20851 .90712 L
.21608 .91175 L
.21765 .91263 L
.22365 .9154 L
.23122 .91992 L
.23177 .9202 L
.23879 .92338 L
.24637 .92768 L
.24654 .92777 L
.25394 .93129 L
.26112 .93534 L
.26151 .93551 L
.26908 .93884 L
.27645 .94291 L
.27665 .94299 L
.28422 .94475 L
.29179 .9492 L
.29511 .95048 L
.29936 .95092 L
.30694 .95524 L
.31269 .95806 L
.31451 .95867 L
.32208 .9608 L
.32965 .96451 L
.33334 .96563 L
.33722 .96653 L
.34479 .96714 L
.35236 .97092 L
.35993 .97314 L
.36027 .9732 L
.3675 .97375 L
.37508 .97647 L
.38265 .97859 L
.39022 .98061 L
.39095 .98077 L
.01923 .98077 L
F
0 g
.01923 .70942 m
.02297 .71578 L
.0268 .72179 L
.02779 .72335 L
.03437 .73069 L
.03457 .73092 L
.0397 .73849 L
.04194 .74209 L
.04446 .74606 L
.04824 .75363 L
.04952 .75678 L
.05299 .76121 L
.05709 .76547 L
.06016 .76878 L
.06453 .77635 L
.06466 .77719 L
.07005 .78392 L
.07223 .78714 L
.07581 .79149 L
.0798 .79547 L
.0838 .79906 L
.08737 .80345 L
.09001 .80663 L
.09494 .81281 L
.09624 .8142 L
.10251 .82047 L
.10365 .82177 L
.10923 .82935 L
.11008 .83058 L
.11707 .83692 L
.11766 .83737 L
.12523 .84339 L
.12648 .84449 L
.1328 .85206 L
.1328 .85206 L
.14037 .85882 L
.1414 .85963 L
.14794 .86465 L
.15083 .8672 L
.15551 .87092 L
.15997 .87477 L
.16308 .87664 L
.17004 .88234 L
.17065 .88277 L
.17823 .88798 L
.18083 .88992 L
.1858 .89157 L
.19337 .89691 L
.19428 .89749 L
.20094 .90256 L
Mistroke
.20436 .90506 L
.20851 .90712 L
.21608 .91175 L
.21765 .91263 L
.22365 .9154 L
.23122 .91992 L
.23177 .9202 L
.23879 .92338 L
.24637 .92768 L
.24654 .92777 L
.25394 .93129 L
.26112 .93534 L
.26151 .93551 L
.26908 .93884 L
.27645 .94291 L
.27665 .94299 L
.28422 .94475 L
.29179 .9492 L
.29511 .95048 L
.29936 .95092 L
.30694 .95524 L
.31269 .95806 L
.31451 .95867 L
.32208 .9608 L
.32965 .96451 L
.33334 .96563 L
.33722 .96653 L
.34479 .96714 L
.35236 .97092 L
.35993 .97314 L
.36027 .9732 L
.3675 .97375 L
.37508 .97647 L
.38265 .97859 L
.39022 .98061 L
.39095 .98077 L
Mfstroke
.2 g
.01923 .71355 m
.02052 .71578 L
.0254 .72335 L
.0268 .72484 L
.0324 .73092 L
.03437 .73444 L
.0373 .73849 L
.04191 .74606 L
.04194 .74614 L
.04614 .75363 L
.04952 .76035 L
.05028 .76121 L
.05709 .76841 L
.05739 .76878 L
.06364 .77635 L
.06466 .78073 L
.06759 .78392 L
.07223 .79037 L
.0732 .79149 L
.0798 .79778 L
.08123 .79906 L
.08737 .80655 L
.08744 .80663 L
.09377 .8142 L
.09494 .81546 L
.10121 .82177 L
.10251 .82352 L
.10725 .82935 L
.11008 .83298 L
.11456 .83692 L
.11766 .83918 L
.12404 .84449 L
.12523 .84476 L
.13231 .85206 L
.1328 .85413 L
.13886 .85963 L
.14037 .86101 L
.1479 .8672 L
.14794 .86724 L
.15551 .87355 L
.15686 .87477 L
.16308 .87878 L
.16711 .88234 L
.17065 .88483 L
.17759 .88992 L
.17823 .89041 L
.1858 .89319 L
.19102 .89749 L
.19337 .89932 L
.2006 .90506 L
.20094 .90549 L
.20851 .90946 L
.2133 .91263 L
.21608 .91394 L
.22365 .91767 L
.22745 .9202 L
.23122 .9221 L
.23879 .92575 L
.24213 .92777 L
.24637 .92968 L
.25394 .93369 L
.25658 .93534 L
.26151 .9375 L
.26908 .94125 L
.2718 .94291 L
.27665 .94483 L
.28422 .94648 L
.29021 .95048 L
.29179 .95119 L
.29936 .95218 L
.30694 .95777 L
.30748 .95806 L
.31451 .96052 L
.32208 .96297 L
.32693 .96563 L
.32965 .96658 L
.33722 .96822 L
.34479 .96877 L
.35236 .97287 L
.3533 .9732 L
.35993 .9746 L
.3675 .97485 L
.37508 .97853 L
.38221 .98077 L
.01923 .98077 L
F
0 g
.01923 .71355 m
.02052 .71578 L
.0254 .72335 L
.0268 .72484 L
.0324 .73092 L
.03437 .73444 L
.0373 .73849 L
.04191 .74606 L
.04194 .74614 L
.04614 .75363 L
.04952 .76035 L
.05028 .76121 L
.05709 .76841 L
.05739 .76878 L
.06364 .77635 L
.06466 .78073 L
.06759 .78392 L
.07223 .79037 L
.0732 .79149 L
.0798 .79778 L
.08123 .79906 L
.08737 .80655 L
.08744 .80663 L
.09377 .8142 L
.09494 .81546 L
.10121 .82177 L
.10251 .82352 L
.10725 .82935 L
.11008 .83298 L
.11456 .83692 L
.11766 .83918 L
.12404 .84449 L
.12523 .84476 L
.13231 .85206 L
.1328 .85413 L
.13886 .85963 L
.14037 .86101 L
.1479 .8672 L
.14794 .86724 L
.15551 .87355 L
.15686 .87477 L
.16308 .87878 L
.16711 .88234 L
.17065 .88483 L
.17759 .88992 L
.17823 .89041 L
.1858 .89319 L
.19102 .89749 L
.19337 .89932 L
.2006 .90506 L
Mistroke
.20094 .90549 L
.20851 .90946 L
.2133 .91263 L
.21608 .91394 L
.22365 .91767 L
.22745 .9202 L
.23122 .9221 L
.23879 .92575 L
.24213 .92777 L
.24637 .92968 L
.25394 .93369 L
.25658 .93534 L
.26151 .9375 L
.26908 .94125 L
.2718 .94291 L
.27665 .94483 L
.28422 .94648 L
.29021 .95048 L
.29179 .95119 L
.29936 .95218 L
.30694 .95777 L
.30748 .95806 L
.31451 .96052 L
.32208 .96297 L
.32693 .96563 L
.32965 .96658 L
.33722 .96822 L
.34479 .96877 L
.35236 .97287 L
.3533 .9732 L
.35993 .9746 L
.3675 .97485 L
.37508 .97853 L
.38221 .98077 L
Mfstroke
.1 g
.01923 .71718 m
.02307 .72335 L
.0268 .72735 L
.03016 .73092 L
.03428 .73849 L
.03437 .7386 L
.03948 .74606 L
.04194 .75185 L
.04312 .75363 L
.04758 .76121 L
.04952 .76327 L
.05481 .76878 L
.05709 .77189 L
.06118 .77635 L
.06457 .78392 L
.06466 .78402 L
.07051 .79149 L
.07223 .7933 L
.07846 .79906 L
.0798 .80038 L
.085 .80663 L
.08737 .8091 L
.09162 .8142 L
.09494 .81775 L
.09896 .82177 L
.10251 .82718 L
.1044 .82935 L
.11008 .83581 L
.1113 .83692 L
.11766 .84101 L
.12186 .84449 L
.12523 .84686 L
.1303 .85206 L
.1328 .85618 L
.13662 .85963 L
.14037 .86308 L
.1454 .8672 L
.14794 .86964 L
.15391 .87477 L
.15551 .87633 L
.16308 .8817 L
.16377 .88234 L
.17065 .88698 L
.17467 .88992 L
.17823 .89271 L
.1858 .89597 L
.18746 .89749 L
.19337 .902 L
.19823 .90506 L
.20094 .9079 L
.20851 .91244 L
.20876 .91263 L
.21608 .91608 L
.22323 .9202 L
.22365 .92052 L
.23122 .9244 L
.23834 .92777 L
.23879 .92855 L
.24637 .93176 L
.25245 .93534 L
.25394 .93646 L
.26151 .93958 L
.26752 .94291 L
.26908 .94403 L
.27665 .94671 L
.28422 .94932 L
.28565 .95048 L
.29179 .95336 L
.29936 .95505 L
.30278 .95806 L
.30694 .96027 L
.31451 .96245 L
.32175 .96563 L
.32208 .96583 L
.32965 .96872 L
.33722 .97 L
.34479 .97164 L
.34715 .9732 L
.35236 .97525 L
.35993 .97638 L
.3675 .97699 L
.37489 .98077 L
.01923 .98077 L
F
0 g
.01923 .71718 m
.02307 .72335 L
.0268 .72735 L
.03016 .73092 L
.03428 .73849 L
.03437 .7386 L
.03948 .74606 L
.04194 .75185 L
.04312 .75363 L
.04758 .76121 L
.04952 .76327 L
.05481 .76878 L
.05709 .77189 L
.06118 .77635 L
.06457 .78392 L
.06466 .78402 L
.07051 .79149 L
.07223 .7933 L
.07846 .79906 L
.0798 .80038 L
.085 .80663 L
.08737 .8091 L
.09162 .8142 L
.09494 .81775 L
.09896 .82177 L
.10251 .82718 L
.1044 .82935 L
.11008 .83581 L
.1113 .83692 L
.11766 .84101 L
.12186 .84449 L
.12523 .84686 L
.1303 .85206 L
.1328 .85618 L
.13662 .85963 L
.14037 .86308 L
.1454 .8672 L
.14794 .86964 L
.15391 .87477 L
.15551 .87633 L
.16308 .8817 L
.16377 .88234 L
.17065 .88698 L
.17467 .88992 L
.17823 .89271 L
.1858 .89597 L
.18746 .89749 L
.19337 .902 L
.19823 .90506 L
.20094 .9079 L
Mistroke
.20851 .91244 L
.20876 .91263 L
.21608 .91608 L
.22323 .9202 L
.22365 .92052 L
.23122 .9244 L
.23834 .92777 L
.23879 .92855 L
.24637 .93176 L
.25245 .93534 L
.25394 .93646 L
.26151 .93958 L
.26752 .94291 L
.26908 .94403 L
.27665 .94671 L
.28422 .94932 L
.28565 .95048 L
.29179 .95336 L
.29936 .95505 L
.30278 .95806 L
.30694 .96027 L
.31451 .96245 L
.32175 .96563 L
.32208 .96583 L
.32965 .96872 L
.33722 .97 L
.34479 .97164 L
.34715 .9732 L
.35236 .97525 L
.35993 .97638 L
.3675 .97699 L
.37489 .98077 L
Mfstroke
.01923 .72055 m
.02076 .72335 L
.0268 .73012 L
.02757 .73092 L
.03059 .73849 L
.03437 .74258 L
.03672 .74606 L
.03903 .75363 L
.04194 .75711 L
.04457 .76121 L
.04952 .76629 L
.05194 .76878 L
.05609 .77635 L
.05709 .77764 L
.06085 .78392 L
.06466 .78782 L
.06749 .79149 L
.07223 .79634 L
.07529 .79906 L
.0798 .80354 L
.08226 .80663 L
.08737 .81189 L
.08927 .8142 L
.09494 .82028 L
.09645 .82177 L
.1002 .82935 L
.10251 .83202 L
.10703 .83692 L
.11008 .83991 L
.11766 .84301 L
.11947 .84449 L
.12481 .85206 L
.12523 .85252 L
.1328 .85843 L
.13414 .85963 L
.14037 .86536 L
.14265 .8672 L
.14794 .87234 L
.15079 .87477 L
.15551 .8795 L
.15962 .88234 L
.16308 .88558 L
.17065 .88944 L
.17131 .88992 L
.17823 .89531 L
.18287 .89749 L
.1858 .89991 L
.19287 .90506 L
.19337 .90549 L
.20094 .91057 L
.20443 .91263 L
.20851 .91622 L
.21608 .91848 L
.21914 .9202 L
.22365 .92398 L
.23122 .9271 L
.23337 .92777 L
.23879 .93188 L
.24637 .93415 L
.24842 .93534 L
.25394 .93976 L
.26151 .94197 L
.26325 .94291 L
.26908 .94733 L
.27665 .9488 L
.28087 .95048 L
.28422 .95313 L
.29179 .95588 L
.29718 .95806 L
.29936 .95966 L
.30694 .96313 L
.31451 .96466 L
.3168 .96563 L
.32208 .96936 L
.32965 .97115 L
.33722 .97201 L
.34103 .9732 L
.34479 .97637 L
.35236 .9783 L
.35993 .97875 L
.36749 .98077 L
.01923 .98077 L
F
.01923 .72055 m
.02076 .72335 L
.0268 .73012 L
.02757 .73092 L
.03059 .73849 L
.03437 .74258 L
.03672 .74606 L
.03903 .75363 L
.04194 .75711 L
.04457 .76121 L
.04952 .76629 L
.05194 .76878 L
.05609 .77635 L
.05709 .77764 L
.06085 .78392 L
.06466 .78782 L
.06749 .79149 L
.07223 .79634 L
.07529 .79906 L
.0798 .80354 L
.08226 .80663 L
.08737 .81189 L
.08927 .8142 L
.09494 .82028 L
.09645 .82177 L
.1002 .82935 L
.10251 .83202 L
.10703 .83692 L
.11008 .83991 L
.11766 .84301 L
.11947 .84449 L
.12481 .85206 L
.12523 .85252 L
.1328 .85843 L
.13414 .85963 L
.14037 .86536 L
.14265 .8672 L
.14794 .87234 L
.15079 .87477 L
.15551 .8795 L
.15962 .88234 L
.16308 .88558 L
.17065 .88944 L
.17131 .88992 L
.17823 .89531 L
.18287 .89749 L
.1858 .89991 L
.19287 .90506 L
.19337 .90549 L
.20094 .91057 L
Mistroke
.20443 .91263 L
.20851 .91622 L
.21608 .91848 L
.21914 .9202 L
.22365 .92398 L
.23122 .9271 L
.23337 .92777 L
.23879 .93188 L
.24637 .93415 L
.24842 .93534 L
.25394 .93976 L
.26151 .94197 L
.26325 .94291 L
.26908 .94733 L
.27665 .9488 L
.28087 .95048 L
.28422 .95313 L
.29179 .95588 L
.29718 .95806 L
.29936 .95966 L
.30694 .96313 L
.31451 .96466 L
.3168 .96563 L
.32208 .96936 L
.32965 .97115 L
.33722 .97201 L
.34103 .9732 L
.34479 .97637 L
.35236 .9783 L
.35993 .97875 L
.36749 .98077 L
Mfstroke
1 g
.01923 .67956 m
.02255 .68549 L
.0268 .6898 L
.02945 .69306 L
.03202 .70064 L
.03437 .70523 L
.03675 .70821 L
.04068 .71578 L
.04194 .71789 L
.04646 .72335 L
.04952 .72678 L
.05307 .73092 L
.05709 .73707 L
.05821 .73849 L
.06466 .74563 L
.06495 .74606 L
.06764 .75363 L
.07223 .76058 L
.07277 .76121 L
.0798 .76796 L
.08037 .76878 L
.08431 .77635 L
.08737 .78021 L
.09026 .78392 L
.09494 .79093 L
.09544 .79149 L
.10251 .79854 L
.10301 .79906 L
.11008 .80662 L
.11009 .80663 L
.11683 .8142 L
.11766 .81596 L
.12433 .82177 L
.12523 .82345 L
.13021 .82935 L
.1328 .83187 L
.13831 .83692 L
.14037 .83831 L
.14794 .84336 L
.14917 .84449 L
.1548 .85206 L
.15551 .85261 L
.16308 .85782 L
.16499 .85963 L
.17065 .86331 L
.17486 .8672 L
.17823 .8697 L
.18451 .87477 L
.1858 .87571 L
.19337 .88009 L
.19643 .88234 L
.20094 .8852 L
.20851 .88942 L
.2095 .88992 L
.21608 .89229 L
.22365 .89452 L
.22847 .88992 L
.22365 .88725 L
.21848 .88234 L
.21608 .88123 L
.20851 .87518 L
.20811 .87477 L
.20094 .8706 L
.19733 .8672 L
.19337 .86479 L
.18635 .85963 L
.1858 .85921 L
.17823 .8541 L
.17632 .85206 L
.17065 .84632 L
.16891 .84449 L
.16308 .84093 L
.15834 .83692 L
.15551 .83439 L
.15035 .82935 L
.14794 .82599 L
.14624 .82177 L
.14037 .81591 L
.1358 .8142 L
.1328 .811 L
.12839 .80663 L
.12523 .80032 L
.12156 .79906 L
.11766 .79588 L
.11362 .79149 L
.11008 .78821 L
.10516 .78392 L
.10251 .77977 L
.09835 .77635 L
.09494 .76933 L
.09454 .76878 L
.08737 .7625 L
.08629 .76121 L
.08129 .75363 L
.0798 .75186 L
.07662 .74606 L
.07223 .74019 L
.07094 .73849 L
.06762 .73092 L
.06466 .72856 L
.06013 .72335 L
.05709 .71852 L
.05384 .71578 L
.05075 .70821 L
.04952 .7075 L
.04614 .70064 L
.04459 .69306 L
.04194 .6908 L
.03848 .68549 L
.03437 .68215 L
.0327 .67792 L
.03142 .67035 L
.0268 .6641 L
.02382 .66278 L
.02149 .65521 L
.01923 .65144 L
F
0 g
.01923 .67956 m
.02255 .68549 L
.0268 .6898 L
.02945 .69306 L
.03202 .70064 L
.03437 .70523 L
.03675 .70821 L
.04068 .71578 L
.04194 .71789 L
.04646 .72335 L
.04952 .72678 L
.05307 .73092 L
.05709 .73707 L
.05821 .73849 L
.06466 .74563 L
.06495 .74606 L
.06764 .75363 L
.07223 .76058 L
.07277 .76121 L
.0798 .76796 L
.08037 .76878 L
.08431 .77635 L
.08737 .78021 L
.09026 .78392 L
.09494 .79093 L
.09544 .79149 L
.10251 .79854 L
.10301 .79906 L
.11008 .80662 L
.11009 .80663 L
.11683 .8142 L
.11766 .81596 L
.12433 .82177 L
.12523 .82345 L
.13021 .82935 L
.1328 .83187 L
.13831 .83692 L
.14037 .83831 L
.14794 .84336 L
.14917 .84449 L
.1548 .85206 L
.15551 .85261 L
.16308 .85782 L
.16499 .85963 L
.17065 .86331 L
.17486 .8672 L
.17823 .8697 L
.18451 .87477 L
.1858 .87571 L
.19337 .88009 L
Mistroke
.19643 .88234 L
.20094 .8852 L
.20851 .88942 L
.2095 .88992 L
.21608 .89229 L
.22365 .89452 L
.22847 .88992 L
.22365 .88725 L
.21848 .88234 L
.21608 .88123 L
.20851 .87518 L
.20811 .87477 L
.20094 .8706 L
.19733 .8672 L
.19337 .86479 L
.18635 .85963 L
.1858 .85921 L
.17823 .8541 L
.17632 .85206 L
.17065 .84632 L
.16891 .84449 L
.16308 .84093 L
.15834 .83692 L
.15551 .83439 L
.15035 .82935 L
.14794 .82599 L
.14624 .82177 L
.14037 .81591 L
.1358 .8142 L
.1328 .811 L
.12839 .80663 L
.12523 .80032 L
.12156 .79906 L
.11766 .79588 L
.11362 .79149 L
.11008 .78821 L
.10516 .78392 L
.10251 .77977 L
.09835 .77635 L
.09494 .76933 L
.09454 .76878 L
.08737 .7625 L
.08629 .76121 L
.08129 .75363 L
.0798 .75186 L
.07662 .74606 L
.07223 .74019 L
.07094 .73849 L
.06762 .73092 L
.06466 .72856 L
Mistroke
.06013 .72335 L
.05709 .71852 L
.05384 .71578 L
.05075 .70821 L
.04952 .7075 L
.04614 .70064 L
.04459 .69306 L
.04194 .6908 L
.03848 .68549 L
.03437 .68215 L
.0327 .67792 L
.03142 .67035 L
.0268 .6641 L
.02382 .66278 L
.02149 .65521 L
.01923 .65144 L
Mfstroke
.8 g
.01923 .25218 m
.02266 .24637 L
.02314 .23879 L
.02569 .23122 L
.0268 .22772 L
.02819 .22365 L
.03107 .21608 L
.03437 .21087 L
.03581 .20851 L
.0359 .20094 L
.03976 .19337 L
.04168 .1858 L
.04194 .18491 L
.04639 .17823 L
.04952 .17204 L
.05009 .17065 L
.05349 .16308 L
.05709 .15907 L
.05953 .15551 L
.06333 .14794 L
.06466 .14422 L
.06618 .14037 L
.07223 .13325 L
.07286 .1328 L
.07663 .12523 L
.07941 .11766 L
.0798 .11696 L
.08479 .11008 L
.08737 .1071 L
.09083 .10251 L
.09494 .09689 L
.09652 .09494 L
.10251 .08824 L
.10319 .08737 L
.1069 .0798 L
.11008 .07555 L
.11448 .07223 L
.11766 .06817 L
.12018 .06466 L
.12485 .05709 L
.12523 .05643 L
.12917 .04952 L
.1328 .04299 L
.13341 .04194 L
.14004 .03437 L
.14037 .03368 L
.14272 .0268 L
.14663 .01923 L
.01923 .01923 L
F
0 g
.01923 .25218 m
.02266 .24637 L
.02314 .23879 L
.02569 .23122 L
.0268 .22772 L
.02819 .22365 L
.03107 .21608 L
.03437 .21087 L
.03581 .20851 L
.0359 .20094 L
.03976 .19337 L
.04168 .1858 L
.04194 .18491 L
.04639 .17823 L
.04952 .17204 L
.05009 .17065 L
.05349 .16308 L
.05709 .15907 L
.05953 .15551 L
.06333 .14794 L
.06466 .14422 L
.06618 .14037 L
.07223 .13325 L
.07286 .1328 L
.07663 .12523 L
.07941 .11766 L
.0798 .11696 L
.08479 .11008 L
.08737 .1071 L
.09083 .10251 L
.09494 .09689 L
.09652 .09494 L
.10251 .08824 L
.10319 .08737 L
.1069 .0798 L
.11008 .07555 L
.11448 .07223 L
.11766 .06817 L
.12018 .06466 L
.12485 .05709 L
.12523 .05643 L
.12917 .04952 L
.1328 .04299 L
.13341 .04194 L
.14004 .03437 L
.14037 .03368 L
.14272 .0268 L
.14663 .01923 L
s
.9 g
.01923 .18918 m
.01999 .1858 L
.02331 .17823 L
.0268 .17123 L
.02705 .17065 L
.03043 .16308 L
.03437 .15813 L
.03627 .15551 L
.04034 .14794 L
.04125 .14037 L
.04194 .13945 L
.04785 .1328 L
.04952 .13193 L
.05314 .12523 L
.05546 .11766 L
.05709 .11458 L
.05967 .11008 L
.06466 .10286 L
.06497 .10251 L
.07067 .09494 L
.07223 .0932 L
.07725 .08737 L
.0798 .08208 L
.08095 .0798 L
.08737 .0741 L
.08926 .07223 L
.09426 .06466 L
.09494 .06414 L
.10006 .05709 L
.10251 .05194 L
.10389 .04952 L
.10949 .04194 L
.11008 .04125 L
.11709 .03437 L
.11766 .0329 L
.11975 .0268 L
.12523 .01937 L
.12548 .01923 L
.01923 .01923 L
F
0 g
.01923 .18918 m
.01999 .1858 L
.02331 .17823 L
.0268 .17123 L
.02705 .17065 L
.03043 .16308 L
.03437 .15813 L
.03627 .15551 L
.04034 .14794 L
.04125 .14037 L
.04194 .13945 L
.04785 .1328 L
.04952 .13193 L
.05314 .12523 L
.05546 .11766 L
.05709 .11458 L
.05967 .11008 L
.06466 .10286 L
.06497 .10251 L
.07067 .09494 L
.07223 .0932 L
.07725 .08737 L
.0798 .08208 L
.08095 .0798 L
.08737 .0741 L
.08926 .07223 L
.09426 .06466 L
.09494 .06414 L
.10006 .05709 L
.10251 .05194 L
.10389 .04952 L
.10949 .04194 L
.11008 .04125 L
.11709 .03437 L
.11766 .0329 L
.11975 .0268 L
.12523 .01937 L
.12548 .01923 L
s
.8 g
.01923 .12298 m
.02064 .11766 L
.02444 .11008 L
.0268 .10618 L
.02955 .10251 L
.03437 .09508 L
.03448 .09494 L
.04031 .08737 L
.04194 .08447 L
.04401 .0798 L
.04952 .07417 L
.0513 .07223 L
.05512 .06466 L
.05709 .06273 L
.06166 .05709 L
.06466 .05107 L
.06554 .04952 L
.07107 .04194 L
.07223 .04092 L
.07929 .03437 L
.0798 .03374 L
.08394 .0268 L
.08737 .02248 L
.09042 .01923 L
.01923 .01923 L
F
0 g
.01923 .12298 m
.02064 .11766 L
.02444 .11008 L
.0268 .10618 L
.02955 .10251 L
.03437 .09508 L
.03448 .09494 L
.04031 .08737 L
.04194 .08447 L
.04401 .0798 L
.04952 .07417 L
.0513 .07223 L
.05512 .06466 L
.05709 .06273 L
.06166 .05709 L
.06466 .05107 L
.06554 .04952 L
.07107 .04194 L
.07223 .04092 L
.07929 .03437 L
.0798 .03374 L
.08394 .0268 L
.08737 .02248 L
.09042 .01923 L
s
.7 g
.01923 .11532 m
.02147 .11008 L
.02648 .10251 L
.0268 .10193 L
.03068 .09494 L
.03437 .09157 L
.03655 .08737 L
.04071 .0798 L
.04194 .0779 L
.04778 .07223 L
.04952 .06992 L
.05143 .06466 L
.05709 .05847 L
.05817 .05709 L
.06179 .04952 L
.06466 .04543 L
.06719 .04194 L
.07223 .03764 L
.07513 .03437 L
.0798 .02737 L
.08014 .0268 L
.08663 .01923 L
.01923 .01923 L
F
0 g
.01923 .11532 m
.02147 .11008 L
.02648 .10251 L
.0268 .10193 L
.03068 .09494 L
.03437 .09157 L
.03655 .08737 L
.04071 .0798 L
.04194 .0779 L
.04778 .07223 L
.04952 .06992 L
.05143 .06466 L
.05709 .05847 L
.05817 .05709 L
.06179 .04952 L
.06466 .04543 L
.06719 .04194 L
.07223 .03764 L
.07513 .03437 L
.0798 .02737 L
.08014 .0268 L
.08663 .01923 L
s
.6 g
.01923 .10986 m
.02362 .10251 L
.0268 .09674 L
.02775 .09494 L
.03437 .08759 L
.03444 .08737 L
.03744 .0798 L
.04194 .07433 L
.04449 .07223 L
.04952 .06505 L
.04963 .06466 L
.055 .05709 L
.05709 .05316 L
.05873 .04952 L
.06466 .04215 L
.06482 .04194 L
.07223 .03469 L
.07242 .03437 L
.07653 .0268 L
.0798 .02221 L
.08303 .01923 L
.01923 .01923 L
F
0 g
.01923 .10986 m
.02362 .10251 L
.0268 .09674 L
.02775 .09494 L
.03437 .08759 L
.03444 .08737 L
.03744 .0798 L
.04194 .07433 L
.04449 .07223 L
.04952 .06505 L
.04963 .06466 L
.055 .05709 L
.05709 .05316 L
.05873 .04952 L
.06466 .04215 L
.06482 .04194 L
.07223 .03469 L
.07242 .03437 L
.07653 .0268 L
.0798 .02221 L
.08303 .01923 L
s
.5 g
.01923 .10464 m
.02065 .10251 L
.02528 .09494 L
.0268 .09324 L
.03167 .08737 L
.03437 .07995 L
.03445 .0798 L
.04155 .07223 L
.04194 .0717 L
.04684 .06466 L
.04952 .06102 L
.05207 .05709 L
.05596 .04952 L
.05709 .04774 L
.06185 .04194 L
.06466 .03946 L
.06936 .03437 L
.07223 .02868 L
.07322 .0268 L
.07976 .01923 L
.01923 .01923 L
F
0 g
.01923 .10464 m
.02065 .10251 L
.02528 .09494 L
.0268 .09324 L
.03167 .08737 L
.03437 .07995 L
.03445 .0798 L
.04155 .07223 L
.04194 .0717 L
.04684 .06466 L
.04952 .06102 L
.05207 .05709 L
.05596 .04952 L
.05709 .04774 L
.06185 .04194 L
.06466 .03946 L
.06936 .03437 L
.07223 .02868 L
.07322 .0268 L
.07976 .01923 L
s
.4 g
.01923 .09996 m
.02285 .09494 L
.0268 .09073 L
.02902 .08737 L
.03175 .0798 L
.03437 .07579 L
.03882 .07223 L
.04194 .06771 L
.04401 .06466 L
.04934 .05709 L
.04952 .05671 L
.05309 .04952 L
.05709 .04392 L
.0589 .04194 L
.06466 .03655 L
.06637 .03437 L
.07017 .0268 L
.07223 .02362 L
.07663 .01923 L
.01923 .01923 L
F
0 g
.01923 .09996 m
.02285 .09494 L
.0268 .09073 L
.02902 .08737 L
.03175 .0798 L
.03437 .07579 L
.03882 .07223 L
.04194 .06771 L
.04401 .06466 L
.04934 .05709 L
.04952 .05671 L
.05309 .04952 L
.05709 .04392 L
.0589 .04194 L
.06466 .03655 L
.06637 .03437 L
.07017 .0268 L
.07223 .02362 L
.07663 .01923 L
s
.3 g
.01923 .09586 m
.02003 .09494 L
.02649 .08737 L
.0268 .0866 L
.02919 .0798 L
.03437 .07359 L
.03624 .07223 L
.04163 .06466 L
.04194 .0638 L
.0468 .05709 L
.04952 .05109 L
.0503 .04952 L
.0563 .04194 L
.05709 .04099 L
.06368 .03437 L
.06466 .03224 L
.06729 .0268 L
.07223 .02044 L
.07366 .01923 L
.01923 .01923 L
F
0 g
.01923 .09586 m
.02003 .09494 L
.02649 .08737 L
.0268 .0866 L
.02919 .0798 L
.03437 .07359 L
.03624 .07223 L
.04163 .06466 L
.04194 .0638 L
.0468 .05709 L
.04952 .05109 L
.0503 .04952 L
.0563 .04194 L
.05709 .04099 L
.06368 .03437 L
.06466 .03224 L
.06729 .0268 L
.07223 .02044 L
.07366 .01923 L
s
.2 g
.01923 .09415 m
.02404 .08737 L
.02666 .0798 L
.0268 .07964 L
.03378 .07223 L
.03437 .07147 L
.0401 .06466 L
.04194 .06017 L
.04411 .05709 L
.04775 .04952 L
.04952 .04682 L
.05398 .04194 L
.05709 .03844 L
.06113 .03437 L
.06452 .0268 L
.06466 .02652 L
.07094 .01923 L
.01923 .01923 L
F
0 g
.01923 .09415 m
.02404 .08737 L
.02666 .0798 L
.0268 .07964 L
.03378 .07223 L
.03437 .07147 L
.0401 .06466 L
.04194 .06017 L
.04411 .05709 L
.04775 .04952 L
.04952 .04682 L
.05398 .04194 L
.05709 .03844 L
.06113 .03437 L
.06452 .0268 L
.06466 .02652 L
.07094 .01923 L
s
.1 g
.01923 .09233 m
.0216 .08737 L
.02407 .0798 L
.0268 .07692 L
.03146 .07223 L
.03437 .06782 L
.0373 .06466 L
.04112 .05709 L
.04194 .05605 L
.04516 .04952 L
.04952 .0433 L
.05087 .04194 L
.05709 .03524 L
.05792 .03437 L
.06199 .0268 L
.06466 .0224 L
.06831 .01923 L
.01923 .01923 L
F
0 g
.01923 .09233 m
.0216 .08737 L
.02407 .0798 L
.0268 .07692 L
.03146 .07223 L
.03437 .06782 L
.0373 .06466 L
.04112 .05709 L
.04194 .05605 L
.04516 .04952 L
.04952 .0433 L
.05087 .04194 L
.05709 .03524 L
.05792 .03437 L
.06199 .0268 L
.06466 .0224 L
.06831 .01923 L
s
.01923 .08716 m
.02131 .0798 L
.0268 .0742 L
.02884 .07223 L
.03263 .06466 L
.03437 .06266 L
.03772 .05709 L
.04194 .04987 L
.04209 .04952 L
.04672 .04194 L
.04952 .03894 L
.0539 .03437 L
.05709 .03086 L
.05915 .0268 L
.06466 .01961 L
.06525 .01923 L
.01923 .01923 L
F
.01923 .08716 m
.02131 .0798 L
.0268 .0742 L
.02884 .07223 L
.03263 .06466 L
.03437 .06266 L
.03772 .05709 L
.04194 .04987 L
.04209 .04952 L
.04672 .04194 L
.04952 .03894 L
.0539 .03437 L
.05709 .03086 L
.05915 .0268 L
.06466 .01961 L
.06525 .01923 L
s
1 g
.01923 .14915 m
.01968 .14794 L
.02178 .14037 L
.0268 .13352 L
.02848 .1328 L
.03249 .12523 L
.0335 .11766 L
.0268 .11364 L
.02419 .11766 L
.02193 .12523 L
.01923 .13112 L
F
0 g
.01923 .14915 m
.01968 .14794 L
.02178 .14037 L
.0268 .13352 L
.02848 .1328 L
.03249 .12523 L
.0335 .11766 L
.0268 .11364 L
.02419 .11766 L
.02193 .12523 L
.01923 .13112 L
s
.7 g
.03437 .32417 m
.03788 .32965 L
.03798 .33722 L
.03651 .34479 L
.03603 .35236 L
.03582 .35993 L
.03437 .3675 L
.02945 .35993 L
.02901 .35236 L
.0285 .34479 L
.02883 .33722 L
.02814 .32965 L
F
0 g
.03437 .32417 m
.03788 .32965 L
.03798 .33722 L
.03651 .34479 L
.03603 .35236 L
.03582 .35993 L
.03437 .3675 L
.02945 .35993 L
.02901 .35236 L
.0285 .34479 L
.02883 .33722 L
.02814 .32965 L
.03437 .32417 L
s
1 g
.04194 .09175 m
.04827 .09494 L
.04359 .10251 L
.04194 .10311 L
.03948 .11008 L
.03437 .11633 L
.02914 .11008 L
.03347 .10251 L
.03437 .10101 L
.03901 .09494 L
F
0 g
.04194 .09175 m
.04827 .09494 L
.04359 .10251 L
.04194 .10311 L
.03948 .11008 L
.03437 .11633 L
.02914 .11008 L
.03347 .10251 L
.03437 .10101 L
.03901 .09494 L
.04194 .09175 L
s
.5 g
.72623 .01923 m
.72817 .0268 L
.73092 .03124 L
.73146 .03437 L
.73849 .04136 L
.74606 .03823 L
.75008 .03437 L
.75363 .02909 L
.75745 .0268 L
.76121 .02507 L
.76805 .0268 L
.76878 .02728 L
.77635 .03151 L
.78066 .03437 L
.78392 .03739 L
.78655 .04194 L
.79149 .04746 L
.79582 .04952 L
.79906 .05319 L
.80412 .05709 L
.80663 .0588 L
.81215 .06466 L
.8142 .06651 L
.82123 .07223 L
.82177 .07304 L
.82596 .0798 L
.82935 .08365 L
.83441 .08737 L
.83692 .09207 L
.83815 .09494 L
.84449 .10133 L
.84558 .10251 L
.85155 .11008 L
.85206 .11073 L
.85768 .11766 L
.85963 .12017 L
.86346 .12523 L
.8672 .12876 L
.87036 .1328 L
.87477 .13871 L
.87623 .14037 L
.88234 .14429 L
.88455 .14794 L
.88713 .15551 L
.88234 .1585 L
.87477 .16191 L
.87384 .16308 L
.87036 .17065 L
.87475 .17823 L
.87477 .17864 L
.88112 .1858 L
.88234 .18765 L
.88878 .19337 L
.88992 .19536 L
.89563 .20094 L
.89749 .20499 L
.90207 .20851 L
.90506 .2131 L
.91263 .21561 L
.91568 .21608 L
.9202 .21941 L
.92287 .22365 L
.92606 .23122 L
.92777 .23501 L
.93023 .23879 L
.93534 .24313 L
.93621 .24637 L
.93755 .25394 L
.9424 .26151 L
.94291 .26219 L
.9464 .26908 L
.94807 .27665 L
.94999 .28422 L
.95048 .28547 L
.95263 .29179 L
.95512 .29936 L
.95766 .30694 L
.95806 .30736 L
.96275 .31451 L
.9633 .32208 L
.96563 .32808 L
.96646 .32965 L
.96899 .33722 L
.96769 .34479 L
.9703 .35236 L
.97156 .35993 L
.97285 .3675 L
.9732 .36831 L
.97582 .37508 L
.97485 .38265 L
.97582 .39022 L
.97609 .39779 L
.97717 .40536 L
.97783 .41293 L
.97994 .4205 L
.97825 .42807 L
.97794 .43565 L
.98057 .44322 L
.97749 .45079 L
.97956 .45836 L
.97684 .46593 L
.97688 .4735 L
.97591 .48107 L
.97385 .48864 L
.9732 .49331 L
.97289 .49621 L
.9718 .50379 L
.97029 .51136 L
.96851 .51893 L
.96634 .5265 L
.96563 .53116 L
.96531 .53407 L
.9642 .54164 L
.96203 .54921 L
.96066 .55678 L
.95863 .56435 L
.95806 .57031 L
.95777 .57193 L
.95339 .5795 L
.95115 .58707 L
.95048 .5881 L
.94797 .59464 L
.94751 .60221 L
.94291 .60805 L
.94145 .60978 L
.94043 .61735 L
.93534 .62443 L
.93499 .62492 L
.93229 .6325 L
.92844 .64007 L
.92777 .64134 L
.92472 .64764 L
.92085 .65521 L
.9202 .65615 L
.91665 .66278 L
.91447 .67035 L
.91263 .67364 L
.90795 .67792 L
.90506 .68211 L
.9036 .68549 L
.9017 .69306 L
.89749 .69748 L
.89388 .70064 L
.88992 .70623 L
.88772 .70821 L
.88234 .71119 L
.87477 .70873 L
.87359 .70821 L
.8672 .70532 L
.85963 .70639 L
.85868 .70821 L
.85963 .70906 L
.86572 .71578 L
.8672 .71994 L
.87058 .72335 L
.87206 .73092 L
.8672 .73803 L
.86689 .73849 L
.86181 .74606 L
.85963 .7482 L
.85306 .75363 L
.85206 .75482 L
.84842 .76121 L
.84449 .76424 L
.84241 .76121 L
.83692 .75479 L
.83609 .75363 L
.82935 .7488 L
.82313 .75363 L
.82535 .76121 L
.825 .76878 L
.82243 .77635 L
.82177 .78283 L
.82155 .78392 L
.81779 .79149 L
.8142 .79659 L
.81176 .79906 L
.80663 .80338 L
.79906 .80454 L
.79176 .79906 L
.79149 .799 L
.78392 .79561 L
.78045 .79906 L
.78392 .80404 L
.78564 .80663 L
.78714 .8142 L
.78392 .82035 L
.78248 .82177 L
.77635 .82423 L
.77459 .82177 L
.76878 .81706 L
.76629 .8142 L
.76212 .80663 L
.76121 .80414 L
.7599 .80663 L
.75777 .8142 L
.75821 .82177 L
.75983 .82935 L
.75906 .83692 L
.75363 .84106 L
.74922 .84449 L
.74606 .84677 L
.73849 .8498 L
.73092 .84785 L
.72876 .84449 L
.72413 .83692 L
.72335 .83547 L
.71701 .83692 L
.71578 .84298 L
.7152 .84449 L
.70821 .84815 L
.70064 .84512 L
.69361 .85206 L
.69705 .85963 L
.69668 .8672 L
.69306 .87333 L
.69019 .87477 L
.68549 .87637 L
.67792 .87994 L
.67035 .88206 L
.6698 .88234 L
.66278 .8846 L
.66169 .88234 L
.65521 .87776 L
.65214 .87477 L
.64764 .86883 L
.64512 .87477 L
.64387 .88234 L
.64245 .88992 L
.64007 .89199 L
.6325 .8961 L
.62812 .89749 L
.62492 .89807 L
.61735 .9 L
.60978 .90131 L
.60221 .90392 L
.59464 .9048 L
.59329 .90506 L
.58707 .90734 L
.5795 .90853 L
.57193 .91077 L
.56435 .91149 L
.56112 .91263 L
.55678 .91401 L
.54921 .91409 L
.54293 .91263 L
.54164 .91182 L
.53407 .90581 L
.53071 .90506 L
.5265 .90108 L
.51893 .89819 L
.51517 .90506 L
.51243 .91263 L
.51136 .91451 L
.50379 .91502 L
.49769 .91263 L
.49621 .91142 L
.49293 .90506 L
.49067 .89749 L
.48864 .89356 L
.48107 .89177 L
.47679 .89749 L
.4735 .9005 L
.46823 .89749 L
.46593 .89526 L
.45836 .89014 L
.45103 .89749 L
.45079 .89776 L
.44382 .90506 L
.44322 .90592 L
.43565 .90854 L
.42807 .90899 L
.4205 .90902 L
.41293 .90865 L
.40536 .90828 L
.39779 .90563 L
.39536 .90506 L
.39022 .90392 L
.38265 .90191 L
.37508 .89819 L
.37322 .89749 L
.3675 .89195 L
.36664 .88992 L
.36477 .88234 L
.36118 .87477 L
.35993 .87329 L
.35334 .8672 L
.35236 .86672 L
.34479 .86351 L
.33722 .86326 L
.33408 .8672 L
.32965 .87462 L
.3294 .87477 L
.32208 .87824 L
.31451 .87623 L
.31085 .87477 L
.30694 .87169 L
.30566 .8672 L
.30456 .85963 L
.30311 .85206 L
.30093 .84449 L
.29936 .84226 L
.29179 .8405 L
.28778 .83692 L
.28422 .8359 L
.27665 .83654 L
.27484 .83692 L
.26908 .84017 L
.26151 .84222 L
.25394 .83748 L
.25293 .83692 L
.24782 .82935 L
.25171 .82177 L
.24907 .8142 L
.24637 .81123 L
.24218 .80663 L
.23879 .8044 L
.23122 .80128 L
.22365 .80054 L
.21608 .80032 L
.20928 .79906 L
.20851 .79877 L
.20094 .79406 L
.19756 .79149 L
.19337 .78813 L
.18864 .78392 L
.1858 .7806 L
.18237 .77635 L
.1794 .76878 L
.17823 .76552 L
.17593 .76121 L
.17238 .75363 L
.17065 .75074 L
.16308 .74716 L
.16145 .74606 L
.15551 .7395 L
.1552 .73849 L
.15366 .73092 L
.14794 .72771 L
.14037 .72476 L
.13873 .72335 L
.133 .71578 L
.1328 .71485 L
.13193 .70821 L
.12523 .70089 L
.12455 .70064 L
.11881 .69306 L
.11766 .6917 L
.11039 .68549 L
.11008 .68506 L
.10566 .67792 L
.1028 .67035 L
.10251 .66976 L
.09524 .66278 L
.09494 .66229 L
.0915 .65521 L
.08737 .64868 L
.08684 .64764 L
.08256 .64007 L
.0798 .63554 L
.07844 .6325 L
.07587 .62492 L
.07455 .61735 L
.07223 .61368 L
.06954 .60978 L
.06745 .60221 L
.06466 .59764 L
.06271 .59464 L
.05961 .58707 L
.05709 .58115 L
.05655 .5795 L
.05659 .57193 L
.05189 .56435 L
.04952 .55824 L
.04905 .55678 L
.04698 .54921 L
.04493 .54164 L
.04293 .53407 L
.04194 .52902 L
.04144 .5265 L
.03937 .51893 L
.03799 .51136 L
.03689 .50379 L
.03534 .49621 L
.03462 .48864 L
.03437 .48716 L
.03315 .48107 L
.03233 .4735 L
.03239 .46593 L
.03309 .45836 L
.03084 .45079 L
.03235 .44322 L
.03047 .43565 L
.03008 .42807 L
.03156 .4205 L
.03008 .41293 L
.03047 .40536 L
.03008 .39779 L
.03008 .39022 L
.03093 .38265 L
.03437 .3766 L
.036 .37508 L
.03979 .3675 L
.04041 .35993 L
.04059 .35236 L
.04117 .34479 L
.04194 .34141 L
.04325 .33722 L
.04379 .32965 L
.04223 .32208 L
.04542 .31451 L
.04498 .30694 L
.04788 .29936 L
.04952 .29548 L
.05069 .29179 L
.05312 .28422 L
.05709 .27753 L
.05741 .27665 L
.05957 .26908 L
.06206 .26151 L
.06282 .25394 L
.06466 .25148 L
.06782 .24637 L
.06756 .23879 L
.07059 .23122 L
.07223 .22463 L
.07263 .22365 L
.07691 .21608 L
.0798 .21223 L
.08232 .20851 L
.08331 .20094 L
.08737 .19389 L
.08778 .19337 L
.09249 .1858 L
.09494 .18078 L
.09645 .17823 L
.09953 .17065 L
.10251 .16532 L
.10414 .16308 L
.11008 .15764 L
.11159 .15551 L
.11556 .14794 L
.11766 .14118 L
.11806 .14037 L
.12523 .13314 L
.12564 .1328 L
.13097 .12523 L
.1328 .12098 L
.13446 .11766 L
.13964 .11008 L
.14037 .10899 L
.14505 .10251 L
.14794 .09742 L
.14975 .09494 L
.15551 .08799 L
.15584 .08737 L
.16308 .08333 L
.16474 .08737 L
.1665 .09494 L
.17017 .10251 L
.17065 .10331 L
.17637 .11008 L
.17823 .11676 L
.17908 .11766 L
.1858 .12478 L
.18629 .12523 L
.19232 .1328 L
.19337 .13506 L
.19663 .14037 L
.20094 .1442 L
.20618 .14794 L
.20851 .14995 L
.21333 .15551 L
.21608 .15954 L
.21877 .16308 L
.22365 .16787 L
.22681 .17065 L
.23122 .17406 L
.23663 .17823 L
.23879 .17989 L
.24598 .1858 L
.24637 .18606 L
.25394 .19098 L
.25545 .19337 L
.26151 .19658 L
.26908 .20015 L
.26993 .20094 L
.27665 .20484 L
.28332 .20851 L
.28422 .20884 L
.29179 .21145 L
.29857 .21608 L
.29936 .21655 L
.30694 .2179 L
.31451 .21913 L
.32208 .22288 L
.32965 .2228 L
.33722 .22246 L
.34479 .2206 L
.35236 .21841 L
.35817 .21608 L
.35993 .21501 L
.3675 .21171 L
.37442 .20851 L
.37508 .20759 L
.38265 .20348 L
.38591 .20094 L
.39022 .19483 L
.39147 .19337 L
.39022 .187 L
.38265 .19057 L
.37508 .19233 L
.37023 .19337 L
.3675 .19418 L
.35993 .19527 L
.35236 .1945 L
.34908 .19337 L
.35115 .1858 L
.35236 .18406 L
.35874 .17823 L
.35993 .17721 L
.3675 .17095 L
.36797 .17065 L
.37438 .16308 L
.37508 .16272 L
.38265 .1567 L
.38394 .15551 L
.38991 .14794 L
.39022 .14671 L
.39365 .14037 L
.39779 .13672 L
.40173 .1328 L
.40536 .12943 L
.4102 .12523 L
.41293 .12104 L
.41663 .11766 L
.4205 .11245 L
.42203 .11008 L
.42807 .10343 L
.42848 .10251 L
.43138 .09494 L
.43565 .08816 L
.4364 .08737 L
.43973 .0798 L
.44322 .07521 L
.44934 .0798 L
.45079 .08093 L
.45801 .08737 L
.45583 .09494 L
.45723 .10251 L
.45317 .11008 L
.45079 .11727 L
.45073 .11766 L
.44971 .12523 L
.44548 .1328 L
.44322 .13712 L
.44136 .14037 L
.44132 .14794 L
.44322 .15107 L
.45079 .15029 L
.45836 .15141 L
.46593 .15427 L
.47133 .14794 L
.4735 .14479 L
.47678 .14037 L
.48107 .13647 L
.48489 .1328 L
.48864 .1299 L
.49621 .12849 L
.50379 .12578 L
.50899 .1328 L
.50936 .14037 L
.51113 .14794 L
.5111 .15551 L
.50986 .16308 L
.50832 .17065 L
.5071 .17823 L
.50603 .1858 L
.50477 .19337 L
.50507 .20094 L
.5101 .20851 L
.51136 .20925 L
.51297 .20851 L
.51893 .20645 L
.52257 .20851 L
.52068 .21608 L
.52211 .22365 L
.52466 .23122 L
.5265 .23597 L
.53046 .23879 L
.53407 .23944 L
.53488 .23879 L
.53694 .23122 L
.54164 .22807 L
.54597 .23122 L
.5443 .23879 L
.54484 .24637 L
.54921 .24885 L
.55048 .24637 L
.55145 .23879 L
.5541 .23122 L
.55278 .22365 L
.55213 .21608 L
.55179 .20851 L
.54951 .20094 L
.55495 .19337 L
.55678 .18969 L
.55968 .1858 L
.56369 .17823 L
.56435 .17676 L
.56686 .17065 L
.57193 .16333 L
.57226 .16308 L
.57913 .15551 L
.5795 .15513 L
.58315 .14794 L
.58707 .1424 L
.58838 .14037 L
.59464 .13438 L
.59845 .1328 L
.60221 .13045 L
.60819 .12523 L
.60978 .12396 L
.61553 .11766 L
.61735 .11564 L
.6229 .11008 L
.62492 .10747 L
.63058 .10251 L
.6325 .10067 L
.63877 .09494 L
.64007 .09434 L
.64713 .08737 L
.64764 .0864 L
.64996 .0798 L
.65521 .07409 L
.65747 .07223 L
.66232 .06466 L
.66278 .06405 L
.66809 .05709 L
.67035 .05245 L
.67166 .04952 L
.67792 .04344 L
.67986 .04194 L
.68549 .03803 L
.69024 .03437 L
.69306 .03155 L
.69629 .0268 L
.69988 .01923 L
F
0 g
.72623 .01923 m
.72817 .0268 L
.73092 .03124 L
.73146 .03437 L
.73849 .04136 L
.74606 .03823 L
.75008 .03437 L
.75363 .02909 L
.75745 .0268 L
.76121 .02507 L
.76805 .0268 L
.76878 .02728 L
.77635 .03151 L
.78066 .03437 L
.78392 .03739 L
.78655 .04194 L
.79149 .04746 L
.79582 .04952 L
.79906 .05319 L
.80412 .05709 L
.80663 .0588 L
.81215 .06466 L
.8142 .06651 L
.82123 .07223 L
.82177 .07304 L
.82596 .0798 L
.82935 .08365 L
.83441 .08737 L
.83692 .09207 L
.83815 .09494 L
.84449 .10133 L
.84558 .10251 L
.85155 .11008 L
.85206 .11073 L
.85768 .11766 L
.85963 .12017 L
.86346 .12523 L
.8672 .12876 L
.87036 .1328 L
.87477 .13871 L
.87623 .14037 L
.88234 .14429 L
.88455 .14794 L
.88713 .15551 L
.88234 .1585 L
.87477 .16191 L
.87384 .16308 L
.87036 .17065 L
.87475 .17823 L
.87477 .17864 L
Mistroke
.88112 .1858 L
.88234 .18765 L
.88878 .19337 L
.88992 .19536 L
.89563 .20094 L
.89749 .20499 L
.90207 .20851 L
.90506 .2131 L
.91263 .21561 L
.91568 .21608 L
.9202 .21941 L
.92287 .22365 L
.92606 .23122 L
.92777 .23501 L
.93023 .23879 L
.93534 .24313 L
.93621 .24637 L
.93755 .25394 L
.9424 .26151 L
.94291 .26219 L
.9464 .26908 L
.94807 .27665 L
.94999 .28422 L
.95048 .28547 L
.95263 .29179 L
.95512 .29936 L
.95766 .30694 L
.95806 .30736 L
.96275 .31451 L
.9633 .32208 L
.96563 .32808 L
.96646 .32965 L
.96899 .33722 L
.96769 .34479 L
.9703 .35236 L
.97156 .35993 L
.97285 .3675 L
.9732 .36831 L
.97582 .37508 L
.97485 .38265 L
.97582 .39022 L
.97609 .39779 L
.97717 .40536 L
.97783 .41293 L
.97994 .4205 L
.97825 .42807 L
.97794 .43565 L
.98057 .44322 L
.97749 .45079 L
.97956 .45836 L
Mistroke
.97684 .46593 L
.97688 .4735 L
.97591 .48107 L
.97385 .48864 L
.9732 .49331 L
.97289 .49621 L
.9718 .50379 L
.97029 .51136 L
.96851 .51893 L
.96634 .5265 L
.96563 .53116 L
.96531 .53407 L
.9642 .54164 L
.96203 .54921 L
.96066 .55678 L
.95863 .56435 L
.95806 .57031 L
.95777 .57193 L
.95339 .5795 L
.95115 .58707 L
.95048 .5881 L
.94797 .59464 L
.94751 .60221 L
.94291 .60805 L
.94145 .60978 L
.94043 .61735 L
.93534 .62443 L
.93499 .62492 L
.93229 .6325 L
.92844 .64007 L
.92777 .64134 L
.92472 .64764 L
.92085 .65521 L
.9202 .65615 L
.91665 .66278 L
.91447 .67035 L
.91263 .67364 L
.90795 .67792 L
.90506 .68211 L
.9036 .68549 L
.9017 .69306 L
.89749 .69748 L
.89388 .70064 L
.88992 .70623 L
.88772 .70821 L
.88234 .71119 L
.87477 .70873 L
.87359 .70821 L
.8672 .70532 L
.85963 .70639 L
Mistroke
.85868 .70821 L
.85963 .70906 L
.86572 .71578 L
.8672 .71994 L
.87058 .72335 L
.87206 .73092 L
.8672 .73803 L
.86689 .73849 L
.86181 .74606 L
.85963 .7482 L
.85306 .75363 L
.85206 .75482 L
.84842 .76121 L
.84449 .76424 L
.84241 .76121 L
.83692 .75479 L
.83609 .75363 L
.82935 .7488 L
.82313 .75363 L
.82535 .76121 L
.825 .76878 L
.82243 .77635 L
.82177 .78283 L
.82155 .78392 L
.81779 .79149 L
.8142 .79659 L
.81176 .79906 L
.80663 .80338 L
.79906 .80454 L
.79176 .79906 L
.79149 .799 L
.78392 .79561 L
.78045 .79906 L
.78392 .80404 L
.78564 .80663 L
.78714 .8142 L
.78392 .82035 L
.78248 .82177 L
.77635 .82423 L
.77459 .82177 L
.76878 .81706 L
.76629 .8142 L
.76212 .80663 L
.76121 .80414 L
.7599 .80663 L
.75777 .8142 L
.75821 .82177 L
.75983 .82935 L
.75906 .83692 L
.75363 .84106 L
Mistroke
.74922 .84449 L
.74606 .84677 L
.73849 .8498 L
.73092 .84785 L
.72876 .84449 L
.72413 .83692 L
.72335 .83547 L
.71701 .83692 L
.71578 .84298 L
.7152 .84449 L
.70821 .84815 L
.70064 .84512 L
.69361 .85206 L
.69705 .85963 L
.69668 .8672 L
.69306 .87333 L
.69019 .87477 L
.68549 .87637 L
.67792 .87994 L
.67035 .88206 L
.6698 .88234 L
.66278 .8846 L
.66169 .88234 L
.65521 .87776 L
.65214 .87477 L
.64764 .86883 L
.64512 .87477 L
.64387 .88234 L
.64245 .88992 L
.64007 .89199 L
.6325 .8961 L
.62812 .89749 L
.62492 .89807 L
.61735 .9 L
.60978 .90131 L
.60221 .90392 L
.59464 .9048 L
.59329 .90506 L
.58707 .90734 L
.5795 .90853 L
.57193 .91077 L
.56435 .91149 L
.56112 .91263 L
.55678 .91401 L
.54921 .91409 L
.54293 .91263 L
.54164 .91182 L
.53407 .90581 L
.53071 .90506 L
.5265 .90108 L
Mistroke
.51893 .89819 L
.51517 .90506 L
.51243 .91263 L
.51136 .91451 L
.50379 .91502 L
.49769 .91263 L
.49621 .91142 L
.49293 .90506 L
.49067 .89749 L
.48864 .89356 L
.48107 .89177 L
.47679 .89749 L
.4735 .9005 L
.46823 .89749 L
.46593 .89526 L
.45836 .89014 L
.45103 .89749 L
.45079 .89776 L
.44382 .90506 L
.44322 .90592 L
.43565 .90854 L
.42807 .90899 L
.4205 .90902 L
.41293 .90865 L
.40536 .90828 L
.39779 .90563 L
.39536 .90506 L
.39022 .90392 L
.38265 .90191 L
.37508 .89819 L
.37322 .89749 L
.3675 .89195 L
.36664 .88992 L
.36477 .88234 L
.36118 .87477 L
.35993 .87329 L
.35334 .8672 L
.35236 .86672 L
.34479 .86351 L
.33722 .86326 L
.33408 .8672 L
.32965 .87462 L
.3294 .87477 L
.32208 .87824 L
.31451 .87623 L
.31085 .87477 L
.30694 .87169 L
.30566 .8672 L
.30456 .85963 L
.30311 .85206 L
Mistroke
.30093 .84449 L
.29936 .84226 L
.29179 .8405 L
.28778 .83692 L
.28422 .8359 L
.27665 .83654 L
.27484 .83692 L
.26908 .84017 L
.26151 .84222 L
.25394 .83748 L
.25293 .83692 L
.24782 .82935 L
.25171 .82177 L
.24907 .8142 L
.24637 .81123 L
.24218 .80663 L
.23879 .8044 L
.23122 .80128 L
.22365 .80054 L
.21608 .80032 L
.20928 .79906 L
.20851 .79877 L
.20094 .79406 L
.19756 .79149 L
.19337 .78813 L
.18864 .78392 L
.1858 .7806 L
.18237 .77635 L
.1794 .76878 L
.17823 .76552 L
.17593 .76121 L
.17238 .75363 L
.17065 .75074 L
.16308 .74716 L
.16145 .74606 L
.15551 .7395 L
.1552 .73849 L
.15366 .73092 L
.14794 .72771 L
.14037 .72476 L
.13873 .72335 L
.133 .71578 L
.1328 .71485 L
.13193 .70821 L
.12523 .70089 L
.12455 .70064 L
.11881 .69306 L
.11766 .6917 L
.11039 .68549 L
.11008 .68506 L
Mistroke
.10566 .67792 L
.1028 .67035 L
.10251 .66976 L
.09524 .66278 L
.09494 .66229 L
.0915 .65521 L
.08737 .64868 L
.08684 .64764 L
.08256 .64007 L
.0798 .63554 L
.07844 .6325 L
.07587 .62492 L
.07455 .61735 L
.07223 .61368 L
.06954 .60978 L
.06745 .60221 L
.06466 .59764 L
.06271 .59464 L
.05961 .58707 L
.05709 .58115 L
.05655 .5795 L
.05659 .57193 L
.05189 .56435 L
.04952 .55824 L
.04905 .55678 L
.04698 .54921 L
.04493 .54164 L
.04293 .53407 L
.04194 .52902 L
.04144 .5265 L
.03937 .51893 L
.03799 .51136 L
.03689 .50379 L
.03534 .49621 L
.03462 .48864 L
.03437 .48716 L
.03315 .48107 L
.03233 .4735 L
.03239 .46593 L
.03309 .45836 L
.03084 .45079 L
.03235 .44322 L
.03047 .43565 L
.03008 .42807 L
.03156 .4205 L
.03008 .41293 L
.03047 .40536 L
.03008 .39779 L
.03008 .39022 L
.03093 .38265 L
Mistroke
.03437 .3766 L
.036 .37508 L
.03979 .3675 L
.04041 .35993 L
.04059 .35236 L
.04117 .34479 L
.04194 .34141 L
.04325 .33722 L
.04379 .32965 L
.04223 .32208 L
.04542 .31451 L
.04498 .30694 L
.04788 .29936 L
.04952 .29548 L
.05069 .29179 L
.05312 .28422 L
.05709 .27753 L
.05741 .27665 L
.05957 .26908 L
.06206 .26151 L
.06282 .25394 L
.06466 .25148 L
.06782 .24637 L
.06756 .23879 L
.07059 .23122 L
.07223 .22463 L
.07263 .22365 L
.07691 .21608 L
.0798 .21223 L
.08232 .20851 L
.08331 .20094 L
.08737 .19389 L
.08778 .19337 L
.09249 .1858 L
.09494 .18078 L
.09645 .17823 L
.09953 .17065 L
.10251 .16532 L
.10414 .16308 L
.11008 .15764 L
.11159 .15551 L
.11556 .14794 L
.11766 .14118 L
.11806 .14037 L
.12523 .13314 L
.12564 .1328 L
.13097 .12523 L
.1328 .12098 L
.13446 .11766 L
.13964 .11008 L
Mistroke
.14037 .10899 L
.14505 .10251 L
.14794 .09742 L
.14975 .09494 L
.15551 .08799 L
.15584 .08737 L
.16308 .08333 L
.16474 .08737 L
.1665 .09494 L
.17017 .10251 L
.17065 .10331 L
.17637 .11008 L
.17823 .11676 L
.17908 .11766 L
.1858 .12478 L
.18629 .12523 L
.19232 .1328 L
.19337 .13506 L
.19663 .14037 L
.20094 .1442 L
.20618 .14794 L
.20851 .14995 L
.21333 .15551 L
.21608 .15954 L
.21877 .16308 L
.22365 .16787 L
.22681 .17065 L
.23122 .17406 L
.23663 .17823 L
.23879 .17989 L
.24598 .1858 L
.24637 .18606 L
.25394 .19098 L
.25545 .19337 L
.26151 .19658 L
.26908 .20015 L
.26993 .20094 L
.27665 .20484 L
.28332 .20851 L
.28422 .20884 L
.29179 .21145 L
.29857 .21608 L
.29936 .21655 L
.30694 .2179 L
.31451 .21913 L
.32208 .22288 L
.32965 .2228 L
.33722 .22246 L
.34479 .2206 L
.35236 .21841 L
Mistroke
.35817 .21608 L
.35993 .21501 L
.3675 .21171 L
.37442 .20851 L
.37508 .20759 L
.38265 .20348 L
.38591 .20094 L
.39022 .19483 L
.39147 .19337 L
.39022 .187 L
.38265 .19057 L
.37508 .19233 L
.37023 .19337 L
.3675 .19418 L
.35993 .19527 L
.35236 .1945 L
.34908 .19337 L
.35115 .1858 L
.35236 .18406 L
.35874 .17823 L
.35993 .17721 L
.3675 .17095 L
.36797 .17065 L
.37438 .16308 L
.37508 .16272 L
.38265 .1567 L
.38394 .15551 L
.38991 .14794 L
.39022 .14671 L
.39365 .14037 L
.39779 .13672 L
.40173 .1328 L
.40536 .12943 L
.4102 .12523 L
.41293 .12104 L
.41663 .11766 L
.4205 .11245 L
.42203 .11008 L
.42807 .10343 L
.42848 .10251 L
.43138 .09494 L
.43565 .08816 L
.4364 .08737 L
.43973 .0798 L
.44322 .07521 L
.44934 .0798 L
.45079 .08093 L
.45801 .08737 L
.45583 .09494 L
.45723 .10251 L
Mistroke
.45317 .11008 L
.45079 .11727 L
.45073 .11766 L
.44971 .12523 L
.44548 .1328 L
.44322 .13712 L
.44136 .14037 L
.44132 .14794 L
.44322 .15107 L
.45079 .15029 L
.45836 .15141 L
.46593 .15427 L
.47133 .14794 L
.4735 .14479 L
.47678 .14037 L
.48107 .13647 L
.48489 .1328 L
.48864 .1299 L
.49621 .12849 L
.50379 .12578 L
.50899 .1328 L
.50936 .14037 L
.51113 .14794 L
.5111 .15551 L
.50986 .16308 L
.50832 .17065 L
.5071 .17823 L
.50603 .1858 L
.50477 .19337 L
.50507 .20094 L
.5101 .20851 L
.51136 .20925 L
.51297 .20851 L
.51893 .20645 L
.52257 .20851 L
.52068 .21608 L
.52211 .22365 L
.52466 .23122 L
.5265 .23597 L
.53046 .23879 L
.53407 .23944 L
.53488 .23879 L
.53694 .23122 L
.54164 .22807 L
.54597 .23122 L
.5443 .23879 L
.54484 .24637 L
.54921 .24885 L
.55048 .24637 L
.55145 .23879 L
Mistroke
.5541 .23122 L
.55278 .22365 L
.55213 .21608 L
.55179 .20851 L
.54951 .20094 L
.55495 .19337 L
.55678 .18969 L
.55968 .1858 L
.56369 .17823 L
.56435 .17676 L
.56686 .17065 L
.57193 .16333 L
.57226 .16308 L
.57913 .15551 L
.5795 .15513 L
.58315 .14794 L
.58707 .1424 L
.58838 .14037 L
.59464 .13438 L
.59845 .1328 L
.60221 .13045 L
.60819 .12523 L
.60978 .12396 L
.61553 .11766 L
.61735 .11564 L
.6229 .11008 L
.62492 .10747 L
.63058 .10251 L
.6325 .10067 L
.63877 .09494 L
.64007 .09434 L
.64713 .08737 L
.64764 .0864 L
.64996 .0798 L
.65521 .07409 L
.65747 .07223 L
.66232 .06466 L
.66278 .06405 L
.66809 .05709 L
.67035 .05245 L
.67166 .04952 L
.67792 .04344 L
.67986 .04194 L
.68549 .03803 L
.69024 .03437 L
.69306 .03155 L
.69629 .0268 L
.69988 .01923 L
Mfstroke
1 g
.05709 .06922 m
.06464 .07223 L
.05801 .0798 L
.05709 .08131 L
.05513 .08737 L
.04952 .09276 L
.04598 .08737 L
.04791 .0798 L
.04952 .07827 L
.05553 .07223 L
F
0 g
.05709 .06922 m
.06464 .07223 L
.05801 .0798 L
.05709 .08131 L
.05513 .08737 L
.04952 .09276 L
.04598 .08737 L
.04791 .0798 L
.04952 .07827 L
.05553 .07223 L
.05709 .06922 L
s
.4 g
.70064 .05143 m
.70821 .05018 L
.71578 .05466 L
.71696 .05709 L
.71981 .06466 L
.72335 .06529 L
.72396 .06466 L
.73092 .05999 L
.73545 .05709 L
.73849 .05376 L
.74606 .05207 L
.75363 .05424 L
.75874 .05709 L
.76121 .05917 L
.76614 .06466 L
.76878 .06782 L
.77468 .07223 L
.77635 .07391 L
.78056 .0798 L
.78392 .08239 L
.79149 .08685 L
.79211 .08737 L
.79906 .0943 L
.7996 .09494 L
.80558 .10251 L
.80663 .10361 L
.81311 .11008 L
.8142 .1114 L
.81905 .11766 L
.82177 .12064 L
.82808 .12523 L
.82935 .12626 L
.83354 .1328 L
.83189 .14037 L
.82935 .14167 L
.82358 .14794 L
.82177 .15041 L
.81867 .15551 L
.81533 .16308 L
.81771 .17065 L
.82056 .17823 L
.82177 .1806 L
.82524 .1858 L
.82935 .18756 L
.83692 .1872 L
.84194 .19337 L
.84113 .20094 L
.84449 .20721 L
.84974 .20094 L
.85206 .19621 L
.85293 .19337 L
.85206 .19148 L
.8505 .1858 L
.85206 .18131 L
.8562 .17823 L
.85963 .17296 L
.86569 .17823 L
.8672 .18199 L
.86992 .1858 L
.87477 .19233 L
.8755 .19337 L
.87901 .20094 L
.88234 .2047 L
.88538 .20851 L
.88649 .21608 L
.88992 .22346 L
.89032 .22365 L
.89458 .23122 L
.89749 .23643 L
.8992 .23879 L
.90421 .24637 L
.90506 .25177 L
.90546 .25394 L
.91046 .26151 L
.91263 .2653 L
.91402 .26908 L
.91683 .27665 L
.91809 .28422 L
.9202 .28974 L
.92159 .29179 L
.92365 .29936 L
.92693 .30694 L
.92777 .30715 L
.93138 .31451 L
.93323 .32208 L
.93534 .32351 L
.93788 .32965 L
.93949 .33722 L
.93993 .34479 L
.94108 .35236 L
.94291 .35845 L
.94332 .35993 L
.94431 .3675 L
.94751 .37508 L
.94767 .38265 L
.94868 .39022 L
.94976 .39779 L
.95048 .40238 L
.95086 .40536 L
.95089 .41293 L
.95344 .4205 L
.95199 .42807 L
.95195 .43565 L
.95418 .44322 L
.95199 .45079 L
.95293 .45836 L
.95083 .46593 L
.95086 .4735 L
.95048 .47648 L
.94965 .48107 L
.94839 .48864 L
.94712 .49621 L
.9449 .50379 L
.94435 .51136 L
.94329 .51893 L
.94291 .52041 L
.94103 .5265 L
.93955 .53407 L
.93779 .54164 L
.93575 .54921 L
.93534 .55046 L
.93351 .55678 L
.93128 .56435 L
.9307 .57193 L
.92777 .57807 L
.92594 .5795 L
.9238 .58707 L
.9206 .59464 L
.92058 .60221 L
.9202 .60278 L
.91517 .60978 L
.91434 .61735 L
.91263 .62263 L
.90935 .62492 L
.90506 .63071 L
.90425 .6325 L
.90175 .64007 L
.89749 .64632 L
.89674 .64764 L
.89285 .65521 L
.88992 .65884 L
.88788 .66278 L
.88528 .67035 L
.88234 .675 L
.87903 .67792 L
.87477 .68171 L
.87256 .68549 L
.86934 .69306 L
.8672 .6947 L
.85963 .69749 L
.85222 .70064 L
.85206 .70107 L
.85118 .70821 L
.85052 .71578 L
.84588 .72335 L
.84449 .72853 L
.84374 .73092 L
.83692 .73833 L
.83565 .73849 L
.82935 .74124 L
.82177 .74319 L
.81446 .74606 L
.8142 .74675 L
.80663 .75308 L
.80625 .75363 L
.80147 .76121 L
.80239 .76878 L
.79906 .77325 L
.79481 .77635 L
.79149 .78067 L
.78736 .78392 L
.78392 .78505 L
.77635 .78523 L
.76878 .78618 L
.76121 .79005 L
.75922 .79149 L
.75374 .79906 L
.75363 .79928 L
.74945 .80663 L
.74642 .8142 L
.74606 .8147 L
.73849 .82083 L
.73636 .82177 L
.73092 .82226 L
.73039 .82177 L
.72335 .82118 L
.71963 .82177 L
.71578 .82347 L
.70991 .82935 L
.70821 .83404 L
.70064 .83648 L
.69306 .83511 L
.69035 .83692 L
.68801 .84449 L
.68549 .84769 L
.67994 .85206 L
.67792 .85346 L
.67035 .85703 L
.66377 .85963 L
.66278 .85998 L
.65521 .86187 L
.65165 .85963 L
.64764 .85876 L
.64007 .85907 L
.63957 .85963 L
.63589 .8672 L
.6325 .87141 L
.62595 .87477 L
.62492 .87505 L
.61735 .87728 L
.60978 .87887 L
.60221 .88173 L
.59978 .88234 L
.59464 .8836 L
.58707 .88557 L
.5795 .88743 L
.57193 .88854 L
.56584 .88992 L
.56435 .89027 L
.55678 .89133 L
.54921 .89157 L
.54832 .88992 L
.54164 .88424 L
.53407 .88323 L
.5265 .88401 L
.51893 .88494 L
.51312 .88992 L
.51136 .8957 L
.50379 .89699 L
.49621 .89537 L
.49002 .88992 L
.48864 .88914 L
.48107 .88646 L
.47407 .88992 L
.4735 .8906 L
.46769 .88992 L
.46593 .88898 L
.45836 .88411 L
.45079 .88555 L
.44351 .88992 L
.44322 .89017 L
.43565 .89084 L
.42807 .89084 L
.4205 .89016 L
.41759 .88992 L
.41293 .88943 L
.40536 .88766 L
.39779 .88603 L
.39022 .88439 L
.38407 .88234 L
.38265 .88173 L
.37508 .87842 L
.36858 .87477 L
.3675 .87354 L
.36124 .8672 L
.35993 .86594 L
.35236 .86063 L
.35037 .85963 L
.34479 .85778 L
.33722 .85714 L
.32965 .85913 L
.32208 .85786 L
.31451 .85412 L
.31045 .85206 L
.30694 .84479 L
.30685 .84449 L
.29936 .83786 L
.29802 .83692 L
.29179 .83307 L
.28422 .82995 L
.28014 .82935 L
.27665 .82836 L
.26908 .8236 L
.26724 .82177 L
.26151 .8172 L
.25849 .8142 L
.25394 .80829 L
.25206 .80663 L
.24637 .80273 L
.24184 .79906 L
.23879 .79677 L
.23122 .79355 L
.22891 .79149 L
.22365 .78628 L
.22123 .78392 L
.21608 .77931 L
.2132 .77635 L
.20932 .76878 L
.20851 .76765 L
.20094 .76156 L
.20047 .76121 L
.19337 .75557 L
.19166 .75363 L
.1867 .74606 L
.1858 .74517 L
.17823 .73995 L
.17683 .73849 L
.17065 .73126 L
.17028 .73092 L
.16308 .72474 L
.1618 .72335 L
.15551 .71617 L
.15518 .71578 L
.14948 .70821 L
.14794 .70695 L
.14279 .70064 L
.14037 .69551 L
.13915 .69306 L
.1328 .68577 L
.13248 .68549 L
.12677 .67792 L
.12523 .67467 L
.12321 .67035 L
.11766 .66387 L
.1165 .66278 L
.11146 .65521 L
.11008 .65275 L
.10725 .64764 L
.10251 .64055 L
.10225 .64007 L
.09876 .6325 L
.09544 .62492 L
.09494 .62297 L
.09316 .61735 L
.08787 .60978 L
.08737 .60751 L
.08636 .60221 L
.08122 .59464 L
.0798 .5918 L
.07799 .58707 L
.07524 .5795 L
.07418 .57193 L
.07223 .56839 L
.06965 .56435 L
.06744 .55678 L
.06516 .54921 L
.06466 .54752 L
.06285 .54164 L
.06092 .53407 L
.05902 .5265 L
.05758 .51893 L
.05709 .51639 L
.05605 .51136 L
.05448 .50379 L
.05381 .49621 L
.05221 .48864 L
.05088 .48107 L
.05006 .4735 L
.05007 .46593 L
.05087 .45836 L
.04952 .45447 L
.04846 .45079 L
.04952 .44737 L
.05076 .44322 L
.04952 .43864 L
.04848 .43565 L
.04848 .42807 L
.04952 .42358 L
.05006 .4205 L
.04952 .41742 L
.04848 .41293 L
.04843 .40536 L
.04837 .39779 L
.04843 .39022 L
.04922 .38265 L
.04952 .38166 L
.05416 .37508 L
.05709 .37441 L
.06466 .37223 L
.07223 .36984 L
.07559 .3675 L
.07923 .35993 L
.0793 .35236 L
.07871 .34479 L
.0798 .34293 L
.08324 .33722 L
.08285 .32965 L
.0798 .32591 L
.07559 .32208 L
.07223 .31541 L
.07106 .31451 L
.071 .30694 L
.07223 .30138 L
.07291 .29936 L
.07551 .29179 L
.07836 .28422 L
.0798 .28208 L
.08269 .27665 L
.08476 .26908 L
.08737 .26451 L
.08819 .26151 L
.0892 .25394 L
.09344 .24637 L
.09457 .23879 L
.09494 .23715 L
.09762 .23122 L
.10203 .22365 L
.10251 .22283 L
.106 .21608 L
.11008 .2103 L
.1109 .20851 L
.11301 .20094 L
.11726 .19337 L
.11766 .19255 L
.12103 .1858 L
.12488 .17823 L
.12523 .17737 L
.12854 .17065 L
.1328 .16421 L
.13343 .16308 L
.13891 .15551 L
.14037 .15327 L
.14357 .14794 L
.14655 .14037 L
.14794 .13727 L
.15299 .1328 L
.15551 .13062 L
.1584 .12523 L
.16072 .11766 L
.16308 .11542 L
.17065 .11471 L
.17229 .11766 L
.17823 .12342 L
.1799 .12523 L
.1856 .1328 L
.1858 .13308 L
.19092 .14037 L
.19337 .14487 L
.19769 .14794 L
.20094 .15311 L
.20261 .15551 L
.20659 .16308 L
.20851 .16587 L
.21336 .17065 L
.21608 .17332 L
.22084 .17823 L
.22365 .18104 L
.22808 .1858 L
.23122 .18873 L
.23661 .19337 L
.23879 .19533 L
.24531 .20094 L
.24637 .20162 L
.25394 .20682 L
.25624 .20851 L
.26151 .21359 L
.26395 .21608 L
.26908 .22014 L
.27385 .22365 L
.27665 .22557 L
.28422 .23018 L
.2854 .23122 L
.29179 .23565 L
.29791 .23879 L
.29936 .23942 L
.30694 .24217 L
.31451 .24591 L
.31506 .24637 L
.32208 .25329 L
.32283 .25394 L
.32965 .25679 L
.33722 .25974 L
.33961 .26151 L
.34236 .26908 L
.34104 .27665 L
.33722 .28048 L
.33414 .28422 L
.32993 .29179 L
.33144 .29936 L
.33722 .30522 L
.34016 .30694 L
.34479 .30997 L
.35236 .31017 L
.35993 .31068 L
.36643 .30694 L
.3675 .30545 L
.37383 .29936 L
.37508 .29853 L
.38265 .29321 L
.38475 .29179 L
.39022 .28833 L
.39411 .28422 L
.39779 .28117 L
.40536 .27759 L
.40788 .27665 L
.41293 .27321 L
.41682 .26908 L
.4205 .26652 L
.42497 .26151 L
.42807 .25767 L
.43093 .25394 L
.43565 .25081 L
.44252 .24637 L
.44322 .24514 L
.44665 .23879 L
.45079 .23333 L
.45361 .23122 L
.45836 .22958 L
.46182 .23122 L
.46593 .23316 L
.47181 .23879 L
.47302 .24637 L
.46919 .25394 L
.46679 .26151 L
.46593 .26299 L
.46141 .26908 L
.45836 .27411 L
.4564 .27665 L
.45169 .28422 L
.45079 .28662 L
.44604 .29179 L
.44322 .29386 L
.43855 .29936 L
.43565 .30143 L
.43057 .30694 L
.42955 .31451 L
.43565 .32149 L
.44322 .31711 L
.45024 .31451 L
.45079 .31404 L
.45836 .30793 L
.45994 .30694 L
.46593 .30153 L
.46958 .29936 L
.4735 .29689 L
.47796 .29179 L
.48107 .2891 L
.48628 .28422 L
.48864 .2823 L
.49621 .27671 L
.49696 .27665 L
.50379 .27136 L
.50636 .26908 L
.51136 .26518 L
.51893 .26236 L
.5265 .26377 L
.53407 .26861 L
.54164 .26651 L
.54921 .26468 L
.55214 .26151 L
.55678 .25532 L
.55726 .25394 L
.55945 .24637 L
.56143 .23879 L
.56362 .23122 L
.56147 .22365 L
.5609 .21608 L
.56354 .20851 L
.56435 .20605 L
.56641 .20094 L
.57116 .19337 L
.57193 .1924 L
.57703 .1858 L
.5795 .18303 L
.58349 .17823 L
.58707 .1755 L
.59174 .17065 L
.59464 .16773 L
.59966 .16308 L
.60221 .16143 L
.60922 .15551 L
.60978 .15498 L
.61591 .14794 L
.61735 .14482 L
.61976 .14037 L
.62418 .1328 L
.62492 .13129 L
.62837 .12523 L
.63223 .11766 L
.6325 .11726 L
.64007 .11053 L
.64072 .11008 L
.64764 .1039 L
.64926 .10251 L
.65521 .0972 L
.65737 .09494 L
.66278 .09143 L
.66621 .08737 L
.66888 .0798 L
.67035 .0776 L
.6775 .07223 L
.67792 .0718 L
.68549 .06673 L
.68827 .06466 L
.69306 .06069 L
.6955 .05709 L
F
0 g
.70064 .05143 m
.70821 .05018 L
.71578 .05466 L
.71696 .05709 L
.71981 .06466 L
.72335 .06529 L
.72396 .06466 L
.73092 .05999 L
.73545 .05709 L
.73849 .05376 L
.74606 .05207 L
.75363 .05424 L
.75874 .05709 L
.76121 .05917 L
.76614 .06466 L
.76878 .06782 L
.77468 .07223 L
.77635 .07391 L
.78056 .0798 L
.78392 .08239 L
.79149 .08685 L
.79211 .08737 L
.79906 .0943 L
.7996 .09494 L
.80558 .10251 L
.80663 .10361 L
.81311 .11008 L
.8142 .1114 L
.81905 .11766 L
.82177 .12064 L
.82808 .12523 L
.82935 .12626 L
.83354 .1328 L
.83189 .14037 L
.82935 .14167 L
.82358 .14794 L
.82177 .15041 L
.81867 .15551 L
.81533 .16308 L
.81771 .17065 L
.82056 .17823 L
.82177 .1806 L
.82524 .1858 L
.82935 .18756 L
.83692 .1872 L
.84194 .19337 L
.84113 .20094 L
.84449 .20721 L
.84974 .20094 L
.85206 .19621 L
Mistroke
.85293 .19337 L
.85206 .19148 L
.8505 .1858 L
.85206 .18131 L
.8562 .17823 L
.85963 .17296 L
.86569 .17823 L
.8672 .18199 L
.86992 .1858 L
.87477 .19233 L
.8755 .19337 L
.87901 .20094 L
.88234 .2047 L
.88538 .20851 L
.88649 .21608 L
.88992 .22346 L
.89032 .22365 L
.89458 .23122 L
.89749 .23643 L
.8992 .23879 L
.90421 .24637 L
.90506 .25177 L
.90546 .25394 L
.91046 .26151 L
.91263 .2653 L
.91402 .26908 L
.91683 .27665 L
.91809 .28422 L
.9202 .28974 L
.92159 .29179 L
.92365 .29936 L
.92693 .30694 L
.92777 .30715 L
.93138 .31451 L
.93323 .32208 L
.93534 .32351 L
.93788 .32965 L
.93949 .33722 L
.93993 .34479 L
.94108 .35236 L
.94291 .35845 L
.94332 .35993 L
.94431 .3675 L
.94751 .37508 L
.94767 .38265 L
.94868 .39022 L
.94976 .39779 L
.95048 .40238 L
.95086 .40536 L
.95089 .41293 L
Mistroke
.95344 .4205 L
.95199 .42807 L
.95195 .43565 L
.95418 .44322 L
.95199 .45079 L
.95293 .45836 L
.95083 .46593 L
.95086 .4735 L
.95048 .47648 L
.94965 .48107 L
.94839 .48864 L
.94712 .49621 L
.9449 .50379 L
.94435 .51136 L
.94329 .51893 L
.94291 .52041 L
.94103 .5265 L
.93955 .53407 L
.93779 .54164 L
.93575 .54921 L
.93534 .55046 L
.93351 .55678 L
.93128 .56435 L
.9307 .57193 L
.92777 .57807 L
.92594 .5795 L
.9238 .58707 L
.9206 .59464 L
.92058 .60221 L
.9202 .60278 L
.91517 .60978 L
.91434 .61735 L
.91263 .62263 L
.90935 .62492 L
.90506 .63071 L
.90425 .6325 L
.90175 .64007 L
.89749 .64632 L
.89674 .64764 L
.89285 .65521 L
.88992 .65884 L
.88788 .66278 L
.88528 .67035 L
.88234 .675 L
.87903 .67792 L
.87477 .68171 L
.87256 .68549 L
.86934 .69306 L
.8672 .6947 L
.85963 .69749 L
Mistroke
.85222 .70064 L
.85206 .70107 L
.85118 .70821 L
.85052 .71578 L
.84588 .72335 L
.84449 .72853 L
.84374 .73092 L
.83692 .73833 L
.83565 .73849 L
.82935 .74124 L
.82177 .74319 L
.81446 .74606 L
.8142 .74675 L
.80663 .75308 L
.80625 .75363 L
.80147 .76121 L
.80239 .76878 L
.79906 .77325 L
.79481 .77635 L
.79149 .78067 L
.78736 .78392 L
.78392 .78505 L
.77635 .78523 L
.76878 .78618 L
.76121 .79005 L
.75922 .79149 L
.75374 .79906 L
.75363 .79928 L
.74945 .80663 L
.74642 .8142 L
.74606 .8147 L
.73849 .82083 L
.73636 .82177 L
.73092 .82226 L
.73039 .82177 L
.72335 .82118 L
.71963 .82177 L
.71578 .82347 L
.70991 .82935 L
.70821 .83404 L
.70064 .83648 L
.69306 .83511 L
.69035 .83692 L
.68801 .84449 L
.68549 .84769 L
.67994 .85206 L
.67792 .85346 L
.67035 .85703 L
.66377 .85963 L
.66278 .85998 L
Mistroke
.65521 .86187 L
.65165 .85963 L
.64764 .85876 L
.64007 .85907 L
.63957 .85963 L
.63589 .8672 L
.6325 .87141 L
.62595 .87477 L
.62492 .87505 L
.61735 .87728 L
.60978 .87887 L
.60221 .88173 L
.59978 .88234 L
.59464 .8836 L
.58707 .88557 L
.5795 .88743 L
.57193 .88854 L
.56584 .88992 L
.56435 .89027 L
.55678 .89133 L
.54921 .89157 L
.54832 .88992 L
.54164 .88424 L
.53407 .88323 L
.5265 .88401 L
.51893 .88494 L
.51312 .88992 L
.51136 .8957 L
.50379 .89699 L
.49621 .89537 L
.49002 .88992 L
.48864 .88914 L
.48107 .88646 L
.47407 .88992 L
.4735 .8906 L
.46769 .88992 L
.46593 .88898 L
.45836 .88411 L
.45079 .88555 L
.44351 .88992 L
.44322 .89017 L
.43565 .89084 L
.42807 .89084 L
.4205 .89016 L
.41759 .88992 L
.41293 .88943 L
.40536 .88766 L
.39779 .88603 L
.39022 .88439 L
.38407 .88234 L
Mistroke
.38265 .88173 L
.37508 .87842 L
.36858 .87477 L
.3675 .87354 L
.36124 .8672 L
.35993 .86594 L
.35236 .86063 L
.35037 .85963 L
.34479 .85778 L
.33722 .85714 L
.32965 .85913 L
.32208 .85786 L
.31451 .85412 L
.31045 .85206 L
.30694 .84479 L
.30685 .84449 L
.29936 .83786 L
.29802 .83692 L
.29179 .83307 L
.28422 .82995 L
.28014 .82935 L
.27665 .82836 L
.26908 .8236 L
.26724 .82177 L
.26151 .8172 L
.25849 .8142 L
.25394 .80829 L
.25206 .80663 L
.24637 .80273 L
.24184 .79906 L
.23879 .79677 L
.23122 .79355 L
.22891 .79149 L
.22365 .78628 L
.22123 .78392 L
.21608 .77931 L
.2132 .77635 L
.20932 .76878 L
.20851 .76765 L
.20094 .76156 L
.20047 .76121 L
.19337 .75557 L
.19166 .75363 L
.1867 .74606 L
.1858 .74517 L
.17823 .73995 L
.17683 .73849 L
.17065 .73126 L
.17028 .73092 L
.16308 .72474 L
Mistroke
.1618 .72335 L
.15551 .71617 L
.15518 .71578 L
.14948 .70821 L
.14794 .70695 L
.14279 .70064 L
.14037 .69551 L
.13915 .69306 L
.1328 .68577 L
.13248 .68549 L
.12677 .67792 L
.12523 .67467 L
.12321 .67035 L
.11766 .66387 L
.1165 .66278 L
.11146 .65521 L
.11008 .65275 L
.10725 .64764 L
.10251 .64055 L
.10225 .64007 L
.09876 .6325 L
.09544 .62492 L
.09494 .62297 L
.09316 .61735 L
.08787 .60978 L
.08737 .60751 L
.08636 .60221 L
.08122 .59464 L
.0798 .5918 L
.07799 .58707 L
.07524 .5795 L
.07418 .57193 L
.07223 .56839 L
.06965 .56435 L
.06744 .55678 L
.06516 .54921 L
.06466 .54752 L
.06285 .54164 L
.06092 .53407 L
.05902 .5265 L
.05758 .51893 L
.05709 .51639 L
.05605 .51136 L
.05448 .50379 L
.05381 .49621 L
.05221 .48864 L
.05088 .48107 L
.05006 .4735 L
.05007 .46593 L
.05087 .45836 L
Mistroke
.04952 .45447 L
.04846 .45079 L
.04952 .44737 L
.05076 .44322 L
.04952 .43864 L
.04848 .43565 L
.04848 .42807 L
.04952 .42358 L
.05006 .4205 L
.04952 .41742 L
.04848 .41293 L
.04843 .40536 L
.04837 .39779 L
.04843 .39022 L
.04922 .38265 L
.04952 .38166 L
.05416 .37508 L
.05709 .37441 L
.06466 .37223 L
.07223 .36984 L
.07559 .3675 L
.07923 .35993 L
.0793 .35236 L
.07871 .34479 L
.0798 .34293 L
.08324 .33722 L
.08285 .32965 L
.0798 .32591 L
.07559 .32208 L
.07223 .31541 L
.07106 .31451 L
.071 .30694 L
.07223 .30138 L
.07291 .29936 L
.07551 .29179 L
.07836 .28422 L
.0798 .28208 L
.08269 .27665 L
.08476 .26908 L
.08737 .26451 L
.08819 .26151 L
.0892 .25394 L
.09344 .24637 L
.09457 .23879 L
.09494 .23715 L
.09762 .23122 L
.10203 .22365 L
.10251 .22283 L
.106 .21608 L
.11008 .2103 L
Mistroke
.1109 .20851 L
.11301 .20094 L
.11726 .19337 L
.11766 .19255 L
.12103 .1858 L
.12488 .17823 L
.12523 .17737 L
.12854 .17065 L
.1328 .16421 L
.13343 .16308 L
.13891 .15551 L
.14037 .15327 L
.14357 .14794 L
.14655 .14037 L
.14794 .13727 L
.15299 .1328 L
.15551 .13062 L
.1584 .12523 L
.16072 .11766 L
.16308 .11542 L
.17065 .11471 L
.17229 .11766 L
.17823 .12342 L
.1799 .12523 L
.1856 .1328 L
.1858 .13308 L
.19092 .14037 L
.19337 .14487 L
.19769 .14794 L
.20094 .15311 L
.20261 .15551 L
.20659 .16308 L
.20851 .16587 L
.21336 .17065 L
.21608 .17332 L
.22084 .17823 L
.22365 .18104 L
.22808 .1858 L
.23122 .18873 L
.23661 .19337 L
.23879 .19533 L
.24531 .20094 L
.24637 .20162 L
.25394 .20682 L
.25624 .20851 L
.26151 .21359 L
.26395 .21608 L
.26908 .22014 L
.27385 .22365 L
.27665 .22557 L
Mistroke
.28422 .23018 L
.2854 .23122 L
.29179 .23565 L
.29791 .23879 L
.29936 .23942 L
.30694 .24217 L
.31451 .24591 L
.31506 .24637 L
.32208 .25329 L
.32283 .25394 L
.32965 .25679 L
.33722 .25974 L
.33961 .26151 L
.34236 .26908 L
.34104 .27665 L
.33722 .28048 L
.33414 .28422 L
.32993 .29179 L
.33144 .29936 L
.33722 .30522 L
.34016 .30694 L
.34479 .30997 L
.35236 .31017 L
.35993 .31068 L
.36643 .30694 L
.3675 .30545 L
.37383 .29936 L
.37508 .29853 L
.38265 .29321 L
.38475 .29179 L
.39022 .28833 L
.39411 .28422 L
.39779 .28117 L
.40536 .27759 L
.40788 .27665 L
.41293 .27321 L
.41682 .26908 L
.4205 .26652 L
.42497 .26151 L
.42807 .25767 L
.43093 .25394 L
.43565 .25081 L
.44252 .24637 L
.44322 .24514 L
.44665 .23879 L
.45079 .23333 L
.45361 .23122 L
.45836 .22958 L
.46182 .23122 L
.46593 .23316 L
Mistroke
.47181 .23879 L
.47302 .24637 L
.46919 .25394 L
.46679 .26151 L
.46593 .26299 L
.46141 .26908 L
.45836 .27411 L
.4564 .27665 L
.45169 .28422 L
.45079 .28662 L
.44604 .29179 L
.44322 .29386 L
.43855 .29936 L
.43565 .30143 L
.43057 .30694 L
.42955 .31451 L
.43565 .32149 L
.44322 .31711 L
.45024 .31451 L
.45079 .31404 L
.45836 .30793 L
.45994 .30694 L
.46593 .30153 L
.46958 .29936 L
.4735 .29689 L
.47796 .29179 L
.48107 .2891 L
.48628 .28422 L
.48864 .2823 L
.49621 .27671 L
.49696 .27665 L
.50379 .27136 L
.50636 .26908 L
.51136 .26518 L
.51893 .26236 L
.5265 .26377 L
.53407 .26861 L
.54164 .26651 L
.54921 .26468 L
.55214 .26151 L
.55678 .25532 L
.55726 .25394 L
.55945 .24637 L
.56143 .23879 L
.56362 .23122 L
.56147 .22365 L
.5609 .21608 L
.56354 .20851 L
.56435 .20605 L
.56641 .20094 L
Mistroke
.57116 .19337 L
.57193 .1924 L
.57703 .1858 L
.5795 .18303 L
.58349 .17823 L
.58707 .1755 L
.59174 .17065 L
.59464 .16773 L
.59966 .16308 L
.60221 .16143 L
.60922 .15551 L
.60978 .15498 L
.61591 .14794 L
.61735 .14482 L
.61976 .14037 L
.62418 .1328 L
.62492 .13129 L
.62837 .12523 L
.63223 .11766 L
.6325 .11726 L
.64007 .11053 L
.64072 .11008 L
.64764 .1039 L
.64926 .10251 L
.65521 .0972 L
.65737 .09494 L
.66278 .09143 L
.66621 .08737 L
.66888 .0798 L
.67035 .0776 L
.6775 .07223 L
.67792 .0718 L
.68549 .06673 L
.68827 .06466 L
.69306 .06069 L
.6955 .05709 L
.70064 .05143 L
Mfstroke
.6 g
.05709 .32022 m
.06332 .32208 L
.06329 .32965 L
.0614 .33722 L
.06466 .34319 L
.07076 .34479 L
.06466 .34593 L
.06 .35236 L
.05898 .35993 L
.06002 .3675 L
.05709 .3682 L
.0556 .3675 L
.05401 .35993 L
.05265 .35236 L
.05238 .34479 L
.05243 .33722 L
.05174 .32965 L
.05156 .32208 L
F
0 g
.05709 .32022 m
.06332 .32208 L
.06329 .32965 L
.0614 .33722 L
.06466 .34319 L
.07076 .34479 L
.06466 .34593 L
.06 .35236 L
.05898 .35993 L
.06002 .3675 L
.05709 .3682 L
.0556 .3675 L
.05401 .35993 L
.05265 .35236 L
.05238 .34479 L
.05243 .33722 L
.05174 .32965 L
.05156 .32208 L
.05709 .32022 L
s
1 g
.06466 .06051 m
.07049 .06466 L
.06466 .0722 L
.06115 .06466 L
F
0 g
.06466 .06051 m
.07049 .06466 L
.06466 .0722 L
.06115 .06466 L
.06466 .06051 L
s
1 g
.0798 .0398 m
.08673 .04194 L
.08093 .04952 L
.0798 .05098 L
.07723 .05709 L
.07223 .0619 L
.06736 .05709 L
.07032 .04952 L
.07223 .04671 L
.07686 .04194 L
F
0 g
.0798 .0398 m
.08673 .04194 L
.08093 .04952 L
.0798 .05098 L
.07723 .05709 L
.07223 .0619 L
.06736 .05709 L
.07032 .04952 L
.07223 .04671 L
.07686 .04194 L
.0798 .0398 L
s
.3 g
.72335 .07728 m
.72905 .0798 L
.73092 .08126 L
.73849 .0856 L
.74099 .08737 L
.74606 .09247 L
.75031 .09494 L
.75363 .0993 L
.75687 .10251 L
.76121 .10436 L
.76669 .11008 L
.76878 .11176 L
.77632 .11766 L
.77635 .11767 L
.78392 .12104 L
.79005 .12523 L
.79149 .12652 L
.79905 .1328 L
.79906 .13282 L
.8047 .14037 L
.80663 .14343 L
.81211 .14794 L
.81198 .15551 L
.80873 .16308 L
.81003 .17065 L
.8142 .17823 L
.8142 .17823 L
.82008 .1858 L
.81732 .19337 L
.81868 .20094 L
.82177 .20421 L
.82673 .20851 L
.82935 .21069 L
.83692 .21316 L
.84449 .21363 L
.85206 .21106 L
.85718 .21608 L
.85963 .22259 L
.8617 .22365 L
.86593 .23122 L
.8672 .23532 L
.86841 .23879 L
.87476 .24637 L
.87477 .24642 L
.87598 .25394 L
.88233 .26151 L
.88234 .26153 L
.88559 .26908 L
.88865 .27665 L
.8899 .28422 L
.88992 .28439 L
.89112 .29179 L
.89537 .29936 L
.89747 .30694 L
.89749 .30696 L
.90253 .31451 L
.90504 .32208 L
.90506 .32211 L
.90883 .32965 L
.91151 .33722 L
.91262 .34479 L
.91263 .34485 L
.9149 .35236 L
.91643 .35993 L
.91767 .3675 L
.9202 .37221 L
.92132 .37508 L
.9202 .38256 L
.92019 .38265 L
.9202 .38288 L
.92124 .39022 L
.9227 .39779 L
.9227 .40536 L
.92397 .41293 L
.92651 .4205 L
.92451 .42807 L
.92397 .43565 L
.92566 .44322 L
.92343 .45079 L
.92524 .45836 L
.92235 .46593 L
.92143 .4735 L
.92124 .48107 L
.9202 .48857 L
.92019 .48864 L
.91892 .49621 L
.91685 .50379 L
.9164 .51136 L
.91472 .51893 L
.91263 .52644 L
.91262 .5265 L
.91261 .53407 L
.90874 .54164 L
.90756 .54921 L
.90618 .55678 L
.90506 .56053 L
.90378 .56435 L
.90251 .57193 L
.89749 .57944 L
.89747 .5795 L
.89639 .58707 L
.89381 .59464 L
.89241 .60221 L
.88992 .60393 L
.88736 .60978 L
.88612 .61735 L
.88234 .62321 L
.88111 .62492 L
.87701 .6325 L
.87477 .63646 L
.87225 .64007 L
.86829 .64764 L
.8672 .64973 L
.86403 .65521 L
.85963 .66049 L
.85857 .66278 L
.85592 .67035 L
.85206 .67476 L
.84889 .67792 L
.84449 .68547 L
.84447 .68549 L
.84015 .69306 L
.83692 .69747 L
.83332 .70064 L
.82935 .70492 L
.82681 .70821 L
.82177 .71576 L
.82176 .71578 L
.81552 .72335 L
.8142 .72529 L
.8097 .73092 L
.80663 .73417 L
.80213 .73849 L
.79906 .7416 L
.79337 .74606 L
.79149 .74731 L
.78392 .75362 L
.7839 .75363 L
.77635 .76119 L
.77633 .76121 L
.76878 .76876 L
.76875 .76878 L
.76121 .77261 L
.75551 .77635 L
.75363 .77764 L
.74606 .78266 L
.74427 .78392 L
.73849 .78769 L
.73092 .79147 L
.7309 .79149 L
.72335 .79755 L
.72138 .79906 L
.71578 .80315 L
.71008 .80663 L
.70821 .80776 L
.70064 .81298 L
.69812 .8142 L
.69306 .81673 L
.68549 .82176 L
.68547 .82177 L
.67792 .82699 L
.67326 .82935 L
.67035 .83055 L
.66278 .83438 L
.6577 .83692 L
.65521 .8382 L
.64764 .84152 L
.64007 .84448 L
.64004 .84449 L
.6325 .8478 L
.62492 .85021 L
.61992 .85206 L
.61735 .85312 L
.60978 .85529 L
.60221 .85838 L
.59464 .85962 L
.59457 .85963 L
.58707 .86158 L
.5795 .86408 L
.57193 .86548 L
.56435 .86719 L
.56431 .8672 L
.55678 .86884 L
.54921 .87113 L
.54164 .87298 L
.53407 .87477 L
.5265 .87477 L
.52645 .87477 L
.51893 .87635 L
.51136 .87641 L
.50379 .8782 L
.49621 .87735 L
.48864 .87749 L
.48107 .87641 L
.4735 .87645 L
.46593 .87558 L
.46241 .87477 L
.45836 .87448 L
.45079 .87419 L
.44322 .87335 L
.43565 .87292 L
.42807 .87098 L
.4205 .87062 L
.41293 .86889 L
.4054 .8672 L
.40536 .86719 L
.39779 .86435 L
.39022 .8625 L
.38268 .85963 L
.38265 .85962 L
.37508 .85794 L
.3675 .85602 L
.35993 .85287 L
.3572 .85206 L
.35236 .8506 L
.34479 .84648 L
.34103 .84449 L
.33722 .84287 L
.32965 .8395 L
.3221 .83692 L
.32208 .83691 L
.31451 .83244 L
.30991 .82935 L
.30694 .8269 L
.30084 .82177 L
.29936 .82054 L
.29324 .8142 L
.29179 .81309 L
.28422 .80793 L
.28295 .80663 L
.27665 .8011 L
.27428 .79906 L
.26908 .79552 L
.26375 .79149 L
.26151 .78923 L
.25395 .78392 L
.25394 .78391 L
.24638 .77635 L
.24637 .77633 L
.24144 .76878 L
.23879 .76565 L
.23124 .76121 L
.23122 .76118 L
.22524 .75363 L
.22365 .75172 L
.21912 .74606 L
.21608 .74281 L
.2104 .73849 L
.20851 .73698 L
.20242 .73092 L
.20094 .7298 L
.19337 .72433 L
.19184 .72335 L
.1858 .71833 L
.18326 .71578 L
.17823 .71082 L
.17567 .70821 L
.17065 .70337 L
.16828 .70064 L
.16414 .69306 L
.16308 .69182 L
.15661 .68549 L
.15551 .68412 L
.15111 .67792 L
.14794 .67218 L
.14685 .67035 L
.14037 .66382 L
.13933 .66278 L
.13472 .65521 L
.1328 .65216 L
.13003 .64764 L
.12524 .64007 L
.12523 .64005 L
.11994 .6325 L
.11766 .62923 L
.11588 .62492 L
.11419 .61735 L
.11008 .61091 L
.10917 .60978 L
.10662 .60221 L
.10251 .59576 L
.10156 .59464 L
.09869 .58707 L
.09577 .5795 L
.09494 .57542 L
.09408 .57193 L
.09017 .56435 L
.08918 .55678 L
.08737 .55069 L
.08479 .54921 L
.08257 .54164 L
.08071 .53407 L
.07981 .5265 L
.0798 .52644 L
.07722 .51893 L
.07595 .51136 L
.07463 .50379 L
.07316 .49621 L
.07224 .48864 L
.07223 .4886 L
.0704 .48107 L
.0703 .4735 L
.06962 .46593 L
.07137 .45836 L
.06936 .45079 L
.07042 .44322 L
.06936 .43565 L
.06896 .42807 L
.07128 .4205 L
.0701 .41293 L
.0694 .40536 L
.07028 .39779 L
.07125 .39022 L
.07117 .38265 L
.07223 .37936 L
.07634 .37508 L
.0798 .37038 L
.08141 .3675 L
.08526 .35993 L
.0856 .35236 L
.08573 .34479 L
.08737 .34107 L
.08899 .33722 L
.09007 .32965 L
.09494 .32748 L
.09537 .32965 L
.09653 .33722 L
.09676 .34479 L
.09717 .35236 L
.09812 .35993 L
.10038 .3675 L
.10251 .36899 L
.11008 .36787 L
.11154 .3675 L
.11008 .36087 L
.10972 .35993 L
.10807 .35236 L
.11008 .34948 L
.11677 .34479 L
.11058 .33722 L
.11008 .33617 L
.10977 .32965 L
.11008 .32915 L
.11766 .32449 L
.12018 .32208 L
.11766 .3195 L
.11008 .31719 L
.10251 .31501 L
.10028 .31451 L
.09874 .30694 L
.10124 .29936 L
.10251 .29562 L
.10375 .29179 L
.10709 .28422 L
.11008 .27952 L
.1116 .27665 L
.11456 .26908 L
.11766 .26155 L
.11768 .26151 L
.1203 .25394 L
.12523 .24639 L
.12524 .24637 L
.12658 .23879 L
.13018 .23122 L
.1328 .22652 L
.13415 .22365 L
.13737 .21608 L
.14037 .21138 L
.14156 .20851 L
.14417 .20094 L
.14794 .19339 L
.14796 .19337 L
.15174 .1858 L
.1543 .17823 L
.15551 .17542 L
.15796 .17065 L
.16308 .1631 L
.1631 .16308 L
.16834 .15551 L
.17065 .15089 L
.17174 .14794 L
.17322 .14037 L
.17823 .13683 L
.18187 .14037 L
.1858 .14169 L
.19007 .14794 L
.19337 .14984 L
.19614 .15551 L
.19876 .16308 L
.20094 .16661 L
.20478 .17065 L
.20851 .17594 L
.21079 .17823 L
.21608 .18377 L
.21796 .1858 L
.22365 .1915 L
.22546 .19337 L
.23122 .19911 L
.23327 .20094 L
.23879 .20491 L
.24304 .20851 L
.24637 .21331 L
.24831 .21608 L
.25394 .22163 L
.25631 .22365 L
.26151 .22868 L
.26405 .23122 L
.26908 .23608 L
.27198 .23879 L
.27665 .24237 L
.28059 .24637 L
.28421 .25394 L
.28422 .25395 L
.29179 .2602 L
.29271 .26151 L
.29624 .26908 L
.29935 .27665 L
.29936 .27674 L
.30022 .28422 L
.30367 .29179 L
.30694 .2971 L
.3082 .29936 L
.31038 .30694 L
.31451 .31355 L
.31716 .31451 L
.32208 .31965 L
.32461 .32208 L
.32965 .32636 L
.33359 .32965 L
.33722 .33336 L
.34149 .33722 L
.34479 .34223 L
.34593 .34479 L
.35109 .35236 L
.35236 .35428 L
.35604 .35993 L
.35992 .3675 L
.35993 .36753 L
.3675 .37424 L
.37508 .37259 L
.37972 .37508 L
.37885 .38265 L
.3757 .39022 L
.38265 .39476 L
.39019 .39779 L
.39022 .39782 L
.39189 .40536 L
.3946 .41293 L
.39779 .41779 L
.39921 .4205 L
.39918 .42807 L
.40028 .43565 L
.39993 .44322 L
.39779 .44718 L
.39419 .45079 L
.39022 .45328 L
.38265 .45197 L
.37508 .45594 L
.37287 .45836 L
.3675 .46421 L
.36579 .46593 L
.35993 .47301 L
.35843 .4735 L
.35236 .47577 L
.34522 .48107 L
.34479 .48162 L
.34064 .48864 L
.33788 .49621 L
.33722 .49969 L
.33616 .50379 L
.33147 .51136 L
.32965 .51343 L
.32669 .51893 L
.3255 .5265 L
.32653 .53407 L
.32357 .54164 L
.32208 .54321 L
.31481 .54921 L
.31451 .54982 L
.31025 .55678 L
.30694 .56434 L
.30693 .56435 L
.30576 .57193 L
.30334 .5795 L
.30217 .58707 L
.29981 .59464 L
.30016 .60221 L
.29936 .60402 L
.29683 .60978 L
.29766 .61735 L
.29375 .62492 L
.29285 .6325 L
.29439 .64007 L
.29418 .64764 L
.29179 .65332 L
.2909 .65521 L
.28959 .66278 L
.29179 .67035 L
.28886 .67792 L
.28823 .68549 L
.29148 .69306 L
.29179 .70064 L
.29179 .7007 L
.29253 .70821 L
.29314 .71578 L
.2943 .72335 L
.29819 .73092 L
.29936 .73353 L
.30137 .73849 L
.30694 .74563 L
.3075 .74606 L
.31382 .75363 L
.31451 .75423 L
.32157 .76121 L
.32208 .76129 L
.32965 .76828 L
.33002 .76878 L
.33127 .77635 L
.33577 .78392 L
.33722 .78465 L
.34479 .7879 L
.35081 .79149 L
.35236 .79221 L
.35993 .79554 L
.3675 .79839 L
.36874 .79906 L
.37508 .80115 L
.38265 .80552 L
.38472 .80663 L
.39019 .8142 L
.39022 .81437 L
.39209 .82177 L
.39779 .82599 L
.40536 .82812 L
.41293 .82656 L
.4205 .82859 L
.42142 .82935 L
.42452 .83692 L
.42807 .83855 L
.43565 .84384 L
.44313 .84449 L
.44322 .84449 L
.45079 .84779 L
.45836 .85094 L
.46084 .85206 L
.46593 .85329 L
.4735 .8548 L
.48107 .85824 L
.48864 .85799 L
.49621 .8531 L
.50379 .85374 L
.51136 .85294 L
.51893 .85295 L
.5265 .85206 L
.52653 .85206 L
.53407 .84695 L
.54164 .84866 L
.54921 .8487 L
.55678 .84959 L
.56435 .84773 L
.57062 .84449 L
.57193 .84291 L
.57549 .83692 L
.5795 .83153 L
.58609 .82935 L
.58707 .82898 L
.59464 .82483 L
.60221 .82203 L
.6028 .82177 L
.60978 .81815 L
.61735 .8191 L
.62492 .81787 L
.6325 .81527 L
.63372 .8142 L
.63636 .80663 L
.64007 .80191 L
.64356 .79906 L
.64547 .79149 L
.64764 .79006 L
.65343 .78392 L
.65521 .78213 L
.65833 .77635 L
.65522 .76878 L
.65521 .76876 L
.65037 .76121 L
.64764 .75448 L
.64721 .75363 L
.64007 .74606 L
.64007 .74606 L
.63474 .73849 L
.63591 .73092 L
.63799 .72335 L
.64007 .71836 L
.64172 .71578 L
.64597 .70821 L
.64764 .70441 L
.64904 .70064 L
.65393 .69306 L
.65387 .68549 L
.65521 .67793 L
.65521 .67792 L
.65831 .67035 L
.65738 .66278 L
.65911 .65521 L
.66083 .64764 L
.66278 .64008 L
.66278 .64007 L
.66384 .6325 L
.66374 .62492 L
.66311 .61735 L
.66278 .61697 L
.65521 .61151 L
.64764 .61202 L
.64007 .6116 L
.63599 .60978 L
.6338 .60221 L
.63271 .59464 L
.6325 .59424 L
.62982 .58707 L
.63101 .5795 L
.6325 .57261 L
.63268 .57193 L
.6325 .57071 L
.63127 .56435 L
.63106 .55678 L
.6303 .54921 L
.63108 .54164 L
.6325 .53871 L
.63361 .53407 L
.63561 .5265 L
.63818 .51893 L
.63751 .51136 L
.63491 .50379 L
.63277 .49621 L
.6325 .49568 L
.62643 .48864 L
.62492 .48679 L
.62074 .48107 L
.61735 .47657 L
.61416 .4735 L
.60978 .47247 L
.60703 .4735 L
.60221 .48105 L
.60218 .48107 L
.59464 .4821 L
.59209 .48107 L
.58707 .47913 L
.58254 .4735 L
.58069 .46593 L
.58149 .45836 L
.57951 .45079 L
.58707 .44327 L
.59024 .45079 L
.59464 .45706 L
.59833 .45836 L
.60221 .45839 L
.60231 .45836 L
.60978 .45087 L
.60979 .45079 L
.60979 .44322 L
.60978 .4432 L
.60527 .43565 L
.60221 .43034 L
.59687 .42807 L
.59464 .42804 L
.59219 .4205 L
.59464 .41875 L
.60214 .4205 L
.60221 .42054 L
.60725 .4205 L
.60978 .41798 L
.6126 .41293 L
.61735 .40915 L
.62247 .40536 L
.62492 .40112 L
.62706 .39779 L
.6325 .39217 L
.6342 .39022 L
.63475 .38265 L
.6325 .37883 L
.62961 .37508 L
.62492 .36934 L
.61739 .3675 L
.61735 .36749 L
.60978 .3659 L
.60221 .36409 L
.59464 .36371 L
.58707 .36366 L
.5795 .36265 L
.57422 .35993 L
.57193 .35892 L
.56435 .35993 L
.56432 .35993 L
.55678 .36212 L
.54921 .36606 L
.54164 .3675 L
.53407 .36605 L
.5265 .36511 L
.51893 .36749 L
.5189 .3675 L
.51136 .37505 L
.51133 .37508 L
.50379 .38262 L
.50378 .38265 L
.49621 .3902 L
.49619 .39022 L
.48995 .39779 L
.48864 .40034 L
.48107 .40041 L
.47355 .39779 L
.47515 .39022 L
.47849 .38265 L
.4793 .37508 L
.47502 .3675 L
.47507 .35993 L
.47655 .35236 L
.48107 .34481 L
.48108 .34479 L
.48864 .33723 L
.48865 .33722 L
.49621 .32966 L
.49622 .32965 L
.50185 .32208 L
.50379 .32156 L
.51136 .31579 L
.51337 .31451 L
.51893 .3105 L
.52461 .30694 L
.5265 .30596 L
.53407 .29937 L
.53483 .29936 L
.54164 .29302 L
.54339 .29179 L
.54921 .28583 L
.55125 .28422 L
.55678 .27844 L
.55925 .27665 L
.5597 .26908 L
.56282 .26151 L
.56435 .25974 L
.57043 .25394 L
.57193 .25292 L
.5795 .24639 L
.5795 .24637 L
.5795 .24515 L
.57745 .23879 L
.57424 .23122 L
.57193 .22988 L
.56733 .22365 L
.56824 .21608 L
.57193 .21217 L
.57534 .20851 L
.5781 .20094 L
.5795 .19831 L
.58332 .19337 L
.58707 .18823 L
.58881 .1858 L
.59464 .17951 L
.59588 .17823 L
.60221 .17108 L
.60269 .17065 L
.60978 .16432 L
.61111 .16308 L
.61735 .15811 L
.62053 .15551 L
.62492 .15192 L
.62756 .14794 L
.63153 .14037 L
.6325 .13926 L
.63896 .1328 L
.64007 .13185 L
.64544 .12523 L
.64764 .12226 L
.65158 .11766 L
.65521 .11416 L
.65941 .11008 L
.66278 .10729 L
.66874 .10251 L
.67035 .10127 L
.67792 .09495 L
.67793 .09494 L
.68549 .08932 L
.68826 .08737 L
.69306 .08104 L
.69718 .08737 L
.70064 .09151 L
.70821 .08807 L
.70976 .08737 L
.71578 .08078 L
.71834 .0798 L
F
0 g
.72335 .07728 m
.72905 .0798 L
.73092 .08126 L
.73849 .0856 L
.74099 .08737 L
.74606 .09247 L
.75031 .09494 L
.75363 .0993 L
.75687 .10251 L
.76121 .10436 L
.76669 .11008 L
.76878 .11176 L
.77632 .11766 L
.77635 .11767 L
.78392 .12104 L
.79005 .12523 L
.79149 .12652 L
.79905 .1328 L
.79906 .13282 L
.8047 .14037 L
.80663 .14343 L
.81211 .14794 L
.81198 .15551 L
.80873 .16308 L
.81003 .17065 L
.8142 .17823 L
.8142 .17823 L
.82008 .1858 L
.81732 .19337 L
.81868 .20094 L
.82177 .20421 L
.82673 .20851 L
.82935 .21069 L
.83692 .21316 L
.84449 .21363 L
.85206 .21106 L
.85718 .21608 L
.85963 .22259 L
.8617 .22365 L
.86593 .23122 L
.8672 .23532 L
.86841 .23879 L
.87476 .24637 L
.87477 .24642 L
.87598 .25394 L
.88233 .26151 L
.88234 .26153 L
.88559 .26908 L
.88865 .27665 L
.8899 .28422 L
Mistroke
.88992 .28439 L
.89112 .29179 L
.89537 .29936 L
.89747 .30694 L
.89749 .30696 L
.90253 .31451 L
.90504 .32208 L
.90506 .32211 L
.90883 .32965 L
.91151 .33722 L
.91262 .34479 L
.91263 .34485 L
.9149 .35236 L
.91643 .35993 L
.91767 .3675 L
.9202 .37221 L
.92132 .37508 L
.9202 .38256 L
.92019 .38265 L
.9202 .38288 L
.92124 .39022 L
.9227 .39779 L
.9227 .40536 L
.92397 .41293 L
.92651 .4205 L
.92451 .42807 L
.92397 .43565 L
.92566 .44322 L
.92343 .45079 L
.92524 .45836 L
.92235 .46593 L
.92143 .4735 L
.92124 .48107 L
.9202 .48857 L
.92019 .48864 L
.91892 .49621 L
.91685 .50379 L
.9164 .51136 L
.91472 .51893 L
.91263 .52644 L
.91262 .5265 L
.91261 .53407 L
.90874 .54164 L
.90756 .54921 L
.90618 .55678 L
.90506 .56053 L
.90378 .56435 L
.90251 .57193 L
.89749 .57944 L
.89747 .5795 L
Mistroke
.89639 .58707 L
.89381 .59464 L
.89241 .60221 L
.88992 .60393 L
.88736 .60978 L
.88612 .61735 L
.88234 .62321 L
.88111 .62492 L
.87701 .6325 L
.87477 .63646 L
.87225 .64007 L
.86829 .64764 L
.8672 .64973 L
.86403 .65521 L
.85963 .66049 L
.85857 .66278 L
.85592 .67035 L
.85206 .67476 L
.84889 .67792 L
.84449 .68547 L
.84447 .68549 L
.84015 .69306 L
.83692 .69747 L
.83332 .70064 L
.82935 .70492 L
.82681 .70821 L
.82177 .71576 L
.82176 .71578 L
.81552 .72335 L
.8142 .72529 L
.8097 .73092 L
.80663 .73417 L
.80213 .73849 L
.79906 .7416 L
.79337 .74606 L
.79149 .74731 L
.78392 .75362 L
.7839 .75363 L
.77635 .76119 L
.77633 .76121 L
.76878 .76876 L
.76875 .76878 L
.76121 .77261 L
.75551 .77635 L
.75363 .77764 L
.74606 .78266 L
.74427 .78392 L
.73849 .78769 L
.73092 .79147 L
.7309 .79149 L
Mistroke
.72335 .79755 L
.72138 .79906 L
.71578 .80315 L
.71008 .80663 L
.70821 .80776 L
.70064 .81298 L
.69812 .8142 L
.69306 .81673 L
.68549 .82176 L
.68547 .82177 L
.67792 .82699 L
.67326 .82935 L
.67035 .83055 L
.66278 .83438 L
.6577 .83692 L
.65521 .8382 L
.64764 .84152 L
.64007 .84448 L
.64004 .84449 L
.6325 .8478 L
.62492 .85021 L
.61992 .85206 L
.61735 .85312 L
.60978 .85529 L
.60221 .85838 L
.59464 .85962 L
.59457 .85963 L
.58707 .86158 L
.5795 .86408 L
.57193 .86548 L
.56435 .86719 L
.56431 .8672 L
.55678 .86884 L
.54921 .87113 L
.54164 .87298 L
.53407 .87477 L
.5265 .87477 L
.52645 .87477 L
.51893 .87635 L
.51136 .87641 L
.50379 .8782 L
.49621 .87735 L
.48864 .87749 L
.48107 .87641 L
.4735 .87645 L
.46593 .87558 L
.46241 .87477 L
.45836 .87448 L
.45079 .87419 L
.44322 .87335 L
Mistroke
.43565 .87292 L
.42807 .87098 L
.4205 .87062 L
.41293 .86889 L
.4054 .8672 L
.40536 .86719 L
.39779 .86435 L
.39022 .8625 L
.38268 .85963 L
.38265 .85962 L
.37508 .85794 L
.3675 .85602 L
.35993 .85287 L
.3572 .85206 L
.35236 .8506 L
.34479 .84648 L
.34103 .84449 L
.33722 .84287 L
.32965 .8395 L
.3221 .83692 L
.32208 .83691 L
.31451 .83244 L
.30991 .82935 L
.30694 .8269 L
.30084 .82177 L
.29936 .82054 L
.29324 .8142 L
.29179 .81309 L
.28422 .80793 L
.28295 .80663 L
.27665 .8011 L
.27428 .79906 L
.26908 .79552 L
.26375 .79149 L
.26151 .78923 L
.25395 .78392 L
.25394 .78391 L
.24638 .77635 L
.24637 .77633 L
.24144 .76878 L
.23879 .76565 L
.23124 .76121 L
.23122 .76118 L
.22524 .75363 L
.22365 .75172 L
.21912 .74606 L
.21608 .74281 L
.2104 .73849 L
.20851 .73698 L
.20242 .73092 L
Mistroke
.20094 .7298 L
.19337 .72433 L
.19184 .72335 L
.1858 .71833 L
.18326 .71578 L
.17823 .71082 L
.17567 .70821 L
.17065 .70337 L
.16828 .70064 L
.16414 .69306 L
.16308 .69182 L
.15661 .68549 L
.15551 .68412 L
.15111 .67792 L
.14794 .67218 L
.14685 .67035 L
.14037 .66382 L
.13933 .66278 L
.13472 .65521 L
.1328 .65216 L
.13003 .64764 L
.12524 .64007 L
.12523 .64005 L
.11994 .6325 L
.11766 .62923 L
.11588 .62492 L
.11419 .61735 L
.11008 .61091 L
.10917 .60978 L
.10662 .60221 L
.10251 .59576 L
.10156 .59464 L
.09869 .58707 L
.09577 .5795 L
.09494 .57542 L
.09408 .57193 L
.09017 .56435 L
.08918 .55678 L
.08737 .55069 L
.08479 .54921 L
.08257 .54164 L
.08071 .53407 L
.07981 .5265 L
.0798 .52644 L
.07722 .51893 L
.07595 .51136 L
.07463 .50379 L
.07316 .49621 L
.07224 .48864 L
.07223 .4886 L
Mistroke
.0704 .48107 L
.0703 .4735 L
.06962 .46593 L
.07137 .45836 L
.06936 .45079 L
.07042 .44322 L
.06936 .43565 L
.06896 .42807 L
.07128 .4205 L
.0701 .41293 L
.0694 .40536 L
.07028 .39779 L
.07125 .39022 L
.07117 .38265 L
.07223 .37936 L
.07634 .37508 L
.0798 .37038 L
.08141 .3675 L
.08526 .35993 L
.0856 .35236 L
.08573 .34479 L
.08737 .34107 L
.08899 .33722 L
.09007 .32965 L
.09494 .32748 L
.09537 .32965 L
.09653 .33722 L
.09676 .34479 L
.09717 .35236 L
.09812 .35993 L
.10038 .3675 L
.10251 .36899 L
.11008 .36787 L
.11154 .3675 L
.11008 .36087 L
.10972 .35993 L
.10807 .35236 L
.11008 .34948 L
.11677 .34479 L
.11058 .33722 L
.11008 .33617 L
.10977 .32965 L
.11008 .32915 L
.11766 .32449 L
.12018 .32208 L
.11766 .3195 L
.11008 .31719 L
.10251 .31501 L
.10028 .31451 L
.09874 .30694 L
Mistroke
.10124 .29936 L
.10251 .29562 L
.10375 .29179 L
.10709 .28422 L
.11008 .27952 L
.1116 .27665 L
.11456 .26908 L
.11766 .26155 L
.11768 .26151 L
.1203 .25394 L
.12523 .24639 L
.12524 .24637 L
.12658 .23879 L
.13018 .23122 L
.1328 .22652 L
.13415 .22365 L
.13737 .21608 L
.14037 .21138 L
.14156 .20851 L
.14417 .20094 L
.14794 .19339 L
.14796 .19337 L
.15174 .1858 L
.1543 .17823 L
.15551 .17542 L
.15796 .17065 L
.16308 .1631 L
.1631 .16308 L
.16834 .15551 L
.17065 .15089 L
.17174 .14794 L
.17322 .14037 L
.17823 .13683 L
.18187 .14037 L
.1858 .14169 L
.19007 .14794 L
.19337 .14984 L
.19614 .15551 L
.19876 .16308 L
.20094 .16661 L
.20478 .17065 L
.20851 .17594 L
.21079 .17823 L
.21608 .18377 L
.21796 .1858 L
.22365 .1915 L
.22546 .19337 L
.23122 .19911 L
.23327 .20094 L
.23879 .20491 L
Mistroke
.24304 .20851 L
.24637 .21331 L
.24831 .21608 L
.25394 .22163 L
.25631 .22365 L
.26151 .22868 L
.26405 .23122 L
.26908 .23608 L
.27198 .23879 L
.27665 .24237 L
.28059 .24637 L
.28421 .25394 L
.28422 .25395 L
.29179 .2602 L
.29271 .26151 L
.29624 .26908 L
.29935 .27665 L
.29936 .27674 L
.30022 .28422 L
.30367 .29179 L
.30694 .2971 L
.3082 .29936 L
.31038 .30694 L
.31451 .31355 L
.31716 .31451 L
.32208 .31965 L
.32461 .32208 L
.32965 .32636 L
.33359 .32965 L
.33722 .33336 L
.34149 .33722 L
.34479 .34223 L
.34593 .34479 L
.35109 .35236 L
.35236 .35428 L
.35604 .35993 L
.35992 .3675 L
.35993 .36753 L
.3675 .37424 L
.37508 .37259 L
.37972 .37508 L
.37885 .38265 L
.3757 .39022 L
.38265 .39476 L
.39019 .39779 L
.39022 .39782 L
.39189 .40536 L
.3946 .41293 L
.39779 .41779 L
.39921 .4205 L
Mistroke
.39918 .42807 L
.40028 .43565 L
.39993 .44322 L
.39779 .44718 L
.39419 .45079 L
.39022 .45328 L
.38265 .45197 L
.37508 .45594 L
.37287 .45836 L
.3675 .46421 L
.36579 .46593 L
.35993 .47301 L
.35843 .4735 L
.35236 .47577 L
.34522 .48107 L
.34479 .48162 L
.34064 .48864 L
.33788 .49621 L
.33722 .49969 L
.33616 .50379 L
.33147 .51136 L
.32965 .51343 L
.32669 .51893 L
.3255 .5265 L
.32653 .53407 L
.32357 .54164 L
.32208 .54321 L
.31481 .54921 L
.31451 .54982 L
.31025 .55678 L
.30694 .56434 L
.30693 .56435 L
.30576 .57193 L
.30334 .5795 L
.30217 .58707 L
.29981 .59464 L
.30016 .60221 L
.29936 .60402 L
.29683 .60978 L
.29766 .61735 L
.29375 .62492 L
.29285 .6325 L
.29439 .64007 L
.29418 .64764 L
.29179 .65332 L
.2909 .65521 L
.28959 .66278 L
.29179 .67035 L
.28886 .67792 L
.28823 .68549 L
Mistroke
.29148 .69306 L
.29179 .70064 L
.29179 .7007 L
.29253 .70821 L
.29314 .71578 L
.2943 .72335 L
.29819 .73092 L
.29936 .73353 L
.30137 .73849 L
.30694 .74563 L
.3075 .74606 L
.31382 .75363 L
.31451 .75423 L
.32157 .76121 L
.32208 .76129 L
.32965 .76828 L
.33002 .76878 L
.33127 .77635 L
.33577 .78392 L
.33722 .78465 L
.34479 .7879 L
.35081 .79149 L
.35236 .79221 L
.35993 .79554 L
.3675 .79839 L
.36874 .79906 L
.37508 .80115 L
.38265 .80552 L
.38472 .80663 L
.39019 .8142 L
.39022 .81437 L
.39209 .82177 L
.39779 .82599 L
.40536 .82812 L
.41293 .82656 L
.4205 .82859 L
.42142 .82935 L
.42452 .83692 L
.42807 .83855 L
.43565 .84384 L
.44313 .84449 L
.44322 .84449 L
.45079 .84779 L
.45836 .85094 L
.46084 .85206 L
.46593 .85329 L
.4735 .8548 L
.48107 .85824 L
.48864 .85799 L
.49621 .8531 L
Mistroke
.50379 .85374 L
.51136 .85294 L
.51893 .85295 L
.5265 .85206 L
.52653 .85206 L
.53407 .84695 L
.54164 .84866 L
.54921 .8487 L
.55678 .84959 L
.56435 .84773 L
.57062 .84449 L
.57193 .84291 L
.57549 .83692 L
.5795 .83153 L
.58609 .82935 L
.58707 .82898 L
.59464 .82483 L
.60221 .82203 L
.6028 .82177 L
.60978 .81815 L
.61735 .8191 L
.62492 .81787 L
.6325 .81527 L
.63372 .8142 L
.63636 .80663 L
.64007 .80191 L
.64356 .79906 L
.64547 .79149 L
.64764 .79006 L
.65343 .78392 L
.65521 .78213 L
.65833 .77635 L
.65522 .76878 L
.65521 .76876 L
.65037 .76121 L
.64764 .75448 L
.64721 .75363 L
.64007 .74606 L
.64007 .74606 L
.63474 .73849 L
.63591 .73092 L
.63799 .72335 L
.64007 .71836 L
.64172 .71578 L
.64597 .70821 L
.64764 .70441 L
.64904 .70064 L
.65393 .69306 L
.65387 .68549 L
.65521 .67793 L
Mistroke
.65521 .67792 L
.65831 .67035 L
.65738 .66278 L
.65911 .65521 L
.66083 .64764 L
.66278 .64008 L
.66278 .64007 L
.66384 .6325 L
.66374 .62492 L
.66311 .61735 L
.66278 .61697 L
.65521 .61151 L
.64764 .61202 L
.64007 .6116 L
.63599 .60978 L
.6338 .60221 L
.63271 .59464 L
.6325 .59424 L
.62982 .58707 L
.63101 .5795 L
.6325 .57261 L
.63268 .57193 L
.6325 .57071 L
.63127 .56435 L
.63106 .55678 L
.6303 .54921 L
.63108 .54164 L
.6325 .53871 L
.63361 .53407 L
.63561 .5265 L
.63818 .51893 L
.63751 .51136 L
.63491 .50379 L
.63277 .49621 L
.6325 .49568 L
.62643 .48864 L
.62492 .48679 L
.62074 .48107 L
.61735 .47657 L
.61416 .4735 L
.60978 .47247 L
.60703 .4735 L
.60221 .48105 L
.60218 .48107 L
.59464 .4821 L
.59209 .48107 L
.58707 .47913 L
.58254 .4735 L
.58069 .46593 L
.58149 .45836 L
Mistroke
.57951 .45079 L
.58707 .44327 L
.59024 .45079 L
.59464 .45706 L
.59833 .45836 L
.60221 .45839 L
.60231 .45836 L
.60978 .45087 L
.60979 .45079 L
.60979 .44322 L
.60978 .4432 L
.60527 .43565 L
.60221 .43034 L
.59687 .42807 L
.59464 .42804 L
.59219 .4205 L
.59464 .41875 L
.60214 .4205 L
.60221 .42054 L
.60725 .4205 L
.60978 .41798 L
.6126 .41293 L
.61735 .40915 L
.62247 .40536 L
.62492 .40112 L
.62706 .39779 L
.6325 .39217 L
.6342 .39022 L
.63475 .38265 L
.6325 .37883 L
.62961 .37508 L
.62492 .36934 L
.61739 .3675 L
.61735 .36749 L
.60978 .3659 L
.60221 .36409 L
.59464 .36371 L
.58707 .36366 L
.5795 .36265 L
.57422 .35993 L
.57193 .35892 L
.56435 .35993 L
.56432 .35993 L
.55678 .36212 L
.54921 .36606 L
.54164 .3675 L
.53407 .36605 L
.5265 .36511 L
.51893 .36749 L
.5189 .3675 L
Mistroke
.51136 .37505 L
.51133 .37508 L
.50379 .38262 L
.50378 .38265 L
.49621 .3902 L
.49619 .39022 L
.48995 .39779 L
.48864 .40034 L
.48107 .40041 L
.47355 .39779 L
.47515 .39022 L
.47849 .38265 L
.4793 .37508 L
.47502 .3675 L
.47507 .35993 L
.47655 .35236 L
.48107 .34481 L
.48108 .34479 L
.48864 .33723 L
.48865 .33722 L
.49621 .32966 L
.49622 .32965 L
.50185 .32208 L
.50379 .32156 L
.51136 .31579 L
.51337 .31451 L
.51893 .3105 L
.52461 .30694 L
.5265 .30596 L
.53407 .29937 L
.53483 .29936 L
.54164 .29302 L
.54339 .29179 L
.54921 .28583 L
.55125 .28422 L
.55678 .27844 L
.55925 .27665 L
.5597 .26908 L
.56282 .26151 L
.56435 .25974 L
.57043 .25394 L
.57193 .25292 L
.5795 .24639 L
.5795 .24637 L
.5795 .24515 L
.57745 .23879 L
.57424 .23122 L
.57193 .22988 L
.56733 .22365 L
.56824 .21608 L
Mistroke
.57193 .21217 L
.57534 .20851 L
.5781 .20094 L
.5795 .19831 L
.58332 .19337 L
.58707 .18823 L
.58881 .1858 L
.59464 .17951 L
.59588 .17823 L
.60221 .17108 L
.60269 .17065 L
.60978 .16432 L
.61111 .16308 L
.61735 .15811 L
.62053 .15551 L
.62492 .15192 L
.62756 .14794 L
.63153 .14037 L
.6325 .13926 L
.63896 .1328 L
.64007 .13185 L
.64544 .12523 L
.64764 .12226 L
.65158 .11766 L
.65521 .11416 L
.65941 .11008 L
.66278 .10729 L
.66874 .10251 L
.67035 .10127 L
.67792 .09495 L
.67793 .09494 L
.68549 .08932 L
.68826 .08737 L
.69306 .08104 L
.69718 .08737 L
.70064 .09151 L
.70821 .08807 L
.70976 .08737 L
.71578 .08078 L
.71834 .0798 L
.72335 .07728 L
Mfstroke
1 g
.09494 .0204 m
.09991 .0268 L
.09662 .03437 L
.09494 .03563 L
.08737 .04095 L
.08544 .03437 L
.08737 .02987 L
.08991 .0268 L
F
0 g
.09494 .0204 m
.09991 .0268 L
.09662 .03437 L
.09494 .03563 L
.08737 .04095 L
.08544 .03437 L
.08737 .02987 L
.08991 .0268 L
.09494 .0204 L
s
.2 g
.19337 .17129 m
.20094 .17525 L
.20255 .17823 L
.20851 .18504 L
.20961 .1858 L
.21608 .19276 L
.21682 .19337 L
.22365 .20005 L
.2246 .20094 L
.23122 .2063 L
.23389 .20851 L
.2387 .21608 L
.23879 .21621 L
.24567 .22365 L
.24637 .225 L
.25184 .23122 L
.25394 .23402 L
.25754 .23879 L
.26151 .24163 L
.26527 .24637 L
.26723 .25394 L
.26908 .25766 L
.27471 .26151 L
.27665 .26511 L
.27855 .26908 L
.28242 .27665 L
.28422 .28325 L
.28456 .28422 L
.28891 .29179 L
.29179 .29597 L
.29448 .29936 L
.29936 .30592 L
.2999 .30694 L
.30481 .31451 L
.30694 .31773 L
.30997 .32208 L
.31451 .32632 L
.31762 .32965 L
.32208 .33514 L
.32329 .33722 L
.32651 .34479 L
.32965 .35006 L
.3311 .35236 L
.33519 .35993 L
.33722 .36472 L
.3386 .3675 L
.34457 .37508 L
.34479 .37578 L
.3473 .38265 L
.35236 .3857 L
.35766 .39022 L
.35785 .39779 L
.35867 .40536 L
.35993 .40846 L
.36555 .41293 L
.3675 .41711 L
.36803 .4205 L
.3675 .42177 L
.36212 .42807 L
.35993 .43429 L
.35898 .43565 L
.35236 .43977 L
.34816 .44322 L
.34479 .44682 L
.34157 .45079 L
.34162 .45836 L
.33755 .46593 L
.33722 .46685 L
.33226 .4735 L
.33075 .48107 L
.32965 .4849 L
.32682 .48864 L
.32208 .49488 L
.32121 .49621 L
.32208 .50031 L
.3234 .50379 L
.32208 .50666 L
.31958 .51136 L
.3175 .51893 L
.31451 .52404 L
.31358 .5265 L
.31418 .53407 L
.31353 .54164 L
.30694 .54898 L
.30662 .54921 L
.29936 .55633 L
.29917 .55678 L
.29504 .56435 L
.2943 .57193 L
.29179 .57746 L
.29056 .5795 L
.28892 .58707 L
.28736 .59464 L
.28842 .60221 L
.2876 .60978 L
.28971 .61735 L
.28565 .62492 L
.28442 .6325 L
.28478 .64007 L
.28648 .64764 L
.2846 .65521 L
.28422 .65659 L
.28319 .66278 L
.28363 .67035 L
.28132 .67792 L
.28153 .68549 L
.28415 .69306 L
.28373 .70064 L
.28414 .70821 L
.28422 .70922 L
.28539 .71578 L
.28763 .72335 L
.2917 .73092 L
.29179 .73094 L
.29746 .73849 L
.29752 .74606 L
.29936 .75088 L
.30087 .75363 L
.30694 .75774 L
.31173 .76121 L
.31451 .76383 L
.31907 .76878 L
.32152 .77635 L
.32208 .77716 L
.32738 .78392 L
.32965 .78593 L
.33722 .78881 L
.34361 .79149 L
.34479 .7923 L
.35236 .79667 L
.35757 .79906 L
.35993 .80139 L
.36589 .80663 L
.3675 .80834 L
.37445 .8142 L
.37508 .81497 L
.38265 .82111 L
.38354 .82177 L
.388 .82935 L
.39022 .83286 L
.39779 .83654 L
.40334 .83692 L
.39779 .8404 L
.39022 .83842 L
.38265 .839 L
.37823 .83692 L
.37508 .83619 L
.3675 .83466 L
.35993 .83125 L
.35679 .82935 L
.35236 .82693 L
.34479 .82371 L
.34165 .82177 L
.33722 .81887 L
.33035 .8142 L
.32965 .81377 L
.32208 .81018 L
.31912 .80663 L
.31451 .80171 L
.31116 .79906 L
.30694 .79646 L
.29976 .79149 L
.29936 .7912 L
.29179 .78464 L
.29036 .78392 L
.28422 .7806 L
.2791 .77635 L
.27665 .77381 L
.27243 .76878 L
.26908 .76635 L
.26449 .76121 L
.26151 .75817 L
.25795 .75363 L
.25394 .74729 L
.2531 .74606 L
.2469 .73849 L
.24637 .73783 L
.23946 .73092 L
.23879 .73046 L
.23122 .7252 L
.22906 .72335 L
.22365 .71786 L
.22127 .71578 L
.21608 .71064 L
.21307 .70821 L
.20851 .70465 L
.20356 .70064 L
.20094 .69807 L
.19589 .69306 L
.19337 .69089 L
.18784 .68549 L
.1858 .68361 L
.18121 .67792 L
.17823 .67336 L
.17615 .67035 L
.17065 .665 L
.16762 .66278 L
.16308 .65629 L
.16244 .65521 L
.15725 .64764 L
.15551 .64509 L
.15218 .64007 L
.14794 .63367 L
.14713 .6325 L
.14078 .62492 L
.14037 .62376 L
.13848 .61735 L
.13319 .60978 L
.1328 .60892 L
.1301 .60221 L
.12561 .59464 L
.12523 .59381 L
.12232 .58707 L
.11808 .5795 L
.11802 .57193 L
.11766 .57105 L
.1142 .56435 L
.11044 .55678 L
.11008 .55597 L
.10851 .54921 L
.10722 .54164 L
.10501 .53407 L
.10287 .5265 L
.10251 .52551 L
.10084 .51893 L
.0996 .51136 L
.09793 .50379 L
.09696 .49621 L
.09636 .48864 L
.09529 .48107 L
.09535 .4735 L
.09494 .47109 L
.09424 .46593 L
.09494 .46118 L
.09538 .45836 L
.09494 .45554 L
.09414 .45079 L
.09494 .44603 L
.09538 .44322 L
.09494 .4404 L
.0942 .43565 L
.09494 .4298 L
.09533 .42807 L
.09729 .4205 L
.0966 .41293 L
.09791 .40536 L
.0984 .39779 L
.10033 .39022 L
.10251 .38351 L
.10297 .38265 L
.10889 .37508 L
.11008 .37487 L
.11766 .373 L
.12335 .3675 L
.12303 .35993 L
.11824 .35236 L
.12358 .34479 L
.12332 .33722 L
.12523 .33197 L
.12707 .32965 L
.12895 .32208 L
.13164 .31451 L
.13154 .30694 L
.1328 .304 L
.13528 .29936 L
.13911 .29179 L
.14037 .28926 L
.14292 .28422 L
.14794 .2784 L
.14852 .27665 L
.15042 .26908 L
.15288 .26151 L
.15473 .25394 L
.15551 .25101 L
.15995 .24637 L
.16092 .23879 L
.16308 .23225 L
.16372 .23122 L
.16827 .22365 L
.17065 .21713 L
.17119 .21608 L
.17606 .20851 L
.17724 .20094 L
.17823 .19762 L
.18011 .19337 L
.18479 .1858 L
.1858 .18345 L
.18799 .17823 L
F
0 g
.19337 .17129 m
.20094 .17525 L
.20255 .17823 L
.20851 .18504 L
.20961 .1858 L
.21608 .19276 L
.21682 .19337 L
.22365 .20005 L
.2246 .20094 L
.23122 .2063 L
.23389 .20851 L
.2387 .21608 L
.23879 .21621 L
.24567 .22365 L
.24637 .225 L
.25184 .23122 L
.25394 .23402 L
.25754 .23879 L
.26151 .24163 L
.26527 .24637 L
.26723 .25394 L
.26908 .25766 L
.27471 .26151 L
.27665 .26511 L
.27855 .26908 L
.28242 .27665 L
.28422 .28325 L
.28456 .28422 L
.28891 .29179 L
.29179 .29597 L
.29448 .29936 L
.29936 .30592 L
.2999 .30694 L
.30481 .31451 L
.30694 .31773 L
.30997 .32208 L
.31451 .32632 L
.31762 .32965 L
.32208 .33514 L
.32329 .33722 L
.32651 .34479 L
.32965 .35006 L
.3311 .35236 L
.33519 .35993 L
.33722 .36472 L
.3386 .3675 L
.34457 .37508 L
.34479 .37578 L
.3473 .38265 L
.35236 .3857 L
Mistroke
.35766 .39022 L
.35785 .39779 L
.35867 .40536 L
.35993 .40846 L
.36555 .41293 L
.3675 .41711 L
.36803 .4205 L
.3675 .42177 L
.36212 .42807 L
.35993 .43429 L
.35898 .43565 L
.35236 .43977 L
.34816 .44322 L
.34479 .44682 L
.34157 .45079 L
.34162 .45836 L
.33755 .46593 L
.33722 .46685 L
.33226 .4735 L
.33075 .48107 L
.32965 .4849 L
.32682 .48864 L
.32208 .49488 L
.32121 .49621 L
.32208 .50031 L
.3234 .50379 L
.32208 .50666 L
.31958 .51136 L
.3175 .51893 L
.31451 .52404 L
.31358 .5265 L
.31418 .53407 L
.31353 .54164 L
.30694 .54898 L
.30662 .54921 L
.29936 .55633 L
.29917 .55678 L
.29504 .56435 L
.2943 .57193 L
.29179 .57746 L
.29056 .5795 L
.28892 .58707 L
.28736 .59464 L
.28842 .60221 L
.2876 .60978 L
.28971 .61735 L
.28565 .62492 L
.28442 .6325 L
.28478 .64007 L
.28648 .64764 L
Mistroke
.2846 .65521 L
.28422 .65659 L
.28319 .66278 L
.28363 .67035 L
.28132 .67792 L
.28153 .68549 L
.28415 .69306 L
.28373 .70064 L
.28414 .70821 L
.28422 .70922 L
.28539 .71578 L
.28763 .72335 L
.2917 .73092 L
.29179 .73094 L
.29746 .73849 L
.29752 .74606 L
.29936 .75088 L
.30087 .75363 L
.30694 .75774 L
.31173 .76121 L
.31451 .76383 L
.31907 .76878 L
.32152 .77635 L
.32208 .77716 L
.32738 .78392 L
.32965 .78593 L
.33722 .78881 L
.34361 .79149 L
.34479 .7923 L
.35236 .79667 L
.35757 .79906 L
.35993 .80139 L
.36589 .80663 L
.3675 .80834 L
.37445 .8142 L
.37508 .81497 L
.38265 .82111 L
.38354 .82177 L
.388 .82935 L
.39022 .83286 L
.39779 .83654 L
.40334 .83692 L
.39779 .8404 L
.39022 .83842 L
.38265 .839 L
.37823 .83692 L
.37508 .83619 L
.3675 .83466 L
.35993 .83125 L
.35679 .82935 L
Mistroke
.35236 .82693 L
.34479 .82371 L
.34165 .82177 L
.33722 .81887 L
.33035 .8142 L
.32965 .81377 L
.32208 .81018 L
.31912 .80663 L
.31451 .80171 L
.31116 .79906 L
.30694 .79646 L
.29976 .79149 L
.29936 .7912 L
.29179 .78464 L
.29036 .78392 L
.28422 .7806 L
.2791 .77635 L
.27665 .77381 L
.27243 .76878 L
.26908 .76635 L
.26449 .76121 L
.26151 .75817 L
.25795 .75363 L
.25394 .74729 L
.2531 .74606 L
.2469 .73849 L
.24637 .73783 L
.23946 .73092 L
.23879 .73046 L
.23122 .7252 L
.22906 .72335 L
.22365 .71786 L
.22127 .71578 L
.21608 .71064 L
.21307 .70821 L
.20851 .70465 L
.20356 .70064 L
.20094 .69807 L
.19589 .69306 L
.19337 .69089 L
.18784 .68549 L
.1858 .68361 L
.18121 .67792 L
.17823 .67336 L
.17615 .67035 L
.17065 .665 L
.16762 .66278 L
.16308 .65629 L
.16244 .65521 L
.15725 .64764 L
Mistroke
.15551 .64509 L
.15218 .64007 L
.14794 .63367 L
.14713 .6325 L
.14078 .62492 L
.14037 .62376 L
.13848 .61735 L
.13319 .60978 L
.1328 .60892 L
.1301 .60221 L
.12561 .59464 L
.12523 .59381 L
.12232 .58707 L
.11808 .5795 L
.11802 .57193 L
.11766 .57105 L
.1142 .56435 L
.11044 .55678 L
.11008 .55597 L
.10851 .54921 L
.10722 .54164 L
.10501 .53407 L
.10287 .5265 L
.10251 .52551 L
.10084 .51893 L
.0996 .51136 L
.09793 .50379 L
.09696 .49621 L
.09636 .48864 L
.09529 .48107 L
.09535 .4735 L
.09494 .47109 L
.09424 .46593 L
.09494 .46118 L
.09538 .45836 L
.09494 .45554 L
.09414 .45079 L
.09494 .44603 L
.09538 .44322 L
.09494 .4404 L
.0942 .43565 L
.09494 .4298 L
.09533 .42807 L
.09729 .4205 L
.0966 .41293 L
.09791 .40536 L
.0984 .39779 L
.10033 .39022 L
.10251 .38351 L
.10297 .38265 L
Mistroke
.10889 .37508 L
.11008 .37487 L
.11766 .373 L
.12335 .3675 L
.12303 .35993 L
.11824 .35236 L
.12358 .34479 L
.12332 .33722 L
.12523 .33197 L
.12707 .32965 L
.12895 .32208 L
.13164 .31451 L
.13154 .30694 L
.1328 .304 L
.13528 .29936 L
.13911 .29179 L
.14037 .28926 L
.14292 .28422 L
.14794 .2784 L
.14852 .27665 L
.15042 .26908 L
.15288 .26151 L
.15473 .25394 L
.15551 .25101 L
.15995 .24637 L
.16092 .23879 L
.16308 .23225 L
.16372 .23122 L
.16827 .22365 L
.17065 .21713 L
.17119 .21608 L
.17606 .20851 L
.17724 .20094 L
.17823 .19762 L
.18011 .19337 L
.18479 .1858 L
.1858 .18345 L
.18799 .17823 L
.19337 .17129 L
Mfstroke
1 g
.10621 .01923 m
.10251 .02163 L
.09583 .01923 L
F
0 g
.10621 .01923 m
.10251 .02163 L
.09583 .01923 L
s
.9 g
.12523 .75689 m
.12939 .76121 L
.12523 .76272 L
.11907 .76121 L
F
0 g
.12523 .75689 m
.12939 .76121 L
.12523 .76272 L
.11907 .76121 L
.12523 .75689 L
s
.1 g
.22365 .20821 m
.22388 .20851 L
.23122 .21466 L
.23203 .21608 L
.23879 .22315 L
.23947 .22365 L
.24408 .23122 L
.24637 .23285 L
.2502 .23879 L
.25394 .24049 L
.25769 .24637 L
.26117 .25394 L
.26151 .25818 L
.2653 .26151 L
.26829 .26908 L
.26908 .27038 L
.27288 .27665 L
.27533 .28422 L
.27665 .28856 L
.27918 .29179 L
.28422 .29892 L
.28465 .29936 L
.29118 .30694 L
.29179 .30759 L
.29909 .31451 L
.29936 .31797 L
.30163 .32208 L
.30694 .32782 L
.30915 .32965 L
.31435 .33722 L
.31451 .33775 L
.317 .34479 L
.32163 .35236 L
.32208 .35398 L
.32504 .35993 L
.32864 .3675 L
.32965 .36891 L
.33394 .37508 L
.33518 .38265 L
.33722 .3876 L
.3395 .39022 L
.34479 .39622 L
.34534 .39779 L
.34693 .40536 L
.351 .41293 L
.35236 .41529 L
.35412 .4205 L
.35236 .42524 L
.35034 .42807 L
.34479 .43476 L
.34367 .43565 L
.33917 .44322 L
.33722 .44426 L
.32965 .44604 L
.32686 .45079 L
.32472 .45836 L
.32344 .46593 L
.32351 .4735 L
.32208 .47652 L
.31934 .48107 L
.31544 .48864 L
.31451 .48953 L
.30957 .49621 L
.30694 .50005 L
.3053 .50379 L
.30111 .51136 L
.30166 .51893 L
.30044 .5265 L
.29936 .53091 L
.29809 .53407 L
.29333 .54164 L
.29179 .54554 L
.2906 .54921 L
.28796 .55678 L
.28591 .56435 L
.28434 .57193 L
.28422 .57219 L
.27994 .5795 L
.27878 .58707 L
.2789 .59464 L
.28196 .60221 L
.27986 .60978 L
.28235 .61735 L
.28174 .62492 L
.28032 .6325 L
.27972 .64007 L
.28018 .64764 L
.28067 .65521 L
.27943 .66278 L
.27967 .67035 L
.27665 .67421 L
.27463 .67792 L
.27465 .68549 L
.27665 .68912 L
.27884 .69306 L
.27871 .70064 L
.27846 .70821 L
.27858 .71578 L
.27838 .72335 L
.27665 .7279 L
.2699 .72335 L
.26908 .7224 L
.26151 .71625 L
.26107 .71578 L
.25394 .70869 L
.2535 .70821 L
.24637 .70273 L
.24364 .70064 L
.23879 .69555 L
.23641 .69306 L
.23122 .68846 L
.22675 .68549 L
.22365 .68342 L
.21875 .67792 L
.21608 .67473 L
.21288 .67035 L
.20851 .66552 L
.20189 .66278 L
.20094 .66152 L
.19699 .65521 L
.19337 .65114 L
.18987 .64764 L
.1858 .64254 L
.18382 .64007 L
.17823 .63308 L
.17781 .6325 L
.17268 .62492 L
.17065 .61828 L
.1702 .61735 L
.16308 .61158 L
.16132 .60978 L
.16017 .60221 L
.15551 .59703 L
.15377 .59464 L
.15134 .58707 L
.14794 .58104 L
.14755 .5795 L
.14629 .57193 L
.14118 .56435 L
.14037 .56217 L
.1386 .55678 L
.13609 .54921 L
.13379 .54164 L
.1328 .53679 L
.1324 .53407 L
.13112 .5265 L
.12978 .51893 L
.12863 .51136 L
.12778 .50379 L
.12624 .49621 L
.126 .48864 L
.12523 .48349 L
.1248 .48107 L
.12475 .4735 L
.12305 .46593 L
.12523 .4611 L
.12607 .45836 L
.12523 .45299 L
.12475 .45079 L
.12523 .44828 L
.12623 .44322 L
.12523 .43816 L
.12471 .43565 L
.12523 .4319 L
.12648 .42807 L
.13024 .4205 L
.13007 .41293 L
.1328 .40764 L
.13402 .40536 L
.1379 .39779 L
.13956 .39022 L
.14037 .38852 L
.14456 .38265 L
.14794 .37654 L
.15221 .37508 L
.15551 .37462 L
.16308 .3722 L
.16736 .3675 L
.17065 .36299 L
.17246 .35993 L
.17504 .35236 L
.17329 .34479 L
.17449 .33722 L
.17648 .32965 L
.1781 .32208 L
.17823 .32136 L
.18348 .31451 L
.17994 .30694 L
.18125 .29936 L
.18313 .29179 L
.1858 .28828 L
.1887 .28422 L
.19007 .27665 L
.19337 .2717 L
.19468 .26908 L
.19664 .26151 L
.19765 .25394 L
.20094 .25075 L
.20384 .24637 L
.20422 .23879 L
.20605 .23122 L
.20851 .22645 L
.20935 .22365 L
.21086 .21608 L
.21608 .20948 L
.21726 .20851 L
F
0 g
.22365 .20821 m
.22388 .20851 L
.23122 .21466 L
.23203 .21608 L
.23879 .22315 L
.23947 .22365 L
.24408 .23122 L
.24637 .23285 L
.2502 .23879 L
.25394 .24049 L
.25769 .24637 L
.26117 .25394 L
.26151 .25818 L
.2653 .26151 L
.26829 .26908 L
.26908 .27038 L
.27288 .27665 L
.27533 .28422 L
.27665 .28856 L
.27918 .29179 L
.28422 .29892 L
.28465 .29936 L
.29118 .30694 L
.29179 .30759 L
.29909 .31451 L
.29936 .31797 L
.30163 .32208 L
.30694 .32782 L
.30915 .32965 L
.31435 .33722 L
.31451 .33775 L
.317 .34479 L
.32163 .35236 L
.32208 .35398 L
.32504 .35993 L
.32864 .3675 L
.32965 .36891 L
.33394 .37508 L
.33518 .38265 L
.33722 .3876 L
.3395 .39022 L
.34479 .39622 L
.34534 .39779 L
.34693 .40536 L
.351 .41293 L
.35236 .41529 L
.35412 .4205 L
.35236 .42524 L
.35034 .42807 L
.34479 .43476 L
Mistroke
.34367 .43565 L
.33917 .44322 L
.33722 .44426 L
.32965 .44604 L
.32686 .45079 L
.32472 .45836 L
.32344 .46593 L
.32351 .4735 L
.32208 .47652 L
.31934 .48107 L
.31544 .48864 L
.31451 .48953 L
.30957 .49621 L
.30694 .50005 L
.3053 .50379 L
.30111 .51136 L
.30166 .51893 L
.30044 .5265 L
.29936 .53091 L
.29809 .53407 L
.29333 .54164 L
.29179 .54554 L
.2906 .54921 L
.28796 .55678 L
.28591 .56435 L
.28434 .57193 L
.28422 .57219 L
.27994 .5795 L
.27878 .58707 L
.2789 .59464 L
.28196 .60221 L
.27986 .60978 L
.28235 .61735 L
.28174 .62492 L
.28032 .6325 L
.27972 .64007 L
.28018 .64764 L
.28067 .65521 L
.27943 .66278 L
.27967 .67035 L
.27665 .67421 L
.27463 .67792 L
.27465 .68549 L
.27665 .68912 L
.27884 .69306 L
.27871 .70064 L
.27846 .70821 L
.27858 .71578 L
.27838 .72335 L
.27665 .7279 L
Mistroke
.2699 .72335 L
.26908 .7224 L
.26151 .71625 L
.26107 .71578 L
.25394 .70869 L
.2535 .70821 L
.24637 .70273 L
.24364 .70064 L
.23879 .69555 L
.23641 .69306 L
.23122 .68846 L
.22675 .68549 L
.22365 .68342 L
.21875 .67792 L
.21608 .67473 L
.21288 .67035 L
.20851 .66552 L
.20189 .66278 L
.20094 .66152 L
.19699 .65521 L
.19337 .65114 L
.18987 .64764 L
.1858 .64254 L
.18382 .64007 L
.17823 .63308 L
.17781 .6325 L
.17268 .62492 L
.17065 .61828 L
.1702 .61735 L
.16308 .61158 L
.16132 .60978 L
.16017 .60221 L
.15551 .59703 L
.15377 .59464 L
.15134 .58707 L
.14794 .58104 L
.14755 .5795 L
.14629 .57193 L
.14118 .56435 L
.14037 .56217 L
.1386 .55678 L
.13609 .54921 L
.13379 .54164 L
.1328 .53679 L
.1324 .53407 L
.13112 .5265 L
.12978 .51893 L
.12863 .51136 L
.12778 .50379 L
.12624 .49621 L
Mistroke
.126 .48864 L
.12523 .48349 L
.1248 .48107 L
.12475 .4735 L
.12305 .46593 L
.12523 .4611 L
.12607 .45836 L
.12523 .45299 L
.12475 .45079 L
.12523 .44828 L
.12623 .44322 L
.12523 .43816 L
.12471 .43565 L
.12523 .4319 L
.12648 .42807 L
.13024 .4205 L
.13007 .41293 L
.1328 .40764 L
.13402 .40536 L
.1379 .39779 L
.13956 .39022 L
.14037 .38852 L
.14456 .38265 L
.14794 .37654 L
.15221 .37508 L
.15551 .37462 L
.16308 .3722 L
.16736 .3675 L
.17065 .36299 L
.17246 .35993 L
.17504 .35236 L
.17329 .34479 L
.17449 .33722 L
.17648 .32965 L
.1781 .32208 L
.17823 .32136 L
.18348 .31451 L
.17994 .30694 L
.18125 .29936 L
.18313 .29179 L
.1858 .28828 L
.1887 .28422 L
.19007 .27665 L
.19337 .2717 L
.19468 .26908 L
.19664 .26151 L
.19765 .25394 L
.20094 .25075 L
.20384 .24637 L
.20422 .23879 L
Mistroke
.20605 .23122 L
.20851 .22645 L
.20935 .22365 L
.21086 .21608 L
.21608 .20948 L
.21726 .20851 L
.22365 .20821 L
Mfstroke
.3 g
.14037 .31613 m
.147 .32208 L
.14794 .32508 L
.15063 .32965 L
.15551 .33468 L
.16115 .32965 L
.16308 .32482 L
.16792 .32965 L
.16633 .33722 L
.1657 .34479 L
.16684 .35236 L
.16535 .35993 L
.16308 .36255 L
.15731 .35993 L
.16043 .35236 L
.15551 .34791 L
.14806 .35236 L
.15089 .35993 L
.15388 .3675 L
.14794 .36861 L
.14037 .36863 L
.13888 .3675 L
.13647 .35993 L
.13561 .35236 L
.13534 .34479 L
.13559 .33722 L
.13472 .32965 L
.13408 .32208 L
F
0 g
.14037 .31613 m
.147 .32208 L
.14794 .32508 L
.15063 .32965 L
.15551 .33468 L
.16115 .32965 L
.16308 .32482 L
.16792 .32965 L
.16633 .33722 L
.1657 .34479 L
.16684 .35236 L
.16535 .35993 L
.16308 .36255 L
.15731 .35993 L
.16043 .35236 L
.15551 .34791 L
.14806 .35236 L
.15089 .35993 L
.15388 .3675 L
.14794 .36861 L
.14037 .36863 L
.13888 .3675 L
.13647 .35993 L
.13561 .35236 L
.13534 .34479 L
.13559 .33722 L
.13472 .32965 L
.13408 .32208 L
.14037 .31613 L
s
.8 g
.30606 .01923 m
.29936 .02136 L
.29179 .02625 L
.29127 .0268 L
.28422 .03002 L
.28014 .03437 L
.27665 .03746 L
.26948 .04194 L
.26908 .04277 L
.26369 .04952 L
.26908 .05567 L
.27161 .05709 L
.27579 .06466 L
.27665 .06732 L
.27976 .07223 L
.27937 .0798 L
.28122 .08737 L
.28035 .09494 L
.28122 .10251 L
.28081 .11008 L
.28341 .11766 L
.28079 .12523 L
.27665 .12981 L
.27456 .1328 L
.26908 .13679 L
.26151 .13969 L
.25956 .14037 L
.25394 .14166 L
.24637 .14214 L
.24111 .14037 L
.23879 .13996 L
.23122 .13851 L
.22686 .1328 L
.22365 .12912 L
.22006 .12523 L
.21608 .12167 L
.20919 .11766 L
.20851 .11719 L
.20134 .11008 L
.20094 .10955 L
.19535 .10251 L
.19337 .0993 L
.19108 .09494 L
.18973 .08737 L
.1858 .08306 L
.18411 .0798 L
.182 .07223 L
.1792 .06466 L
.17823 .06184 L
.17617 .05709 L
.17201 .04952 L
.17065 .04843 L
.16859 .04194 L
.1698 .03437 L
.16308 .02723 L
.16276 .0268 L
.16069 .01923 L
F
0 g
.30606 .01923 m
.29936 .02136 L
.29179 .02625 L
.29127 .0268 L
.28422 .03002 L
.28014 .03437 L
.27665 .03746 L
.26948 .04194 L
.26908 .04277 L
.26369 .04952 L
.26908 .05567 L
.27161 .05709 L
.27579 .06466 L
.27665 .06732 L
.27976 .07223 L
.27937 .0798 L
.28122 .08737 L
.28035 .09494 L
.28122 .10251 L
.28081 .11008 L
.28341 .11766 L
.28079 .12523 L
.27665 .12981 L
.27456 .1328 L
.26908 .13679 L
.26151 .13969 L
.25956 .14037 L
.25394 .14166 L
.24637 .14214 L
.24111 .14037 L
.23879 .13996 L
.23122 .13851 L
.22686 .1328 L
.22365 .12912 L
.22006 .12523 L
.21608 .12167 L
.20919 .11766 L
.20851 .11719 L
.20134 .11008 L
.20094 .10955 L
.19535 .10251 L
.19337 .0993 L
.19108 .09494 L
.18973 .08737 L
.1858 .08306 L
.18411 .0798 L
.182 .07223 L
.1792 .06466 L
.17823 .06184 L
.17617 .05709 L
Mistroke
.17201 .04952 L
.17065 .04843 L
.16859 .04194 L
.1698 .03437 L
.16308 .02723 L
.16276 .0268 L
.16069 .01923 L
Mfstroke
.25394 .26925 m
.26151 .27212 L
.26298 .27665 L
.26569 .28422 L
.26908 .28683 L
.27098 .29179 L
.27665 .29648 L
.27771 .29936 L
.28374 .30694 L
.28422 .30743 L
.29179 .31325 L
.29313 .31451 L
.29514 .32208 L
.29936 .32634 L
.3027 .32965 L
.30694 .3324 L
.309 .33722 L
.31107 .34479 L
.31451 .35025 L
.31683 .35236 L
.31875 .35993 L
.32207 .3675 L
.32208 .36752 L
.32676 .37508 L
.32814 .38265 L
.32965 .38641 L
.33253 .39022 L
.33651 .39779 L
.33722 .39861 L
.34079 .40536 L
.34478 .41293 L
.34479 .41294 L
.34795 .4205 L
.34479 .42493 L
.33894 .42807 L
.33722 .42896 L
.32965 .43383 L
.32771 .43565 L
.32322 .44322 L
.32208 .44515 L
.3182 .45079 L
.32049 .45836 L
.31451 .46201 L
.31139 .46593 L
.31037 .4735 L
.31031 .48107 L
.30855 .48864 L
.30694 .49129 L
.30345 .49621 L
.30033 .50379 L
.29936 .50535 L
.297 .51136 L
.29589 .51893 L
.29429 .5265 L
.29179 .52964 L
.28931 .53407 L
.28691 .54164 L
.28422 .54811 L
.28388 .54921 L
.28166 .55678 L
.27893 .56435 L
.2774 .57193 L
.27665 .57299 L
.27358 .5795 L
.27333 .58707 L
.27356 .59464 L
.27602 .60221 L
.27389 .60978 L
.27665 .61409 L
.27823 .61735 L
.27665 .62378 L
.27602 .62492 L
.27458 .6325 L
.27339 .64007 L
.27282 .64764 L
.27278 .65521 L
.27084 .66278 L
.26908 .66597 L
.26151 .66651 L
.25403 .66278 L
.25394 .66268 L
.24649 .65521 L
.24637 .65513 L
.23887 .64764 L
.23879 .64756 L
.23537 .64007 L
.23122 .63788 L
.22372 .6325 L
.22365 .6324 L
.21618 .62492 L
.21608 .62477 L
.21372 .61735 L
.20851 .61073 L
.20607 .60978 L
.20101 .60221 L
.20094 .60208 L
.19605 .59464 L
.19337 .59072 L
.19093 .58707 L
.18584 .5795 L
.18588 .57193 L
.1858 .57174 L
.18227 .56435 L
.17829 .55678 L
.17823 .55659 L
.1764 .54921 L
.17431 .54164 L
.1738 .53407 L
.17073 .5265 L
.17266 .51893 L
.17266 .51136 L
.17074 .50379 L
.17074 .49621 L
.17316 .48864 L
.17074 .48107 L
.17358 .4735 L
.17449 .46593 L
.17579 .45836 L
.17823 .45105 L
.17832 .45079 L
.1809 .44322 L
.18058 .43565 L
.18328 .42807 L
.1858 .42463 L
.18971 .4205 L
.19337 .41324 L
.19357 .41293 L
.19728 .40536 L
.20094 .40192 L
.20507 .39779 L
.20475 .39022 L
.20851 .386 L
.21214 .38265 L
.21608 .37949 L
.22365 .37514 L
.22373 .37508 L
.23122 .3735 L
.23879 .36907 L
.24301 .3675 L
.24637 .36211 L
.25394 .36335 L
.26151 .36691 L
.26908 .36497 L
.27098 .35993 L
.26908 .3557 L
.26565 .35236 L
.26153 .34479 L
.26151 .34475 L
.2612 .33722 L
.26118 .32965 L
.25949 .32208 L
.25966 .31451 L
.25394 .30841 L
.2512 .30694 L
.24637 .30474 L
.24282 .29936 L
.24147 .29179 L
.23993 .28422 L
.24637 .27678 L
.24646 .27665 L
F
.25394 .26925 m
.26151 .27212 L
.26298 .27665 L
.26569 .28422 L
.26908 .28683 L
.27098 .29179 L
.27665 .29648 L
.27771 .29936 L
.28374 .30694 L
.28422 .30743 L
.29179 .31325 L
.29313 .31451 L
.29514 .32208 L
.29936 .32634 L
.3027 .32965 L
.30694 .3324 L
.309 .33722 L
.31107 .34479 L
.31451 .35025 L
.31683 .35236 L
.31875 .35993 L
.32207 .3675 L
.32208 .36752 L
.32676 .37508 L
.32814 .38265 L
.32965 .38641 L
.33253 .39022 L
.33651 .39779 L
.33722 .39861 L
.34079 .40536 L
.34478 .41293 L
.34479 .41294 L
.34795 .4205 L
.34479 .42493 L
.33894 .42807 L
.33722 .42896 L
.32965 .43383 L
.32771 .43565 L
.32322 .44322 L
.32208 .44515 L
.3182 .45079 L
.32049 .45836 L
.31451 .46201 L
.31139 .46593 L
.31037 .4735 L
.31031 .48107 L
.30855 .48864 L
.30694 .49129 L
.30345 .49621 L
.30033 .50379 L
Mistroke
.29936 .50535 L
.297 .51136 L
.29589 .51893 L
.29429 .5265 L
.29179 .52964 L
.28931 .53407 L
.28691 .54164 L
.28422 .54811 L
.28388 .54921 L
.28166 .55678 L
.27893 .56435 L
.2774 .57193 L
.27665 .57299 L
.27358 .5795 L
.27333 .58707 L
.27356 .59464 L
.27602 .60221 L
.27389 .60978 L
.27665 .61409 L
.27823 .61735 L
.27665 .62378 L
.27602 .62492 L
.27458 .6325 L
.27339 .64007 L
.27282 .64764 L
.27278 .65521 L
.27084 .66278 L
.26908 .66597 L
.26151 .66651 L
.25403 .66278 L
.25394 .66268 L
.24649 .65521 L
.24637 .65513 L
.23887 .64764 L
.23879 .64756 L
.23537 .64007 L
.23122 .63788 L
.22372 .6325 L
.22365 .6324 L
.21618 .62492 L
.21608 .62477 L
.21372 .61735 L
.20851 .61073 L
.20607 .60978 L
.20101 .60221 L
.20094 .60208 L
.19605 .59464 L
.19337 .59072 L
.19093 .58707 L
.18584 .5795 L
Mistroke
.18588 .57193 L
.1858 .57174 L
.18227 .56435 L
.17829 .55678 L
.17823 .55659 L
.1764 .54921 L
.17431 .54164 L
.1738 .53407 L
.17073 .5265 L
.17266 .51893 L
.17266 .51136 L
.17074 .50379 L
.17074 .49621 L
.17316 .48864 L
.17074 .48107 L
.17358 .4735 L
.17449 .46593 L
.17579 .45836 L
.17823 .45105 L
.17832 .45079 L
.1809 .44322 L
.18058 .43565 L
.18328 .42807 L
.1858 .42463 L
.18971 .4205 L
.19337 .41324 L
.19357 .41293 L
.19728 .40536 L
.20094 .40192 L
.20507 .39779 L
.20475 .39022 L
.20851 .386 L
.21214 .38265 L
.21608 .37949 L
.22365 .37514 L
.22373 .37508 L
.23122 .3735 L
.23879 .36907 L
.24301 .3675 L
.24637 .36211 L
.25394 .36335 L
.26151 .36691 L
.26908 .36497 L
.27098 .35993 L
.26908 .3557 L
.26565 .35236 L
.26153 .34479 L
.26151 .34475 L
.2612 .33722 L
.26118 .32965 L
Mistroke
.25949 .32208 L
.25966 .31451 L
.25394 .30841 L
.2512 .30694 L
.24637 .30474 L
.24282 .29936 L
.24147 .29179 L
.23993 .28422 L
.24637 .27678 L
.24646 .27665 L
.25394 .26925 L
Mfstroke
.9 g
.25489 .01923 m
.25394 .02014 L
.24637 .02391 L
.24388 .0268 L
.23879 .02881 L
.23122 .03166 L
.22645 .03437 L
.22365 .03523 L
.21608 .03523 L
.20851 .03659 L
.20571 .03437 L
.20094 .03236 L
.19337 .02778 L
.19023 .0268 L
.1858 .02566 L
.18055 .01923 L
F
0 g
.25489 .01923 m
.25394 .02014 L
.24637 .02391 L
.24388 .0268 L
.23879 .02881 L
.23122 .03166 L
.22645 .03437 L
.22365 .03523 L
.21608 .03523 L
.20851 .03659 L
.20571 .03437 L
.20094 .03236 L
.19337 .02778 L
.19023 .0268 L
.1858 .02566 L
.18055 .01923 L
s
.2 g
.20094 .31537 m
.20842 .32208 L
.20851 .32229 L
.21075 .32965 L
.21124 .33722 L
.20851 .34291 L
.2079 .34479 L
.20851 .35087 L
.20862 .35236 L
.21608 .35748 L
.2179 .35993 L
.21608 .36441 L
.20851 .36639 L
.20094 .36734 L
.2003 .3675 L
.19337 .36846 L
.1858 .36836 L
.1846 .3675 L
.18209 .35993 L
.1858 .35519 L
.19337 .35247 L
.19352 .35236 L
.19502 .34479 L
.19545 .33722 L
.19522 .32965 L
.19471 .32208 L
F
0 g
.20094 .31537 m
.20842 .32208 L
.20851 .32229 L
.21075 .32965 L
.21124 .33722 L
.20851 .34291 L
.2079 .34479 L
.20851 .35087 L
.20862 .35236 L
.21608 .35748 L
.2179 .35993 L
.21608 .36441 L
.20851 .36639 L
.20094 .36734 L
.2003 .3675 L
.19337 .36846 L
.1858 .36836 L
.1846 .3675 L
.18209 .35993 L
.1858 .35519 L
.19337 .35247 L
.19352 .35236 L
.19502 .34479 L
.19545 .33722 L
.19522 .32965 L
.19471 .32208 L
.20094 .31537 L
s
.7 g
.23879 .82108 m
.24584 .82177 L
.24177 .82935 L
.23879 .8342 L
.23122 .83256 L
.22919 .82935 L
.23122 .82642 L
.23724 .82177 L
F
0 g
.23879 .82108 m
.24584 .82177 L
.24177 .82935 L
.23879 .8342 L
.23122 .83256 L
.22919 .82935 L
.23122 .82642 L
.23724 .82177 L
.23879 .82108 L
s
.2 g
.25394 .33266 m
.2542 .33722 L
.25474 .34479 L
.25838 .35236 L
.25394 .35371 L
.24637 .3526 L
.2395 .35993 L
.23879 .36055 L
.23628 .35993 L
.23741 .35236 L
.23879 .35017 L
.24236 .34479 L
.24637 .33894 L
.24872 .33722 L
F
0 g
.25394 .33266 m
.2542 .33722 L
.25474 .34479 L
.25838 .35236 L
.25394 .35371 L
.24637 .3526 L
.2395 .35993 L
.23879 .36055 L
.23628 .35993 L
.23741 .35236 L
.23879 .35017 L
.24236 .34479 L
.24637 .33894 L
.24872 .33722 L
.25394 .33266 L
s
.2 g
.24637 .32049 m
.24904 .32208 L
.24637 .32662 L
.24502 .32208 L
F
0 g
.24637 .32049 m
.24904 .32208 L
.24637 .32662 L
.24502 .32208 L
.24637 .32049 L
s
.8 g
.26151 .86315 m
.26421 .8672 L
.26823 .87477 L
.26908 .87535 L
.27665 .88009 L
.28422 .87991 L
.28805 .88234 L
.28422 .88636 L
.27665 .88894 L
.26908 .889 L
.26282 .88234 L
.26151 .87887 L
.25936 .87477 L
.25945 .8672 L
F
0 g
.26151 .86315 m
.26421 .8672 L
.26823 .87477 L
.26908 .87535 L
.27665 .88009 L
.28422 .87991 L
.28805 .88234 L
.28422 .88636 L
.27665 .88894 L
.26908 .889 L
.26282 .88234 L
.26151 .87887 L
.25936 .87477 L
.25945 .8672 L
.26151 .86315 L
s
.5 g
.28422 .84488 m
.29179 .85063 L
.29204 .85206 L
.29179 .8538 L
.28422 .85769 L
.27785 .85206 L
F
0 g
.28422 .84488 m
.29179 .85063 L
.29204 .85206 L
.29179 .8538 L
.28422 .85769 L
.27785 .85206 L
.28422 .84488 L
s
.5 g
.55678 .37867 m
.56435 .37653 L
.57193 .37866 L
.57663 .38265 L
.57436 .39022 L
.57193 .39375 L
.56763 .39779 L
.56435 .40388 L
.56394 .40536 L
.56336 .41293 L
.55938 .4205 L
.55678 .42302 L
.55384 .42807 L
.54921 .4323 L
.54164 .43485 L
.54085 .43565 L
.53912 .44322 L
.53407 .44944 L
.5332 .45079 L
.53097 .45836 L
.53407 .46248 L
.54164 .4634 L
.54483 .46593 L
.54699 .4735 L
.54883 .48107 L
.54921 .48357 L
.55053 .48864 L
.55315 .49621 L
.55198 .50379 L
.55515 .51136 L
.55678 .51229 L
.55838 .51136 L
.56435 .50716 L
.56835 .50379 L
.57193 .5013 L
.5795 .49806 L
.5846 .49621 L
.58707 .49586 L
.59058 .49621 L
.59464 .497 L
.60221 .49774 L
.60978 .49917 L
.61735 .50274 L
.61861 .50379 L
.62128 .51136 L
.62231 .51893 L
.62395 .5265 L
.62481 .53407 L
.62492 .53552 L
.6251 .54164 L
.62492 .54414 L
.62452 .54921 L
.62492 .55449 L
.62517 .55678 L
.62523 .56435 L
.62639 .57193 L
.62492 .57548 L
.62359 .5795 L
.62304 .58707 L
.62492 .59061 L
.62773 .59464 L
.6325 .60184 L
.63257 .60221 L
.6325 .60265 L
.62892 .60978 L
.6325 .61326 L
.64007 .6168 L
.6433 .61735 L
.64764 .61763 L
.65521 .61885 L
.65914 .62492 L
.65981 .6325 L
.65903 .64007 L
.65654 .64764 L
.65521 .65234 L
.65458 .65521 L
.65309 .66278 L
.65324 .67035 L
.64959 .67792 L
.64862 .68549 L
.64931 .69306 L
.64764 .69621 L
.64503 .70064 L
.6416 .70821 L
.64007 .7112 L
.63732 .71578 L
.6325 .72249 L
.63215 .72335 L
.62979 .73092 L
.62616 .73849 L
.62492 .7417 L
.62365 .74606 L
.62492 .75053 L
.62685 .75363 L
.6325 .75828 L
.64007 .75811 L
.64463 .76121 L
.64739 .76878 L
.64286 .77635 L
.64007 .78252 L
.63942 .78392 L
.6325 .79123 L
.63234 .79149 L
.62843 .79906 L
.62603 .80663 L
.62492 .81003 L
.61894 .8142 L
.61735 .81455 L
.60978 .81638 L
.60221 .8169 L
.59464 .8151 L
.58707 .81622 L
.5795 .82118 L
.57456 .82177 L
.57193 .82336 L
.56435 .82871 L
.56215 .82935 L
.55678 .83048 L
.54921 .83216 L
.54164 .83584 L
.54055 .83692 L
.53407 .8411 L
.5265 .83942 L
.51926 .83692 L
.51893 .83686 L
.51136 .83431 L
.50379 .8344 L
.5004 .83692 L
.49621 .83946 L
.48864 .84142 L
.48107 .83729 L
.4796 .83692 L
.4735 .83627 L
.46593 .83679 L
.45836 .83636 L
.45079 .83478 L
.44322 .83229 L
.43685 .82935 L
.43565 .82827 L
.43194 .82177 L
.42807 .81614 L
.42333 .8142 L
.4205 .81346 L
.41293 .8114 L
.40536 .8078 L
.40252 .80663 L
.39779 .80361 L
.39115 .79906 L
.39022 .79862 L
.38265 .79394 L
.37508 .79296 L
.36922 .79149 L
.3675 .7911 L
.35993 .78975 L
.35236 .78743 L
.34584 .78392 L
.34479 .78335 L
.33835 .77635 L
.33732 .76878 L
.33722 .76779 L
.33134 .76121 L
.32965 .75897 L
.32569 .75363 L
.32208 .74875 L
.32035 .74606 L
.31533 .73849 L
.31451 .73642 L
.31201 .73092 L
.30734 .72335 L
.30694 .72194 L
.30278 .71578 L
.29936 .70895 L
.29912 .70821 L
.29709 .70064 L
.29849 .69306 L
.29623 .68549 L
.2968 .67792 L
.29936 .67341 L
.30085 .67035 L
.29993 .66278 L
.29936 .65934 L
.29911 .65521 L
.29936 .6538 L
.30062 .64764 L
.3016 .64007 L
.30129 .6325 L
.30178 .62492 L
.30534 .61735 L
.30599 .60978 L
.30694 .60824 L
.31134 .60221 L
.31228 .59464 L
.31451 .58886 L
.31531 .58707 L
.31806 .5795 L
.3216 .57193 L
.32146 .56435 L
.32208 .56283 L
.32878 .55678 L
.32965 .5562 L
.33351 .54921 L
.33483 .54164 L
.3359 .53407 L
.33722 .53057 L
.33918 .5265 L
.34479 .52124 L
.3483 .51893 L
.35236 .51444 L
.35637 .51136 L
.35993 .50502 L
.36088 .50379 L
.3675 .50251 L
.37508 .49956 L
.37894 .50379 L
.38265 .50749 L
.38874 .51136 L
.39022 .51157 L
.39779 .5127 L
.40536 .51315 L
.40808 .51136 L
.41293 .50802 L
.41822 .50379 L
.4205 .5021 L
.42807 .49706 L
.43565 .49691 L
.4431 .50379 L
.44322 .50407 L
.44466 .51136 L
.44322 .51846 L
.44298 .51893 L
.43922 .5265 L
.43565 .53218 L
.43432 .53407 L
.42807 .53899 L
.42099 .54164 L
.4205 .54173 L
.41498 .54921 L
.41293 .55356 L
.41178 .55678 L
.41048 .56435 L
.41142 .57193 L
.41017 .5795 L
.41166 .58707 L
.41293 .59018 L
.41665 .59464 L
.4205 .59661 L
.4225 .59464 L
.42742 .58707 L
.42807 .58651 L
.43182 .58707 L
.43565 .58995 L
.44064 .59464 L
.44322 .59786 L
.4475 .60221 L
.45079 .60481 L
.45836 .60251 L
.45899 .60221 L
.46346 .59464 L
.45836 .5883 L
.45669 .58707 L
.45079 .5833 L
.44648 .5795 L
.44322 .57664 L
.43565 .57411 L
.43334 .57193 L
.42983 .56435 L
.43065 .55678 L
.43281 .54921 L
.43565 .54636 L
.44239 .54164 L
.44322 .54082 L
.4457 .54164 L
.45079 .54475 L
.45836 .54692 L
.46593 .54678 L
.4735 .54229 L
.47412 .54164 L
.47848 .53407 L
.48107 .52855 L
.48148 .5265 L
.48107 .52376 L
.48002 .51893 L
.48107 .51626 L
.48864 .51298 L
.49621 .51362 L
.49762 .51136 L
.49621 .50705 L
.49162 .50379 L
.48864 .50181 L
.48107 .50088 L
.47778 .49621 L
.4735 .49118 L
.47164 .48864 L
.46822 .48107 L
.46728 .4735 L
.4666 .46593 L
.47103 .45836 L
.47257 .45079 L
.4735 .4496 L
.48107 .44365 L
.48171 .44322 L
.48864 .43652 L
.48937 .43565 L
.49146 .42807 L
.49621 .42306 L
.4984 .4205 L
.50379 .41359 L
.51136 .41458 L
.51893 .41464 L
.51955 .41293 L
.52172 .40536 L
.5217 .39779 L
.5265 .39596 L
.53407 .39227 L
.54164 .3925 L
.54692 .39022 L
.54921 .38554 L
.55248 .38265 L
F
0 g
.55678 .37867 m
.56435 .37653 L
.57193 .37866 L
.57663 .38265 L
.57436 .39022 L
.57193 .39375 L
.56763 .39779 L
.56435 .40388 L
.56394 .40536 L
.56336 .41293 L
.55938 .4205 L
.55678 .42302 L
.55384 .42807 L
.54921 .4323 L
.54164 .43485 L
.54085 .43565 L
.53912 .44322 L
.53407 .44944 L
.5332 .45079 L
.53097 .45836 L
.53407 .46248 L
.54164 .4634 L
.54483 .46593 L
.54699 .4735 L
.54883 .48107 L
.54921 .48357 L
.55053 .48864 L
.55315 .49621 L
.55198 .50379 L
.55515 .51136 L
.55678 .51229 L
.55838 .51136 L
.56435 .50716 L
.56835 .50379 L
.57193 .5013 L
.5795 .49806 L
.5846 .49621 L
.58707 .49586 L
.59058 .49621 L
.59464 .497 L
.60221 .49774 L
.60978 .49917 L
.61735 .50274 L
.61861 .50379 L
.62128 .51136 L
.62231 .51893 L
.62395 .5265 L
.62481 .53407 L
.62492 .53552 L
.6251 .54164 L
Mistroke
.62492 .54414 L
.62452 .54921 L
.62492 .55449 L
.62517 .55678 L
.62523 .56435 L
.62639 .57193 L
.62492 .57548 L
.62359 .5795 L
.62304 .58707 L
.62492 .59061 L
.62773 .59464 L
.6325 .60184 L
.63257 .60221 L
.6325 .60265 L
.62892 .60978 L
.6325 .61326 L
.64007 .6168 L
.6433 .61735 L
.64764 .61763 L
.65521 .61885 L
.65914 .62492 L
.65981 .6325 L
.65903 .64007 L
.65654 .64764 L
.65521 .65234 L
.65458 .65521 L
.65309 .66278 L
.65324 .67035 L
.64959 .67792 L
.64862 .68549 L
.64931 .69306 L
.64764 .69621 L
.64503 .70064 L
.6416 .70821 L
.64007 .7112 L
.63732 .71578 L
.6325 .72249 L
.63215 .72335 L
.62979 .73092 L
.62616 .73849 L
.62492 .7417 L
.62365 .74606 L
.62492 .75053 L
.62685 .75363 L
.6325 .75828 L
.64007 .75811 L
.64463 .76121 L
.64739 .76878 L
.64286 .77635 L
.64007 .78252 L
Mistroke
.63942 .78392 L
.6325 .79123 L
.63234 .79149 L
.62843 .79906 L
.62603 .80663 L
.62492 .81003 L
.61894 .8142 L
.61735 .81455 L
.60978 .81638 L
.60221 .8169 L
.59464 .8151 L
.58707 .81622 L
.5795 .82118 L
.57456 .82177 L
.57193 .82336 L
.56435 .82871 L
.56215 .82935 L
.55678 .83048 L
.54921 .83216 L
.54164 .83584 L
.54055 .83692 L
.53407 .8411 L
.5265 .83942 L
.51926 .83692 L
.51893 .83686 L
.51136 .83431 L
.50379 .8344 L
.5004 .83692 L
.49621 .83946 L
.48864 .84142 L
.48107 .83729 L
.4796 .83692 L
.4735 .83627 L
.46593 .83679 L
.45836 .83636 L
.45079 .83478 L
.44322 .83229 L
.43685 .82935 L
.43565 .82827 L
.43194 .82177 L
.42807 .81614 L
.42333 .8142 L
.4205 .81346 L
.41293 .8114 L
.40536 .8078 L
.40252 .80663 L
.39779 .80361 L
.39115 .79906 L
.39022 .79862 L
.38265 .79394 L
Mistroke
.37508 .79296 L
.36922 .79149 L
.3675 .7911 L
.35993 .78975 L
.35236 .78743 L
.34584 .78392 L
.34479 .78335 L
.33835 .77635 L
.33732 .76878 L
.33722 .76779 L
.33134 .76121 L
.32965 .75897 L
.32569 .75363 L
.32208 .74875 L
.32035 .74606 L
.31533 .73849 L
.31451 .73642 L
.31201 .73092 L
.30734 .72335 L
.30694 .72194 L
.30278 .71578 L
.29936 .70895 L
.29912 .70821 L
.29709 .70064 L
.29849 .69306 L
.29623 .68549 L
.2968 .67792 L
.29936 .67341 L
.30085 .67035 L
.29993 .66278 L
.29936 .65934 L
.29911 .65521 L
.29936 .6538 L
.30062 .64764 L
.3016 .64007 L
.30129 .6325 L
.30178 .62492 L
.30534 .61735 L
.30599 .60978 L
.30694 .60824 L
.31134 .60221 L
.31228 .59464 L
.31451 .58886 L
.31531 .58707 L
.31806 .5795 L
.3216 .57193 L
.32146 .56435 L
.32208 .56283 L
.32878 .55678 L
.32965 .5562 L
Mistroke
.33351 .54921 L
.33483 .54164 L
.3359 .53407 L
.33722 .53057 L
.33918 .5265 L
.34479 .52124 L
.3483 .51893 L
.35236 .51444 L
.35637 .51136 L
.35993 .50502 L
.36088 .50379 L
.3675 .50251 L
.37508 .49956 L
.37894 .50379 L
.38265 .50749 L
.38874 .51136 L
.39022 .51157 L
.39779 .5127 L
.40536 .51315 L
.40808 .51136 L
.41293 .50802 L
.41822 .50379 L
.4205 .5021 L
.42807 .49706 L
.43565 .49691 L
.4431 .50379 L
.44322 .50407 L
.44466 .51136 L
.44322 .51846 L
.44298 .51893 L
.43922 .5265 L
.43565 .53218 L
.43432 .53407 L
.42807 .53899 L
.42099 .54164 L
.4205 .54173 L
.41498 .54921 L
.41293 .55356 L
.41178 .55678 L
.41048 .56435 L
.41142 .57193 L
.41017 .5795 L
.41166 .58707 L
.41293 .59018 L
.41665 .59464 L
.4205 .59661 L
.4225 .59464 L
.42742 .58707 L
.42807 .58651 L
.43182 .58707 L
Mistroke
.43565 .58995 L
.44064 .59464 L
.44322 .59786 L
.4475 .60221 L
.45079 .60481 L
.45836 .60251 L
.45899 .60221 L
.46346 .59464 L
.45836 .5883 L
.45669 .58707 L
.45079 .5833 L
.44648 .5795 L
.44322 .57664 L
.43565 .57411 L
.43334 .57193 L
.42983 .56435 L
.43065 .55678 L
.43281 .54921 L
.43565 .54636 L
.44239 .54164 L
.44322 .54082 L
.4457 .54164 L
.45079 .54475 L
.45836 .54692 L
.46593 .54678 L
.4735 .54229 L
.47412 .54164 L
.47848 .53407 L
.48107 .52855 L
.48148 .5265 L
.48107 .52376 L
.48002 .51893 L
.48107 .51626 L
.48864 .51298 L
.49621 .51362 L
.49762 .51136 L
.49621 .50705 L
.49162 .50379 L
.48864 .50181 L
.48107 .50088 L
.47778 .49621 L
.4735 .49118 L
.47164 .48864 L
.46822 .48107 L
.46728 .4735 L
.4666 .46593 L
.47103 .45836 L
.47257 .45079 L
.4735 .4496 L
.48107 .44365 L
Mistroke
.48171 .44322 L
.48864 .43652 L
.48937 .43565 L
.49146 .42807 L
.49621 .42306 L
.4984 .4205 L
.50379 .41359 L
.51136 .41458 L
.51893 .41464 L
.51955 .41293 L
.52172 .40536 L
.5217 .39779 L
.5265 .39596 L
.53407 .39227 L
.54164 .3925 L
.54692 .39022 L
.54921 .38554 L
.55248 .38265 L
.55678 .37867 L
Mfstroke
.6 g
.5795 .51656 m
.58707 .51421 L
.59464 .51314 L
.60221 .51526 L
.6059 .51893 L
.60978 .52594 L
.61005 .5265 L
.61392 .53407 L
.61566 .54164 L
.6138 .54921 L
.60978 .55647 L
.60881 .55678 L
.60221 .56047 L
.59617 .56435 L
.59464 .56702 L
.5942 .57193 L
.59152 .5795 L
.59464 .58622 L
.59557 .58707 L
.60221 .59125 L
.60573 .59464 L
.60978 .59625 L
.61735 .59937 L
.6216 .60221 L
.62398 .60978 L
.62492 .61114 L
.63171 .61735 L
.6325 .61828 L
.64007 .62264 L
.64702 .62492 L
.64764 .62519 L
.65351 .6325 L
.65181 .64007 L
.64993 .64764 L
.64764 .65349 L
.64689 .65521 L
.6449 .66278 L
.64404 .67035 L
.64153 .67792 L
.64099 .68549 L
.64213 .69306 L
.64007 .69734 L
.63818 .70064 L
.63504 .70821 L
.6325 .71323 L
.6308 .71578 L
.62503 .72335 L
.62492 .72359 L
.62137 .73092 L
.61735 .7353 L
.61419 .73849 L
.60978 .74047 L
.60615 .74606 L
.60221 .74952 L
.59791 .75363 L
.60221 .75924 L
.60978 .76 L
.6163 .76121 L
.61735 .76126 L
.62492 .76425 L
.6325 .76555 L
.6397 .76878 L
.63427 .77635 L
.6325 .77893 L
.62883 .78392 L
.62492 .78796 L
.62037 .79149 L
.61867 .79906 L
.61735 .80106 L
.60978 .80539 L
.60221 .8061 L
.59501 .79906 L
.59464 .79855 L
.58707 .79492 L
.58132 .79149 L
.5795 .79064 L
.57193 .78842 L
.56818 .79149 L
.57057 .79906 L
.57193 .80522 L
.57214 .80663 L
.57193 .81214 L
.57064 .8142 L
.56435 .81753 L
.55678 .81767 L
.54921 .81628 L
.54766 .8142 L
.5435 .80663 L
.54164 .80458 L
.53601 .79906 L
.53407 .79616 L
.5265 .793 L
.52351 .79149 L
.52414 .78392 L
.52519 .77635 L
.51893 .77059 L
.51136 .77048 L
.50379 .77194 L
.50094 .77635 L
.49932 .78392 L
.49621 .79011 L
.49576 .79149 L
.49621 .79833 L
.49639 .79906 L
.50379 .80473 L
.51017 .80663 L
.51136 .80719 L
.51893 .81217 L
.5207 .8142 L
.52512 .82177 L
.51893 .82572 L
.51136 .82725 L
.50379 .82527 L
.49621 .82554 L
.48864 .82801 L
.48107 .82629 L
.4735 .82524 L
.46593 .82695 L
.45836 .82454 L
.45079 .82196 L
.45026 .82177 L
.44322 .81843 L
.43968 .8142 L
.43565 .80806 L
.43099 .80663 L
.42807 .80587 L
.4205 .80443 L
.41293 .80115 L
.40862 .79906 L
.40536 .79692 L
.39779 .7938 L
.39149 .79149 L
.39022 .79098 L
.38265 .78742 L
.37508 .78495 L
.37342 .78392 L
.3675 .78173 L
.35993 .78112 L
.35236 .77739 L
.35054 .77635 L
.34526 .76878 L
.34479 .7681 L
.33981 .76121 L
.33722 .7571 L
.33527 .75363 L
.3318 .74606 L
.32965 .74008 L
.32897 .73849 L
.32775 .73092 L
.32274 .72335 L
.32208 .72249 L
.31583 .71578 L
.31451 .71137 L
.31352 .70821 L
.30945 .70064 L
.30867 .69306 L
.30725 .68549 L
.31002 .67792 L
.31274 .67035 L
.30969 .66278 L
.30915 .65521 L
.30973 .64764 L
.31139 .64007 L
.31427 .6325 L
.31451 .63209 L
.31881 .62492 L
.32208 .62341 L
.32624 .61735 L
.32961 .60978 L
.32965 .60732 L
.33248 .60221 L
.33041 .59464 L
.33261 .58707 L
.33722 .58185 L
.34096 .5795 L
.34305 .57193 L
.34479 .56559 L
.34539 .56435 L
.35236 .55888 L
.35993 .56346 L
.36038 .56435 L
.3675 .56838 L
.37468 .56435 L
.37508 .56363 L
.38265 .558 L
.38298 .55678 L
.38346 .54921 L
.39022 .54283 L
.3913 .54164 L
.39623 .53407 L
.39779 .53192 L
.40464 .53407 L
.40536 .53734 L
.40656 .54164 L
.40741 .54921 L
.40551 .55678 L
.40536 .55726 L
.40405 .56435 L
.40536 .56946 L
.40569 .57193 L
.40536 .57369 L
.4047 .5795 L
.40418 .58707 L
.40474 .59464 L
.40536 .59734 L
.40683 .60221 L
.40736 .60978 L
.41293 .61539 L
.41538 .61735 L
.4205 .62121 L
.42807 .61944 L
.43041 .61735 L
.42946 .60978 L
.43565 .6078 L
.43676 .60978 L
.44322 .61531 L
.45079 .61721 L
.45836 .6171 L
.46013 .61735 L
.46593 .6179 L
.46865 .61735 L
.47324 .60978 L
.4735 .60914 L
.47519 .60221 L
.4735 .59699 L
.47258 .59464 L
.47236 .58707 L
.47166 .5795 L
.4735 .57323 L
.47416 .57193 L
.47781 .56435 L
.48107 .55877 L
.48715 .55678 L
.48864 .55603 L
.49621 .55276 L
.50379 .54986 L
.50472 .54921 L
.51136 .54241 L
.51215 .54164 L
.51893 .538 L
.5265 .53993 L
.53407 .54141 L
.53491 .54164 L
.54164 .54261 L
.54562 .54164 L
.54921 .53997 L
.55678 .53465 L
.55735 .53407 L
.56435 .52779 L
.56567 .5265 L
.57193 .52001 L
.57411 .51893 L
F
0 g
.5795 .51656 m
.58707 .51421 L
.59464 .51314 L
.60221 .51526 L
.6059 .51893 L
.60978 .52594 L
.61005 .5265 L
.61392 .53407 L
.61566 .54164 L
.6138 .54921 L
.60978 .55647 L
.60881 .55678 L
.60221 .56047 L
.59617 .56435 L
.59464 .56702 L
.5942 .57193 L
.59152 .5795 L
.59464 .58622 L
.59557 .58707 L
.60221 .59125 L
.60573 .59464 L
.60978 .59625 L
.61735 .59937 L
.6216 .60221 L
.62398 .60978 L
.62492 .61114 L
.63171 .61735 L
.6325 .61828 L
.64007 .62264 L
.64702 .62492 L
.64764 .62519 L
.65351 .6325 L
.65181 .64007 L
.64993 .64764 L
.64764 .65349 L
.64689 .65521 L
.6449 .66278 L
.64404 .67035 L
.64153 .67792 L
.64099 .68549 L
.64213 .69306 L
.64007 .69734 L
.63818 .70064 L
.63504 .70821 L
.6325 .71323 L
.6308 .71578 L
.62503 .72335 L
.62492 .72359 L
.62137 .73092 L
.61735 .7353 L
Mistroke
.61419 .73849 L
.60978 .74047 L
.60615 .74606 L
.60221 .74952 L
.59791 .75363 L
.60221 .75924 L
.60978 .76 L
.6163 .76121 L
.61735 .76126 L
.62492 .76425 L
.6325 .76555 L
.6397 .76878 L
.63427 .77635 L
.6325 .77893 L
.62883 .78392 L
.62492 .78796 L
.62037 .79149 L
.61867 .79906 L
.61735 .80106 L
.60978 .80539 L
.60221 .8061 L
.59501 .79906 L
.59464 .79855 L
.58707 .79492 L
.58132 .79149 L
.5795 .79064 L
.57193 .78842 L
.56818 .79149 L
.57057 .79906 L
.57193 .80522 L
.57214 .80663 L
.57193 .81214 L
.57064 .8142 L
.56435 .81753 L
.55678 .81767 L
.54921 .81628 L
.54766 .8142 L
.5435 .80663 L
.54164 .80458 L
.53601 .79906 L
.53407 .79616 L
.5265 .793 L
.52351 .79149 L
.52414 .78392 L
.52519 .77635 L
.51893 .77059 L
.51136 .77048 L
.50379 .77194 L
.50094 .77635 L
.49932 .78392 L
Mistroke
.49621 .79011 L
.49576 .79149 L
.49621 .79833 L
.49639 .79906 L
.50379 .80473 L
.51017 .80663 L
.51136 .80719 L
.51893 .81217 L
.5207 .8142 L
.52512 .82177 L
.51893 .82572 L
.51136 .82725 L
.50379 .82527 L
.49621 .82554 L
.48864 .82801 L
.48107 .82629 L
.4735 .82524 L
.46593 .82695 L
.45836 .82454 L
.45079 .82196 L
.45026 .82177 L
.44322 .81843 L
.43968 .8142 L
.43565 .80806 L
.43099 .80663 L
.42807 .80587 L
.4205 .80443 L
.41293 .80115 L
.40862 .79906 L
.40536 .79692 L
.39779 .7938 L
.39149 .79149 L
.39022 .79098 L
.38265 .78742 L
.37508 .78495 L
.37342 .78392 L
.3675 .78173 L
.35993 .78112 L
.35236 .77739 L
.35054 .77635 L
.34526 .76878 L
.34479 .7681 L
.33981 .76121 L
.33722 .7571 L
.33527 .75363 L
.3318 .74606 L
.32965 .74008 L
.32897 .73849 L
.32775 .73092 L
.32274 .72335 L
Mistroke
.32208 .72249 L
.31583 .71578 L
.31451 .71137 L
.31352 .70821 L
.30945 .70064 L
.30867 .69306 L
.30725 .68549 L
.31002 .67792 L
.31274 .67035 L
.30969 .66278 L
.30915 .65521 L
.30973 .64764 L
.31139 .64007 L
.31427 .6325 L
.31451 .63209 L
.31881 .62492 L
.32208 .62341 L
.32624 .61735 L
.32961 .60978 L
.32965 .60732 L
.33248 .60221 L
.33041 .59464 L
.33261 .58707 L
.33722 .58185 L
.34096 .5795 L
.34305 .57193 L
.34479 .56559 L
.34539 .56435 L
.35236 .55888 L
.35993 .56346 L
.36038 .56435 L
.3675 .56838 L
.37468 .56435 L
.37508 .56363 L
.38265 .558 L
.38298 .55678 L
.38346 .54921 L
.39022 .54283 L
.3913 .54164 L
.39623 .53407 L
.39779 .53192 L
.40464 .53407 L
.40536 .53734 L
.40656 .54164 L
.40741 .54921 L
.40551 .55678 L
.40536 .55726 L
.40405 .56435 L
.40536 .56946 L
.40569 .57193 L
Mistroke
.40536 .57369 L
.4047 .5795 L
.40418 .58707 L
.40474 .59464 L
.40536 .59734 L
.40683 .60221 L
.40736 .60978 L
.41293 .61539 L
.41538 .61735 L
.4205 .62121 L
.42807 .61944 L
.43041 .61735 L
.42946 .60978 L
.43565 .6078 L
.43676 .60978 L
.44322 .61531 L
.45079 .61721 L
.45836 .6171 L
.46013 .61735 L
.46593 .6179 L
.46865 .61735 L
.47324 .60978 L
.4735 .60914 L
.47519 .60221 L
.4735 .59699 L
.47258 .59464 L
.47236 .58707 L
.47166 .5795 L
.4735 .57323 L
.47416 .57193 L
.47781 .56435 L
.48107 .55877 L
.48715 .55678 L
.48864 .55603 L
.49621 .55276 L
.50379 .54986 L
.50472 .54921 L
.51136 .54241 L
.51215 .54164 L
.51893 .538 L
.5265 .53993 L
.53407 .54141 L
.53491 .54164 L
.54164 .54261 L
.54562 .54164 L
.54921 .53997 L
.55678 .53465 L
.55735 .53407 L
.56435 .52779 L
.56567 .5265 L
Mistroke
.57193 .52001 L
.57411 .51893 L
.5795 .51656 L
Mfstroke
.7 g
.38265 .57666 m
.38802 .5795 L
.38822 .58707 L
.38713 .59464 L
.38708 .60221 L
.38899 .60978 L
.39022 .61288 L
.39779 .61514 L
.40441 .61735 L
.40536 .61816 L
.40977 .62492 L
.41293 .62774 L
.4205 .63199 L
.42222 .6325 L
.42807 .6353 L
.43195 .64007 L
.43565 .64309 L
.44322 .64567 L
.45079 .64017 L
.4508 .64007 L
.45836 .63514 L
.46593 .63704 L
.4735 .63448 L
.48107 .63544 L
.48864 .63375 L
.49154 .6325 L
.49621 .63195 L
.50379 .63124 L
.5094 .62492 L
.51136 .62054 L
.51893 .6186 L
.5265 .62234 L
.52876 .62492 L
.53407 .63072 L
.53607 .6325 L
.54164 .63623 L
.54921 .637 L
.55678 .63629 L
.56435 .63461 L
.57193 .63251 L
.57197 .6325 L
.5795 .63017 L
.58707 .62632 L
.58903 .62492 L
.59464 .61742 L
.59465 .61735 L
.59464 .61732 L
.59106 .60978 L
.59308 .60221 L
.59464 .60121 L
.60221 .60085 L
.60598 .60221 L
.60978 .60446 L
.6145 .60978 L
.61735 .61131 L
.6239 .61735 L
.62492 .61968 L
.62847 .62492 L
.6325 .62838 L
.63792 .6325 L
.63856 .64007 L
.63441 .64764 L
.6325 .6514 L
.63071 .65521 L
.62769 .66278 L
.62877 .67035 L
.62779 .67792 L
.62805 .68549 L
.63101 .69306 L
.62784 .70064 L
.62547 .70821 L
.62492 .70959 L
.62277 .71578 L
.61735 .72219 L
.61563 .72335 L
.60978 .73024 L
.609 .73092 L
.60221 .73535 L
.59464 .73848 L
.59461 .73849 L
.58707 .74047 L
.5795 .7403 L
.57193 .74081 L
.56435 .74016 L
.55683 .73849 L
.55678 .73848 L
.55627 .73849 L
.54921 .74188 L
.54164 .74473 L
.5358 .74606 L
.53407 .7469 L
.5265 .74939 L
.51896 .74606 L
.51893 .74605 L
.51136 .74516 L
.50579 .74606 L
.50379 .74695 L
.49621 .75223 L
.49421 .75363 L
.49122 .76121 L
.49042 .76878 L
.48999 .77635 L
.48864 .78158 L
.48792 .78392 L
.48421 .79149 L
.48267 .79906 L
.48107 .80115 L
.4735 .80093 L
.47069 .79906 L
.46593 .79835 L
.46412 .79906 L
.45836 .8036 L
.45079 .80412 L
.44322 .79979 L
.4426 .79906 L
.43565 .79352 L
.43081 .79149 L
.42807 .79076 L
.4205 .79148 L
.42048 .79149 L
.41293 .79293 L
.40871 .79149 L
.40536 .79041 L
.39779 .7862 L
.39346 .78392 L
.39022 .78235 L
.38265 .77727 L
.38199 .77635 L
.37983 .76878 L
.37508 .76416 L
.37207 .76121 L
.3675 .75584 L
.36182 .75363 L
.35993 .75281 L
.35236 .74824 L
.35025 .74606 L
.34479 .74362 L
.33934 .73849 L
.33821 .73092 L
.33722 .72657 L
.33633 .72335 L
.33499 .71578 L
.32967 .70821 L
.32965 .70819 L
.32486 .70064 L
.32812 .69306 L
.32864 .68549 L
.32874 .67792 L
.32965 .67439 L
.33043 .67035 L
.32966 .66278 L
.33514 .65521 L
.33722 .64768 L
.33723 .64764 L
.33723 .64007 L
.33893 .6325 L
.34479 .62638 L
.34513 .62492 L
.35155 .61735 L
.35236 .6164 L
.35691 .60978 L
.35838 .60221 L
.35993 .59467 L
.35994 .59464 L
.36539 .58707 L
.3675 .58532 L
.37508 .58062 L
.3772 .5795 L
F
0 g
.38265 .57666 m
.38802 .5795 L
.38822 .58707 L
.38713 .59464 L
.38708 .60221 L
.38899 .60978 L
.39022 .61288 L
.39779 .61514 L
.40441 .61735 L
.40536 .61816 L
.40977 .62492 L
.41293 .62774 L
.4205 .63199 L
.42222 .6325 L
.42807 .6353 L
.43195 .64007 L
.43565 .64309 L
.44322 .64567 L
.45079 .64017 L
.4508 .64007 L
.45836 .63514 L
.46593 .63704 L
.4735 .63448 L
.48107 .63544 L
.48864 .63375 L
.49154 .6325 L
.49621 .63195 L
.50379 .63124 L
.5094 .62492 L
.51136 .62054 L
.51893 .6186 L
.5265 .62234 L
.52876 .62492 L
.53407 .63072 L
.53607 .6325 L
.54164 .63623 L
.54921 .637 L
.55678 .63629 L
.56435 .63461 L
.57193 .63251 L
.57197 .6325 L
.5795 .63017 L
.58707 .62632 L
.58903 .62492 L
.59464 .61742 L
.59465 .61735 L
.59464 .61732 L
.59106 .60978 L
.59308 .60221 L
.59464 .60121 L
Mistroke
.60221 .60085 L
.60598 .60221 L
.60978 .60446 L
.6145 .60978 L
.61735 .61131 L
.6239 .61735 L
.62492 .61968 L
.62847 .62492 L
.6325 .62838 L
.63792 .6325 L
.63856 .64007 L
.63441 .64764 L
.6325 .6514 L
.63071 .65521 L
.62769 .66278 L
.62877 .67035 L
.62779 .67792 L
.62805 .68549 L
.63101 .69306 L
.62784 .70064 L
.62547 .70821 L
.62492 .70959 L
.62277 .71578 L
.61735 .72219 L
.61563 .72335 L
.60978 .73024 L
.609 .73092 L
.60221 .73535 L
.59464 .73848 L
.59461 .73849 L
.58707 .74047 L
.5795 .7403 L
.57193 .74081 L
.56435 .74016 L
.55683 .73849 L
.55678 .73848 L
.55627 .73849 L
.54921 .74188 L
.54164 .74473 L
.5358 .74606 L
.53407 .7469 L
.5265 .74939 L
.51896 .74606 L
.51893 .74605 L
.51136 .74516 L
.50579 .74606 L
.50379 .74695 L
.49621 .75223 L
.49421 .75363 L
.49122 .76121 L
Mistroke
.49042 .76878 L
.48999 .77635 L
.48864 .78158 L
.48792 .78392 L
.48421 .79149 L
.48267 .79906 L
.48107 .80115 L
.4735 .80093 L
.47069 .79906 L
.46593 .79835 L
.46412 .79906 L
.45836 .8036 L
.45079 .80412 L
.44322 .79979 L
.4426 .79906 L
.43565 .79352 L
.43081 .79149 L
.42807 .79076 L
.4205 .79148 L
.42048 .79149 L
.41293 .79293 L
.40871 .79149 L
.40536 .79041 L
.39779 .7862 L
.39346 .78392 L
.39022 .78235 L
.38265 .77727 L
.38199 .77635 L
.37983 .76878 L
.37508 .76416 L
.37207 .76121 L
.3675 .75584 L
.36182 .75363 L
.35993 .75281 L
.35236 .74824 L
.35025 .74606 L
.34479 .74362 L
.33934 .73849 L
.33821 .73092 L
.33722 .72657 L
.33633 .72335 L
.33499 .71578 L
.32967 .70821 L
.32965 .70819 L
.32486 .70064 L
.32812 .69306 L
.32864 .68549 L
.32874 .67792 L
.32965 .67439 L
.33043 .67035 L
Mistroke
.32966 .66278 L
.33514 .65521 L
.33722 .64768 L
.33723 .64764 L
.33723 .64007 L
.33893 .6325 L
.34479 .62638 L
.34513 .62492 L
.35155 .61735 L
.35236 .6164 L
.35691 .60978 L
.35838 .60221 L
.35993 .59467 L
.35994 .59464 L
.36539 .58707 L
.3675 .58532 L
.37508 .58062 L
.3772 .5795 L
.38265 .57666 L
Mfstroke
.8 g
.32965 .89765 m
.33701 .90506 L
.32965 .90918 L
.32496 .90506 L
F
0 g
.32965 .89765 m
.33701 .90506 L
.32965 .90918 L
.32496 .90506 L
.32965 .89765 L
s
.5 g
.34479 .87329 m
.35236 .87062 L
.35597 .87477 L
.35367 .88234 L
.35236 .88622 L
.34479 .88672 L
.34405 .88234 L
.34396 .87477 L
F
0 g
.34479 .87329 m
.35236 .87062 L
.35597 .87477 L
.35367 .88234 L
.35236 .88622 L
.34479 .88672 L
.34405 .88234 L
.34396 .87477 L
.34479 .87329 L
s
.7 g
.35993 .88849 m
.36071 .88992 L
.36332 .89749 L
.35993 .90397 L
.35316 .89749 L
.3586 .88992 L
F
0 g
.35993 .88849 m
.36071 .88992 L
.36332 .89749 L
.35993 .90397 L
.35316 .89749 L
.3586 .88992 L
.35993 .88849 L
s
.8 g
.3675 .69573 m
.36826 .70064 L
.36898 .70821 L
.37445 .71578 L
.37508 .71609 L
.38265 .71797 L
.38621 .72335 L
.38738 .73092 L
.38265 .73795 L
.38224 .73849 L
.37508 .74432 L
.3675 .74061 L
.3634 .73849 L
.35993 .73542 L
.3572 .73092 L
.35829 .72335 L
.35428 .71578 L
.35424 .70821 L
.35993 .7014 L
.36063 .70064 L
F
0 g
.3675 .69573 m
.36826 .70064 L
.36898 .70821 L
.37445 .71578 L
.37508 .71609 L
.38265 .71797 L
.38621 .72335 L
.38738 .73092 L
.38265 .73795 L
.38224 .73849 L
.37508 .74432 L
.3675 .74061 L
.3634 .73849 L
.35993 .73542 L
.3572 .73092 L
.35829 .72335 L
.35428 .71578 L
.35424 .70821 L
.35993 .7014 L
.36063 .70064 L
.3675 .69573 L
s
.5 g
.35993 .12287 m
.36688 .12523 L
.35993 .12759 L
.35921 .12523 L
F
0 g
.35993 .12287 m
.36688 .12523 L
.35993 .12759 L
.35921 .12523 L
.35993 .12287 L
s
.5 g
.44307 .01923 m
.44322 .02269 L
.44386 .0268 L
.44543 .03437 L
.44487 .04194 L
.44322 .04654 L
.43979 .04952 L
.43677 .05709 L
.43565 .05812 L
.43293 .06466 L
.42807 .07174 L
.4275 .07223 L
.42121 .0798 L
.4205 .08115 L
.4169 .08737 L
.41293 .09002 L
.40536 .09271 L
.3997 .09494 L
.39779 .09603 L
.39022 .10208 L
.38981 .10251 L
.38265 .10989 L
.38235 .11008 L
.37588 .11766 L
.37508 .11841 L
.3675 .12481 L
.36275 .11766 L
.36583 .11008 L
.3675 .10737 L
.37046 .10251 L
.37435 .09494 L
.37508 .09425 L
.38097 .08737 L
.38265 .08422 L
.38439 .0798 L
.39022 .07324 L
.39194 .07223 L
.39656 .06466 L
.39779 .06201 L
.40042 .05709 L
.40393 .04952 L
.40536 .04442 L
.40709 .04194 L
.41218 .03437 L
.41293 .03251 L
.41343 .0268 L
.41396 .01923 L
F
0 g
.44307 .01923 m
.44322 .02269 L
.44386 .0268 L
.44543 .03437 L
.44487 .04194 L
.44322 .04654 L
.43979 .04952 L
.43677 .05709 L
.43565 .05812 L
.43293 .06466 L
.42807 .07174 L
.4275 .07223 L
.42121 .0798 L
.4205 .08115 L
.4169 .08737 L
.41293 .09002 L
.40536 .09271 L
.3997 .09494 L
.39779 .09603 L
.39022 .10208 L
.38981 .10251 L
.38265 .10989 L
.38235 .11008 L
.37588 .11766 L
.37508 .11841 L
.3675 .12481 L
.36275 .11766 L
.36583 .11008 L
.3675 .10737 L
.37046 .10251 L
.37435 .09494 L
.37508 .09425 L
.38097 .08737 L
.38265 .08422 L
.38439 .0798 L
.39022 .07324 L
.39194 .07223 L
.39656 .06466 L
.39779 .06201 L
.40042 .05709 L
.40393 .04952 L
.40536 .04442 L
.40709 .04194 L
.41218 .03437 L
.41293 .03251 L
.41343 .0268 L
.41396 .01923 L
s
.6 g
.37508 .6022 m
.37509 .60221 L
.37706 .60978 L
.37817 .61735 L
.3768 .62492 L
.37508 .63078 L
.37289 .6325 L
.36774 .64007 L
.3675 .6401 L
.36749 .64007 L
.36575 .6325 L
.36604 .62492 L
.3675 .62024 L
.36868 .61735 L
.3675 .61398 L
.36614 .60978 L
.3675 .60771 L
.37503 .60221 L
F
0 g
.37508 .6022 m
.37509 .60221 L
.37706 .60978 L
.37817 .61735 L
.3768 .62492 L
.37508 .63078 L
.37289 .6325 L
.36774 .64007 L
.3675 .6401 L
.36749 .64007 L
.36575 .6325 L
.36604 .62492 L
.3675 .62024 L
.36868 .61735 L
.3675 .61398 L
.36614 .60978 L
.3675 .60771 L
.37503 .60221 L
.37508 .6022 L
s
.4 g
.37508 .51411 m
.38265 .51732 L
.38299 .51893 L
.38265 .52047 L
.37508 .52598 L
.3709 .51893 L
F
0 g
.37508 .51411 m
.38265 .51732 L
.38299 .51893 L
.38265 .52047 L
.37508 .52598 L
.3709 .51893 L
.37508 .51411 L
s
.8 g
.38265 .67671 m
.38423 .67792 L
.38265 .68468 L
.37643 .67792 L
F
0 g
.38265 .67671 m
.38423 .67792 L
.38265 .68468 L
.37643 .67792 L
.38265 .67671 L
s
.3 g
.38265 .46318 m
.3838 .46593 L
.38265 .46697 L
.37984 .46593 L
F
0 g
.38265 .46318 m
.3838 .46593 L
.38265 .46697 L
.37984 .46593 L
.38265 .46318 L
s
.8 g
.39779 .68913 m
.40536 .69168 L
.40862 .69306 L
.41293 .69609 L
.4205 .69926 L
.42591 .70064 L
.42807 .70096 L
.43064 .70064 L
.43565 .69977 L
.43754 .70064 L
.44322 .70371 L
.45079 .70172 L
.45836 .70348 L
.46261 .70821 L
.46593 .71222 L
.46823 .71578 L
.4735 .72112 L
.47697 .72335 L
.48107 .72573 L
.48828 .73092 L
.48234 .73849 L
.48237 .74606 L
.48107 .75063 L
.47816 .75363 L
.4735 .75486 L
.46593 .75751 L
.46142 .76121 L
.45836 .7636 L
.45079 .76494 L
.44615 .76878 L
.44322 .77051 L
.43565 .77074 L
.43039 .76878 L
.42807 .7673 L
.42715 .76121 L
.42807 .75536 L
.42913 .75363 L
.43217 .74606 L
.42807 .74147 L
.42164 .74606 L
.4205 .74743 L
.41293 .75298 L
.41239 .75363 L
.40992 .76121 L
.40536 .76845 L
.40055 .76121 L
.39927 .75363 L
.40166 .74606 L
.40536 .74337 L
.40918 .73849 L
.40965 .73092 L
.40536 .72636 L
.40257 .72335 L
.39779 .71772 L
.39022 .71703 L
.38884 .71578 L
.39022 .7124 L
.39173 .70821 L
.39397 .70064 L
.39457 .69306 L
F
0 g
.39779 .68913 m
.40536 .69168 L
.40862 .69306 L
.41293 .69609 L
.4205 .69926 L
.42591 .70064 L
.42807 .70096 L
.43064 .70064 L
.43565 .69977 L
.43754 .70064 L
.44322 .70371 L
.45079 .70172 L
.45836 .70348 L
.46261 .70821 L
.46593 .71222 L
.46823 .71578 L
.4735 .72112 L
.47697 .72335 L
.48107 .72573 L
.48828 .73092 L
.48234 .73849 L
.48237 .74606 L
.48107 .75063 L
.47816 .75363 L
.4735 .75486 L
.46593 .75751 L
.46142 .76121 L
.45836 .7636 L
.45079 .76494 L
.44615 .76878 L
.44322 .77051 L
.43565 .77074 L
.43039 .76878 L
.42807 .7673 L
.42715 .76121 L
.42807 .75536 L
.42913 .75363 L
.43217 .74606 L
.42807 .74147 L
.42164 .74606 L
.4205 .74743 L
.41293 .75298 L
.41239 .75363 L
.40992 .76121 L
.40536 .76845 L
.40055 .76121 L
.39927 .75363 L
.40166 .74606 L
.40536 .74337 L
.40918 .73849 L
Mistroke
.40965 .73092 L
.40536 .72636 L
.40257 .72335 L
.39779 .71772 L
.39022 .71703 L
.38884 .71578 L
.39022 .7124 L
.39173 .70821 L
.39397 .70064 L
.39457 .69306 L
.39779 .68913 L
Mfstroke
.6 g
.39779 .18513 m
.40536 .1793 L
.40622 .1858 L
.40536 .1868 L
.39779 .18984 L
.39298 .1858 L
F
0 g
.39779 .18513 m
.40536 .1793 L
.40622 .1858 L
.40536 .1868 L
.39779 .18984 L
.39298 .1858 L
.39779 .18513 L
s
.6 g
.40536 .52593 m
.40589 .5265 L
.40536 .53144 L
.40457 .5265 L
F
0 g
.40536 .52593 m
.40589 .5265 L
.40536 .53144 L
.40457 .5265 L
.40536 .52593 L
s
.3 g
.4205 .46507 m
.42807 .46246 L
.43565 .46065 L
.44213 .46593 L
.44071 .4735 L
.43938 .48107 L
.43675 .48864 L
.43565 .48906 L
.42807 .49173 L
.4205 .49585 L
.41971 .49621 L
.41293 .49833 L
.41085 .49621 L
.40538 .48864 L
.40687 .48107 L
.4078 .4735 L
.41293 .46597 L
.41301 .46593 L
F
0 g
.4205 .46507 m
.42807 .46246 L
.43565 .46065 L
.44213 .46593 L
.44071 .4735 L
.43938 .48107 L
.43675 .48864 L
.43565 .48906 L
.42807 .49173 L
.4205 .49585 L
.41971 .49621 L
.41293 .49833 L
.41085 .49621 L
.40538 .48864 L
.40687 .48107 L
.4078 .4735 L
.41293 .46597 L
.41301 .46593 L
.4205 .46507 L
s
.4 g
.43307 .01923 m
.43199 .0268 L
.43257 .03437 L
.43051 .04194 L
.42807 .04555 L
.42552 .04952 L
.42185 .05709 L
.4205 .05947 L
.41293 .06285 L
.40954 .05709 L
.41056 .04952 L
.41293 .04466 L
.4149 .04194 L
.4186 .03437 L
.4205 .02933 L
.42128 .0268 L
.4259 .01923 L
F
0 g
.43307 .01923 m
.43199 .0268 L
.43257 .03437 L
.43051 .04194 L
.42807 .04555 L
.42552 .04952 L
.42185 .05709 L
.4205 .05947 L
.41293 .06285 L
.40954 .05709 L
.41056 .04952 L
.41293 .04466 L
.4149 .04194 L
.4186 .03437 L
.4205 .02933 L
.42128 .0268 L
.4259 .01923 L
s
.5 g
.4205 .31945 m
.42807 .3156 L
.43496 .32208 L
.42807 .32766 L
.42491 .32965 L
.4205 .33118 L
.41438 .32965 L
.41722 .32208 L
F
0 g
.4205 .31945 m
.42807 .3156 L
.43496 .32208 L
.42807 .32766 L
.42491 .32965 L
.4205 .33118 L
.41438 .32965 L
.41722 .32208 L
.4205 .31945 L
s
.6 g
.42807 .50675 m
.42985 .51136 L
.42807 .51484 L
.42221 .51136 L
F
0 g
.42807 .50675 m
.42985 .51136 L
.42807 .51484 L
.42221 .51136 L
.42807 .50675 L
s
.7 g
.43565 .71923 m
.44009 .72335 L
.44322 .72531 L
.44586 .73092 L
.44322 .7341 L
.43565 .73465 L
.43161 .73092 L
.43327 .72335 L
F
0 g
.43565 .71923 m
.44009 .72335 L
.44322 .72531 L
.44586 .73092 L
.44322 .7341 L
.43565 .73465 L
.43161 .73092 L
.43327 .72335 L
.43565 .71923 L
s
.3 g
.45836 .42646 m
.46319 .42807 L
.45985 .43565 L
.45836 .43956 L
.4542 .43565 L
.4563 .42807 L
F
0 g
.45836 .42646 m
.46319 .42807 L
.45985 .43565 L
.45836 .43956 L
.4542 .43565 L
.4563 .42807 L
.45836 .42646 L
s
.7 g
.67755 .01923 m
.67051 .0268 L
.67035 .02741 L
.66558 .03437 L
.66278 .03643 L
.65722 .04194 L
.65521 .04374 L
.65194 .04952 L
.64764 .05708 L
.64763 .05709 L
.64148 .06466 L
.64007 .06601 L
.63399 .07223 L
.6325 .07314 L
.62675 .0798 L
.62492 .08502 L
.62313 .08737 L
.61735 .09033 L
.60978 .09493 L
.60977 .09494 L
.60298 .10251 L
.60221 .10382 L
.59758 .11008 L
.59464 .11686 L
.59442 .11766 L
.59128 .12523 L
.58707 .13018 L
.58408 .1328 L
.5795 .13632 L
.57379 .14037 L
.57193 .14226 L
.56649 .14794 L
.56435 .14978 L
.55678 .15549 L
.55676 .15551 L
.54921 .16198 L
.54164 .16301 L
.53413 .15551 L
.53407 .15545 L
.52929 .14794 L
.5265 .14341 L
.52472 .14037 L
.5265 .13705 L
.5282 .1328 L
.52949 .12523 L
.52863 .11766 L
.53055 .11008 L
.53356 .10251 L
.53407 .1006 L
.53733 .09494 L
.54164 .0909 L
.54378 .08737 L
.54164 .0813 L
.5409 .0798 L
.54164 .07776 L
.54464 .07223 L
.54589 .06466 L
.54688 .05709 L
.54654 .04952 L
.54608 .04194 L
.54164 .04191 L
.54162 .04194 L
.53549 .04952 L
.53407 .05702 L
.53405 .05709 L
.52785 .06466 L
.5265 .06658 L
.52233 .07223 L
.51893 .07563 L
.51136 .07661 L
.50379 .07843 L
.49621 .0786 L
.49303 .0798 L
.48864 .0823 L
.48358 .08737 L
.48107 .0885 L
.4735 .09215 L
.47121 .08737 L
.4705 .0798 L
.4735 .07224 L
.47351 .07223 L
.47582 .06466 L
.47701 .05709 L
.47803 .04952 L
.48 .04194 L
.48107 .03726 L
.48175 .03437 L
.48107 .03082 L
.48079 .0268 L
.48074 .01923 L
F
0 g
.67755 .01923 m
.67051 .0268 L
.67035 .02741 L
.66558 .03437 L
.66278 .03643 L
.65722 .04194 L
.65521 .04374 L
.65194 .04952 L
.64764 .05708 L
.64763 .05709 L
.64148 .06466 L
.64007 .06601 L
.63399 .07223 L
.6325 .07314 L
.62675 .0798 L
.62492 .08502 L
.62313 .08737 L
.61735 .09033 L
.60978 .09493 L
.60977 .09494 L
.60298 .10251 L
.60221 .10382 L
.59758 .11008 L
.59464 .11686 L
.59442 .11766 L
.59128 .12523 L
.58707 .13018 L
.58408 .1328 L
.5795 .13632 L
.57379 .14037 L
.57193 .14226 L
.56649 .14794 L
.56435 .14978 L
.55678 .15549 L
.55676 .15551 L
.54921 .16198 L
.54164 .16301 L
.53413 .15551 L
.53407 .15545 L
.52929 .14794 L
.5265 .14341 L
.52472 .14037 L
.5265 .13705 L
.5282 .1328 L
.52949 .12523 L
.52863 .11766 L
.53055 .11008 L
.53356 .10251 L
.53407 .1006 L
.53733 .09494 L
Mistroke
.54164 .0909 L
.54378 .08737 L
.54164 .0813 L
.5409 .0798 L
.54164 .07776 L
.54464 .07223 L
.54589 .06466 L
.54688 .05709 L
.54654 .04952 L
.54608 .04194 L
.54164 .04191 L
.54162 .04194 L
.53549 .04952 L
.53407 .05702 L
.53405 .05709 L
.52785 .06466 L
.5265 .06658 L
.52233 .07223 L
.51893 .07563 L
.51136 .07661 L
.50379 .07843 L
.49621 .0786 L
.49303 .0798 L
.48864 .0823 L
.48358 .08737 L
.48107 .0885 L
.4735 .09215 L
.47121 .08737 L
.4705 .0798 L
.4735 .07224 L
.47351 .07223 L
.47582 .06466 L
.47701 .05709 L
.47803 .04952 L
.48 .04194 L
.48107 .03726 L
.48175 .03437 L
.48107 .03082 L
.48079 .0268 L
.48074 .01923 L
Mfstroke
.6 g
.48107 .91678 m
.48357 .9202 L
.48241 .92777 L
.48107 .9296 L
.48065 .92777 L
.47952 .9202 L
F
0 g
.48107 .91678 m
.48357 .9202 L
.48241 .92777 L
.48107 .9296 L
.48065 .92777 L
.47952 .9202 L
.48107 .91678 L
s
.8 g
.58707 .66089 m
.5926 .66278 L
.59464 .66465 L
.60135 .67035 L
.60164 .67792 L
.60221 .68067 L
.60362 .68549 L
.60419 .69306 L
.60221 .69502 L
.59464 .70007 L
.59349 .70064 L
.58707 .70434 L
.5795 .70715 L
.57835 .70821 L
.57193 .7122 L
.56435 .71182 L
.55678 .71018 L
.54921 .71131 L
.54164 .71116 L
.53727 .70821 L
.53407 .70706 L
.53087 .70821 L
.5265 .7101 L
.51893 .71366 L
.51136 .71391 L
.50895 .71578 L
.50379 .71864 L
.49903 .71578 L
.49621 .71503 L
.49424 .71578 L
.49621 .71847 L
.49898 .72335 L
.49621 .72474 L
.4902 .72335 L
.48864 .71974 L
.48708 .71578 L
.48498 .70821 L
.48864 .7012 L
.4895 .70064 L
.49621 .6968 L
.49834 .69306 L
.49894 .68549 L
.50085 .67792 L
.50141 .67035 L
.50379 .66803 L
.51136 .6672 L
.51893 .6672 L
.52486 .67035 L
.5265 .67176 L
.53175 .67792 L
.53407 .67895 L
.54164 .68218 L
.54921 .67878 L
.5505 .67792 L
.55678 .67197 L
.56435 .67379 L
.56928 .67035 L
.57193 .66725 L
.5795 .66359 L
.58153 .66278 L
F
0 g
.58707 .66089 m
.5926 .66278 L
.59464 .66465 L
.60135 .67035 L
.60164 .67792 L
.60221 .68067 L
.60362 .68549 L
.60419 .69306 L
.60221 .69502 L
.59464 .70007 L
.59349 .70064 L
.58707 .70434 L
.5795 .70715 L
.57835 .70821 L
.57193 .7122 L
.56435 .71182 L
.55678 .71018 L
.54921 .71131 L
.54164 .71116 L
.53727 .70821 L
.53407 .70706 L
.53087 .70821 L
.5265 .7101 L
.51893 .71366 L
.51136 .71391 L
.50895 .71578 L
.50379 .71864 L
.49903 .71578 L
.49621 .71503 L
.49424 .71578 L
.49621 .71847 L
.49898 .72335 L
.49621 .72474 L
.4902 .72335 L
.48864 .71974 L
.48708 .71578 L
.48498 .70821 L
.48864 .7012 L
.4895 .70064 L
.49621 .6968 L
.49834 .69306 L
.49894 .68549 L
.50085 .67792 L
.50141 .67035 L
.50379 .66803 L
.51136 .6672 L
.51893 .6672 L
.52486 .67035 L
.5265 .67176 L
.53175 .67792 L
Mistroke
.53407 .67895 L
.54164 .68218 L
.54921 .67878 L
.5505 .67792 L
.55678 .67197 L
.56435 .67379 L
.56928 .67035 L
.57193 .66725 L
.5795 .66359 L
.58153 .66278 L
.58707 .66089 L
Mfstroke
.8 g
.53277 .01923 m
.5265 .02526 L
.52488 .0268 L
.51893 .03181 L
.51612 .03437 L
.51136 .03804 L
.50379 .04159 L
.50319 .04194 L
.49621 .04609 L
.48981 .04194 L
.49169 .03437 L
.49027 .0268 L
.48984 .01923 L
F
0 g
.53277 .01923 m
.5265 .02526 L
.52488 .0268 L
.51893 .03181 L
.51612 .03437 L
.51136 .03804 L
.50379 .04159 L
.50319 .04194 L
.49621 .04609 L
.48981 .04194 L
.49169 .03437 L
.49027 .0268 L
.48984 .01923 L
s
.8 g
.98077 .70668 m
.97976 .70821 L
.97617 .71578 L
.9732 .71932 L
.97037 .72335 L
.9681 .73092 L
.96563 .73488 L
.96275 .73849 L
.95806 .74577 L
.95777 .74606 L
.95092 .75363 L
.95048 .75484 L
.94511 .76121 L
.94291 .76623 L
.94059 .76878 L
.93534 .77362 L
.93278 .77635 L
.92777 .78294 L
.92691 .78392 L
.9204 .79149 L
.9202 .79183 L
.91475 .79906 L
.91263 .80126 L
.90746 .80663 L
.90506 .80934 L
.90013 .8142 L
.89749 .81748 L
.89278 .82177 L
.88992 .8236 L
.88381 .82935 L
.88234 .83068 L
.87617 .83692 L
.87477 .83908 L
.86926 .84449 L
.8672 .84564 L
.85963 .85 L
.8573 .85206 L
.85206 .85481 L
.84684 .85963 L
.84449 .86173 L
.83808 .8672 L
.83692 .86797 L
.82935 .87459 L
.82911 .87477 L
.82177 .87971 L
.81819 .88234 L
.8142 .88388 L
.80663 .88861 L
.80494 .88992 L
.79906 .89386 L
.79382 .89749 L
.79149 .8985 L
.78392 .90338 L
.78132 .90506 L
.77635 .90716 L
.76878 .91245 L
.76845 .91263 L
.76121 .91552 L
.75363 .92002 L
.75328 .9202 L
.74606 .92321 L
.73849 .92735 L
.73756 .92777 L
.73092 .93025 L
.72335 .93425 L
.7209 .93534 L
.71578 .93691 L
.70821 .94099 L
.70407 .94291 L
.70064 .94393 L
.69306 .94737 L
.68575 .95048 L
.68549 .95052 L
.67792 .95179 L
.67035 .95382 L
.66278 .9573 L
.66091 .95806 L
.65521 .95907 L
.64764 .96095 L
.64007 .96391 L
.63278 .96563 L
.6325 .96567 L
.62492 .96675 L
.61735 .96775 L
.60978 .96946 L
.60221 .97041 L
.59464 .97208 L
.59039 .9732 L
.58707 .97388 L
.5795 .97398 L
.57193 .97536 L
.56435 .97651 L
.55678 .97735 L
.54921 .97823 L
.54164 .97877 L
.53407 .97973 L
.5265 .98004 L
.51893 .98051 L
.51679 .98077 L
.98077 .98077 L
F
0 g
.98077 .70668 m
.97976 .70821 L
.97617 .71578 L
.9732 .71932 L
.97037 .72335 L
.9681 .73092 L
.96563 .73488 L
.96275 .73849 L
.95806 .74577 L
.95777 .74606 L
.95092 .75363 L
.95048 .75484 L
.94511 .76121 L
.94291 .76623 L
.94059 .76878 L
.93534 .77362 L
.93278 .77635 L
.92777 .78294 L
.92691 .78392 L
.9204 .79149 L
.9202 .79183 L
.91475 .79906 L
.91263 .80126 L
.90746 .80663 L
.90506 .80934 L
.90013 .8142 L
.89749 .81748 L
.89278 .82177 L
.88992 .8236 L
.88381 .82935 L
.88234 .83068 L
.87617 .83692 L
.87477 .83908 L
.86926 .84449 L
.8672 .84564 L
.85963 .85 L
.8573 .85206 L
.85206 .85481 L
.84684 .85963 L
.84449 .86173 L
.83808 .8672 L
.83692 .86797 L
.82935 .87459 L
.82911 .87477 L
.82177 .87971 L
.81819 .88234 L
.8142 .88388 L
.80663 .88861 L
.80494 .88992 L
.79906 .89386 L
Mistroke
.79382 .89749 L
.79149 .8985 L
.78392 .90338 L
.78132 .90506 L
.77635 .90716 L
.76878 .91245 L
.76845 .91263 L
.76121 .91552 L
.75363 .92002 L
.75328 .9202 L
.74606 .92321 L
.73849 .92735 L
.73756 .92777 L
.73092 .93025 L
.72335 .93425 L
.7209 .93534 L
.71578 .93691 L
.70821 .94099 L
.70407 .94291 L
.70064 .94393 L
.69306 .94737 L
.68575 .95048 L
.68549 .95052 L
.67792 .95179 L
.67035 .95382 L
.66278 .9573 L
.66091 .95806 L
.65521 .95907 L
.64764 .96095 L
.64007 .96391 L
.63278 .96563 L
.6325 .96567 L
.62492 .96675 L
.61735 .96775 L
.60978 .96946 L
.60221 .97041 L
.59464 .97208 L
.59039 .9732 L
.58707 .97388 L
.5795 .97398 L
.57193 .97536 L
.56435 .97651 L
.55678 .97735 L
.54921 .97823 L
.54164 .97877 L
.53407 .97973 L
.5265 .98004 L
.51893 .98051 L
.51679 .98077 L
Mfstroke
.2 g
.69306 .10959 m
.70064 .10774 L
.70701 .11008 L
.70821 .11059 L
.71578 .11347 L
.71843 .11766 L
.72335 .12251 L
.73092 .12421 L
.73378 .12523 L
.73849 .12816 L
.74493 .1328 L
.74606 .13367 L
.7529 .14037 L
.75363 .14093 L
.76121 .14436 L
.76688 .14794 L
.76878 .1497 L
.77421 .15551 L
.77635 .15996 L
.77679 .16308 L
.77837 .17065 L
.78195 .17823 L
.78246 .1858 L
.78071 .19337 L
.77658 .20094 L
.78392 .20801 L
.79149 .20178 L
.7928 .20094 L
.79824 .19337 L
.79906 .18842 L
.80663 .19214 L
.80824 .19337 L
.81303 .20094 L
.8142 .20238 L
.81904 .20851 L
.82177 .21302 L
.8252 .21608 L
.82935 .21873 L
.83143 .22365 L
.83641 .23122 L
.83692 .23207 L
.84037 .23879 L
.84449 .24322 L
.84536 .24637 L
.84667 .25394 L
.8516 .26151 L
.85206 .26235 L
.85551 .26908 L
.85924 .27665 L
.8592 .28422 L
.85963 .28534 L
.86369 .29179 L
.86668 .29936 L
.8672 .30095 L
.86901 .30694 L
.87433 .31451 L
.87477 .3164 L
.87561 .32208 L
.88064 .32965 L
.88234 .33386 L
.88318 .33722 L
.88415 .34479 L
.88711 .35236 L
.8885 .35993 L
.88955 .3675 L
.88992 .36821 L
.89395 .37508 L
.89395 .38265 L
.89494 .39022 L
.89607 .39779 L
.89623 .40536 L
.89711 .41293 L
.89749 .41413 L
.89927 .4205 L
.89823 .42807 L
.8982 .43565 L
.90019 .44322 L
.89749 .44981 L
.8971 .45079 L
.89749 .45406 L
.89816 .45836 L
.89749 .46113 L
.89602 .46593 L
.89578 .4735 L
.89372 .48107 L
.89395 .48864 L
.89198 .49621 L
.89062 .50379 L
.88992 .50643 L
.88862 .51136 L
.88735 .51893 L
.88629 .5265 L
.88407 .53407 L
.88308 .54164 L
.88234 .54483 L
.88093 .54921 L
.87811 .55678 L
.87658 .56435 L
.87545 .57193 L
.87477 .57488 L
.87106 .5795 L
.86893 .58707 L
.8672 .58974 L
.86572 .59464 L
.86464 .60221 L
.86035 .60978 L
.85963 .6114 L
.85666 .61735 L
.85206 .62202 L
.85046 .62492 L
.84783 .6325 L
.84449 .63766 L
.84284 .64007 L
.83776 .64764 L
.83692 .64925 L
.83411 .65521 L
.82935 .66219 L
.82895 .66278 L
.82523 .67035 L
.82177 .67465 L
.81842 .67792 L
.8142 .68267 L
.81282 .68549 L
.80764 .69306 L
.80663 .69412 L
.80014 .70064 L
.79906 .70184 L
.79276 .70821 L
.79149 .70922 L
.78493 .71578 L
.78392 .71669 L
.77635 .72266 L
.77573 .72335 L
.77013 .73092 L
.76878 .73216 L
.76121 .73661 L
.75845 .73849 L
.75363 .74361 L
.75031 .74606 L
.74606 .74817 L
.73849 .7531 L
.73765 .75363 L
.73092 .75743 L
.72491 .76121 L
.72335 .76294 L
.71746 .76878 L
.71578 .76975 L
.70821 .77482 L
.70064 .77583 L
.6997 .77635 L
.69306 .78193 L
.68965 .78392 L
.68549 .7863 L
.67792 .78954 L
.67536 .79149 L
.67035 .79497 L
.66626 .79149 L
.66915 .78392 L
.66876 .77635 L
.67035 .77233 L
.6714 .76878 L
.67035 .7657 L
.66751 .76121 L
.66371 .75363 L
.66278 .75194 L
.65521 .74656 L
.65456 .74606 L
.64764 .74296 L
.64228 .73849 L
.64186 .73092 L
.64233 .72335 L
.64503 .71578 L
.64764 .71109 L
.64919 .70821 L
.65158 .70064 L
.65521 .69629 L
.65706 .69306 L
.65718 .68549 L
.65717 .67792 L
.66163 .67035 L
.66048 .66278 L
.66225 .65521 L
.66278 .65247 L
.66374 .64764 L
.66522 .64007 L
.66702 .6325 L
.66768 .62492 L
.66887 .61735 L
.66356 .60978 L
.66278 .60766 L
.66135 .60221 L
.65521 .59809 L
.64764 .60113 L
.64007 .59769 L
.63811 .59464 L
.63519 .58707 L
.63469 .5795 L
.63712 .57193 L
.63606 .56435 L
.63799 .55678 L
.64007 .55228 L
.64163 .54921 L
.64272 .54164 L
.647 .53407 L
.64764 .53309 L
.64974 .5265 L
.64889 .51893 L
.65521 .51716 L
.66278 .51652 L
.67035 .51244 L
.6713 .51136 L
.67071 .50379 L
.67035 .5036 L
.66278 .50094 L
.65521 .49995 L
.64764 .50336 L
.64007 .49938 L
.63922 .49621 L
.63874 .48864 L
.64007 .48585 L
.6436 .48107 L
.64721 .4735 L
.64405 .46593 L
.64007 .46248 L
.6325 .4588 L
.62816 .45836 L
.62492 .45581 L
.61895 .45079 L
.62169 .44322 L
.61772 .43565 L
.62322 .42807 L
.62492 .4261 L
.62714 .4205 L
.63026 .41293 L
.6325 .41027 L
.63734 .40536 L
.64007 .40335 L
.64686 .39779 L
.64764 .39696 L
.65486 .39022 L
.65521 .38946 L
.65593 .38265 L
.65543 .37508 L
.65521 .37472 L
.6506 .3675 L
.64764 .36566 L
.64007 .36062 L
.63977 .35993 L
.6325 .35362 L
.62492 .35256 L
.61735 .35291 L
.60978 .35298 L
.60221 .35307 L
.59464 .35359 L
.58707 .35271 L
.58545 .35236 L
.5795 .34942 L
.57193 .34751 L
.56575 .34479 L
.56621 .33722 L
.56435 .33208 L
.5637 .32965 L
.55678 .3253 L
.55176 .32208 L
.55651 .31451 L
.55539 .30694 L
.55504 .29936 L
.55516 .29179 L
.55678 .28747 L
.55874 .28422 L
.56435 .27795 L
.56505 .27665 L
.56849 .26908 L
.57193 .26679 L
.5795 .26238 L
.58028 .26151 L
.58586 .25394 L
.58707 .24977 L
.58853 .24637 L
.58711 .23879 L
.58707 .2379 L
.58584 .23122 L
.58072 .22365 L
.57963 .21608 L
.58528 .20851 L
.58707 .20549 L
.58848 .20094 L
.59464 .19361 L
.59483 .19337 L
.60047 .1858 L
.60221 .18381 L
.60733 .17823 L
.60978 .17573 L
.61504 .17065 L
.61735 .16827 L
.62192 .16308 L
.62492 .16032 L
.63039 .15551 L
.6325 .15354 L
.63524 .14794 L
.64007 .14326 L
.64242 .14037 L
.64764 .13439 L
.65253 .1328 L
.65521 .12962 L
.6617 .12523 L
.66278 .12436 L
.66627 .12523 L
.67035 .12783 L
.67421 .12523 L
.67792 .12387 L
.6824 .11766 L
.68549 .11564 L
.69257 .11008 L
F
0 g
.69306 .10959 m
.70064 .10774 L
.70701 .11008 L
.70821 .11059 L
.71578 .11347 L
.71843 .11766 L
.72335 .12251 L
.73092 .12421 L
.73378 .12523 L
.73849 .12816 L
.74493 .1328 L
.74606 .13367 L
.7529 .14037 L
.75363 .14093 L
.76121 .14436 L
.76688 .14794 L
.76878 .1497 L
.77421 .15551 L
.77635 .15996 L
.77679 .16308 L
.77837 .17065 L
.78195 .17823 L
.78246 .1858 L
.78071 .19337 L
.77658 .20094 L
.78392 .20801 L
.79149 .20178 L
.7928 .20094 L
.79824 .19337 L
.79906 .18842 L
.80663 .19214 L
.80824 .19337 L
.81303 .20094 L
.8142 .20238 L
.81904 .20851 L
.82177 .21302 L
.8252 .21608 L
.82935 .21873 L
.83143 .22365 L
.83641 .23122 L
.83692 .23207 L
.84037 .23879 L
.84449 .24322 L
.84536 .24637 L
.84667 .25394 L
.8516 .26151 L
.85206 .26235 L
.85551 .26908 L
.85924 .27665 L
.8592 .28422 L
Mistroke
.85963 .28534 L
.86369 .29179 L
.86668 .29936 L
.8672 .30095 L
.86901 .30694 L
.87433 .31451 L
.87477 .3164 L
.87561 .32208 L
.88064 .32965 L
.88234 .33386 L
.88318 .33722 L
.88415 .34479 L
.88711 .35236 L
.8885 .35993 L
.88955 .3675 L
.88992 .36821 L
.89395 .37508 L
.89395 .38265 L
.89494 .39022 L
.89607 .39779 L
.89623 .40536 L
.89711 .41293 L
.89749 .41413 L
.89927 .4205 L
.89823 .42807 L
.8982 .43565 L
.90019 .44322 L
.89749 .44981 L
.8971 .45079 L
.89749 .45406 L
.89816 .45836 L
.89749 .46113 L
.89602 .46593 L
.89578 .4735 L
.89372 .48107 L
.89395 .48864 L
.89198 .49621 L
.89062 .50379 L
.88992 .50643 L
.88862 .51136 L
.88735 .51893 L
.88629 .5265 L
.88407 .53407 L
.88308 .54164 L
.88234 .54483 L
.88093 .54921 L
.87811 .55678 L
.87658 .56435 L
.87545 .57193 L
.87477 .57488 L
Mistroke
.87106 .5795 L
.86893 .58707 L
.8672 .58974 L
.86572 .59464 L
.86464 .60221 L
.86035 .60978 L
.85963 .6114 L
.85666 .61735 L
.85206 .62202 L
.85046 .62492 L
.84783 .6325 L
.84449 .63766 L
.84284 .64007 L
.83776 .64764 L
.83692 .64925 L
.83411 .65521 L
.82935 .66219 L
.82895 .66278 L
.82523 .67035 L
.82177 .67465 L
.81842 .67792 L
.8142 .68267 L
.81282 .68549 L
.80764 .69306 L
.80663 .69412 L
.80014 .70064 L
.79906 .70184 L
.79276 .70821 L
.79149 .70922 L
.78493 .71578 L
.78392 .71669 L
.77635 .72266 L
.77573 .72335 L
.77013 .73092 L
.76878 .73216 L
.76121 .73661 L
.75845 .73849 L
.75363 .74361 L
.75031 .74606 L
.74606 .74817 L
.73849 .7531 L
.73765 .75363 L
.73092 .75743 L
.72491 .76121 L
.72335 .76294 L
.71746 .76878 L
.71578 .76975 L
.70821 .77482 L
.70064 .77583 L
.6997 .77635 L
Mistroke
.69306 .78193 L
.68965 .78392 L
.68549 .7863 L
.67792 .78954 L
.67536 .79149 L
.67035 .79497 L
.66626 .79149 L
.66915 .78392 L
.66876 .77635 L
.67035 .77233 L
.6714 .76878 L
.67035 .7657 L
.66751 .76121 L
.66371 .75363 L
.66278 .75194 L
.65521 .74656 L
.65456 .74606 L
.64764 .74296 L
.64228 .73849 L
.64186 .73092 L
.64233 .72335 L
.64503 .71578 L
.64764 .71109 L
.64919 .70821 L
.65158 .70064 L
.65521 .69629 L
.65706 .69306 L
.65718 .68549 L
.65717 .67792 L
.66163 .67035 L
.66048 .66278 L
.66225 .65521 L
.66278 .65247 L
.66374 .64764 L
.66522 .64007 L
.66702 .6325 L
.66768 .62492 L
.66887 .61735 L
.66356 .60978 L
.66278 .60766 L
.66135 .60221 L
.65521 .59809 L
.64764 .60113 L
.64007 .59769 L
.63811 .59464 L
.63519 .58707 L
.63469 .5795 L
.63712 .57193 L
.63606 .56435 L
.63799 .55678 L
Mistroke
.64007 .55228 L
.64163 .54921 L
.64272 .54164 L
.647 .53407 L
.64764 .53309 L
.64974 .5265 L
.64889 .51893 L
.65521 .51716 L
.66278 .51652 L
.67035 .51244 L
.6713 .51136 L
.67071 .50379 L
.67035 .5036 L
.66278 .50094 L
.65521 .49995 L
.64764 .50336 L
.64007 .49938 L
.63922 .49621 L
.63874 .48864 L
.64007 .48585 L
.6436 .48107 L
.64721 .4735 L
.64405 .46593 L
.64007 .46248 L
.6325 .4588 L
.62816 .45836 L
.62492 .45581 L
.61895 .45079 L
.62169 .44322 L
.61772 .43565 L
.62322 .42807 L
.62492 .4261 L
.62714 .4205 L
.63026 .41293 L
.6325 .41027 L
.63734 .40536 L
.64007 .40335 L
.64686 .39779 L
.64764 .39696 L
.65486 .39022 L
.65521 .38946 L
.65593 .38265 L
.65543 .37508 L
.65521 .37472 L
.6506 .3675 L
.64764 .36566 L
.64007 .36062 L
.63977 .35993 L
.6325 .35362 L
.62492 .35256 L
Mistroke
.61735 .35291 L
.60978 .35298 L
.60221 .35307 L
.59464 .35359 L
.58707 .35271 L
.58545 .35236 L
.5795 .34942 L
.57193 .34751 L
.56575 .34479 L
.56621 .33722 L
.56435 .33208 L
.5637 .32965 L
.55678 .3253 L
.55176 .32208 L
.55651 .31451 L
.55539 .30694 L
.55504 .29936 L
.55516 .29179 L
.55678 .28747 L
.55874 .28422 L
.56435 .27795 L
.56505 .27665 L
.56849 .26908 L
.57193 .26679 L
.5795 .26238 L
.58028 .26151 L
.58586 .25394 L
.58707 .24977 L
.58853 .24637 L
.58711 .23879 L
.58707 .2379 L
.58584 .23122 L
.58072 .22365 L
.57963 .21608 L
.58528 .20851 L
.58707 .20549 L
.58848 .20094 L
.59464 .19361 L
.59483 .19337 L
.60047 .1858 L
.60221 .18381 L
.60733 .17823 L
.60978 .17573 L
.61504 .17065 L
.61735 .16827 L
.62192 .16308 L
.62492 .16032 L
.63039 .15551 L
.6325 .15354 L
.63524 .14794 L
Mistroke
.64007 .14326 L
.64242 .14037 L
.64764 .13439 L
.65253 .1328 L
.65521 .12962 L
.6617 .12523 L
.66278 .12436 L
.66627 .12523 L
.67035 .12783 L
.67421 .12523 L
.67792 .12387 L
.6824 .11766 L
.68549 .11564 L
.69257 .11008 L
.69306 .10959 L
Mfstroke
.8 g
.66476 .01923 m
.66278 .02063 L
.6571 .0268 L
.65521 .02965 L
.65008 .03437 L
.64764 .03708 L
.64007 .04124 L
.63908 .04194 L
.6325 .04579 L
.63032 .04952 L
.62492 .05647 L
.62454 .05709 L
.61808 .06466 L
.61735 .06542 L
.61095 .07223 L
.60978 .07296 L
.60221 .07772 L
.60043 .0798 L
.59464 .08665 L
.59386 .08737 L
.58707 .09153 L
.58337 .09494 L
.5795 .09689 L
.57327 .09494 L
.57193 .09356 L
.56653 .08737 L
.56435 .0838 L
.55903 .0798 L
.55812 .07223 L
.55758 .06466 L
.55748 .05709 L
.55804 .04952 L
.55915 .04194 L
.56345 .03437 L
.56345 .0268 L
.56435 .02032 L
.56475 .01923 L
F
0 g
.66476 .01923 m
.66278 .02063 L
.6571 .0268 L
.65521 .02965 L
.65008 .03437 L
.64764 .03708 L
.64007 .04124 L
.63908 .04194 L
.6325 .04579 L
.63032 .04952 L
.62492 .05647 L
.62454 .05709 L
.61808 .06466 L
.61735 .06542 L
.61095 .07223 L
.60978 .07296 L
.60221 .07772 L
.60043 .0798 L
.59464 .08665 L
.59386 .08737 L
.58707 .09153 L
.58337 .09494 L
.5795 .09689 L
.57327 .09494 L
.57193 .09356 L
.56653 .08737 L
.56435 .0838 L
.55903 .0798 L
.55812 .07223 L
.55758 .06466 L
.55748 .05709 L
.55804 .04952 L
.55915 .04194 L
.56345 .03437 L
.56345 .0268 L
.56435 .02032 L
.56475 .01923 L
s
.7 g
.98077 .71136 m
.97844 .71578 L
.97337 .72335 L
.9732 .72376 L
.97059 .73092 L
.96585 .73849 L
.96563 .73875 L
.96065 .74606 L
.95806 .75053 L
.95358 .75363 L
.95048 .75989 L
.94782 .76121 L
.94458 .76878 L
.94291 .77051 L
.93689 .77635 L
.93534 .77783 L
.93008 .78392 L
.92777 .78831 L
.92346 .79149 L
.9202 .79651 L
.91815 .79906 L
.91263 .80495 L
.91107 .80663 L
.90506 .81335 L
.90422 .8142 L
.89749 .8216 L
.89729 .82177 L
.88992 .82727 L
.88775 .82935 L
.88234 .83444 L
.87997 .83692 L
.87477 .84346 L
.87361 .84449 L
.8672 .84855 L
.86244 .85206 L
.85963 .85421 L
.85219 .85963 L
.85206 .85975 L
.84449 .86633 L
.84345 .8672 L
.83692 .87192 L
.83359 .87477 L
.82935 .87788 L
.82533 .88234 L
.82177 .88376 L
.8142 .88836 L
.81211 .88992 L
.80663 .89395 L
.80142 .89749 L
.79906 .89851 L
.79149 .90243 L
.78939 .90506 L
.78392 .90727 L
.77635 .91167 L
.77494 .91263 L
.76878 .91571 L
.76121 .92015 L
.76113 .9202 L
.75363 .92344 L
.74606 .92772 L
.74603 .92777 L
.73849 .93089 L
.73092 .93476 L
.73016 .93534 L
.72335 .93781 L
.71578 .94098 L
.71328 .94291 L
.70821 .94491 L
.70064 .94782 L
.69547 .95048 L
.69306 .95208 L
.68549 .95313 L
.67792 .95502 L
.67035 .95801 L
.67029 .95806 L
.66278 .96054 L
.65521 .96246 L
.64764 .96498 L
.64623 .96563 L
.64007 .96706 L
.6325 .96825 L
.62492 .96966 L
.61735 .97125 L
.61024 .9732 L
.60978 .97328 L
.60221 .97438 L
.59464 .97585 L
.58707 .97731 L
.5795 .97799 L
.57193 .97939 L
.56435 .98016 L
.56045 .98077 L
.98077 .98077 L
F
0 g
.98077 .71136 m
.97844 .71578 L
.97337 .72335 L
.9732 .72376 L
.97059 .73092 L
.96585 .73849 L
.96563 .73875 L
.96065 .74606 L
.95806 .75053 L
.95358 .75363 L
.95048 .75989 L
.94782 .76121 L
.94458 .76878 L
.94291 .77051 L
.93689 .77635 L
.93534 .77783 L
.93008 .78392 L
.92777 .78831 L
.92346 .79149 L
.9202 .79651 L
.91815 .79906 L
.91263 .80495 L
.91107 .80663 L
.90506 .81335 L
.90422 .8142 L
.89749 .8216 L
.89729 .82177 L
.88992 .82727 L
.88775 .82935 L
.88234 .83444 L
.87997 .83692 L
.87477 .84346 L
.87361 .84449 L
.8672 .84855 L
.86244 .85206 L
.85963 .85421 L
.85219 .85963 L
.85206 .85975 L
.84449 .86633 L
.84345 .8672 L
.83692 .87192 L
.83359 .87477 L
.82935 .87788 L
.82533 .88234 L
.82177 .88376 L
.8142 .88836 L
.81211 .88992 L
.80663 .89395 L
.80142 .89749 L
.79906 .89851 L
Mistroke
.79149 .90243 L
.78939 .90506 L
.78392 .90727 L
.77635 .91167 L
.77494 .91263 L
.76878 .91571 L
.76121 .92015 L
.76113 .9202 L
.75363 .92344 L
.74606 .92772 L
.74603 .92777 L
.73849 .93089 L
.73092 .93476 L
.73016 .93534 L
.72335 .93781 L
.71578 .94098 L
.71328 .94291 L
.70821 .94491 L
.70064 .94782 L
.69547 .95048 L
.69306 .95208 L
.68549 .95313 L
.67792 .95502 L
.67035 .95801 L
.67029 .95806 L
.66278 .96054 L
.65521 .96246 L
.64764 .96498 L
.64623 .96563 L
.64007 .96706 L
.6325 .96825 L
.62492 .96966 L
.61735 .97125 L
.61024 .9732 L
.60978 .97328 L
.60221 .97438 L
.59464 .97585 L
.58707 .97731 L
.5795 .97799 L
.57193 .97939 L
.56435 .98016 L
.56045 .98077 L
Mfstroke
.1 g
.67035 .14714 m
.67792 .14727 L
.68034 .14794 L
.68549 .14908 L
.69306 .14937 L
.69957 .15551 L
.70064 .15688 L
.70821 .16228 L
.70947 .16308 L
.71465 .17065 L
.71578 .17368 L
.71636 .17823 L
.71712 .1858 L
.71822 .19337 L
.71885 .20094 L
.72228 .20851 L
.72335 .20939 L
.73092 .21024 L
.73304 .20851 L
.73092 .20126 L
.73081 .20094 L
.73092 .1992 L
.73231 .19337 L
.73372 .1858 L
.73641 .17823 L
.73849 .17556 L
.74414 .17823 L
.74524 .1858 L
.74578 .19337 L
.74606 .19417 L
.74795 .20094 L
.75363 .20658 L
.759 .20851 L
.76121 .21071 L
.76878 .21498 L
.77635 .21574 L
.77965 .21608 L
.78392 .21761 L
.78982 .22365 L
.79149 .22583 L
.79401 .23122 L
.79906 .23816 L
.79987 .23879 L
.80663 .24474 L
.80712 .24637 L
.80917 .25394 L
.8142 .25672 L
.81695 .26151 L
.8185 .26908 L
.82177 .27495 L
.82237 .27665 L
.82417 .28422 L
.82935 .29129 L
.82975 .29179 L
.8321 .29936 L
.83587 .30694 L
.83692 .30716 L
.84199 .31451 L
.84213 .32208 L
.84449 .32496 L
.84956 .32965 L
.85206 .33536 L
.85252 .33722 L
.8525 .34479 L
.85717 .35236 L
.85879 .35993 L
.85963 .36593 L
.86009 .3675 L
.86369 .37508 L
.86448 .38265 L
.86617 .39022 L
.8672 .39507 L
.86754 .39779 L
.86868 .40536 L
.86885 .41293 L
.87143 .4205 L
.87016 .42807 L
.87154 .43565 L
.87269 .44322 L
.87011 .45079 L
.87137 .45836 L
.86994 .46593 L
.86757 .4735 L
.86754 .48107 L
.8672 .48432 L
.86636 .48864 L
.86428 .49621 L
.8633 .50379 L
.86128 .51136 L
.85963 .51555 L
.85883 .51893 L
.85795 .5265 L
.85558 .53407 L
.85371 .54164 L
.85244 .54921 L
.85206 .55086 L
.85 .55678 L
.84751 .56435 L
.84715 .57193 L
.84449 .57659 L
.84199 .5795 L
.83737 .58707 L
.83692 .58781 L
.83435 .59464 L
.8329 .60221 L
.82935 .60834 L
.82615 .60978 L
.82388 .61735 L
.82177 .62019 L
.81696 .62492 L
.8142 .62822 L
.81108 .6325 L
.80663 .63677 L
.80404 .64007 L
.80136 .64764 L
.79906 .6503 L
.79396 .65521 L
.79149 .65679 L
.78808 .66278 L
.78468 .67035 L
.78392 .67104 L
.77693 .67792 L
.77635 .67868 L
.77199 .68549 L
.76878 .68871 L
.76121 .69184 L
.75955 .69306 L
.75363 .69889 L
.74927 .70064 L
.74606 .70374 L
.74179 .70821 L
.73849 .71022 L
.73092 .7148 L
.72917 .71578 L
.72335 .72007 L
.7194 .72335 L
.71578 .72666 L
.70959 .73092 L
.70821 .7315 L
.70064 .73678 L
.69829 .73849 L
.69306 .74103 L
.68549 .74518 L
.68371 .74606 L
.67792 .74854 L
.67347 .74606 L
.67035 .74438 L
.66278 .73907 L
.66202 .73849 L
.65521 .73492 L
.65072 .73092 L
.64764 .72749 L
.64638 .72335 L
.64764 .71891 L
.64938 .71578 L
.65233 .70821 L
.65521 .70082 L
.65534 .70064 L
.66001 .69306 L
.6601 .68549 L
.66003 .67792 L
.66278 .67487 L
.66494 .67035 L
.66366 .66278 L
.66531 .65521 L
.66654 .64764 L
.66823 .64007 L
.6703 .6325 L
.67035 .63217 L
.67121 .62492 L
.67254 .61735 L
.67035 .612 L
.66923 .60978 L
.66867 .60221 L
.66593 .59464 L
.66741 .58707 L
.67035 .58136 L
.67093 .5795 L
.67568 .57193 L
.67744 .56435 L
.67792 .563 L
.68222 .55678 L
.68499 .54921 L
.68549 .54845 L
.68835 .54164 L
.69306 .53464 L
.69322 .53407 L
.69597 .5265 L
.69905 .51893 L
.6989 .51136 L
.69306 .5051 L
.69073 .50379 L
.68549 .49973 L
.67792 .49934 L
.67126 .49621 L
.67035 .49583 L
.6639 .48864 L
.66314 .48107 L
.66278 .47448 L
.66267 .4735 L
.661 .46593 L
.65706 .45836 L
.65521 .45723 L
.64816 .45079 L
.65393 .44322 L
.64849 .43565 L
.64764 .43502 L
.64238 .42807 L
.64213 .4205 L
.6438 .41293 L
.64764 .40887 L
.65155 .40536 L
.65521 .40092 L
.65851 .39779 L
.66278 .39369 L
.66517 .39022 L
.66587 .38265 L
.66616 .37508 L
.66278 .36893 L
.66191 .3675 L
.65891 .35993 L
.65521 .3558 L
.64892 .35236 L
.64764 .35159 L
.64007 .346 L
.63676 .34479 L
.6325 .34379 L
.62492 .34311 L
.61735 .34301 L
.60978 .34336 L
.60221 .34277 L
.59464 .34133 L
.58707 .33929 L
.58387 .33722 L
.58148 .32965 L
.5795 .32635 L
.57845 .32208 L
.57782 .31451 L
.57193 .30825 L
.56996 .30694 L
.56435 .30058 L
.56373 .29936 L
.5624 .29179 L
.56435 .28747 L
.5647 .28422 L
.57193 .27713 L
.57239 .27665 L
.57698 .26908 L
.5795 .26756 L
.58693 .26151 L
.58707 .26135 L
.59075 .25394 L
.59464 .24693 L
.5949 .24637 L
.59464 .24268 L
.59255 .23879 L
.59154 .23122 L
.58734 .22365 L
.59464 .21701 L
.597 .21608 L
.60221 .21288 L
.60537 .20851 L
.60978 .20273 L
.61189 .20094 L
.61735 .19511 L
.61908 .19337 L
.62492 .18712 L
.62526 .1858 L
.6325 .17901 L
.63278 .17823 L
.64007 .17146 L
.64073 .17065 L
.64764 .16457 L
.64962 .16308 L
.65521 .15724 L
.65917 .15551 L
.66278 .15154 L
.66889 .14794 L
F
0 g
.67035 .14714 m
.67792 .14727 L
.68034 .14794 L
.68549 .14908 L
.69306 .14937 L
.69957 .15551 L
.70064 .15688 L
.70821 .16228 L
.70947 .16308 L
.71465 .17065 L
.71578 .17368 L
.71636 .17823 L
.71712 .1858 L
.71822 .19337 L
.71885 .20094 L
.72228 .20851 L
.72335 .20939 L
.73092 .21024 L
.73304 .20851 L
.73092 .20126 L
.73081 .20094 L
.73092 .1992 L
.73231 .19337 L
.73372 .1858 L
.73641 .17823 L
.73849 .17556 L
.74414 .17823 L
.74524 .1858 L
.74578 .19337 L
.74606 .19417 L
.74795 .20094 L
.75363 .20658 L
.759 .20851 L
.76121 .21071 L
.76878 .21498 L
.77635 .21574 L
.77965 .21608 L
.78392 .21761 L
.78982 .22365 L
.79149 .22583 L
.79401 .23122 L
.79906 .23816 L
.79987 .23879 L
.80663 .24474 L
.80712 .24637 L
.80917 .25394 L
.8142 .25672 L
.81695 .26151 L
.8185 .26908 L
.82177 .27495 L
Mistroke
.82237 .27665 L
.82417 .28422 L
.82935 .29129 L
.82975 .29179 L
.8321 .29936 L
.83587 .30694 L
.83692 .30716 L
.84199 .31451 L
.84213 .32208 L
.84449 .32496 L
.84956 .32965 L
.85206 .33536 L
.85252 .33722 L
.8525 .34479 L
.85717 .35236 L
.85879 .35993 L
.85963 .36593 L
.86009 .3675 L
.86369 .37508 L
.86448 .38265 L
.86617 .39022 L
.8672 .39507 L
.86754 .39779 L
.86868 .40536 L
.86885 .41293 L
.87143 .4205 L
.87016 .42807 L
.87154 .43565 L
.87269 .44322 L
.87011 .45079 L
.87137 .45836 L
.86994 .46593 L
.86757 .4735 L
.86754 .48107 L
.8672 .48432 L
.86636 .48864 L
.86428 .49621 L
.8633 .50379 L
.86128 .51136 L
.85963 .51555 L
.85883 .51893 L
.85795 .5265 L
.85558 .53407 L
.85371 .54164 L
.85244 .54921 L
.85206 .55086 L
.85 .55678 L
.84751 .56435 L
.84715 .57193 L
.84449 .57659 L
Mistroke
.84199 .5795 L
.83737 .58707 L
.83692 .58781 L
.83435 .59464 L
.8329 .60221 L
.82935 .60834 L
.82615 .60978 L
.82388 .61735 L
.82177 .62019 L
.81696 .62492 L
.8142 .62822 L
.81108 .6325 L
.80663 .63677 L
.80404 .64007 L
.80136 .64764 L
.79906 .6503 L
.79396 .65521 L
.79149 .65679 L
.78808 .66278 L
.78468 .67035 L
.78392 .67104 L
.77693 .67792 L
.77635 .67868 L
.77199 .68549 L
.76878 .68871 L
.76121 .69184 L
.75955 .69306 L
.75363 .69889 L
.74927 .70064 L
.74606 .70374 L
.74179 .70821 L
.73849 .71022 L
.73092 .7148 L
.72917 .71578 L
.72335 .72007 L
.7194 .72335 L
.71578 .72666 L
.70959 .73092 L
.70821 .7315 L
.70064 .73678 L
.69829 .73849 L
.69306 .74103 L
.68549 .74518 L
.68371 .74606 L
.67792 .74854 L
.67347 .74606 L
.67035 .74438 L
.66278 .73907 L
.66202 .73849 L
.65521 .73492 L
Mistroke
.65072 .73092 L
.64764 .72749 L
.64638 .72335 L
.64764 .71891 L
.64938 .71578 L
.65233 .70821 L
.65521 .70082 L
.65534 .70064 L
.66001 .69306 L
.6601 .68549 L
.66003 .67792 L
.66278 .67487 L
.66494 .67035 L
.66366 .66278 L
.66531 .65521 L
.66654 .64764 L
.66823 .64007 L
.6703 .6325 L
.67035 .63217 L
.67121 .62492 L
.67254 .61735 L
.67035 .612 L
.66923 .60978 L
.66867 .60221 L
.66593 .59464 L
.66741 .58707 L
.67035 .58136 L
.67093 .5795 L
.67568 .57193 L
.67744 .56435 L
.67792 .563 L
.68222 .55678 L
.68499 .54921 L
.68549 .54845 L
.68835 .54164 L
.69306 .53464 L
.69322 .53407 L
.69597 .5265 L
.69905 .51893 L
.6989 .51136 L
.69306 .5051 L
.69073 .50379 L
.68549 .49973 L
.67792 .49934 L
.67126 .49621 L
.67035 .49583 L
.6639 .48864 L
.66314 .48107 L
.66278 .47448 L
.66267 .4735 L
Mistroke
.661 .46593 L
.65706 .45836 L
.65521 .45723 L
.64816 .45079 L
.65393 .44322 L
.64849 .43565 L
.64764 .43502 L
.64238 .42807 L
.64213 .4205 L
.6438 .41293 L
.64764 .40887 L
.65155 .40536 L
.65521 .40092 L
.65851 .39779 L
.66278 .39369 L
.66517 .39022 L
.66587 .38265 L
.66616 .37508 L
.66278 .36893 L
.66191 .3675 L
.65891 .35993 L
.65521 .3558 L
.64892 .35236 L
.64764 .35159 L
.64007 .346 L
.63676 .34479 L
.6325 .34379 L
.62492 .34311 L
.61735 .34301 L
.60978 .34336 L
.60221 .34277 L
.59464 .34133 L
.58707 .33929 L
.58387 .33722 L
.58148 .32965 L
.5795 .32635 L
.57845 .32208 L
.57782 .31451 L
.57193 .30825 L
.56996 .30694 L
.56435 .30058 L
.56373 .29936 L
.5624 .29179 L
.56435 .28747 L
.5647 .28422 L
.57193 .27713 L
.57239 .27665 L
.57698 .26908 L
.5795 .26756 L
.58693 .26151 L
Mistroke
.58707 .26135 L
.59075 .25394 L
.59464 .24693 L
.5949 .24637 L
.59464 .24268 L
.59255 .23879 L
.59154 .23122 L
.58734 .22365 L
.59464 .21701 L
.597 .21608 L
.60221 .21288 L
.60537 .20851 L
.60978 .20273 L
.61189 .20094 L
.61735 .19511 L
.61908 .19337 L
.62492 .18712 L
.62526 .1858 L
.6325 .17901 L
.63278 .17823 L
.64007 .17146 L
.64073 .17065 L
.64764 .16457 L
.64962 .16308 L
.65521 .15724 L
.65917 .15551 L
.66278 .15154 L
.66889 .14794 L
.67035 .14714 L
Mfstroke
.5 g
.56435 .76271 m
.57193 .76146 L
.5795 .76256 L
.58383 .76878 L
.5795 .77345 L
.57193 .77417 L
.56435 .77075 L
.56337 .76878 L
F
0 g
.56435 .76271 m
.57193 .76146 L
.5795 .76256 L
.58383 .76878 L
.5795 .77345 L
.57193 .77417 L
.56435 .77075 L
.56337 .76878 L
.56435 .76271 L
s
.66278 .206 m
.67035 .20207 L
.67792 .20576 L
.68524 .20851 L
.68549 .20859 L
.69306 .21119 L
.70047 .21608 L
.70064 .21617 L
.70821 .21776 L
.71578 .21973 L
.72318 .22365 L
.72335 .22371 L
.73092 .22732 L
.73468 .23122 L
.73849 .2354 L
.74215 .23879 L
.74606 .23913 L
.75144 .24637 L
.75363 .25028 L
.75753 .25394 L
.76121 .25796 L
.76364 .26151 L
.76878 .26486 L
.7713 .26908 L
.77624 .27665 L
.77625 .28422 L
.77635 .28434 L
.78384 .29179 L
.78392 .29185 L
.78981 .29936 L
.79149 .30172 L
.79597 .30694 L
.79906 .31056 L
.80106 .31451 L
.80259 .32208 L
.80663 .32795 L
.81063 .32965 L
.81415 .33722 L
.81414 .34479 L
.8142 .3449 L
.81895 .35236 L
.82171 .35993 L
.82177 .3602 L
.82328 .3675 L
.82929 .37508 L
.82739 .38265 L
.82928 .39022 L
.82935 .39048 L
.83122 .39779 L
.83335 .40536 L
.83433 .41293 L
.83685 .4205 L
.83503 .42807 L
.83503 .43565 L
.83685 .44322 L
.83503 .45079 L
.83692 .45448 L
.83872 .45836 L
.83692 .46266 L
.83503 .46593 L
.83299 .4735 L
.83314 .48107 L
.83122 .48864 L
.82935 .49596 L
.82929 .49621 L
.82759 .50379 L
.8242 .51136 L
.82382 .51893 L
.82177 .52259 L
.81982 .5265 L
.8192 .53407 L
.81608 .54164 L
.8142 .54606 L
.81275 .54921 L
.80968 .55678 L
.80663 .56416 L
.80656 .56435 L
.80462 .57193 L
.79906 .57944 L
.79901 .5795 L
.79521 .58707 L
.79149 .59203 L
.78756 .59464 L
.78392 .59804 L
.78179 .60221 L
.77635 .60969 L
.77626 .60978 L
.7725 .61735 L
.76878 .62379 L
.76618 .62492 L
.76121 .63236 L
.76112 .6325 L
.75363 .63996 L
.75354 .64007 L
.74606 .64755 L
.74601 .64764 L
.74124 .65521 L
.73849 .6574 L
.73367 .66278 L
.73092 .66561 L
.72586 .67035 L
.72335 .67271 L
.71578 .67784 L
.7157 .67792 L
.70821 .68314 L
.70498 .68549 L
.70064 .68832 L
.69306 .68793 L
.68549 .693 L
.67792 .69288 L
.67783 .69306 L
.67035 .70052 L
.66472 .69306 L
.66451 .68549 L
.66672 .67792 L
.66919 .67035 L
.66818 .66278 L
.66885 .65521 L
.66973 .64764 L
.67035 .64331 L
.67324 .64007 L
.6747 .6325 L
.67526 .62492 L
.67638 .61735 L
.67414 .60978 L
.67409 .60221 L
.67098 .59464 L
.67341 .58707 L
.67559 .5795 L
.67792 .57655 L
.68211 .57193 L
.68273 .56435 L
.68549 .5598 L
.68814 .55678 L
.69031 .54921 L
.69306 .54485 L
.69579 .54164 L
.69789 .53407 L
.70064 .52947 L
.70324 .5265 L
.70503 .51893 L
.70504 .51136 L
.70179 .50379 L
.70064 .5026 L
.69306 .49912 L
.68551 .49621 L
.68549 .4962 L
.67792 .49346 L
.67035 .49029 L
.66898 .48864 L
.66778 .48107 L
.66749 .4735 L
.66716 .46593 L
.66602 .45836 L
.66278 .45472 L
.6588 .45079 L
.65984 .44322 L
.65692 .43565 L
.65521 .43386 L
.64928 .42807 L
.64867 .4205 L
.65145 .41293 L
.65521 .40867 L
.65839 .40536 L
.66278 .40117 L
.66643 .39779 L
.67035 .39333 L
.67275 .39022 L
.67315 .38265 L
.67366 .37508 L
.67035 .36846 L
.66949 .3675 L
.66645 .35993 L
.66278 .35285 L
.66237 .35236 L
.65521 .34624 L
.65308 .34479 L
.64764 .34181 L
.64412 .33722 L
.64007 .33611 L
.6325 .33533 L
.62492 .33511 L
.61735 .33477 L
.60978 .33463 L
.60221 .33371 L
.59464 .33163 L
.59186 .32965 L
.58707 .3254 L
.58519 .32208 L
.58465 .31451 L
.58094 .30694 L
.5795 .30524 L
.5731 .29936 L
.57193 .29783 L
.57029 .29179 L
.57193 .2869 L
.57449 .28422 L
.5795 .27908 L
.58116 .27665 L
.58707 .26998 L
.59464 .26913 L
.60221 .26913 L
.6024 .26908 L
.60978 .26168 L
.60985 .26151 L
.61194 .25394 L
.61735 .24945 L
.61905 .24637 L
.61969 .23879 L
.62492 .23133 L
.62523 .23122 L
.6325 .22388 L
.63262 .22365 L
.64007 .21765 L
.64396 .21608 L
.64764 .21505 L
.65521 .20861 L
.6554 .20851 L
F
.66278 .206 m
.67035 .20207 L
.67792 .20576 L
.68524 .20851 L
.68549 .20859 L
.69306 .21119 L
.70047 .21608 L
.70064 .21617 L
.70821 .21776 L
.71578 .21973 L
.72318 .22365 L
.72335 .22371 L
.73092 .22732 L
.73468 .23122 L
.73849 .2354 L
.74215 .23879 L
.74606 .23913 L
.75144 .24637 L
.75363 .25028 L
.75753 .25394 L
.76121 .25796 L
.76364 .26151 L
.76878 .26486 L
.7713 .26908 L
.77624 .27665 L
.77625 .28422 L
.77635 .28434 L
.78384 .29179 L
.78392 .29185 L
.78981 .29936 L
.79149 .30172 L
.79597 .30694 L
.79906 .31056 L
.80106 .31451 L
.80259 .32208 L
.80663 .32795 L
.81063 .32965 L
.81415 .33722 L
.81414 .34479 L
.8142 .3449 L
.81895 .35236 L
.82171 .35993 L
.82177 .3602 L
.82328 .3675 L
.82929 .37508 L
.82739 .38265 L
.82928 .39022 L
.82935 .39048 L
.83122 .39779 L
.83335 .40536 L
Mistroke
.83433 .41293 L
.83685 .4205 L
.83503 .42807 L
.83503 .43565 L
.83685 .44322 L
.83503 .45079 L
.83692 .45448 L
.83872 .45836 L
.83692 .46266 L
.83503 .46593 L
.83299 .4735 L
.83314 .48107 L
.83122 .48864 L
.82935 .49596 L
.82929 .49621 L
.82759 .50379 L
.8242 .51136 L
.82382 .51893 L
.82177 .52259 L
.81982 .5265 L
.8192 .53407 L
.81608 .54164 L
.8142 .54606 L
.81275 .54921 L
.80968 .55678 L
.80663 .56416 L
.80656 .56435 L
.80462 .57193 L
.79906 .57944 L
.79901 .5795 L
.79521 .58707 L
.79149 .59203 L
.78756 .59464 L
.78392 .59804 L
.78179 .60221 L
.77635 .60969 L
.77626 .60978 L
.7725 .61735 L
.76878 .62379 L
.76618 .62492 L
.76121 .63236 L
.76112 .6325 L
.75363 .63996 L
.75354 .64007 L
.74606 .64755 L
.74601 .64764 L
.74124 .65521 L
.73849 .6574 L
.73367 .66278 L
.73092 .66561 L
Mistroke
.72586 .67035 L
.72335 .67271 L
.71578 .67784 L
.7157 .67792 L
.70821 .68314 L
.70498 .68549 L
.70064 .68832 L
.69306 .68793 L
.68549 .693 L
.67792 .69288 L
.67783 .69306 L
.67035 .70052 L
.66472 .69306 L
.66451 .68549 L
.66672 .67792 L
.66919 .67035 L
.66818 .66278 L
.66885 .65521 L
.66973 .64764 L
.67035 .64331 L
.67324 .64007 L
.6747 .6325 L
.67526 .62492 L
.67638 .61735 L
.67414 .60978 L
.67409 .60221 L
.67098 .59464 L
.67341 .58707 L
.67559 .5795 L
.67792 .57655 L
.68211 .57193 L
.68273 .56435 L
.68549 .5598 L
.68814 .55678 L
.69031 .54921 L
.69306 .54485 L
.69579 .54164 L
.69789 .53407 L
.70064 .52947 L
.70324 .5265 L
.70503 .51893 L
.70504 .51136 L
.70179 .50379 L
.70064 .5026 L
.69306 .49912 L
.68551 .49621 L
.68549 .4962 L
.67792 .49346 L
.67035 .49029 L
.66898 .48864 L
Mistroke
.66778 .48107 L
.66749 .4735 L
.66716 .46593 L
.66602 .45836 L
.66278 .45472 L
.6588 .45079 L
.65984 .44322 L
.65692 .43565 L
.65521 .43386 L
.64928 .42807 L
.64867 .4205 L
.65145 .41293 L
.65521 .40867 L
.65839 .40536 L
.66278 .40117 L
.66643 .39779 L
.67035 .39333 L
.67275 .39022 L
.67315 .38265 L
.67366 .37508 L
.67035 .36846 L
.66949 .3675 L
.66645 .35993 L
.66278 .35285 L
.66237 .35236 L
.65521 .34624 L
.65308 .34479 L
.64764 .34181 L
.64412 .33722 L
.64007 .33611 L
.6325 .33533 L
.62492 .33511 L
.61735 .33477 L
.60978 .33463 L
.60221 .33371 L
.59464 .33163 L
.59186 .32965 L
.58707 .3254 L
.58519 .32208 L
.58465 .31451 L
.58094 .30694 L
.5795 .30524 L
.5731 .29936 L
.57193 .29783 L
.57029 .29179 L
.57193 .2869 L
.57449 .28422 L
.5795 .27908 L
.58116 .27665 L
.58707 .26998 L
Mistroke
.59464 .26913 L
.60221 .26913 L
.6024 .26908 L
.60978 .26168 L
.60985 .26151 L
.61194 .25394 L
.61735 .24945 L
.61905 .24637 L
.61969 .23879 L
.62492 .23133 L
.62523 .23122 L
.6325 .22388 L
.63262 .22365 L
.64007 .21765 L
.64396 .21608 L
.64764 .21505 L
.65521 .20861 L
.6554 .20851 L
.66278 .206 L
Mfstroke
.9 g
.59107 .01923 m
.58707 .02231 L
.58442 .0268 L
.5795 .03253 L
.57248 .0268 L
.57193 .02218 L
.57181 .01923 L
F
0 g
.59107 .01923 m
.58707 .02231 L
.58442 .0268 L
.5795 .03253 L
.57248 .0268 L
.57193 .02218 L
.57181 .01923 L
s
.6 g
.98077 .71444 m
.98002 .71578 L
.97565 .72335 L
.9732 .72955 L
.97265 .73092 L
.96859 .73849 L
.96563 .74221 L
.96288 .74606 L
.95806 .75275 L
.95573 .75363 L
.95048 .76108 L
.95006 .76121 L
.94764 .76878 L
.94291 .77353 L
.94005 .77635 L
.93534 .78101 L
.93242 .78392 L
.92777 .79064 L
.92585 .79149 L
.92088 .79906 L
.9202 .79985 L
.91394 .80663 L
.91263 .80804 L
.90746 .8142 L
.90506 .81667 L
.90081 .82177 L
.89749 .82488 L
.89079 .82935 L
.88992 .83018 L
.88297 .83692 L
.88234 .83763 L
.87699 .84449 L
.87477 .8465 L
.8672 .8509 L
.86567 .85206 L
.85963 .85676 L
.85617 .85963 L
.85206 .8635 L
.8473 .8672 L
.84449 .86971 L
.83692 .87477 L
.83692 .87477 L
.82935 .88036 L
.82862 .88234 L
.82177 .88608 L
.81639 .88992 L
.8142 .89169 L
.80663 .89697 L
.80596 .89749 L
.79906 .90094 L
.79182 .90506 L
.79149 .90528 L
.78392 .90971 L
.77929 .91263 L
.77635 .91488 L
.76878 .91816 L
.76582 .9202 L
.76121 .92371 L
.75363 .926 L
.7509 .92777 L
.74606 .93121 L
.73849 .93347 L
.73517 .93534 L
.73092 .93808 L
.72335 .94029 L
.71768 .94291 L
.71578 .94402 L
.70821 .94739 L
.70064 .95048 L
.70063 .95048 L
.69306 .95561 L
.68549 .95525 L
.67792 .95757 L
.67674 .95806 L
.67035 .96132 L
.66278 .96286 L
.65521 .96498 L
.6533 .96563 L
.64764 .96796 L
.64007 .96909 L
.6325 .97037 L
.62492 .97203 L
.6201 .9732 L
.61735 .97391 L
.60978 .97588 L
.60221 .97702 L
.59464 .97826 L
.58707 .97957 L
.5795 .98067 L
.57918 .98077 L
.98077 .98077 L
F
0 g
.98077 .71444 m
.98002 .71578 L
.97565 .72335 L
.9732 .72955 L
.97265 .73092 L
.96859 .73849 L
.96563 .74221 L
.96288 .74606 L
.95806 .75275 L
.95573 .75363 L
.95048 .76108 L
.95006 .76121 L
.94764 .76878 L
.94291 .77353 L
.94005 .77635 L
.93534 .78101 L
.93242 .78392 L
.92777 .79064 L
.92585 .79149 L
.92088 .79906 L
.9202 .79985 L
.91394 .80663 L
.91263 .80804 L
.90746 .8142 L
.90506 .81667 L
.90081 .82177 L
.89749 .82488 L
.89079 .82935 L
.88992 .83018 L
.88297 .83692 L
.88234 .83763 L
.87699 .84449 L
.87477 .8465 L
.8672 .8509 L
.86567 .85206 L
.85963 .85676 L
.85617 .85963 L
.85206 .8635 L
.8473 .8672 L
.84449 .86971 L
.83692 .87477 L
.83692 .87477 L
.82935 .88036 L
.82862 .88234 L
.82177 .88608 L
.81639 .88992 L
.8142 .89169 L
.80663 .89697 L
.80596 .89749 L
.79906 .90094 L
Mistroke
.79182 .90506 L
.79149 .90528 L
.78392 .90971 L
.77929 .91263 L
.77635 .91488 L
.76878 .91816 L
.76582 .9202 L
.76121 .92371 L
.75363 .926 L
.7509 .92777 L
.74606 .93121 L
.73849 .93347 L
.73517 .93534 L
.73092 .93808 L
.72335 .94029 L
.71768 .94291 L
.71578 .94402 L
.70821 .94739 L
.70064 .95048 L
.70063 .95048 L
.69306 .95561 L
.68549 .95525 L
.67792 .95757 L
.67674 .95806 L
.67035 .96132 L
.66278 .96286 L
.65521 .96498 L
.6533 .96563 L
.64764 .96796 L
.64007 .96909 L
.6325 .97037 L
.62492 .97203 L
.6201 .9732 L
.61735 .97391 L
.60978 .97588 L
.60221 .97702 L
.59464 .97826 L
.58707 .97957 L
.5795 .98067 L
.57918 .98077 L
Mfstroke
.5 g
.98077 .71702 m
.97756 .72335 L
.9745 .73092 L
.9732 .73374 L
.97062 .73849 L
.96563 .74501 L
.96483 .74606 L
.95806 .75352 L
.95763 .75363 L
.95198 .76121 L
.95048 .76492 L
.94943 .76878 L
.94291 .77517 L
.94183 .77635 L
.93534 .78317 L
.93449 .78392 L
.92792 .79149 L
.92777 .79181 L
.92337 .79906 L
.9202 .80261 L
.91643 .80663 L
.91263 .81083 L
.90997 .8142 L
.90506 .81937 L
.90321 .82177 L
.89749 .82703 L
.89352 .82935 L
.88992 .83281 L
.88578 .83692 L
.88234 .84096 L
.87974 .84449 L
.87477 .84871 L
.86854 .85206 L
.8672 .85305 L
.85963 .85903 L
.85898 .85963 L
.85206 .86592 L
.85022 .8672 L
.84449 .87221 L
.84012 .87477 L
.83692 .87729 L
.82964 .88234 L
.82935 .88253 L
.82177 .88815 L
.81956 .88992 L
.8142 .8944 L
.80957 .89749 L
.80663 .89915 L
.79906 .90303 L
.79556 .90506 L
.79149 .90778 L
.78392 .91183 L
.78269 .91263 L
.77635 .91723 L
.76899 .9202 L
.76878 .92029 L
.76121 .92591 L
.75458 .92777 L
.75363 .9282 L
.74606 .93343 L
.73932 .93534 L
.73849 .93568 L
.73092 .94038 L
.72335 .94251 L
.72247 .94291 L
.71578 .94659 L
.70821 .94948 L
.70567 .95048 L
.70064 .9525 L
.69306 .95732 L
.68549 .95717 L
.68269 .95806 L
.67792 .95983 L
.67035 .9635 L
.66278 .96488 L
.66013 .96563 L
.65521 .96688 L
.64764 .97006 L
.64007 .97091 L
.6325 .9723 L
.62869 .9732 L
.62492 .97417 L
.61735 .97618 L
.60978 .97794 L
.60221 .97908 L
.59464 .98013 L
.59053 .98077 L
.98077 .98077 L
F
0 g
.98077 .71702 m
.97756 .72335 L
.9745 .73092 L
.9732 .73374 L
.97062 .73849 L
.96563 .74501 L
.96483 .74606 L
.95806 .75352 L
.95763 .75363 L
.95198 .76121 L
.95048 .76492 L
.94943 .76878 L
.94291 .77517 L
.94183 .77635 L
.93534 .78317 L
.93449 .78392 L
.92792 .79149 L
.92777 .79181 L
.92337 .79906 L
.9202 .80261 L
.91643 .80663 L
.91263 .81083 L
.90997 .8142 L
.90506 .81937 L
.90321 .82177 L
.89749 .82703 L
.89352 .82935 L
.88992 .83281 L
.88578 .83692 L
.88234 .84096 L
.87974 .84449 L
.87477 .84871 L
.86854 .85206 L
.8672 .85305 L
.85963 .85903 L
.85898 .85963 L
.85206 .86592 L
.85022 .8672 L
.84449 .87221 L
.84012 .87477 L
.83692 .87729 L
.82964 .88234 L
.82935 .88253 L
.82177 .88815 L
.81956 .88992 L
.8142 .8944 L
.80957 .89749 L
.80663 .89915 L
.79906 .90303 L
.79556 .90506 L
Mistroke
.79149 .90778 L
.78392 .91183 L
.78269 .91263 L
.77635 .91723 L
.76899 .9202 L
.76878 .92029 L
.76121 .92591 L
.75458 .92777 L
.75363 .9282 L
.74606 .93343 L
.73932 .93534 L
.73849 .93568 L
.73092 .94038 L
.72335 .94251 L
.72247 .94291 L
.71578 .94659 L
.70821 .94948 L
.70567 .95048 L
.70064 .9525 L
.69306 .95732 L
.68549 .95717 L
.68269 .95806 L
.67792 .95983 L
.67035 .9635 L
.66278 .96488 L
.66013 .96563 L
.65521 .96688 L
.64764 .97006 L
.64007 .97091 L
.6325 .9723 L
.62869 .9732 L
.62492 .97417 L
.61735 .97618 L
.60978 .97794 L
.60221 .97908 L
.59464 .98013 L
.59053 .98077 L
Mfstroke
.4 g
.98077 .72001 m
.97925 .72335 L
.97624 .73092 L
.9732 .73674 L
.97217 .73849 L
.96648 .74606 L
.96563 .74703 L
.95926 .75363 L
.95806 .75548 L
.95373 .76121 L
.95048 .7685 L
.95041 .76878 L
.94291 .77613 L
.94275 .77635 L
.9356 .78392 L
.93534 .78492 L
.92937 .79149 L
.92777 .79527 L
.92554 .79906 L
.9202 .80484 L
.91851 .80663 L
.91263 .81326 L
.91191 .8142 L
.90506 .82151 L
.90487 .82177 L
.89749 .82845 L
.89584 .82935 L
.88992 .83518 L
.88823 .83692 L
.88234 .84399 L
.88198 .84449 L
.87477 .85024 L
.87122 .85206 L
.8672 .85512 L
.86167 .85963 L
.85963 .86108 L
.85265 .8672 L
.85206 .86732 L
.84449 .87399 L
.84301 .87477 L
.83692 .87943 L
.83265 .88234 L
.82935 .88435 L
.82208 .88992 L
.82177 .89005 L
.8142 .8965 L
.81268 .89749 L
.80663 .90073 L
.79906 .90496 L
.79889 .90506 L
.79149 .90987 L
.78619 .91263 L
.78392 .91317 L
.77635 .91888 L
.77275 .9202 L
.76878 .92193 L
.76121 .92722 L
.75882 .92777 L
.75363 .93004 L
.74606 .93482 L
.74386 .93534 L
.73849 .93744 L
.73092 .94194 L
.72723 .94291 L
.72335 .94437 L
.71578 .94867 L
.7107 .95048 L
.70821 .95123 L
.70064 .95407 L
.69306 .95792 L
.68856 .95806 L
.68549 .95847 L
.67792 .96187 L
.67035 .96493 L
.66654 .96563 L
.66278 .96659 L
.65521 .96839 L
.64764 .97151 L
.64007 .97262 L
.63711 .9732 L
.6325 .97416 L
.62492 .9762 L
.61735 .9782 L
.60978 .97967 L
.60252 .98077 L
.98077 .98077 L
F
0 g
.98077 .72001 m
.97925 .72335 L
.97624 .73092 L
.9732 .73674 L
.97217 .73849 L
.96648 .74606 L
.96563 .74703 L
.95926 .75363 L
.95806 .75548 L
.95373 .76121 L
.95048 .7685 L
.95041 .76878 L
.94291 .77613 L
.94275 .77635 L
.9356 .78392 L
.93534 .78492 L
.92937 .79149 L
.92777 .79527 L
.92554 .79906 L
.9202 .80484 L
.91851 .80663 L
.91263 .81326 L
.91191 .8142 L
.90506 .82151 L
.90487 .82177 L
.89749 .82845 L
.89584 .82935 L
.88992 .83518 L
.88823 .83692 L
.88234 .84399 L
.88198 .84449 L
.87477 .85024 L
.87122 .85206 L
.8672 .85512 L
.86167 .85963 L
.85963 .86108 L
.85265 .8672 L
.85206 .86732 L
.84449 .87399 L
.84301 .87477 L
.83692 .87943 L
.83265 .88234 L
.82935 .88435 L
.82208 .88992 L
.82177 .89005 L
.8142 .8965 L
.81268 .89749 L
.80663 .90073 L
.79906 .90496 L
.79889 .90506 L
Mistroke
.79149 .90987 L
.78619 .91263 L
.78392 .91317 L
.77635 .91888 L
.77275 .9202 L
.76878 .92193 L
.76121 .92722 L
.75882 .92777 L
.75363 .93004 L
.74606 .93482 L
.74386 .93534 L
.73849 .93744 L
.73092 .94194 L
.72723 .94291 L
.72335 .94437 L
.71578 .94867 L
.7107 .95048 L
.70821 .95123 L
.70064 .95407 L
.69306 .95792 L
.68856 .95806 L
.68549 .95847 L
.67792 .96187 L
.67035 .96493 L
.66654 .96563 L
.66278 .96659 L
.65521 .96839 L
.64764 .97151 L
.64007 .97262 L
.63711 .9732 L
.6325 .97416 L
.62492 .9762 L
.61735 .9782 L
.60978 .97967 L
.60252 .98077 L
Mfstroke
.9 g
.62242 .01923 m
.61735 .02125 L
.60978 .0248 L
.60501 .01923 L
F
0 g
.62242 .01923 m
.61735 .02125 L
.60978 .0248 L
.60501 .01923 L
s
.3 g
.98077 .72335 m
.97792 .73092 L
.97353 .73849 L
.9732 .73901 L
.96796 .74606 L
.96563 .74869 L
.96082 .75363 L
.95806 .75799 L
.95554 .76121 L
.95187 .76878 L
.95048 .77028 L
.94407 .77635 L
.94291 .77699 L
.93622 .78392 L
.93534 .78673 L
.9309 .79149 L
.92777 .79866 L
.92753 .79906 L
.92035 .80663 L
.9202 .8068 L
.91365 .8142 L
.91263 .8153 L
.90658 .82177 L
.90506 .8232 L
.89787 .82935 L
.89749 .82972 L
.89039 .83692 L
.88992 .83727 L
.88322 .84449 L
.88234 .84584 L
.87477 .85149 L
.8737 .85206 L
.8672 .8572 L
.86435 .85963 L
.85963 .86315 L
.85517 .8672 L
.85206 .86778 L
.84491 .87477 L
.84449 .87554 L
.83692 .88139 L
.83554 .88234 L
.82935 .88623 L
.8248 .88992 L
.82177 .89142 L
.81519 .89749 L
.8142 .89826 L
.80663 .90215 L
.80189 .90506 L
.79906 .90665 L
.79149 .91177 L
.78989 .91263 L
.78392 .91418 L
.77635 .9202 L
.77635 .9202 L
.76878 .92363 L
.76266 .92777 L
.76121 .92847 L
.75363 .93189 L
.74801 .93534 L
.74606 .93617 L
.73849 .93923 L
.73183 .94291 L
.73092 .94328 L
.72335 .94625 L
.71578 .95048 L
.71578 .95049 L
.70821 .95275 L
.70064 .95556 L
.69414 .95806 L
.69306 .95841 L
.68549 .95947 L
.67792 .96384 L
.67267 .96563 L
.67035 .96625 L
.66278 .96815 L
.65521 .9699 L
.64764 .97269 L
.64489 .9732 L
.64007 .9743 L
.6325 .97601 L
.62492 .97819 L
.61735 .98005 L
.61295 .98077 L
.98077 .98077 L
F
0 g
.98077 .72335 m
.97792 .73092 L
.97353 .73849 L
.9732 .73901 L
.96796 .74606 L
.96563 .74869 L
.96082 .75363 L
.95806 .75799 L
.95554 .76121 L
.95187 .76878 L
.95048 .77028 L
.94407 .77635 L
.94291 .77699 L
.93622 .78392 L
.93534 .78673 L
.9309 .79149 L
.92777 .79866 L
.92753 .79906 L
.92035 .80663 L
.9202 .8068 L
.91365 .8142 L
.91263 .8153 L
.90658 .82177 L
.90506 .8232 L
.89787 .82935 L
.89749 .82972 L
.89039 .83692 L
.88992 .83727 L
.88322 .84449 L
.88234 .84584 L
.87477 .85149 L
.8737 .85206 L
.8672 .8572 L
.86435 .85963 L
.85963 .86315 L
.85517 .8672 L
.85206 .86778 L
.84491 .87477 L
.84449 .87554 L
.83692 .88139 L
.83554 .88234 L
.82935 .88623 L
.8248 .88992 L
.82177 .89142 L
.81519 .89749 L
.8142 .89826 L
.80663 .90215 L
.80189 .90506 L
.79906 .90665 L
.79149 .91177 L
Mistroke
.78989 .91263 L
.78392 .91418 L
.77635 .9202 L
.77635 .9202 L
.76878 .92363 L
.76266 .92777 L
.76121 .92847 L
.75363 .93189 L
.74801 .93534 L
.74606 .93617 L
.73849 .93923 L
.73183 .94291 L
.73092 .94328 L
.72335 .94625 L
.71578 .95048 L
.71578 .95049 L
.70821 .95275 L
.70064 .95556 L
.69414 .95806 L
.69306 .95841 L
.68549 .95947 L
.67792 .96384 L
.67267 .96563 L
.67035 .96625 L
.66278 .96815 L
.65521 .9699 L
.64764 .97269 L
.64489 .9732 L
.64007 .9743 L
.6325 .97601 L
.62492 .97819 L
.61735 .98005 L
.61295 .98077 L
Mfstroke
.2 g
.98077 .72769 m
.97957 .73092 L
.97494 .73849 L
.9732 .74109 L
.96947 .74606 L
.96563 .75035 L
.96241 .75363 L
.95806 .76067 L
.95761 .76121 L
.9534 .76878 L
.95048 .77185 L
.94565 .77635 L
.94291 .77855 L
.93764 .78392 L
.93534 .78891 L
.93289 .79149 L
.92944 .79906 L
.92777 .80085 L
.92217 .80663 L
.9202 .80879 L
.91544 .8142 L
.91263 .81721 L
.90836 .82177 L
.90506 .82483 L
.89975 .82935 L
.89749 .83156 L
.89228 .83692 L
.88992 .83908 L
.88475 .84449 L
.88234 .84743 L
.87594 .85206 L
.87477 .85313 L
.8672 .85947 L
.86702 .85963 L
.85963 .86552 L
.85784 .8672 L
.85206 .8689 L
.84616 .87477 L
.84449 .87723 L
.83803 .88234 L
.83692 .88339 L
.82935 .88844 L
.82763 .88992 L
.82177 .89338 L
.81752 .89749 L
.8142 .89996 L
.80663 .90384 L
.80488 .90506 L
.79906 .90837 L
.79294 .91263 L
.79149 .91374 L
.78392 .91585 L
.77905 .9202 L
.77635 .92204 L
.76878 .92571 L
.76607 .92777 L
.76121 .93017 L
.75363 .93403 L
.75175 .93534 L
.74606 .93785 L
.73849 .94135 L
.73605 .94291 L
.73092 .94505 L
.72335 .94849 L
.72027 .95048 L
.71578 .95234 L
.70821 .95429 L
.70064 .95731 L
.69901 .95806 L
.69306 .96014 L
.68549 .9612 L
.67864 .96563 L
.67792 .96593 L
.67035 .96795 L
.66278 .96975 L
.65521 .97177 L
.65147 .9732 L
.64764 .97402 L
.64007 .976 L
.6325 .97794 L
.62492 .98021 L
.62269 .98077 L
.98077 .98077 L
F
0 g
.98077 .72769 m
.97957 .73092 L
.97494 .73849 L
.9732 .74109 L
.96947 .74606 L
.96563 .75035 L
.96241 .75363 L
.95806 .76067 L
.95761 .76121 L
.9534 .76878 L
.95048 .77185 L
.94565 .77635 L
.94291 .77855 L
.93764 .78392 L
.93534 .78891 L
.93289 .79149 L
.92944 .79906 L
.92777 .80085 L
.92217 .80663 L
.9202 .80879 L
.91544 .8142 L
.91263 .81721 L
.90836 .82177 L
.90506 .82483 L
.89975 .82935 L
.89749 .83156 L
.89228 .83692 L
.88992 .83908 L
.88475 .84449 L
.88234 .84743 L
.87594 .85206 L
.87477 .85313 L
.8672 .85947 L
.86702 .85963 L
.85963 .86552 L
.85784 .8672 L
.85206 .8689 L
.84616 .87477 L
.84449 .87723 L
.83803 .88234 L
.83692 .88339 L
.82935 .88844 L
.82763 .88992 L
.82177 .89338 L
.81752 .89749 L
.8142 .89996 L
.80663 .90384 L
.80488 .90506 L
.79906 .90837 L
.79294 .91263 L
Mistroke
.79149 .91374 L
.78392 .91585 L
.77905 .9202 L
.77635 .92204 L
.76878 .92571 L
.76607 .92777 L
.76121 .93017 L
.75363 .93403 L
.75175 .93534 L
.74606 .93785 L
.73849 .94135 L
.73605 .94291 L
.73092 .94505 L
.72335 .94849 L
.72027 .95048 L
.71578 .95234 L
.70821 .95429 L
.70064 .95731 L
.69901 .95806 L
.69306 .96014 L
.68549 .9612 L
.67864 .96563 L
.67792 .96593 L
.67035 .96795 L
.66278 .96975 L
.65521 .97177 L
.65147 .9732 L
.64764 .97402 L
.64007 .976 L
.6325 .97794 L
.62492 .98021 L
.62269 .98077 L
Mfstroke
.1 g
.98077 .73189 m
.97666 .73849 L
.9732 .74324 L
.97108 .74606 L
.96563 .75212 L
.96414 .75363 L
.96004 .76121 L
.95806 .76335 L
.95501 .76878 L
.95048 .77345 L
.94731 .77635 L
.94291 .78159 L
.9406 .78392 L
.93565 .79149 L
.93534 .79182 L
.93144 .79906 L
.92777 .80288 L
.92408 .80663 L
.9202 .8109 L
.91731 .8142 L
.91263 .81922 L
.91024 .82177 L
.90506 .82652 L
.90171 .82935 L
.89749 .83355 L
.89425 .83692 L
.88992 .84217 L
.88765 .84449 L
.88234 .84906 L
.87812 .85206 L
.87477 .85523 L
.86961 .85963 L
.8672 .86192 L
.86083 .8672 L
.85963 .86834 L
.85206 .8717 L
.84893 .87477 L
.84449 .87899 L
.84026 .88234 L
.83692 .88555 L
.83068 .88992 L
.82935 .89112 L
.82177 .89645 L
.82071 .89749 L
.8142 .90172 L
.80799 .90506 L
.80663 .90617 L
.79906 .91019 L
.79559 .91263 L
.79149 .91588 L
.78392 .9188 L
.78243 .9202 L
.77635 .924 L
.7696 .92777 L
.76878 .92842 L
.76121 .93197 L
.7552 .93534 L
.75363 .93662 L
.74606 .93961 L
.73986 .94291 L
.73849 .94401 L
.73092 .94693 L
.72435 .95048 L
.72335 .95127 L
.71578 .95428 L
.70821 .95592 L
.70108 .95806 L
.70064 .95963 L
.69306 .96201 L
.68549 .96421 L
.6837 .96563 L
.67792 .96822 L
.67035 .96974 L
.66278 .97146 L
.65717 .9732 L
.65521 .97432 L
.64764 .97586 L
.64007 .97777 L
.6325 .98006 L
.63041 .98077 L
.98077 .98077 L
F
0 g
.98077 .73189 m
.97666 .73849 L
.9732 .74324 L
.97108 .74606 L
.96563 .75212 L
.96414 .75363 L
.96004 .76121 L
.95806 .76335 L
.95501 .76878 L
.95048 .77345 L
.94731 .77635 L
.94291 .78159 L
.9406 .78392 L
.93565 .79149 L
.93534 .79182 L
.93144 .79906 L
.92777 .80288 L
.92408 .80663 L
.9202 .8109 L
.91731 .8142 L
.91263 .81922 L
.91024 .82177 L
.90506 .82652 L
.90171 .82935 L
.89749 .83355 L
.89425 .83692 L
.88992 .84217 L
.88765 .84449 L
.88234 .84906 L
.87812 .85206 L
.87477 .85523 L
.86961 .85963 L
.8672 .86192 L
.86083 .8672 L
.85963 .86834 L
.85206 .8717 L
.84893 .87477 L
.84449 .87899 L
.84026 .88234 L
.83692 .88555 L
.83068 .88992 L
.82935 .89112 L
.82177 .89645 L
.82071 .89749 L
.8142 .90172 L
.80799 .90506 L
.80663 .90617 L
.79906 .91019 L
.79559 .91263 L
.79149 .91588 L
Mistroke
.78392 .9188 L
.78243 .9202 L
.77635 .924 L
.7696 .92777 L
.76878 .92842 L
.76121 .93197 L
.7552 .93534 L
.75363 .93662 L
.74606 .93961 L
.73986 .94291 L
.73849 .94401 L
.73092 .94693 L
.72435 .95048 L
.72335 .95127 L
.71578 .95428 L
.70821 .95592 L
.70108 .95806 L
.70064 .95963 L
.69306 .96201 L
.68549 .96421 L
.6837 .96563 L
.67792 .96822 L
.67035 .96974 L
.66278 .97146 L
.65717 .9732 L
.65521 .97432 L
.64764 .97586 L
.64007 .97777 L
.6325 .98006 L
.63041 .98077 L
Mfstroke
.98077 .73558 m
.97896 .73849 L
.9732 .74571 L
.97294 .74606 L
.96656 .75363 L
.96563 .75463 L
.9631 .76121 L
.95806 .76642 L
.95682 .76878 L
.95048 .77519 L
.94919 .77635 L
.94486 .78392 L
.94291 .78611 L
.93912 .79149 L
.93534 .79553 L
.93371 .79906 L
.92777 .8051 L
.92624 .80663 L
.9202 .81335 L
.91947 .8142 L
.91263 .82156 L
.91242 .82177 L
.90506 .82843 L
.90395 .82935 L
.89749 .83587 L
.89649 .83692 L
.89208 .84449 L
.88992 .84684 L
.88234 .85085 L
.88058 .85206 L
.87477 .85774 L
.87256 .85963 L
.8672 .86488 L
.86435 .8672 L
.85963 .87181 L
.85385 .87477 L
.85206 .87631 L
.84449 .88097 L
.84273 .88234 L
.83692 .88806 L
.83416 .88992 L
.82935 .89452 L
.82509 .89749 L
.82177 .90048 L
.8142 .90369 L
.81148 .90506 L
.80663 .90939 L
.79906 .91233 L
.79862 .91263 L
.79149 .91837 L
.78711 .9202 L
.78392 .92276 L
.77635 .92626 L
.77351 .92777 L
.76878 .93185 L
.76121 .93401 L
.75876 .93534 L
.75363 .93987 L
.74606 .94162 L
.74355 .94291 L
.73849 .94743 L
.73092 .94907 L
.72824 .95048 L
.72335 .95472 L
.71578 .95649 L
.70821 .9578 L
.70673 .95806 L
.70064 .96271 L
.69306 .96418 L
.68913 .96563 L
.68549 .96821 L
.67792 .97095 L
.67035 .97177 L
.66376 .9732 L
.66278 .97348 L
.65521 .9779 L
.64764 .97862 L
.64007 .9797 L
.63656 .98077 L
.98077 .98077 L
F
.98077 .73558 m
.97896 .73849 L
.9732 .74571 L
.97294 .74606 L
.96656 .75363 L
.96563 .75463 L
.9631 .76121 L
.95806 .76642 L
.95682 .76878 L
.95048 .77519 L
.94919 .77635 L
.94486 .78392 L
.94291 .78611 L
.93912 .79149 L
.93534 .79553 L
.93371 .79906 L
.92777 .8051 L
.92624 .80663 L
.9202 .81335 L
.91947 .8142 L
.91263 .82156 L
.91242 .82177 L
.90506 .82843 L
.90395 .82935 L
.89749 .83587 L
.89649 .83692 L
.89208 .84449 L
.88992 .84684 L
.88234 .85085 L
.88058 .85206 L
.87477 .85774 L
.87256 .85963 L
.8672 .86488 L
.86435 .8672 L
.85963 .87181 L
.85385 .87477 L
.85206 .87631 L
.84449 .88097 L
.84273 .88234 L
.83692 .88806 L
.83416 .88992 L
.82935 .89452 L
.82509 .89749 L
.82177 .90048 L
.8142 .90369 L
.81148 .90506 L
.80663 .90939 L
.79906 .91233 L
.79862 .91263 L
.79149 .91837 L
Mistroke
.78711 .9202 L
.78392 .92276 L
.77635 .92626 L
.77351 .92777 L
.76878 .93185 L
.76121 .93401 L
.75876 .93534 L
.75363 .93987 L
.74606 .94162 L
.74355 .94291 L
.73849 .94743 L
.73092 .94907 L
.72824 .95048 L
.72335 .95472 L
.71578 .95649 L
.70821 .9578 L
.70673 .95806 L
.70064 .96271 L
.69306 .96418 L
.68913 .96563 L
.68549 .96821 L
.67792 .97095 L
.67035 .97177 L
.66376 .9732 L
.66278 .97348 L
.65521 .9779 L
.64764 .97862 L
.64007 .9797 L
.63656 .98077 L
Mfstroke
.2 g
.66278 .79588 m
.66522 .79906 L
.66278 .80126 L
.65796 .79906 L
F
0 g
.66278 .79588 m
.66522 .79906 L
.66278 .80126 L
.65796 .79906 L
.66278 .79588 L
s
.3 g
.72335 .15177 m
.73092 .15245 L
.73242 .15551 L
.73092 .15771 L
.72727 .16308 L
.72626 .17065 L
.72516 .17823 L
.72335 .18265 L
.72245 .17823 L
.72143 .17065 L
.72049 .16308 L
.72089 .15551 L
F
0 g
.72335 .15177 m
.73092 .15245 L
.73242 .15551 L
.73092 .15771 L
.72727 .16308 L
.72626 .17065 L
.72516 .17823 L
.72335 .18265 L
.72245 .17823 L
.72143 .17065 L
.72049 .16308 L
.72089 .15551 L
.72335 .15177 L
s
.3 g
.75363 .17682 m
.76121 .17091 L
.76573 .17823 L
.76121 .18257 L
.75762 .1858 L
.75669 .19337 L
.76121 .20017 L
.76226 .20094 L
.76878 .20551 L
.77635 .20127 L
.78274 .20851 L
.77635 .21004 L
.76878 .20897 L
.76757 .20851 L
.76121 .20316 L
.75401 .20094 L
.75363 .20064 L
.75129 .19337 L
.75113 .1858 L
.75259 .17823 L
F
0 g
.75363 .17682 m
.76121 .17091 L
.76573 .17823 L
.76121 .18257 L
.75762 .1858 L
.75669 .19337 L
.76121 .20017 L
.76226 .20094 L
.76878 .20551 L
.77635 .20127 L
.78274 .20851 L
.77635 .21004 L
.76878 .20897 L
.76757 .20851 L
.76121 .20316 L
.75401 .20094 L
.75363 .20064 L
.75129 .19337 L
.75113 .1858 L
.75259 .17823 L
.75363 .17682 L
s
.4 g
.76878 .12611 m
.77635 .13129 L
.77775 .1328 L
.78172 .14037 L
.78392 .14259 L
.78899 .14794 L
.79149 .15276 L
.79369 .15551 L
.79485 .16308 L
.79519 .17065 L
.79477 .17823 L
.79375 .1858 L
.79149 .19284 L
.78864 .1858 L
.78798 .17823 L
.78603 .17065 L
.78392 .16728 L
.78239 .16308 L
.78092 .15551 L
.77635 .14806 L
.77627 .14794 L
.76878 .14181 L
.76723 .14037 L
.7622 .1328 L
F
0 g
.76878 .12611 m
.77635 .13129 L
.77775 .1328 L
.78172 .14037 L
.78392 .14259 L
.78899 .14794 L
.79149 .15276 L
.79369 .15551 L
.79485 .16308 L
.79519 .17065 L
.79477 .17823 L
.79375 .1858 L
.79149 .19284 L
.78864 .1858 L
.78798 .17823 L
.78603 .17065 L
.78392 .16728 L
.78239 .16308 L
.78092 .15551 L
.77635 .14806 L
.77627 .14794 L
.76878 .14181 L
.76723 .14037 L
.7622 .1328 L
.76878 .12611 L
s
.7 g
.98077 .2893 m
.97891 .28422 L
.97868 .27665 L
.97562 .26908 L
.9732 .26365 L
.97211 .26151 L
.96882 .25394 L
.96679 .24637 L
.96563 .24391 L
.96248 .23879 L
.9592 .23122 L
.95806 .22893 L
.95597 .22365 L
.95321 .21608 L
.9505 .20851 L
.95048 .20848 L
.9455 .20094 L
.94291 .19595 L
.94185 .19337 L
.93804 .1858 L
.93534 .18179 L
.93264 .17823 L
.92777 .1774 L
.9202 .17722 L
.91898 .17823 L
.91752 .1858 L
.91678 .19337 L
.91616 .20094 L
.91583 .20851 L
.91263 .2098 L
.90882 .20851 L
.90506 .20519 L
.90087 .20094 L
.8975 .19337 L
.90506 .18915 L
.90536 .1858 L
.90506 .18307 L
.90355 .17823 L
.89749 .17392 L
.88992 .17315 L
.88234 .17822 L
.87652 .17065 L
.88234 .16778 L
.88992 .16588 L
.89678 .16308 L
.89749 .16265 L
.90442 .15551 L
.90506 .14801 L
.90506 .14794 L
.90625 .14037 L
.90507 .1328 L
.90506 .13277 L
.90005 .12523 L
.89749 .12262 L
.89139 .11766 L
.88992 .11584 L
.88614 .11008 L
.88234 .10438 L
.88123 .10251 L
.87479 .09494 L
.87477 .09492 L
.87027 .08737 L
.8672 .08337 L
.86356 .0798 L
.85963 .07496 L
.85813 .07223 L
.85208 .06466 L
.85206 .06463 L
.84647 .05709 L
.84449 .05572 L
.83693 .04952 L
.83692 .0495 L
.82937 .04194 L
.82935 .04192 L
.82482 .03437 L
.82177 .03118 L
.81584 .0268 L
.8142 .0261 L
.80827 .01923 L
.98077 .01923 L
F
0 g
.98077 .2893 m
.97891 .28422 L
.97868 .27665 L
.97562 .26908 L
.9732 .26365 L
.97211 .26151 L
.96882 .25394 L
.96679 .24637 L
.96563 .24391 L
.96248 .23879 L
.9592 .23122 L
.95806 .22893 L
.95597 .22365 L
.95321 .21608 L
.9505 .20851 L
.95048 .20848 L
.9455 .20094 L
.94291 .19595 L
.94185 .19337 L
.93804 .1858 L
.93534 .18179 L
.93264 .17823 L
.92777 .1774 L
.9202 .17722 L
.91898 .17823 L
.91752 .1858 L
.91678 .19337 L
.91616 .20094 L
.91583 .20851 L
.91263 .2098 L
.90882 .20851 L
.90506 .20519 L
.90087 .20094 L
.8975 .19337 L
.90506 .18915 L
.90536 .1858 L
.90506 .18307 L
.90355 .17823 L
.89749 .17392 L
.88992 .17315 L
.88234 .17822 L
.87652 .17065 L
.88234 .16778 L
.88992 .16588 L
.89678 .16308 L
.89749 .16265 L
.90442 .15551 L
.90506 .14801 L
.90506 .14794 L
.90625 .14037 L
Mistroke
.90507 .1328 L
.90506 .13277 L
.90005 .12523 L
.89749 .12262 L
.89139 .11766 L
.88992 .11584 L
.88614 .11008 L
.88234 .10438 L
.88123 .10251 L
.87479 .09494 L
.87477 .09492 L
.87027 .08737 L
.8672 .08337 L
.86356 .0798 L
.85963 .07496 L
.85813 .07223 L
.85208 .06466 L
.85206 .06463 L
.84647 .05709 L
.84449 .05572 L
.83693 .04952 L
.83692 .0495 L
.82937 .04194 L
.82935 .04192 L
.82482 .03437 L
.82177 .03118 L
.81584 .0268 L
.8142 .0261 L
.80827 .01923 L
Mfstroke
.4 g
.82935 .15821 m
.83692 .15796 L
.84149 .16308 L
.843 .17065 L
.83692 .17611 L
.82935 .17667 L
.82254 .17065 L
.82292 .16308 L
F
0 g
.82935 .15821 m
.83692 .15796 L
.84149 .16308 L
.843 .17065 L
.83692 .17611 L
.82935 .17667 L
.82254 .17065 L
.82292 .16308 L
.82935 .15821 L
s
.6 g
.83692 .14636 m
.84449 .14583 L
.84894 .14794 L
.85206 .14966 L
.8567 .15551 L
.85604 .16308 L
.85387 .17065 L
.85206 .17316 L
.84953 .17065 L
.84758 .16308 L
.84449 .15666 L
.84368 .15551 L
.83692 .15 L
.83375 .14794 L
F
0 g
.83692 .14636 m
.84449 .14583 L
.84894 .14794 L
.85206 .14966 L
.8567 .15551 L
.85604 .16308 L
.85387 .17065 L
.85206 .17316 L
.84953 .17065 L
.84758 .16308 L
.84449 .15666 L
.84368 .15551 L
.83692 .15 L
.83375 .14794 L
.83692 .14636 L
s
.8 g
.98077 .22022 m
.97903 .21608 L
.9766 .20851 L
.9732 .20185 L
.97219 .20094 L
.96726 .19337 L
.96563 .19026 L
.96379 .1858 L
.96168 .17823 L
.95844 .17065 L
.95806 .17007 L
.9546 .16308 L
.95195 .15551 L
.95048 .15266 L
.9472 .14794 L
.94291 .14544 L
.93996 .14037 L
.9379 .1328 L
.93534 .12784 L
.932 .12523 L
.92777 .12186 L
.92368 .11766 L
.9202 .11263 L
.91812 .11008 L
.91263 .10349 L
.91191 .10251 L
.90647 .09494 L
.90506 .09139 L
.90298 .08737 L
.89749 .08414 L
.89398 .0798 L
.89162 .07223 L
.88992 .06941 L
.88457 .06466 L
.88234 .0611 L
.87889 .05709 L
.87477 .05287 L
.87132 .04952 L
.8672 .04561 L
.86375 .04194 L
.85997 .03437 L
.85963 .03375 L
.85206 .02724 L
.85109 .0268 L
.84449 .02053 L
.84354 .01923 L
.98077 .01923 L
F
0 g
.98077 .22022 m
.97903 .21608 L
.9766 .20851 L
.9732 .20185 L
.97219 .20094 L
.96726 .19337 L
.96563 .19026 L
.96379 .1858 L
.96168 .17823 L
.95844 .17065 L
.95806 .17007 L
.9546 .16308 L
.95195 .15551 L
.95048 .15266 L
.9472 .14794 L
.94291 .14544 L
.93996 .14037 L
.9379 .1328 L
.93534 .12784 L
.932 .12523 L
.92777 .12186 L
.92368 .11766 L
.9202 .11263 L
.91812 .11008 L
.91263 .10349 L
.91191 .10251 L
.90647 .09494 L
.90506 .09139 L
.90298 .08737 L
.89749 .08414 L
.89398 .0798 L
.89162 .07223 L
.88992 .06941 L
.88457 .06466 L
.88234 .0611 L
.87889 .05709 L
.87477 .05287 L
.87132 .04952 L
.8672 .04561 L
.86375 .04194 L
.85997 .03437 L
.85963 .03375 L
.85206 .02724 L
.85109 .0268 L
.84449 .02053 L
.84354 .01923 L
s
.9 g
.98077 .1749 m
.97936 .17065 L
.9758 .16308 L
.97354 .15551 L
.9732 .15475 L
.96918 .14794 L
.96563 .14292 L
.96376 .14037 L
.96131 .1328 L
.95806 .12615 L
.95725 .12523 L
.95079 .11766 L
.95048 .11703 L
.94579 .11008 L
.94291 .10519 L
.94134 .10251 L
.93659 .09494 L
.93534 .09027 L
.93344 .08737 L
.92777 .08078 L
.9266 .0798 L
.92257 .07223 L
.9202 .06749 L
.91843 .06466 L
.91263 .05829 L
.91168 .05709 L
.90506 .04975 L
.90479 .04952 L
.89925 .04194 L
.89749 .03887 L
.89376 .03437 L
.88992 .03011 L
.88606 .0268 L
.88234 .02438 L
.87906 .01923 L
.98077 .01923 L
F
0 g
.98077 .1749 m
.97936 .17065 L
.9758 .16308 L
.97354 .15551 L
.9732 .15475 L
.96918 .14794 L
.96563 .14292 L
.96376 .14037 L
.96131 .1328 L
.95806 .12615 L
.95725 .12523 L
.95079 .11766 L
.95048 .11703 L
.94579 .11008 L
.94291 .10519 L
.94134 .10251 L
.93659 .09494 L
.93534 .09027 L
.93344 .08737 L
.92777 .08078 L
.9266 .0798 L
.92257 .07223 L
.9202 .06749 L
.91843 .06466 L
.91263 .05829 L
.91168 .05709 L
.90506 .04975 L
.90479 .04952 L
.89925 .04194 L
.89749 .03887 L
.89376 .03437 L
.88992 .03011 L
.88606 .0268 L
.88234 .02438 L
.87906 .01923 L
s
.6 g
.88992 .74433 m
.89194 .74606 L
.88992 .74804 L
.88869 .74606 L
F
0 g
.88992 .74433 m
.89194 .74606 L
.88992 .74804 L
.88869 .74606 L
.88992 .74433 L
s
1 g
.90498 .01923 m
.90506 .01931 L
.91028 .0268 L
.91263 .02963 L
.91633 .03437 L
.91263 .04188 L
.90844 .03437 L
.90506 .02988 L
.89978 .0268 L
.89749 .02569 L
.89442 .01923 L
F
0 g
.90498 .01923 m
.90506 .01931 L
.91028 .0268 L
.91263 .02963 L
.91633 .03437 L
.91263 .04188 L
.90844 .03437 L
.90506 .02988 L
.89978 .0268 L
.89749 .02569 L
.89442 .01923 L
s
.8 g
.91263 .15139 m
.91463 .15551 L
.918 .16308 L
.9202 .16489 L
.92777 .16575 L
.92845 .17065 L
.92777 .1712 L
.9202 .17147 L
.91263 .1751 L
.90806 .17065 L
.90753 .16308 L
.91043 .15551 L
F
0 g
.91263 .15139 m
.91463 .15551 L
.918 .16308 L
.9202 .16489 L
.92777 .16575 L
.92845 .17065 L
.92777 .1712 L
.9202 .17147 L
.91263 .1751 L
.90806 .17065 L
.90753 .16308 L
.91043 .15551 L
.91263 .15139 L
s
.8 g
.98077 .09987 m
.97749 .09494 L
.9759 .08737 L
.9732 .08535 L
.9682 .0798 L
.96563 .07266 L
.9653 .07223 L
.95983 .06466 L
.95806 .0621 L
.95359 .05709 L
.95048 .05345 L
.94687 .04952 L
.94291 .04482 L
.94063 .04194 L
.93729 .03437 L
.93534 .0326 L
.92924 .0268 L
.92777 .02458 L
.92266 .01923 L
.98077 .01923 L
F
0 g
.98077 .09987 m
.97749 .09494 L
.9759 .08737 L
.9732 .08535 L
.9682 .0798 L
.96563 .07266 L
.9653 .07223 L
.95983 .06466 L
.95806 .0621 L
.95359 .05709 L
.95048 .05345 L
.94687 .04952 L
.94291 .04482 L
.94063 .04194 L
.93729 .03437 L
.93534 .0326 L
.92924 .0268 L
.92777 .02458 L
.92266 .01923 L
s
.7 g
.98077 .09539 m
.98054 .09494 L
.9787 .08737 L
.9732 .08224 L
.97119 .0798 L
.96848 .07223 L
.96563 .06692 L
.96279 .06466 L
.95806 .0582 L
.95705 .05709 L
.95058 .04952 L
.95048 .04942 L
.94496 .04194 L
.94291 .03874 L
.94047 .03437 L
.93534 .02953 L
.93258 .0268 L
.92777 .02065 L
.92623 .01923 L
.98077 .01923 L
F
0 g
.98077 .09539 m
.98054 .09494 L
.9787 .08737 L
.9732 .08224 L
.97119 .0798 L
.96848 .07223 L
.96563 .06692 L
.96279 .06466 L
.95806 .0582 L
.95705 .05709 L
.95058 .04952 L
.95048 .04942 L
.94496 .04194 L
.94291 .03874 L
.94047 .03437 L
.93534 .02953 L
.93258 .0268 L
.92777 .02065 L
.92623 .01923 L
s
.6 g
.98077 .08777 m
.98063 .08737 L
.97368 .0798 L
.9732 .07863 L
.97092 .07223 L
.96563 .06484 L
.96525 .06466 L
.95999 .05709 L
.95806 .055 L
.95368 .04952 L
.95048 .04629 L
.94801 .04194 L
.94314 .03437 L
.94291 .03404 L
.93534 .0268 L
.93534 .0268 L
.9293 .01923 L
.98077 .01923 L
F
0 g
.98077 .08777 m
.98063 .08737 L
.97368 .0798 L
.9732 .07863 L
.97092 .07223 L
.96563 .06484 L
.96525 .06466 L
.95999 .05709 L
.95806 .055 L
.95368 .04952 L
.95048 .04629 L
.94801 .04194 L
.94314 .03437 L
.94291 .03404 L
.93534 .0268 L
.93534 .0268 L
.9293 .01923 L
s
1 g
.93534 .0572 m
.93782 .06466 L
.93534 .07213 L
.93084 .06466 L
F
0 g
.93534 .0572 m
.93782 .06466 L
.93534 .07213 L
.93084 .06466 L
.93534 .0572 L
s
.5 g
.98077 .08357 m
.97594 .0798 L
.9732 .07257 L
.97306 .07223 L
.96752 .06466 L
.96563 .0618 L
.96252 .05709 L
.95806 .05228 L
.95599 .04952 L
.95048 .04337 L
.94989 .04194 L
.94572 .03437 L
.94291 .03074 L
.93804 .0268 L
.93534 .02404 L
.93207 .01923 L
.98077 .01923 L
F
0 g
.98077 .08357 m
.97594 .0798 L
.9732 .07257 L
.97306 .07223 L
.96752 .06466 L
.96563 .0618 L
.96252 .05709 L
.95806 .05228 L
.95599 .04952 L
.95048 .04337 L
.94989 .04194 L
.94572 .03437 L
.94291 .03074 L
.93804 .0268 L
.93534 .02404 L
.93207 .01923 L
s
.4 g
.98077 .08155 m
.97808 .0798 L
.97502 .07223 L
.9732 .06869 L
.96963 .06466 L
.96563 .05859 L
.96465 .05709 L
.95806 .04992 L
.95777 .04952 L
.95119 .04194 L
.95048 .03915 L
.94808 .03437 L
.94291 .02851 L
.94052 .0268 L
.93534 .02083 L
.93449 .01923 L
.98077 .01923 L
F
0 g
.98077 .08155 m
.97808 .0798 L
.97502 .07223 L
.9732 .06869 L
.96963 .06466 L
.96563 .05859 L
.96465 .05709 L
.95806 .04992 L
.95777 .04952 L
.95119 .04194 L
.95048 .03915 L
.94808 .03437 L
.94291 .02851 L
.94052 .0268 L
.93534 .02083 L
.93449 .01923 L
s
.3 g
.98077 .08026 m
.98017 .0798 L
.97687 .07223 L
.9732 .06608 L
.9717 .06466 L
.96646 .05709 L
.96563 .05613 L
.95945 .04952 L
.95806 .04819 L
.95248 .04194 L
.95048 .03467 L
.95031 .03437 L
.94291 .02686 L
.94282 .0268 L
.93644 .01923 L
.98077 .01923 L
F
0 g
.98077 .08026 m
.98017 .0798 L
.97687 .07223 L
.9732 .06608 L
.9717 .06466 L
.96646 .05709 L
.96563 .05613 L
.95945 .04952 L
.95806 .04819 L
.95248 .04194 L
.95048 .03467 L
.95031 .03437 L
.94291 .02686 L
.94282 .0268 L
.93644 .01923 L
s
.2 g
.98077 .07737 m
.97865 .07223 L
.97387 .06466 L
.9732 .06396 L
.96814 .05709 L
.96563 .05425 L
.96116 .04952 L
.95806 .04611 L
.95431 .04194 L
.95228 .03437 L
.95048 .03243 L
.94476 .0268 L
.94291 .0253 L
.9382 .01923 L
.98077 .01923 L
F
0 g
.98077 .07737 m
.97865 .07223 L
.97387 .06466 L
.9732 .06396 L
.96814 .05709 L
.96563 .05425 L
.96116 .04952 L
.95806 .04611 L
.95431 .04194 L
.95228 .03437 L
.95048 .03243 L
.94476 .0268 L
.94291 .0253 L
.9382 .01923 L
s
.1 g
.98077 .07325 m
.98039 .07223 L
.97625 .06466 L
.9732 .06161 L
.96988 .05709 L
.96563 .05232 L
.96296 .04952 L
.95806 .04287 L
.95722 .04194 L
.95431 .03437 L
.95048 .03039 L
.94675 .0268 L
.94291 .02333 L
.94003 .01923 L
.98077 .01923 L
F
0 g
.98077 .07325 m
.98039 .07223 L
.97625 .06466 L
.9732 .06161 L
.96988 .05709 L
.96563 .05232 L
.96296 .04952 L
.95806 .04287 L
.95722 .04194 L
.95431 .03437 L
.95048 .03039 L
.94675 .0268 L
.94291 .02333 L
.94003 .01923 L
s
1 g
.94291 .07496 m
.94833 .0798 L
.94291 .08277 L
.9403 .0798 L
F
0 g
.94291 .07496 m
.94833 .0798 L
.94291 .08277 L
.9403 .0798 L
.94291 .07496 L
s
.98077 .06853 m
.97899 .06466 L
.9732 .05898 L
.97184 .05709 L
.96563 .05014 L
.96503 .04952 L
.96104 .04194 L
.95806 .03839 L
.95664 .03437 L
.95048 .02819 L
.94901 .0268 L
.94291 .02045 L
.94211 .01923 L
.98077 .01923 L
F
.98077 .06853 m
.97899 .06466 L
.9732 .05898 L
.97184 .05709 L
.96563 .05014 L
.96503 .04952 L
.96104 .04194 L
.95806 .03839 L
.95664 .03437 L
.95048 .02819 L
.94901 .0268 L
.94291 .02045 L
.94211 .01923 L
s
.7 g
.98077 .5708 m
.98005 .56435 L
.98077 .56121 L
F
0 g
.98077 .5708 m
.98005 .56435 L
.98077 .56121 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282, 282},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{-0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J00016Q000`40n007h00Ooooo6ooo003ooolK
ool00?oooa_oo`00oooo6ooo003ooolKool00?oooa_oo`00oooo6ooo000Gool2000Qool40003ool2
000Pool00`00ooooo`02ool2000Pool20004ool2000Oool20004ool2000Kool40003ool20004ool2
000Iool40002ool40003ool2000?ool001Koo`04003ooooo000Pool00`00ooooo`03ool01000oooo
o`007ooo00D00?ooooooo`0000;oo`03003ooooo01coo`04003ooooo0002ool01000ooooo`007Ooo
00@00?ooool000;oo`04003ooooo000Lool01@00oooooooo00000_oo00@00?ooool000;oo`03003o
oooo01Soo`05003oooooool00005ool01000ooooo`003_oo000Fool01000ooooo`008Ooo00<00?oo
ool00_oo00@00?ooool001coo`D000;oo`04003ooooo000Nool01000ooooo`000_oo00@00?ooool0
01goo`04003ooooo0002ool01000ooooo`007?oo00D00?ooooooo`0000;oo`04003ooooo0002ool0
0`00ooooo`0Hool00`00ooooo`02ool00`00ooooo`02ool01000ooooo`003_oo000Fool01000oooo
o`008_oo00D00?ooooooo`0000;oo`03003ooooo01[oo`04003ooooo0003ool01000ooooo`007_oo
0`000ooo00@00?ooool001koo`8000?oo`04003ooooo000Lool01@00oooooooo00000_oo00@00?oo
ool000;oo`03003ooooo01Soo`03003ooooo00?oo`05003oooooool00002ool00`00ooooo`0<ool0
01Koo`04003ooooo000Sool01000ooooo`000_oo00<00?ooool06ooo00<00?oo00000ooo00@00?oo
ool001koo`03003ooooo00?oo`04003ooooo000Mool01000ooooo`000_oo00@00?ooool001coo`05
003oooooool00002ool01000ooooo`000_oo00<00?ooool06?oo00<00?ooool01?oo00@00?ooool0
00;oo`03003ooooo00coo`005_oo00@00?ooool0023oo`04003ooooo0002ool01000ooooo`007_oo
0P000ooo00@00?ooool001koo`03003ooooo00?oo`04003ooooo000Mool01000ooooo`000_oo00@0
0?ooool001[oo`<000?oo`04003ooooo0002ool01000ooooo`006?oo0`000ooo00@00?ooool000;o
o`04003ooooo000>ool001Ooo`8002;oo`8000Coo`80023oo`03003ooooo00;oo`80023oo`<000?o
o`8001ooo`8000Coo`8001goo`03003ooooo00;oo`8000Coo`8001_oo`03003ooooo00;oo`8000Co
o`8000ooo`00oooo6ooo003ooolKool00?oooa_oo`005Oooo`001@000Ooo000>ool20005ool01000
ooooo`002Ooo00<00?ooool01_oo00<00?ooool01ooo00<00?ooool01ooo00<00?ooool01ooo00<0
0?ooool01ooo00<00?ooool01ooo00<00?ooool01_oo00<00?ooool01ooo00<00?ooool01ooo00<0
0?ooool01ooo00<00?ooool01ooo00<00?ooool01ooo00<00?ooool01_oo00<00?ooool01ooo00<0
0?ooool01ooo00<00?ooool01ooo00<00?ooool01ooo00<00?ooool01ooo00<00?ooool01_oo00<0
0?ooool01ooo00<00?ooool01ooo00<00?ooool01ooo00<00?ooool01ooo00<00?ooool01_oo00<0
0?ooool01ooo0P000Ooo000=ool01000ooooo`001?oo00@00?ooool002Koo`03003ooooo02Coo`03
003ooooo02Goo`03003ooooo02Coo`03003ooooo02Coo`03003ooooo02Goo`03003ooooo017oo`40
007oo`003Ooo00@00?ooool000Coo`800?ooo`7oo`80007oo`003Ooo00@00?ooool000Coo`03003o
oooo0?ooo`7oo`40007oo`003Ooo00@00?ooool000Coo`03003ooooo00koo`L00004ool00?oo0004
ool00`00ooooo`03ool01000ooooo`001Ooo00<00?ooool04?oo00<00?ooool02_oo00<00?ooool0
5?oo00<00?ooool00_oo00H00?ooool00?oo0002ool00`00ooooo`07ool00`00ool0000:ool00`00
ooooo`05ool00`00ool00004ool01@00oooooooo00000ooo00<00?ooool02?oo00D00?ooooooo`00
00Coo`03003ooooo00Coo`03003ooooo01?oo`03003ooooo00Koo`03003ooooo00Koo`05003ooooo
ool00002ool01000oooooooo1P003_oo0@000Ooo000=ool01000ooooo`001?oo00<00?ooool00_oo
3@0000=:J@0000000P0000CW?000ic`000CW?003003>NLii00?>N@03002eU[FF00:eUP03003>NLii
00?>N@03003W?>Ll00oW?003003>NLii00S>N@8001JeUP03002LdicC00>Ld`03001kk`00009S;004
001kkg__0009W=<00`00]IH00009cWT00`00]IJeUP06]IH00`00cWT00003ic`00`00cWW>N@03cWT0
0`00ic`0000;cWT01000]IJeUP001IcC00<007__Nnl01G__00<009cCW=<04icC00<00;FF]IH01KFF
00<00<iicWT01lii00D00>LliccW?00000;oo`04003W?>Llic`>0005ool10001ool000koo`8000Go
o`03003ooooo00;ooa<00003ool0000000CW?003003>NLii00?>N@03002eU[FF00:eUP03003>NLii
00?>N@8000gW?0<000W>N@8001ReUP03002LdicC00>Ld`03001kk`00009S;004001kkg__0009W=<0
0`00]IH00008cWT00`00]IJeUP07]IH00`00cWT00002ic`00`00cWW>N@04cWT2000:cWT20002]IH0
0`00W=>Ld`04W=<00`00Nnmkk`05Nnl00`00W=>Ld`04W=<4000;W=<20007]IH20007cWT20002ic`0
1000ooooo`001>Ll3@001Ooo0@000Ooo000Eool00`00ooooo`02ool=00000g__003>N@020002ool0
0`00iccW?002ic`00`00cWW>N@03cWT00`00]IJeUP04]IH00`00cWW>N@04cWT00`00iccW?009ic`0
0`00cWW>N@09cWT00`00]IJeUP0G]IH00`00W=>Ld`04W=<00`00Nnl00002Hb`01000Nnmkk`002IcC
00<00;FF00001lii00<00;FF]IH02;FF00<00<iicWT00P004lii00@00;FF]IH000JLd`03001kkg__
00Mkk`03002LdicC00:Ld`03001kkg__009kk`8000^Ld`03002eU[FF00JeUP03003>NLii00K>N@03
003W?>Ll00800003ool00>Ll00?W?0`000Goo`40007oo`005Ooo00<00?ooool00_oo400000GW?000
ooooo`0000CW?003003>NLii00?>N@03002eU[FF00FeUP03003>NLii00C>N@<000;W?0H000[>N@80
01ZeUP03002LdicC00BLd`8000=S;004001kkg__0009W=<00`00]IH00006cWT00`00]IJeUP09]IH0
1@00cWW>NLii00004/ii00D00;FF]IJeUP0000FLd`03001kkg__00Qkk`05002LdicCW=<00007Nnl0
0`00W=>Ld`09W=<00`00]IJeUP06]IH00`00cWW>N@06cWT01`00iccW?>Ll003oo`0000CW?0/000Go
o`40007oo`005Ooo00<00?ooool00_oo2`0000AS;000000000;W?003003oo`0000CW?003003>NLii
00?>N@03002eU[FF00JeUP03003>NLii00O>N@80013>N@03002eU[FF01ReUP03002LdicC00BLd`80
00AS;004001kkg__0009W=<00`00]IH00005cWT00`00]IJeUP09]IH00`00cWW>N@0DcWT01@00]IJe
U[FF00001IcC00<007__Nnl02W__00<009cC00002G__00<009cCW=<02IcC00<00;FF]IH01[FF00<0
0<iicWT01/ii00D00>LliccW?00000KW?0X000Goo`40007oo`005Ooo00<00?ooool00_oo4`001>Ll
00<00<iicWT00lii00<00;FF]IH01kFF00<00<iicWT05lii0P006[FF00<009cCW=<019cC00<007__
000016</00@007__Nnl000RLd`04002eU[FF0002cWT30007]IH30002]IH00`00cWW>N@0BcWT20002
]IH20004W=<2000=Nnl2000;Nnl00`00W=>Ld`08W=<00`00]IJeUP06]IH00`00cWW>N@06cWT01@00
iccW?>Ll00001^Ll2P001Ooo0@000Ooo000Eool00`00ooooo`02ool700000aS3001S;00300001>Ll
003oo`001NLl00<00<iicWT00lii00<00;FF]IH01;FF00D00;FF]IJeUP0001S>N@03002eU[FF01Ve
UP03002LdicC00FLd`03001kk`0000=S;005001kkg__Nnl00008W=<01000]IJeU[FF0P002KFF00@0
09cCW=<000:eUP03003>NLii013>N@8000BeUP03002LdicC00>Ld`03001kkg__01Ykk`03002LdicC
00RLd`03002eU[FF00JeUP03003>NLii00K>N@03003W?>Ll00SW?0T000Goo`40007oo`005Ooo0P00
0ooo3P000_oo00<00>Llic`00nLl00<00<iicWT00lii00<00;FF]IH00kFF00<009cC00000[FF00<0
0<iicWT05Lii00<00;FF]IH06[FF00<009cCW=<01IcC0P000f</00D007__Nnmkk`0000VLd`03002e
U[FF00beUP04002LdicC0002]IH00`00cWW>N@0?cWT00`00]IJeUP03]IH00`00W=>Ld`02W=<20008
Nnl00`00Nnmkk`0BNnl2000:W=<00`00]IJeUP06]IH00`00cWW>N@06cWT00`00iccW?008ic`80004
ool20001ool001Goo`03003ooooo00;oo`L00006BVT009cC003>N@000_oo00<00>Llic`00nLl00<0
0<iicWT00lii00<00;FF]IH00kFF00D009cCW=>Ld`0000:eUP03003>NLii01G>N@03002eU[FF01Ve
UP03002LdicC00BLd`03001kk`00009S;005001kkg__Nnl0000:W=<00`00]IJeUP0;]IH01`00W=>L
dicC002eUP00017>N@03002eU[FF00>eUP03002LdicC00>Ld`03001kkg__00Ekk`800003Hb`00000
00Akk`D000]kk`03002LdicC00RLd`03002eU[FF00JeUP03003>NLii00K>N@03003W?>Ll00SW?0L0
00Goo`40007oo`005Ooo00<00?ooool00_oo3@000_oo00<00>Llic`00nLl00<00<iicWT00lii00<0
0;FF]IH00kFF00<009cCW=<00YcC00<00;FF00006<ii00<00;FF]IH06;FF00<009cCW=<019cC00<0
07__00000V</00D007__Nnmkk`0000ZLd`03002eU[FF00^eUP07002LdicCW=<00;FF00004Lii00<0
0;FF]IH00kFF00<009cCW=<00YcC00<007__Nnl017__0P0016</00<007__Nnl00W__00<006</Hb`0
0V</0P002W__0P002IcC0P001kFF00<00<iicWT01Lii0P001NLl00@00>LliccW?0L000Goo`40007o
o`005Ooo00<00?ooool00_oo1@0000<aQP0000000`0000CW?000000000GW?003003>NLii00?>N@03
002eU[FF00BeUP03002LdicC00:Ld`04002eU[FF000HcWT00`00]IJeUP0F]IH00`00W=>Ld`04W=<0
1`00Nnmkkg__001S;000009kk`03002LdicC00RLd`03002eU[FF00^eUP05002LdicCW=<00003]IH0
0`00cWW>N@0=cWT00`00]IJeUP03]IH00`00W=>Ld`02W=<00`00Nnmkk`05Nnl00`00HbaS;004Hb`0
1000Nnmkk`001V</00<007__Nnl02G__00<009cCW=<02IcC00<00;FF]IH01KFF00<00<iicWT01/ii
00@00>LliccW?08000CW?0<00003Hb`0000000Goo`40007oo`005Ooo00<00?ooool00_oo300000?o
o`00ic`01>Ll00<00<iicWT01<ii00<00;FF]IH01;FF00<009cCW=<00YcC00@00;FF]IH001S>N@03
002eU[FF01JeUP03002LdicC00BLd`04001kkg__Nnl20003Nnl00`00W=>Ld`08W=<00`00]IJeUP0;
]IH01@00W=>LdicC00000kFF00<00<iicWT03<ii00<00;FF]IH00kFF00<009cCW=<00icC00<007__
Nnl00g__0P001f</0`0026</0P002W__0P002IcC00<00;FF]IH01KFF00<00<iicWT01/ii00H00>Ll
ic`00?oo0005ic`60004ool10001ool001Goo`03003ooooo00;oo`<000036<<0000000<00004ic`0
0>Ll0005ic`00`00cWW>N@04cWT00`00]IJeUP04]IH00`00W=>Ld`04W=<01000]IJeUP006<ii00<0
0;FF]IH05;FF00<009cCW=<019cC00<007__Nnl01W__00<009cCW=<02IcC00<00;FF]IH02[FF00<0
09cCW=<00YcC00D00;FF]IJeUP0000g>N@03002eU[FF00>eUP03002LdicC00>Ld`03001kkg__00Ak
k`03001S;6</019S;003001kkg__00Ukk`03002LdicC00RLd`03002eU[FF00FeUP8000O>N@03003W
?>Ll008000KW?0D000Coo`40007oo`005Ooo00<00?ooool00_oo2P0000?oo`0000001NLl00<00<ii
cWT00lii00<00;FF]IH01;FF00<009cCW=<01IcC00@00;FF]IH001S>N@03002eU[FF01:eUP<000FL
d`8000Qkk`03002LdicC00VLd`03002eU[FF00VeUP03002LdicC00>Ld`05002eU[FF]IH0000<cWT0
0`00]IJeUP03]IH00`00W=>Ld`03W=<00`00Nnmkk`03Nnl2000FHb`2000:Nnl20009W=<00`00]IJe
UP05]IH00`00cWW>N@05cWT01@00iccW?>Ll00001^Ll1@001?oo0@000Ooo000Eool00`00ooooo`02
ool700001Lii003ooooo00001NLl00<00<iicWT00lii00<00;FF]IH01;FF00<009cCW=<01YcC00D0
0;FF]IJeUP0001O>N@03002eU[FF01:eUP03002LdicC00BLd`03001kkg__00Mkk`03002LdicC00:L
d`03002LdicC00BLd`03002eU[FF00ReUP8000FLd`03002eU[FF00:eUP03003>NLii00S>N@8000Fe
UP03002LdicC00BLd`04001kkg__Nnl2000<Hb`00`00HbaS;00;Hb`00`00Nnmkk`09Nnl00`00W=>L
d`06W=<00`00]IJeUP06]IH00`00cWW>N@05cWT00`00iccW?002ic`00`00iccW?003ic`40004ool1
0001ool001Goo`03003ooooo00;oo`T00003ool00>Ll00CW?003003>NLii00C>N@03002eU[FF00>e
UP03002LdicC00NLd`05002eU[FF]IH0000GcWT00`00]IJeUP0B]IH00`00W=>Ld`04W=<00`00Nnmk
k`06Nnl00`00W=>Ld`02W=<01000Nnl0000019cC00<00;FF]IH00kFF1@001icC00<00;FF]IH00[FF
00<00<iicWT02<ii00<00;FF]IH00kFF00<009cCW=<00icC0P000g__00<006</Hb`016</00<006</
Hb`00f</0P0000=:J@0000002f</00<007__Nnl02G__00<009cCW=<01icC00<00;FF]IH01KFF00<0
0<iicWT01Lii0P000^Ll00<00?oo00001>Ll10001?oo0@000Ooo000Eool00`00ooooo`02ool50000
1Lii00000?oo00001NLl00<00<iicWT01<ii00<00;FF]IH01;FF00<009cCW=<01IcC00@009cCW=<0
00:eUP03003>NLii01K>N@03002eU[FF00neUP8000JLd`03001kkg__00Ikk`03002LdicC00:Ld`03
001kkg__009kk`05002LdicCW=<00004]IH00`00W=>Ld`0;W=<00`00]IJeUP02]IH00`00cWW>N@06
cWT00`00]IJeUP04]IH00`00W=>Ld`03W=<00`00Nnmkk`02Nnl00`00HbaS;003Hb`00`00BVT00003
Hb`00`00BVU:J@03BVT00`00HbaS;009Hb`00`00Nnmkk`09Nnl00`00W=>Ld`07W=<00`00]IJeUP05
]IH00`00cWW>N@06cWT01000iccW?0001^Ll00<00;FF00001?oo0@000Ooo000Eool20003ool60000
1>Ll003oo`001NLl00<00<iicWT00lii0P001KFF00<009cCW=<019cC0P0000Akk`00W=<000>eUP03
003>NLii01G>N@03002eU[FF00neUP03002LdicC00FLd`03001kkg__00Ikk`03002LdicC00:Ld`03
001kkg__00=kk`04002LdicC0002]IH2000>W=<00`00]IJeUP03]IH00`00cWW>N@04cWT00`00]IJe
UP05]IH00`00W=>Ld`03W=<00`00Nnmkk`02Nnl00`00HbaS;002Hb`01000BVU:J@000V</00<004YY
BVT014YY0P002f</0P002W__00<009cCW=<01icC00<00;FF]IH01KFF00<00<iicWT01Lii00<00>Ll
ic`02>Ll0P000ooo0P000Ooo000Eool00`00ooooo`02ool500001>Ll003W?0001NLl00<00<iicWT0
0lii00<00;FF]IH01;FF00<009cCW=<019cC00L007__Nnmkk`00W=<00003]IH00`00cWW>N@0EcWT0
0`00]IJeUP0>]IH00`00W=>Ld`05W=<00`00Nnmkk`04Nnl30004W=<00`00Nnmkk`03Nnl00`00W=>L
d`02W=<2000?W=<00`00]IJeUP05]IH01000cWW>NLii0P001[FF0P001IcC00<007__Nnl00W__00<0
06</Hb`00V</00<004YYBVT00TYY0P002DYY00<006</Hb`02V</00<007__Nnl027__00<009cCW=<0
1icC00<00;FF]IH01KFF00<00<iicWT01Lii00<00>Llic`02>Ll00<00?ooool00_oo0@000Ooo000E
ool00`00ooooo`02ool600000ooo003W?004ic`20004cWT20006]IH00`00W=>Ld`04W=<01`00Nnmk
kg__002Ld`0000>eUP03003>NLii01G>N@03002eU[FF00feUP8000JLd`03001kkg__00=kk`8000NL
d`03001kkg__00=kk`03002LdicC01:Ld`03002eU[FF00JeUP@000JeUP8000JLd`04001kkg__Nnl2
0004Hb`00`00BVU:J@0?BVT2000;Hb`00`00Nnmkk`07Nnl00`00W=>Ld`07W=<00`00]IJeUP05]IH0
0`00cWW>N@05cWT00`00iccW?008ic`00`00ooooo`02ool10001ool001Goo`03003ooooo00;oo`D0
0003ool00>Ll00CW?003003>NLii00?>N@03002eU[FF00FeUP03002LdicC00BLd`03001kkg__00=k
k`03002Ld`0000>eUP03003>NLii01C>N@03002eU[FF00feUP03002LdicC00BLd`03001kkg__00=k
k`03002LdicC00JLd`03001kkg__00Akk`03002LdicC016Ld`03002eU[FF012eUP03002LdicC00BL
d`8000Akk`03001S;6</009S;003001:JDYY015:J@03001S;6</00YS;003001kkg__00Mkk`03002L
dicC00NLd`03002eU[FF00FeUP03003>NLii00G>N@03003W?>Ll00OW?003003ooooo00;oo`40007o
o`005Ooo00<00?ooool00_oo1@0000?oo`00ic`01>Ll00<00<iicWT00lii00<00;FF]IH01;FF0P00
1IcC00<007__Nnl017__00<009cC00000kFF00<00<iicWT05<ii00<00;FF]IH03KFF00<009cCW=<0
19cC00<007__Nnl00W__00<009cCW=<01icC00<007__Nnl017__00<009cCW=<04IcC00<00;FF]IH0
3kFF00<009cCW=<019cC00<007__Nnl00W__0P000f</0P005DYY0P002f</00<007__Nnl01g__00<0
09cCW=<01icC00<00;FF]IH01KFF00<00<iicWT01<ii00<00>Llic`01nLl1Ooo0@000Ooo000Eool0
0`00ooooo`02ool30002ool00`00iccW?003ic`00`00cWW>N@03cWT00`00]IJeUP04]IH00`00W=>L
d`04W=<00`00Nnmkk`06Nnl00`00W=<00003]IH00`00cWW>N@0CcWT00`00]IJeUP0=]IH00`00W=>L
d`03W=<00`00Nnmkk`02Nnl00`00W=>Ld`07W=<00`00Nnmkk`04Nnl00`00W=>Ld`0AW=<00`00]IJe
UP0?]IH00`00W=>Ld`04W=<00`00Nnmkk`02Nnl00`00HbaS;002Hb`00`00BVU:J@07BVT00`00BVU:
J@0=BVT00`00HbaS;009Hb`00`00Nnmkk`07Nnl00`00W=>Ld`07W=<00`00]IJeUP05]IH00`00cWW>
N@04cWT00`00iccW?006ic`5ool10001ool001Goo`03003ooooo00;oo`<000;oo`03003W?>Ll00;W
?003003>NLii00C>N@03002eU[FF00BeUP03002LdicC00BLd`03001kkg__00Mkk`8000BeUP03003>
NLii01;>N@03002eU[FF00feUP03002LdicC00>Ld`05001kkg__Nnl00009W=<00`00Nnmkk`05Nnl0
0`00W=>Ld`0AW=<00`00]IJeUP0?]IH00`00W=>Ld`03W=<00`00Nnmkk`02Nnl00`00HbaS;002Hb`0
0`00BVU:J@06BVT200000c660000000>BVT00`00HbaS;009Hb`00`00Nnmkk`07Nnl00`00W=>Ld`06
W=<00`00]IJeUP05]IH00`00cWW>N@04cWT00`00iccW?006ic`5ool10001ool001Goo`03003ooooo
00;oo`03003W?000008000GW?003003>NLii00?>N@03002eU[FF00BeUP03002LdicC00BLd`03001k
kg__00Akk`<00004Nnl009cC0004]IH00`00cWW>N@0AcWT00`00]IJeUP0<]IH00`00W=>Ld`03W=<0
1@00Nnmkkg__00002YcC00<007__Nnl01G__00<009cCW=<04IcC00<00;FF]IH03[FF00<009cCW=<0
0icC00<007__Nnl00W__00<006</Hb`00V</00<004YYBVT01DYY0P001C660P003DYY00<006</Hb`0
2F</00<007__Nnl01g__00<009cCW=<01YcC00<00;FF]IH01KFF00<00<iicWT01<ii00<00>Llic`0
1NLl1Ooo0@000Ooo000Eool00`00ooooo`02ool200000ooo00000004ic`00`00cWW>N@03cWT00`00
]IJeUP04]IH00`00W=>Ld`05W=<00`00Nnmkk`03Nnl01P00HbaS;000Nnl000:Ld`03002eU[FF00:e
UP03003>NLii013>N@03002eU[FF00beUP03002LdicC00>Ld`04001kkg__000:W=<00`00Nnmkk`06
Nnl00`00W=>Ld`0AW=<00`00]IJeUP0>]IH00`00W=>Ld`03W=<01@00Nnmkkg__000016</00<004YY
BVT01DYY00<00366<HH01S6600<004YYBVT034YY0P002F</00<007__Nnl01g__00<009cCW=<01YcC
00<00;FF]IH01[FF00<00<iicWT01<ii00<00>Llic`01>Ll1Ooo0@000Ooo000Eool00`00ooooo`02
ool01000ooooo`001NLl00<00<iicWT00lii00<00;FF]IH00kFF00<009cCW=<01IcC00<007__Nnl0
17__00@006</HbaS;0<000:Ld`03002eU[FF00:eUP80013>N@03002eU[FF00^eUP03002LdicC00>L
d`04002Ld`00000:W=<00`00Nnmkk`07Nnl00`00W=>Ld`0AW=<00`00]IJeUP0=]IH00`00W=>Ld`02
W=<20003Nnl00`00HbaS;002Hb`00`00BVU:J@05BVT00`00<HHaQP08<HH2000=BVT20009Hb`00`00
Nnmkk`07Nnl00`00W=>Ld`06W=<20007]IH00`00cWW>N@04cWT00`00iccW?003ic`5ool10001ool0
01Goo`8000?oo`04003ooooo0005ic`00`00cWW>N@03cWT00`00]IJeUP03]IH20006W=<00`00Nnmk
k`04Nnl00`00HbaS;002Hb`00`00Nnl00002W=<00`00]IJeUP03]IH00`00cWW>N@0=cWT00`00]IJe
UP0;]IH20004W=<3000:W=<00`00Nnmkk`08Nnl00`00W=>Ld`0;W=<00`00W=>Ld`03W=<00`00]IJe
UP0=]IH00`00W=>Ld`02W=<00`00Nnmkk`02Nnl01@00HbaS;6</000014YY10003C660P0024YY00<0
04YYBVT00TYY0P0026</0P0027__00<009cCW=<01YcC00<00;FF]IH01[FF0P001<ii00<00>Llic`0
0nLl1?oo0P000Ooo000Eool00`00ooooo`02ool00`00ool00005ic`00`00cWW>N@03cWT00`00]IJe
UP03]IH00`00W=>Ld`05W=<00`00Nnmkk`04Nnl00`00HbaS;004Hb`00`00Nnl00002W=<00`00]IJe
UP03]IH00`00cWW>N@0;cWT00`00]IJeUP0:]IH2000BW=<00`00Nnmkk`08Nnl00`00W=>Ld`08W=<4
00000g__002Ld`03W=<00`00]IJeUP0<]IH01000W=>LdicC0P0017__00D006</HbaS;00000=:J@80
01<aQP03001:JDYY00A:J@04001S;0000004BVT00`00HbaS;007Hb`00`00Nnmkk`06Nnl00`00W=>L
d`06W=<00`00]IJeUP06]IH00`00cWW>N@03cWT00`00iccW?002ic`5ool10001ool001Goo`03003o
oooo00Coo`03003W?>Ll00;W?08000G>N@03002eU[FF00:eUP8000JLd`03001kkg__00Akk`03001S
;6</00IS;005001kk`00W=<00006]IH00`00cWW>N@09cWT00`00]IJeUP0;]IH00`00W=>Ld`0@W=<0
0`00Nnmkk`08Nnl00`00W=>Ld`08W=<00`00Nnmkk`03Nnl00`00W=>Ld`02W=<00`00]IJeUP0;]IH0
0`00W=>Ld`020006Nnl01P00HbaS;6</001:J@8001HaQP8000A:J@05001S;6</Hb`00004BVT00`00
HbaS;006Hb`00`00Nnmkk`07Nnl00`00W=>Ld`06W=<00`00]IJeUP05]IH00`00cWW>N@03cWT00`00
iccW?002ic`5ool10001ool001Goo`03003ooooo00?oo`03003W?>Ll00;W?003003>NLii00C>N@03
002eU[FF00:eUP03002LdicC00FLd`03001kkg__00Akk`03001S;6</00ES;008001S;6</001kk`00
W=<000JeUP03003>NLii00O>N@03002eU[FF00ZeUP8001:Ld`03001kkg__00Ukk`03002LdicC00NL
d`03001kkg__00Akk`05002LdicCW=<0000=]IH01000W=>Ld`001g__00<006</Hb`00P0000=:J@00
<HH06C6600<004YYBVT00TYY00D006</HbaS;00000A:J@03001S;6</00ES;003001kkg__00Qkk`03
002LdicC00FLd`03002eU[FF00JeUP03003>NLii00?>N@04003W?>Llic`5ool10001ool001Goo`03
003ooooo00;oo`03003W?>Ll00;W?08000G>N@03002eU[FF00>eUP03002LdicC00BLd`03001kkg__
00Ekk`03001S;6</00AS;003001:J@0000800005Nnl009cCW=<00006]IH9000;]IH2000CW=<00`00
Nnmkk`09Nnl00`00W=>Ld`07W=<00`00Nnmkk`05Nnl01@00W=>LdicC00002kFF0P000YcC0P001g__
00@006</Hb`0009:J@03000aQS6601TaQP05001:JDYYBVT00003Hb`00`00BVU:J@03BVT00`00HbaS
;003Hb`2000:Nnl00`00W=>Ld`05W=<00`00]IJeUP06]IH00`00cWW>N@03cWT01000iccW?>Ll1Ooo
0@000Ooo000Eool00`00ooooo`02ool00`00iccW?002ic`00`00cWW>N@04cWT00`00]IJeUP02]IH2
0006W=<00`00Nnmkk`04Nnl00`00HbaS;004Hb`00`00BVU:J@02BVT2000017__002LdicC0P005[FF
0P0059cC00<007__Nnl02W__00<009cCW=<01YcC00<007__Nnl01W__00D009cCW=>Ld`0000ZeUP05
002LdicCW=<00008Nnl01000HbaS;0000TYY00<00366<HH06c660P000TYY00D006</001S;00000A:
J@03001S;6</009S;003001kkg__00<000Qkk`8000FLd`03002eU[FF00NeUP03003>NLii00?>N@03
003W?>Ll00Goo`40007oo`005Ooo00<00?ooool00_oo00<00>Llic`00^Ll00<00<iicWT00lii00<0
0;FF]IH00kFF00<009cCW=<01IcC00<007__Nnl017__00<006</Hb`016</00<004YYBVT00TYY0`00
00Ekk`00002Ld`0001BeUP8001JLd`03001kkg__00Ykk`04002LdicC0004W=<00`00Nnmkk`07Nnl0
0`00W=>Ld`02W=<00`00]IJeUP06]IH20003W=<00`00Nnmkk`06Nnl01P00HbaS;000BVT000LaQPP0
014aQP800003BVT006</009S;003001:JDYY009:J@800004Hb`00000Nnl20002W=<20007Nnl00`00
W=>Ld`03W=<00`00]IJeUP08]IH00`00cWW>N@02cWT00`00iccW?005ool10001ool001Goo`03003o
oooo00;oo`CW?003003>NLii00?>N@03002eU[FF00>eUP03002LdicC00FLd`03001kkg__00Akk`03
001S;6</00AS;003001:JDYY00E:J@80009kk`04002Ld`00000A]IH00`00W=>Ld`0EW=<00`00Nnmk
k`0<Nnl200000g__00000002000:Nnl00`00W=>Ld`03W=<20005]IH00`00W=>Ld`02W=<00`00Nnmk
k`06Nnl01P00HbaS;000BVT000LaQP03000H`aS300HH``03000aQS6600@aQP<000TaQP03001:J@00
009S;003001:JDYY00=:J@8000Ekk`05002LdicCW=<00007Nnl00`00W=>Ld`02W=<00`00]IH00009
]IH00`00cWW>N@02cWT00`00iccoo`04ool10001ool000Ooo`@000?oo`8000Goo`03003ooooo00;o
o`CW?003003>NLii00?>N@03002eU[FF00>eUP03002LdicC00BLd`8000Ikk`03001S;6</00AS;003
001:JDYY00E:J@80009kk`04002LdicCW=<2000=]IH2000GW=<00`00Nnmkk`0NNnl00`00W=>Ld`03
W=<00`00]IJeUP03]IH00`00W=>Ld`03W=<00`00Nnmkk`05Nnl01P00Hb`00000BVT000HaQP8000TH
``8000@aQP04001:JDYY000:<HH20003Hb`00`00BVU:J@02BVT20002Nnl300001G__002LdicC0000
1W__0P0019cC0`002KFF00<00<iicWT00lii00<00?ooool00ooo0@000Ooo0007ool00`00ooooo`03
ool01000ooooo`001?oo00<00?ooool00_oo0nLl00<00<iicWT01<ii00<00;FF]IH00[FF00<009cC
W=<019cC00<007__Nnl01G__00<006</Hb`016</00<004YYBVT01TYY00<006</00000W__00<009cC
W=<00YcC0P002[FF00<009cCW=<05YcC00<007__Nnl07g__00<009cCW=<019cC00<00;FF]IH00P00
1IcC00<007__Nnl017__0P0000ES;000BVU:J@0000HaQP03000H`aS300/H``80008aQP03001:J@00
00/aQP03001:J@00009S;004001:JDYYBVT20002Nnl02@00HbaS;6</001kk`00W=<00004Nnl20005
W=<20002cWT00`00]IJeUP07]IH00`00cWW>N@02cWT00`00ooooo`03ool10001ool000Soo`03003o
oooo00;oo`04003ooooo0004ool20003ool3ic`00`00cWW>N@03cWT00`00]IJeUP03]IH00`00W=>L
d`03W=<20006Nnl00`00HbaS;005Hb`00`00BVU:J@06BVT01000Hb`000000W__00<009cCW=<00icC
2P0069cC00<007__Nnl087__00<009cCW=<01IcC0P001YcC00<007__Nnl017__00@006</Hb`0009:
J@03000aQS6600@aQP03000H`aS300dH``06000aQS66001:J@002c6600<004YY00000V</00@004YY
BVU:J@800003Nnl006</00=S;005001kk`00W=<00004Nnl01000W=>LdicC0`0000BeUP00cWW>N@@0
00JeUP03003>NLii00;>N@03003ooooo00;oo`80007oo`002Ooo00D00?ooooooo`0000;oo`03003o
oooo00;oo`03003ooooo00;oo`;W?003003>NLii00?>N@03002eU[FF00>eUP03002LdicC00BLd`03
001kkg__00Akk`03001S;6</00ES;003001:JDYY00Q:J@04001S;6</0002Nnl00`00W=>Ld`0SW=<0
0`00Nnmkk`0QNnl00`00W=>Ld`0<W=<00`00Nnmkk`04Nnl01000HbaS;0000TYY00<00366<HH01366
00<001S36<<03aS300@00366000000daQP80009S;006001:JDYYBVT006</0P001F</0`0017__00<0
09cCW=<00P001KFF00<00<iicWT00/ii00<00;FF]IH01;FF00<00<iicWT00lii00<00?ooool00_oo
0@000Ooo000:ool01000ooooo`000_oo00<00?ooool00_oo00<00?ooool00_oo0^Ll00<00<iicWT0
0lii00<00;FF]IH00kFF00<009cCW=<019cC00<007__Nnl017__00<006</Hb`01F</00<004YYBVT0
1TYY00D004YYBVT006</0080009kk`8002:Ld`03001kkg__029kk`03002LdicC00bLd`03001kkg__
00=kk`04001S;6</0002BVT00`00<HHaQP04<HH00`006<<H``0@6<<40008<HH00`00<HHaQP02<HH0
1@00BVT006</00000dYY00@006</000000ES;0<00004Nnl007__Nnl30002]IH30002]IH00`00cWW>
N@030007]IH00`00cWW>N@02cWT00`00ooooo`02ool10001ool000Ooo`04003ooooo0002ool01000
ooooo`001?oo00<00?ooool00_oo00?W?000cWT01<ii00<00;FF]IH00kFF00<009cCW=<019cC00<0
07__Nnl017__00<006</Hb`01F</00<004YYBVT01TYY00H00366000004YY0002Hb`01@00Nnmkkg__
00007icC0P0097__00<009cCW=<039cC00<007__Nnl00g__00@006</Hb`0009:J@03000aQS6600@a
QP03000H`aS3018H``<0008aQP04000aQS66<HH200000dYY000aQP03<HH200000f</001:J@03BVT0
0`00Hb`000050003Nnl00`00Hb`00002Nnl200000kFF002Ld`02W=<00`00]IJeUP050007]IH00`00
cWW>N@02cWT00`00ooooo`02ool10001ool000Soo`8000Coo`8000Goo`03003ooooo00;oo`03ic`0
0<ii00C>N@03002eU[FF00>eUP03002LdicC00>Ld`8000Ikk`03001S;6</00ES;003001:JDYY00I:
J@06000aQS66001:J@000V</0P000W__0P007YcC00<007__Nnl02G__00<007__Nnl05g__00<009cC
W=<039cC00<007__Nnl00W__00@006</Hb`0009:J@03000aQS6600@aQP03000H`aS301<H``<0008a
QP<00003<HH004YY009:J@04000aQS66<HH200000f</001:J@03BVT00`00Hb`00007Nnl20002Hb`0
1@00Nnl009cC000019cC00D00;FF]IJeUP0000>Ld`03002eU[FF00BeUP03003>NLii00;>N@Goo`40
007oo`005Ooo00<00?ooool00_oo00<00<iicWT00lii00<00;FF]IH00kFF00<009cCW=<019cC00<0
07__Nnl017__00<006</Hb`01F</00<004YYBVT01TYY00<00366<HH00S6610000V</00D007__Nnmk
k`0001^Ld`8000Ykk`<001Ukk`03002LdicC00^Ld`03001kkg__009kk`04001S;6</0002BVT00`00
<HHaQP04<HH00`006<<H``0D6<<01@00<HH0036600000QS300@00366001:J@8000@aQP04001:J@00
0005BVT00`00Hb`00006Nnl01@00HbaS;6</00000W__00<009cCW=<019cC00@00;FF]IH000BLd`03
002eU[FF00BeUP04003>NLiicWT5ool10001ool001Goo`03003ooooo00;oo`03003>NLii00?>N@03
002eU[FF00>eUP03002LdicC00BLd`03001kkg__00Akk`03001S;6</00ES;003001:JDYY00I:J@03
000aQS6600<aQP03001:J@00009S;08000=kk`03002LdicC01RLd`03001kkg__00Mkk`8000:Ld`03
001kkg__01Mkk`03002LdicC00^Ld`03001kkg__009kk`04001S;0000002BVT00`00<HHaQP03<HH0
0`006<<H``0E6<<01@00<HHaQS6600000QS300@00366000000HaQP03001:J@00008000E:J@D000=k
k`03001S;6</009S;004001kkg__0005W=<01000]IJeUP0019cC00<00;FF]IH01;FF00@00<iicWW>
N@Goo`40007oo`005Ooo00<00?ooool00_oo1Lii00<00;FF]IH00kFF00<009cCW=<019cC00<007__
Nnl017__00<006</Hb`01F</00<004YYBVT01TYY00<00366<HH01C6610000V</00@007__Nnmkk`80
01NLd`03001kkg__00Akk`D00003Nnl0000001Ykk`03002LdicC00ZLd`04001kkg__Nnl200000f</
001:J@02BVT00`00<HHaQP03<HH00`006<<H``0F6<<01@00<HHaQS6600000QS300@00366000000Da
QP05001:JDYY001:J@030002BVT00`00HbaS;003Hb`01000Nnmkk`001F</00@007__Nnl000>Ld`05
002eU[FF]IH00005W=<00`00]IJeUP03]IH01000cWW>NLii1Ooo0@000Ooo000Eool00`00ooooo`02
ool5cWT00`00]IJeUP03]IH00`00W=>Ld`03W=<20006Nnl00`00HbaS;005Hb`00`00BVU:J@06BVT0
0`00<HHaQP06<HH00`00BVT00002Hb`20003Nnl3000EW=<70004W=<00`00Nnmkk`0KNnl00`00W=>L
d`0:W=<01@00Nnmkkg__00000V</00@004YYBVT000DaQP03000H`aS301LH``05000aQS66<HH00002
6<<01000<HH000001C6600<004YYBVT00TYY00H00366<HH004YY0005Hb`01000Nnmkk`001F</00<0
07__Nnl00P0000>Ld`00]IH00kFF00<009cCW=<00icC0P001KFF00<00<iicWT01Ooo0@000Ooo000E
ool20003ool4cWT00`00]IJeUP03]IH00`00W=>Ld`03W=<00`00Nnmkk`05Nnl00`00HbaS;005Hb`0
0`00BVU:J@06BVT00`00<HHaQP08<HH40002Hb`00`00Nnmkk`03Nnl2000MW=<00`00Nnmkk`0LNnl0
0`00W=>Ld`08W=<20003Nnl01000HbaS;0000TYY00<00366<HH00c6600<001S36<<061S300<00366
<HH00P000aS31@000S6600<004YYBVT00TYY00<00366<HH00S660P001F</00<007__00001f</00L0
07__Nnmkk`00W=<00003]IH00`00W=>Ld`04W=<00`00]IJeUP04]IH00`00cWWoo`03ool20001ool0
01Goo`03003ooooo00;oo`C>N@03002eU[FF00>eUP03002LdicC00>Ld`03001kkg__00Ekk`03001S
;6</00ES;003001:JDYY00E:J@03000aQS6600/aQP03001:J@00009S;003001kkg__00Akk`8001ZL
d`03001kkg__01ikk`03002LdicC00RLd`04001kkg__0002Hb`01000BVU:J@001C6600<001S36<<0
3AS300<001S36<<02QS300@00366<HH000@H``06000aQP00BVT003660P000TYY00<00366<HH00c66
00<004YY00001F</00<006</Hb`01f</00L007__Nnmkk`00W=<00002]IH00`00W=>Ld`05W=<00`00
]IJeUP03]IH00`00cWWoo`04ool10001ool001Goo`03003ooooo00;oo`C>N@03002eU[FF00>eUP03
002LdicC00>Ld`03001kkg__00Ekk`03001S;6</00ES;003001:JDYY00E:J@03000aQS6600PaQP<0
0003<HH004YY00800003Hb`0000000Ikk`03002LdicC01FLd`80025kk`@000NLd`04001kkg__0002
Hb`01000BVU:J@00136600<001S36<<02QS32@0021S300@00366<HH000@H``H00004BVT000000007
<HH00`00BVT00004Hb`00`00HbaS;008Hb`00`00Nnmkk`0400000kFF002Ld`07W=<00`00]IJeUP03
]IH00`00ooooo`03ool10001ool001Goo`03003ooooo00;oo`C>N@03002eU[FF00:eUP03002LdicC
00>Ld`03001kkg__00Ekk`03001S;6</00ES;003001:JDYY00E:J@03000aQS6600TaQP06000H`aS3
000aQP000TYY00@006</Hb`000Ikk`<001:Ld`8002Akk`03001kk`0000NLd`03001kk`00009S;004
001:JDYY0004<HH00`006<<H``0:6<<<00076<<300066<<00`00<HH00003000:<HH00`00BVT00005
Hb`00`00HbaS;006Hb`00`00Nnmkk`02Nnl00`00W=<00009W=<00`00]IJeUP04]IH00`00ooooo`02
ool10001ool001Goo`03003ooooo00;oo`?>N@03002eU[FF00:eUP03002LdicC00BLd`03001kkg__
00Akk`03001S;6</00ES;003001:JDYY00I:J@03000aQS6600LaQP8000@H``05000aQP00BVT00003
Hb`00`00Nnmkk`06Nnl00`00W=>Ld`0=W=<2000XNnl00`00W=>Ld`05W=<01@00Nnl006</00000TYY
00<00366<HH00S660P002QS340003aS31@002S660P0000=:J@0000000`0000=:J@00Hb`01V</00<0
07__Nnl00W__0`002IcC00<00;FF]IH01;FF00<00?ooool00_oo0@000Ooo000Eool00`00ooooo`02
ool2cWT00`00]IJeUP03]IH00`00W=>Ld`03W=<00`00Nnmkk`04Nnl00`00HbaS;006Hb`00`00BVU:
J@06BVT00`00<HHaQP07<HH00`006<<H``046<<01@00<HH004YY00000f</0P001W__1@002IcC0P00
:W__00<009cCW=<01IcC00<007__Nnl00P000dYY00@00366<HH000/H`aD0010H``03000aQS6600Ta
QP03001:JDYY00E:J@03001S;6</00ES;003001kkg__00Akk`8000RLd`03002eU[FF00>eUP03003o
oooo00;oo`40007oo`005Ooo00<00?ooool00_oo0/ii00<00;FF]IH00kFF00<009cCW=<00icC00<0
07__Nnl017__00<006</Hb`01V</00<004YYBVT01DYY00<00366<HH0236600<001S36<<01AS300D0
0366001:J@0000AS;003001kkg__00Qkk`T002akk`03002LdicC00FLd`03001kkg__008000=:J@<0
00XH`aT000lH``8000XaQP03001:JDYY00A:J@03001S;6</00ES;003001kkg__00Ekk`03002LdicC
00JLd`03002eU[FF00>eUPGoo`40007oo`005Ooo00<00?ooool00_oo0/ii00<00;FF]IH00[FF00<0
09cCW=<019cC00<007__Nnl00g__00<006</Hb`01V</00<004YYBVT01DYY00<00366<HH02C6600<0
01S36<<01QS30P000TYY00<006</Hb`00V</00<007__Nnl0?G__00<009cCW=<01IcC00D007__001S
;00000=:J@8000TH`a`000hH``03000aQS6600TaQP03001:JDYY00A:J@03001S;6</00ES;003001k
kg__00Ekk`03002LdicC00FLd`03002eU[FF00>eUPGoo`40007oo`005Ooo00<00?ooool00_oo00?>
N@00]IH01;FF00<009cCW=<00icC00<007__Nnl017__00<006</Hb`01V</00<004YYBVT01DYY00<0
0366<HH0236600<001S36<<01aS300<0036600000TYY00<006</Hb`00V</0P00:g__0`003g__00<0
09cCW=<00`000YcC00@007__001S;080009:J@8000PH`ad000lH``03000aQS6600PaQP03001:JDYY
00E:J@03001S;6</00AS;003001kkg__00Ekk`03002LdicC00FLd`8000BeUPGoo`40007oo`005Ooo
00<00?ooool00_oo00?>N@00]IH00kFF00<009cCW=<00icC00<007__Nnl017__00<006</Hb`01V</
00<004YYBVT01TYY00<00366<HH0236600<001S36<<021S300<0036600000TYY00<006</Hb`00f</
0P00:7__00D006</HbaS;00000ikk`08002LdicC001kk`00W=<0009kk`09001S;6</Hb`004YY000a
QP0000HH`al000lH``03000aQS6600LaQP03001:JDYY00E:J@03001S;6</00ES;003001kkg__00Ek
k`03002LdicC00JLd`04002eU[FF]IH5ool10001ool001Goo`8000?oo`03cWT00;FF00>eUP03002L
dicC00>Ld`03001kkg__00Akk`03001S;6</00IS;003001:JDYY00I:J@03000aQS6600PaQP03000H
`aS300TH``03000aQP00009:J@03001S;6</00AS;003001kkg__02Akk`03001S;6</00=S;003001k
kg__00]kk`@00004Nnl009cC0002Nnl02@00HbaS;6</001:J@00<HH000066<<Q000=6<<00`00<HHa
QP08<HH00`00BVU:J@04BVT00`00HbaS;005Hb`00`00Nnmkk`05Nnl00`00W=>Ld`06W=<01000]IJe
U[FF1?oo0P000Ooo000Eool00`00ooooo`02ool00lii002eUP03]IH00`00W=>Ld`03W=<00`00Nnmk
k`04Nnl00`00HbaS;005Hb`00`00BVU:J@06BVT00`00<HHaQP09<HH00`006<<H``0:6<<00`00<HH0
0002BVT20005Hb`2000SNnl00`00HbaS;005Hb`00`00Nnmkk`0?Nnl01@00W=<007__000016</00<0
04YYBVT00P001AS38`003AS300<00366<HH0236600<004YYBVT014YY00<006</Hb`01F</00<007__
Nnl01G__0P001YcC00@00;FF]IJeUPGoo`40007oo`005Ooo00<00?ooool00_oo00?>N@00]IH00kFF
00<009cCW=<00icC00<007__Nnl017__00<006</Hb`01F</0P001dYY00<00366<HH02C6600<001S3
6<<02aS300<0036600000dYY00<006</Hb`016</0`0087__00<006</Hb`01F</00<007__Nnl03g__
00D009cC001kk`0000AS;003001:JDYY008000DH`b@000dH``03000aQS6600LaQP03001:JDYY00E:
J@03001S;6</00ES;003001kkg__00Ekk`03002LdicC00BLd`8000:eUPGoo`40007oo`005Ooo00<0
0?ooool00_oo00<00;FF]IH00kFF00<009cCW=<00icC00<007__Nnl00g__00<006</Hb`01F</00<0
04YYBVT01TYY00<00366<HH02C6600<001S36<<03AS30P0014YY00<006</Hb`01V</00<007__Nnl0
6g__0P001f</00<007__Nnl04G__00<007__000016</00<004YYBVT00P001QS390003QS300<00366
<HH01c6600<004YYBVT014YY00<006</Hb`01F</00<007__Nnl01G__00<009cCW=<01IcC00<00;FF
]IH01Ooo0@000Ooo000Eool00`00ooooo`02ool00`00]IJeUP02]IH00`00W=>Ld`03W=<20005Nnl0
0`00HbaS;005Hb`00`00BVU:J@06BVT00`00<HHaQP08<HH00`006<<H``0>6<<20004BVT00`00HbaS
;006Hb`2000KNnl00`00HbaS;007Hb`00`00Nnmkk`0CNnl01@00HbaS;6</00000dYY0P001AS39P00
3AS300<00366<HH01c6600<004YYBVT014YY00<006</Hb`01F</00<007__Nnl01G__00<009cCW=<0
1IcC00<00;FF]IH01Ooo0@000Ooo000Eool00`00ooooo`02ool5]IH00`00W=>Ld`03W=<00`00Nnmk
k`04Nnl00`00HbaS;004Hb`00`00BVU:J@06BVT00`00<HHaQP09<HH00`006<<H``0>6<<00`00<HH0
0004BVT00`00HbaS;007Hb`00`00Nnmkk`0GNnl00`00HbaS;007Hb`00`00Nnmkk`0DNnl01000HbaS
;0000dYY0P001AS3:0003AS300<00366<HH01c6600<004YYBVT014YY00<006</Hb`01F</00<007__
Nnl01G__00<009cCW=<01IcC00<00;FFool01?oo0@000Ooo000Eool00`00ooooo`02ool5]IH00`00
W=>Ld`03W=<00`00Nnmkk`04Nnl00`00HbaS;004Hb`20007BVT00`00<HHaQP09<HH00`006<<H``0?
6<<00`00<HH00004BVT00`00HbaS;007Hb`3000ENnl00`00HbaS;008Hb`00`00Nnmkk`0:Nnl00`00
Nnmkk`06Nnl01000HbaS;0000dYY00<0036600001AS3:@003AS300<00366<HH01S6600<004YYBVT0
1DYY00<006</Hb`016</00<007__Nnl01G__0P001YcC00<00;FFool01?oo0@000Ooo000Eool00`00
ooooo`02ool4]IH00`00W=>Ld`03W=<00`00Nnmkk`04Nnl00`00HbaS;004Hb`00`00BVU:J@07BVT0
0`00<HHaQP08<HH00`006<<H``0@6<<01000<HHaQP0014YY00<006</Hb`02F</00<007__Nnl04G__
00<006</Hb`02F</00<007__Nnl02G__00@006</000000Ekk`04001S;6</0003BVT00`00<HH00005
6<<[000<6<<00`00<HHaQP07<HH00`00BVU:J@05BVT00`00HbaS;004Hb`00`00Nnmkk`05Nnl00`00
W=>Ld`04W=<00`00]IKoo`04ool10001ool001Goo`03003ooooo00;oo`BeUP03002LdicC00>Ld`03
001kkg__00Akk`03001S;6</00AS;003001:JDYY00M:J@03000aQS6600PaQP03000H`aS300dH``04
000H`aS30002<HH00`00BVU:J@02BVT00`00HbaS;009Hb`00`00Nnmkk`0@Nnl2000:Hb`00`00Nnmk
k`08Nnl20004Hb`50003Hb`01`00BVT00000<HH001S3034000/H``03000aQS6600LaQP03001:JDYY
00E:J@03001S;6</00AS;003001kkg__00Ekk`03002LdicC00FLd`03003ooooo00?oo`40007oo`00
5Ooo00<00?ooool00_oo1;FF00<009cCW=<00icC00<007__Nnl00g__00<006</Hb`01F</00<004YY
BVT01TYY00<00366<HH02C6600<001S36<<031S3100000DH``00<HHaQP0000=:J@03001S;6</00QS
;003001kkg__011kk`03001S;6</00US;003001kkg__00Ukk`03001S;6</00]S;080008aQP03000H
``00038000/H``03000aQS6600LaQP03001:JDYY00A:J@03001S;6</00ES;003001kkg__00Ekk`03
002LdicC00FLd`03003ooooo00;oo`40007oo`005Ooo0P000ooo1;FF00<009cCW=<00icC00<007__
Nnl00g__00<006</Hb`01F</00<004YYBVT01TYY00<00366<HH0236600<001S36<<031S31@000QS3
00<0036600000dYY0P002F</00<007__Nnl03W__0P002f</00<007__Nnl027__0P003V</0P0000@a
QP006<<H`c<000/H``03000aQS6600LaQP03001:JDYY00A:J@03001S;6</00ES;003001kkg__00Ek
k`03002LdicC00FLd`04003oooooool20001ool001Goo`03003ooooo00;oo`>eUP03002LdicC00>L
d`03001kkg__00=kk`03001S;6</00ES;003001:JDYY00M:J@03000aQS6600PaQP03000H`aS300/H
``L000056<<00366<HH00003BVT00`00HbaS;006Hb`00`00Nnmkk`0=Nnl2000<Hb`00`00Nnmkk`08
Nnl00`00HbaS;00=Hb`200001366000H`aS3=00031S300<00366<HH01S6600<004YYBVT01DYY00<0
06</Hb`016</00<007__Nnl01G__00<009cCW=<01IcC00<00?ooool00_oo0@000Ooo000Eool00`00
ooooo`02ool3]IH00`00W=>Ld`03W=<00`00Nnmkk`03Nnl00`00HbaS;005Hb`00`00BVU:J@06BVT0
0`00<HHaQP09<HH00`006<<H``0:6<<800001AS3000aQS6600000dYY00<006</Hb`01V</00<007__
Nnl037__00<006</Hb`036</00<007__Nnl01W__0P003f</00@004YY0000008H`cD000`H``03000a
QS6600HaQP03001:JDYY00E:J@03001S;6</00AS;003001kkg__00Ekk`8000JLd`03003ooooo00;o
o`40007oo`005Ooo00<00?ooool00_oo0[FF00<009cCW=<00icC00<007__Nnl00g__00<006</Hb`0
1F</00<004YYBVT01TYY00<00366<HH02C6600<001S36<<02aS32@0000DH``00<HHaQP0000=:J@03
001S;6</00AS;003001kkg__00akk`03001S;6</00eS;003001kkg__00Ekk`03001S;6</00iS;006
001:J@00<HH001S3=`0031S300<00366<HH01S6600<004YYBVT014YY00<006</Hb`01F</00<007__
Nnl01G__00<009cCW=<019cC00<00?ooool00_oo0@000Ooo000Eool00`00ooooo`02ool2]IH00`00
W=>Ld`03W=<00`00Nnmkk`03Nnl00`00HbaS;005Hb`00`00BVU:J@06BVT00`00<HHaQP08<HH00`00
6<<H``0<6<<900001AS3000aQS6600000dYY00<006</Hb`00f</00<007__Nnl02g__0P003f</00<0
07__Nnl01G__00<006</Hb`03F</0P000TYY00@00366000H`cT000XH``03000aQS6600HaQP03001:
JDYY00A:J@03001S;6</00ES;003001kkg__00Ekk`03002LdicC00BLd`Goo`40007oo`005Ooo00<0
0?ooool00_oo0[FF00<009cCW=<00icC00<007__Nnl00g__00<006</Hb`016</00<004YYBVT01TYY
00<00366<HH02C6600<001S36<<03AS32`000S6600@004YYBVT000IS;003001kkg__00Ukk`03001S
;6</00iS;003001kkg__00Ekk`03001S;6</00eS;003001:JDYY009:J@04000aQP006<<i000;6<<0
0`00<HHaQP06<HH00`00BVU:J@04BVT00`00HbaS;005Hb`00`00Nnmkk`05Nnl00`00W=>Ld`03W=<5
ool10001ool001Goo`03003ooooo00;oo`03]IH009cC00BLd`03001kkg__00Akk`03001S;6</00AS
;003001:JDYY00I:J@03000aQS6600TaQP03000H`aS300dH``X000046<<003660003BVT00`00HbaS
;003Hb`00`00Nnmkk`08Nnl00`00HbaS;00>Hb`00`00Nnmkk`05Nnl00`00HbaS;00=Hb`20004BVT0
1000<HH001S3>P002QS300<00366<HH01S6600<004YYBVT014YY00<006</Hb`01F</00<007__Nnl0
1G__00<009cCW=<00icC1Ooo0@000Ooo000Eool00`00ooooo`02ool00kFF002Ld`03W=<00`00Nnmk
k`05Nnl00`00HbaS;003Hb`00`00BVU:J@06BVT00`00<HHaQP09<HH00`006<<H``0?6<<:000011S3
000aQP000TYY00<006</Hb`016</00<007__Nnl01W__00<006</Hb`03V</00<007__Nnl01G__00<0
06</Hb`03F</00<004YYBVT014YY00@00366<HH0008H`cP000/H``03000aQS6600DaQP03001:JDYY
00E:J@03001S;6</00AS;003001kkg__00Ekk`03002LdicC00>Ld`Goo`40007oo`002Ooo00<00?oo
ool00_oo0P001Ooo00<00?ooool00_oo00>eUP00W=<00icC00<007__Nnl017__00<006</Hb`016</
00<004YYBVT01TYY00<00366<HH02C6600<001S36<<041S33P0000=:J@00Hb`01F</0P001W__00<0
06</Hb`03V</00<007__Nnl017__0P003f</00<004YYBVT01DYY00H00366<HHaQP006<<i000:6<<0
0`00<HHaQP05<HH00`00BVU:J@05BVT00`00HbaS;004Hb`20006Nnl00`00W=>Ld`03W=<5ool10001
ool000Woo`05003oooooool00002ool00`00ooooo`02ool00`00ooooo`02ool00kFF002Ld`04W=<0
0`00Nnmkk`03Nnl00`00HbaS;005Hb`00`00BVU:J@05BVT00`00<HHaQP0:<HH00`006<<H``0A6<<9
00001QS3000aQP00BVT000MS;0H0011S;003001kkg__00Akk`03001S;6</00eS;08000Q:J@03000a
QS66008aQP03000H`aS303P000XH``03000aQS6600DaQP03001:JDYY00E:J@03001S;6</00ES;003
001kkg__00Akk`03002LdicC00:Ld`Goo`40007oo`001_oo1@000_oo00@00?ooool000Coo`8000?o
o`03]IH009cC00BLd`03001kkg__00=kk`8000IS;003001:JDYY00E:J@03000aQP0000XaQP03000H
`aS3008H``03000H`aS300`H``/00003<HH004YY008001aS;003001kkg__00=kk`03001S;6</00eS
;003001:JDYY00Q:J@03000aQS6600<aQP03000H``0003P000TH``03000aQS6600HaQP03001:JDYY
00A:J@03001S;6</00ES;003001kkg__00Ekk`04002LdicCW=<4ool20001ool000Koo`04003ooooo
0003ool01000ooooo`001?oo00<00?ooool00_oo00<009cCW=<00icC00D007__Nnmkk`0000=kk`03
001S;6</00ES;0@0009:J@05000aQP00BVT00008<HH00`006<<H``026<<00`00<HH0000=6<<;0000
0c66001:J@02BVT00`00HbaS;00GHb`2000017__001kkg__0P003f</00<004YYBVT024YY00<00366
<HH0136600<001S30000>0002AS300<00366<HH01S6600<004YYBVT01DYY00<006</Hb`016</00<0
07__Nnl01G__00@009cCW=>Ld`Goo`40007oo`001ooo00<00?oo00000ooo00@00?ooool000Coo`03
003ooooo00;oo`08002LdicCW=<009cC001kk`800005W=<007__Nnl0000;Hb`01@00BVT003660000
0TYY00<00366<HH01C6600D001S36<<H``0000<aQP03000H`aS300HH``80008H``X000046<<00366
0003BVT00`00HbaS;00EHb`00`00Nnmkk`02Nnl2000?Hb`2000;BVT00`00<HHaQP04<HH00`006<<0
000h00096<<00`00<HHaQP06<HH00`00BVU:J@05BVT00`00HbaS;004Hb`20006Nnl01000W=>LdicC
1Ooo0@000Ooo0008ool20003ool01000ooooo`001?oo00<00?ooool00_oo00D009cCW=<00;FF0080
0005Nnl009cCW=<00003Nnl01@00HbaS;6</00001F</00H004YYBVT003660002BVT01@00<HHaQS66
00000c6600D001S36<<H``0000<aQP03000H`aS300LH``04000H`aS36<<:000011S3000aQP000dYY
00<006</Hb`04f</00@007__Nnmkk`80011S;003001:JDYY00a:J@03000aQS6600<aQP03000H``00
03T000TH``03000aQS6600HaQP03001:JDYY00E:J@03001S;6</00AS;003001kkg__00Akk`04002L
dicCW=<5ool10001ool000Woo`03003ooooo00;oo`8000Goo`03003ooooo00;oo`03002Ld`0000:e
UP800005Nnl009cCW=<00004Nnl01@00Hb`004YY00000V</0P000TYY0P0000<aQP00BVT00TYY00<0
0366<HH00P000S6600D001S36<<H``0000<aQP03000H`aS300/H``/000046<<003660003BVT00`00
HbaS;00BHb`4000BHb`00`00BVU:J@0=BVT20004<HH00`006<<0000i00096<<00`00<HHaQP05<HH0
0`00BVU:J@05BVT00`00HbaS;004Hb`00`00Nnmkk`05Nnl00`00W=>Ld`05ool10001ool001Goo`03
003ooooo00;oo`03002Ld`0000:eUP800005Nnl009cCW=<00004Nnl01@00Hb`004YY00000V</00D0
04YYBVU:J@00008aQP03001:JDYY009:J@800004BVT0036600046<<00`00<HHaQP02<HH00`006<<H
``086<<00`006<<0000;000011S3000aQP000dYY00<006</Hb`09V</00<004YYBVT03dYY00<00366
<HH00S6600@001S36<<H`cT000TH``03000aQS6600DaQP03001:JDYY00A:J@03001S;6</00ES;003
001kkg__00Akk`03002LdicC00Goo`40007oo`005Ooo00<00?ooool00_oo00<009cC00000[FF0P00
00Ekk`00W=>Ld`0000Akk`05001S;000BVT00002Hb`01@00BVU:JDYY00000S6600<004YYBVT01DYY
00<00366000011S300<00366<HH00S6600<001S36<<01QS30`0000<H``00000030000S6600D004YY
BVU:J@0002IS;003001:JDYY015:J@04000aQS66<HH2000<6<<_00096<<00`00<HHaQP05<HH00`00
BVU:J@04BVT00`00HbaS;005Hb`00`00Nnmkk`04Nnl00`00W=>Ld`05ool10001ool001Goo`03003o
oooo00;oo`:Ld`07002eUP00W=<007__00000icC00H007__Nnl006</0002BVT01@00HbaS;6</0000
0TYY00@00366<HH000M:J@03000aQP0000@H``05000aQS66<HH000086<<01@00<HHaQP006<<03`00
0S6600D004YYBVU:J@0002AS;003001:JDYY019:J@03000aQS6600<aQPX000DH`b`000TH``03000a
QS6600DaQP03001:JDYY00E:J@03001S;6</00AS;003001kkg__00Akk`03002LdicC00Goo`40007o
o`005Ooo00<00?ooool00_oo0YcC00@00;FF0000009kk`04002LdicCW=<2000017__001S;0000TYY
00<006</Hb`00V</00<004YY00000S6600<004YYBVT01DYY00<00366000011S300D00366<HHaQP00
00PH``05000aQS66000H``0?0002<HH00`00BVU:J@02BVT00`00HbaS;00PHb`00`00BVU:J@0CBVT0
0`00<HHaQP0=<HH400026<<[00096<<00`00<HHaQP05<HH00`00BVU:J@05BVT00`00HbaS;004Hb`0
0`00Nnmkk`04Nnl00`00W=>Ld`05ool10001ool001Goo`03003ooooo00;oo`:Ld`04002eUP000002
Nnl01000W=>Ld`000g__00<006</00000TYY00<006</Hb`00P0000=:J@00<HH00S6600<004YYBVT0
0TYY00H004YYBVT0036600046<<01@00<HHaQS6600001aS300<00366<HH00S6600<001S300003000
00@H``00<HH000E:J@03001S;6</01iS;003001:JDYY01E:J@<0010aQP04000H`aS36<<Z00096<<0
0`00<HHaQP05<HH00`00BVU:J@04BVT00`00HbaS;004Hb`00`00Nnmkk`05Nnl00`00W=?oo`04ool1
0001ool001Goo`8000?oo`:Ld`04002eUP000002Nnl00`00W=<00004Nnl00`00Hb`00002BVT01P00
HbaS;000BVT000@aQP03001:JDYY00800006<HH004YY000aQP0011S300D00366<HHaQP0000HH``03
000aQS6600@000036<<0000000d0008aQP03001:JDYY009:J@03001S;6</01eS;003001:JDYY01U:
J@h000<aQP04000H`aS36<<Y00096<<00`00<HHaQP05<HH00`00BVU:J@04BVT00`00HbaS;004Hb`0
0`00Nnmkk`05Nnl00`00W=?oo`03ool20001ool001Goo`03003ooooo00;oo`:Ld`04002eUP000003
Nnl20004Nnl00`00Hb`00002BVT01000HbaS;0000TYY00D00366<HHaQP0000=:J@07000aQP00BVT0
036600000QS30P001C660P0011S300<0036600001QS33`000S6600<004YYBVT00TYY00<006</Hb`0
76</00<004YYBVT05TYY00<004YYBVT03TYY00@00366<HHaQP80008H`bT000TH``03000aQS6600@a
QP03001:JDYY00E:J@03001S;6</00AS;003001kkg__00Akk`03002Ldooo00Coo`40007oo`005Ooo
00<00?ooool00_oo0YcC00@00;FF000000=kk`8000Akk`03001S;000009:J@04001S;6</0003BVT0
1000<HHaQP000dYY00<0036600000P0000@aQP006<<000PaQP03000H`aS3008H``8000036<<001S3
00@H``l0008aQP03001:JDYY009:J@03001S;6</01aS;003001:JDYY019:J@@00003Hb`0000000m:
J@03000aQS66008aQP03000H``0002P000TH``03000aQS6600@aQP03001:JDYY00E:J@03001S;6</
00AS;003001kkg__00Akk`03002Ldooo00Coo`40007oo`005Ooo00<00?ooool00_oo0icC0`000g__
0P000g__00<006</000014YY00@006</Hb`0009:J@05000aQS66<HH00003BVT01@00<HHaQS660000
0aS300<00366<HH00c660`001QS310000aS3400000<aQP00BVT014YY00<006</Hb`06f</00<004YY
BVT02DYY10000dYY0P001f</200000=:J@00BVT01DYY0P000c6600<001S300009`002AS300<00366
<HH01C6600<004YYBVT014YY00<006</Hb`016</00<007__Nnl017__00<009cCool01?oo0@000Ooo
000Eool00`00ooooo`02ool4W=<20003Nnl20003Nnl30004BVT40002BVT01000<HHaQS661@000S66
00<001S36<<00QS31P0021S35P0000DH``00<HHaQP0000A:J@03001S;6</01]S;003001:JDYY00Q:
J@8000=S;0<0015S;0@000I:J@05000aQS66000H``0X00096<<00`00<HHaQP05<HH00`00BVU:J@04
BVT00`00HbaS;004Hb`00`00Nnmkk`04Nnl00`00W=?oo`04ool10001ool001Goo`03003ooooo00;o
o`BLd`03001kkg__00Ekk`800003Hb`004YY00Q:J@8000XaQP03000H`aS300dH``03000H``0001P0
00056<<00366<HH00004BVT4000JHb`00`00BVU:J@06BVT00`00HbaS;00KHb`00`00BVU:J@04BVT0
1@00<HHaQP006<<0:0002AS300<00366<HH01C6600<004YYBVT014YY00<006</Hb`016</00<007__
Nnl017__00<00?ooool00ooo0@000Ooo000Eool00`00ooooo`02ool4W=<00`00Nnmkk`02Nnl30003
Hb`00`00BVU:J@05BVT20008<HH4000@6<<M0002<HH00`00BVU:J@06BVT00`00HbaS;00GHb`00`00
BVU:J@06BVT00`00HbaS;00:Hb`00`00HbaS;00>Hb`00`00BVU:J@04BVT01@00<HHaQP006<<0:@00
21S300<00366<HH01C6600<004YYBVT014YY00<006</Hb`016</00<007__Nnl017__00<00?ooool0
0ooo0@000Ooo000Eool00`00ooooo`02ool3W=<00`00Nnmkk`02Nnl00`00HbaS;003Hb`00`00BVU:
J@05BVT00`00<HHaQP07<HH00`006<<H``0@6<<N00001AS3000aQS6600001dYY00<006</Hb`05f</
00<004YYBVT014YY0P002f</0P0000=kk`0000003f</00<004YYBVT00dYY00D00366<HH001S302T0
00PH``03000aQS6600DaQP03001:JDYY00A:J@03001S;6</00AS;003001kkg__00Akk`03003ooooo
00?oo`40007oo`005Ooo00<00?ooool00_oo0icC00<007__Nnl00W__00<006</Hb`00V</00<004YY
BVT01DYY00<00366<HH0236600<001S36<<03aS37`0000@H``00<HHaQP8000I:J@03001S;6</01MS
;003001:JDYY00A:J@03001S;6</00QS;08000Ekk`03001S;6</00eS;003001:JDYY009:J@05000a
QS66000H``0Y00086<<00`00<HHaQP05<HH00`00BVU:J@04BVT00`00HbaS;004Hb`00`00Nnmkk`04
Nnl00`00ooooo`03ool10001ool001Goo`03003ooooo00;oo`>Ld`05001kkg__Nnl00005Hb`00`00
BVU:J@05BVT00`00<HHaQP07<HH00`006<<H``0?6<<P00000aS3000aQP03<HH00`00BVU:J@02BVT0
0`00HbaS;00GHb`00`00BVU:J@03BVT2000;Hb`00`00Nnmkk`04Nnl00`00HbaS;00<Hb`00`00BVU:
J@03BVT01000<HH001S3:P002AS300<00366<HH0136600<004YYBVT014YY00<006</Hb`016</00<0
07__Nnl017__00<00?ooool00ooo0@000Ooo000Eool20003ool3W=<01@00Nnmkkg__00001F</00<0
04YYBVT01DYY00<00366<HH01c6600<001S36<<03QS38P0000<H``00<HH00c6600D004YYBVU:J@00
01US;003001:JDYY00=:J@03001S;6</00IS;0D000Ikk`03001S;6</00aS;003001:JDYY00=:J@04
000aQP006<<Z00096<<00`00<HHaQP04<HH00`00BVU:J@04BVT00`00HbaS;004Hb`00`00Nnmkk`04
Nnl00`00ooooo`02ool20001ool001Goo`03003ooooo00;oo`>Ld`05001kkg__Nnl00005Hb`00`00
BVU:J@04BVT00`00<HHaQP08<HH00`006<<H``0>6<<S00000aS3000aQP02<HH00`00BVU:J@02BVT2
00000f</001S;00DHb`00`00BVU:J@02BVT00`00HbaS;005Hb`2000:Nnl00`00HbaS;00<Hb`00`00
BVU:J@02BVT20002<HH]00086<<00`00<HHaQP04<HH00`00BVU:J@04BVT00`00HbaS;004Hb`00`00
Nnmkk`04Nnl00`00ooooo`03ool10001ool001Goo`03003ooooo00;oo`>Ld`05001kkg__Nnl00005
Hb`00`00BVU:J@04BVT00`00<HHaQP08<HH00`006<<H``0>6<<S00000aS3000aQP02<HH00`00BVU:
J@04BVT2000EHb`50007Hb`00`00Nnmkk`09Nnl00`00HbaS;00<Hb`20004BVT00`00<HH0000^0008
6<<00`00<HHaQP04<HH00`00BVU:J@04BVT00`00HbaS;004Hb`00`00Nnmkk`04Nnl00`00ooooo`03
ool10001ool001Goo`03003ooooo00;oo`>Ld`05001kkg__Nnl00005Hb`00`00BVU:J@04BVT00`00
<HHaQP07<HH00`006<<H``0>6<<U00001AS3000aQS6600001dYY00<006</Hb`07f</00<007__Nnl0
27__00<006</Hb`036</00<004YYBVT00TYY0P0000<aQP006<<0;P0021S300<00366<HH0136600<0
04YYBVT014YY00<006</Hb`01F</00<007__Nnl00g__00<00?ooool00ooo0@000Ooo000Eool00`00
ooooo`02ool3W=<01@00Nnmkkg__00001F</00<004YYBVT014YY00<00366<HH01S660P003aS39P00
00DH``00<HHaQP0000M:J@03001S;6</01mS;003001kkg__00Qkk`03001S;6</00aS;005001:JDYY
BVT00002<HHa00086<<00`00<HHaQP04<HH00`00BVU:J@04BVT00`00HbaS;005Hb`00`00Nnmkk`03
Nnl00`00ooooo`03ool10001ool001Goo`03003ooooo00;oo`>Ld`05001kkg__Nnl00005Hb`00`00
BVU:J@04BVT00`00<HHaQP06<HH00`006<<H``0=6<<Z0002<HH00`00BVU:J@05BVT00`00HbaS;00N
Hb`00`00Nnmkk`08Nnl00`00HbaS;00;Hb`01@00BVU:JDYY00000S6600<001S30000;`0021S300<0
0366<HH01C6600<004YYBVT014YY00<006</Hb`016</00<007__Nnl017__00<00?ooool00_oo0@00
0Ooo000Eool00`00ooooo`02ool3W=<01@00Nnmkkg__00001F</00<004YYBVT014YY00<00366<HH0
1S6600<001S36<<03AS3:00000<H``00<HH00S6600<004YYBVT014YY00<006</Hb`06V</1@002W__
00<006</Hb`02V</00D004YYBVU:J@0000<aQP03000H``0002l000PH``03000aQS6600DaQP03001:
JDYY00A:J@03001S;6</00AS;003001kkg__00Akk`03003ooooo00;oo`40007oo`005Ooo00<00?oo
ool00_oo0icC00<007__Nnl00W__00<006</Hb`00V</00<004YYBVT014YY00<00366<HH01S6600<0
01S36<<031S3:P0000DH``00<HHaQP0000M:J@03001S;6</01MS;08000ikk`03001S;6</00ES;0H0
00A:J@05000aQS66000H``0b00086<<00`00<HHaQP04<HH00`00BVU:J@04BVT00`00HbaS;004Hb`0
0`00Nnmkk`04Nnl00`00ooooo`02ool10001ool001Goo`03003ooooo00;oo`>Ld`03001kkg__009k
k`03001S;6</009S;003001:JDYY00=:J@03000aQS6600HaQP03000H`aS300`H`bX000036<<00366
008aQP03001:JDYY00E:J@03001S;6</01MS;003001kkg__00akk`03001S;6</00MS;003001:JDYY
00E:J@03000aQS66008aQS<000PH``03000aQS6600@aQP03001:JDYY00A:J@03001S;6</00AS;003
001kkg__00Akk`03003ooooo00;oo`40007oo`005Ooo0P000ooo0icC00D007__Nnmkk`0000ES;003
001:JDYY00=:J@03000aQS6600HaQP03000H`aS300/H`b/000056<<00366<HH00008BVT00`00HbaS
;00<Hb`30006Hb`2000?Nnl00`00HbaS;007Hb`20006BVT00`00<HHaQP02<HHc00086<<00`00<HHa
QP04<HH00`00BVU:J@04BVT00`00HbaS;004Hb`00`00Nnmkk`04Nnl01000oooooooo0P000Ooo000E
ool00`00ooooo`02ool3W=<01@00Nnmkkg__00001F</00<004YYBVT00dYY00<00366<HH01C6600<0
01S36<<031S3:@000QS300@00366<HH000Y:J@03001S;6</00]S;08000MS;003001kkg__00ekk`03
001S;6</00YS;003001:JDYY009:J@03000aQS6600@aQS8000PH``03000aQS6600@aQP03001:JDYY
00A:J@03001S;6</00AS;003001kkg__00Akk`03003ooooo00;oo`40007oo`005Ooo00<00?ooool0
0_oo0icC00D007__Nnmkk`0000ES;003001:JDYY00=:J@03000aQS6600DaQP03000H`aS300`H`bP0
008H``05000aQS66<HH0000:BVT00`00HbaS;00;Hb`20007Hb`00`00Nnmkk`0:Nnl3000>Hb`01000
BVU:J@001c6600<001S30000;`0021S300<00366<HH0136600<004YYBVT014YY00<006</Hb`016</
00<007__Nnl017__00<00?ooool00_oo0@000Ooo000Eool00`00ooooo`02ool3W=<00`00Nnmkk`02
Nnl00`00HbaS;002Hb`00`00BVU:J@03BVT00`00<HHaQP05<HH00`006<<H``0<6<<V00036<<00`00
<HHaQP02000;BVT00`00HbaS;00<Hb`00`00HbaS;005Hb`00`00Nnmkk`0:Nnl00`00HbaS;00?Hb`0
1000BVU:J@001c6600<001S30000;P0021S300<00366<HH0136600<004YYBVT014YY00<006</Hb`0
16</00<007__Nnl017__00<00?ooool00_oo0@000Ooo000Eool00`00ooooo`02ool3W=<00`00Nnmk
k`02Nnl00`00HbaS;002Hb`00`00BVU:J@03BVT20007<HH00`006<<H``0;6<<V00036<<00`00<HH0
000=BVT00`00HbaS;00BHb`2000=Nnl00`00HbaS;009Hb`00`00HbaS;003Hb`01000BVU:J@002366
<00021S300<00366<HH0136600<004YYBVT014YY00<006</Hb`016</00<007__Nnl017__00<00?oo
ool00_oo0@000Ooo000Eool00`00ooooo`02ool3W=<00`00Nnmkk`02Nnl00`00HbaS;002Hb`00`00
BVU:J@03BVT00`00<HHaQP05<HH00`006<<H``0;6<<V00001QS300000000<HH000e:J@03001S;6</
019S;003001kkg__00akk`03001S;6</00US;003001:J@0000AS;003001:J@0000PaQP03000H``00
02h000PH``03000aQS6600@aQP03001:JDYY00=:J@03001S;6</00ES;003001kkg__00Akk`03003o
oooo00;oo`40007oo`005Ooo00<00?ooool00_oo0icC00D007__Nnmkk`0000ES;003001:JDYY00=:
J@03000aQS6600DaQP03000H`aS300/H`bD0008H``04000aQS66000=BVT00`00HbaS;00AHb`2000>
Nnl00`00HbaS;009Hb`01000BVU:J@0016</00<004YY00001c6600<001S36<<0;`0021S300<00366
<HH0136600<004YYBVT00dYY00<006</Hb`01F</00<007__Nnl017__00<00?ooool00_oo0@000Ooo
000Eool00`00ooooo`02ool3W=<00`00Nnmkk`02Nnl00`00HbaS;002Hb`00`00BVU:J@03BVT00`00
<HHaQP05<HH00`006<<H``0:6<<X0003<HH00`00BVU:J@08BVT3000DHb`00`00Nnmkk`0=Nnl00`00
HbaS;00:Hb`01000BVU:J@000V</00D004YYBVU:J@0000LaQP03000H`aS302h000PH``03000aQS66
00@aQP03001:JDYY00A:J@03001S;6</00AS;003001kkg__00Akk`03003ooooo00;oo`40007oo`00
2?oo0P001?oo0P001Ooo00<00?ooool00_oo0icC00<007__Nnl00W__00<006</Hb`00V</00<004YY
BVT00dYY0P001S6600<001S36<<02QS3:0000c6600<004YYBVT01TYY0P005f</00<007__Nnl03G__
00<006</Hb`02V</00<004YYBVT00`001DYY0`001C6600<001S36<<0;P001aS300<00366<HH01366
00<004YYBVT014YY00<006</Hb`016</00<007__Nnl017__00<00?ooool00_oo0@000Ooo0007ool0
1000ooooo`000_oo00@00?ooool000Coo`03003ooooo00;oo`>Ld`03001kkg__009kk`03001S;6</
009S;003001:JDYY00=:J@03000aQS6600DaQP03000H`aS300XH`bH000056<<00366<HH00008BVT0
0`00HbaS;00<Hb`30007Hb`00`00Nnmkk`0>Nnl00`00HbaS;00:Hb`00`00BVU:J@0;BVT20004<HH0
0`006<<0000/00086<<00`00<HHaQP04<HH00`00BVU:J@03BVT00`00HbaS;005Hb`00`00Nnmkk`03
Nnl00`00ooooo`03ool10001ool000Ooo`04003ooooo0002ool01000ooooo`001?oo0P000ooo0icC
00<007__Nnl00W__00<006</Hb`00V</00<004YYBVT00dYY00<00366<HH01C6600<001S36<<02QS3
9@000QS300@00366<HH000M:J@03001S;6</008000MS;0@000=:J@8000ES;003001kkg__00mkk`<0
00US;003001:JDYY00e:J@06000aQS66<HH001S3;@0021S300<00366<HH00c6600<004YYBVT014YY
00<006</Hb`01F</00<007__Nnl00g__00<00?ooool00_oo0P000Ooo0007ool30003ool01000oooo
o`001?oo00<00?ooool00_oo0icC00<007__Nnl00W__00<006</Hb`00V</00<004YYBVT00dYY00<0
0366<HH01C6600<001S36<<02QS390000aS300@00366<HH000I:J@03001S;6</009S;003001S;6</
00AS;003001:JDYY00E:J@03001S;6</00AS;003001kkg__019kk`03001S;6</00IS;003001:JDYY
00i:J@04000aQS66<HH]00086<<00`00<HHaQP04<HH00`00BVU:J@04BVT00`00HbaS;005Hb`00`00
Nnmkk`03Nnl00`00ooooo`03ool10001ool000Ooo`03003ooooo00?oo`04003ooooo0004ool00`00
ooooo`02ool3W=<00`00Nnmkk`02Nnl00`00HbaS;002Hb`00`00BVU:J@03BVT20006<HH00`006<<H
``0:6<<T00036<<00`00<HH00006BVT00`00HbaS;00:Hb`00`00BVU:J@05BVT00`00HbaS;004Hb`0
0`00Nnmkk`0BNnl00`00HbaS;006Hb`00`00BVU:J@03BVT30008BVT01000<HHaQS66;@0021S300<0
0366<HH0136600<004YYBVT014YY00<006</Hb`01F</00<007__Nnl00g__00<00?ooool00ooo0@00
0Ooo0007ool00`00ooooo`03ool01000ooooo`001?oo00<00?ooool00_oo0icC00<007__Nnl00W__
00<006</Hb`00V</00<004YYBVT00dYY00<00366<HH01C6600<001S36<<02AS39@000QS300@00366
<HH000A:J@8000aS;003001:JDYY00I:J@03001S;6</00AS;003001kkg__019kk`03001S;6</00MS
;005001:JDYYBVT00003Hb`00`00BVU:J@04BVT00`00<HHaQP02<HH]00086<<00`00<HHaQP04<HH0
0`00BVU:J@04BVT00`00HbaS;005Hb`00`00Nnmkk`03Nnl00`00ooooo`03ool10001ool000Soo`<0
00?oo`8000Goo`03003ooooo00;oo`>Ld`03001kkg__009kk`03001S;6</009S;003001:JDYY00=:
J@03000aQS6600DaQP03000H`aS300TH`bD0008H``04000aQS660002BVT2000>Hb`00`00BVU:J@06
BVT00`00HbaS;004Hb`00`00Nnmkk`0BNnl00`00HbaS;007Hb`50004Hb`00`00BVU:J@03BVT00`00
<HHaQP02<HH]00086<<00`00<HHaQP04<HH00`00BVU:J@04BVT00`00HbaS;004Hb`00`00Nnmkk`04
Nnl00`00ooooo`03ool10001ool001Goo`03003ooooo00;oo`BLd`05001kkg__Nnl00005Hb`00`00
BVU:J@03BVT00`00<HHaQP04<HH00`006<<H``0:6<<T00001AS3000aQS6600000TYY00<006</Hb`0
3V</00<004YYBVT01DYY00<006</Hb`01V</00<007__Nnl04G__00<006</Hb`04F</00D004YYBVU:
J@0000DaQRd000PH``03000aQS6600@aQP03001:JDYY00A:J@03001S;6</00AS;003001kkg__00Ak
k`03003ooooo00?oo`40007oo`005Ooo00<00?ooool00_oo19cC00D007__Nnmkk`0000ES;003001:
JDYY00=:J@03000aQS6600@aQP03000H`aS300XH`bH0008aQP04001:JDYY000@Hb`00`00BVU:J@05
BVT00`00HbaS;006Hb`00`00Nnmkk`0BNnl00`00HbaS;00@Hb`01@00BVU:JDYY00001C66;@0021S3
00<00366<HH0136600<004YYBVT014YY00<006</Hb`016</00<007__Nnl017__00<00?ooool00ooo
0@000Ooo000Eool00`00ooooo`02ool4W=<00`00Nnmkk`02Nnl00`00HbaS;002Hb`00`00BVU:J@03
BVT00`00<HHaQP05<HH00`006<<H``086<<U0003<HH01000BVU:J@004V</00<004YYBVT00TYY0P00
2V</00<007__Nnl04G__00<006</Hb`04F</00@004YYBVT000HaQR/000PH``03000aQS6600@aQP03
001:JDYY00A:J@03001S;6</00ES;003001kkg__00=kk`03002Ldooo00Coo`40007oo`005Ooo00<0
0?ooool00_oo19cC00<007__Nnl00W__00<006</Hb`00V</00<004YYBVT00dYY00<00366<HH01C66
00<001S36<<021S39@000S6600D004YYBVU:J@00019S;003001:JDYY00D000YS;003001kkg__011k
k`03001S;6</00IS;0<000US;003001:J@0000LaQP03000H`aS302L000PH``03000aQS6600@aQP03
001:JDYY00A:J@03001S;6</00ES;003001kkg__00=kk`03002Ldooo00Coo`40007oo`005Ooo00<0
0?ooool00_oo00D009cCW=>Ld`0000Akk`03001S;6</009S;003001:JDYY00=:J@03000aQS6600Da
QP03000H`aS300PH`b@000<aQP05001:JDYYBVT00009Hb`00`00HbaS;007Hb`200000f</001kk`02
Nnl00`00HbaS;008Hb`00`00Nnmkk`0?Nnl00`00HbaS;002Hb`40003Nnl40006Hb`20003<HH30002
<HHY00086<<00`00<HHaQP04<HH00`00BVU:J@04BVT00`00HbaS;004Hb`00`00Nnmkk`04Nnl00`00
W=?oo`04ool10001ool001Goo`8000?oo`05002LdicCW=<00004Nnl00`00HbaS;002Hb`00`00BVU:
J@03BVT00`00<HHaQP05<HH00`006<<H``086<<T0004<HH01000BVU:J@001F</100000=kk`00Hb`0
26</0P001G__00<006</Hb`026</0P003g__00D006</HbaS;00000]kk`8000AS;003001:J@000080
00=:J@8000@aQRD000PH``03000aQS6600@aQP03001:JDYY00A:J@03001S;6</00AS;003001kkg__
00Akk`03002Ldooo00?oo`80007oo`005Ooo00<00?ooool00_oo00<009cCW=<00YcC00D007__Nnmk
k`0000AS;003001:JDYY00A:J@03000aQS6600@aQP03000H`aS300TH`b8000@aQP04001:JDYY0005
Hb`00`00Nnmkk`04Nnl00`00HbaS;005Hb`01@00Nnmkkg__00000g__00<006</Hb`02V</0P003W__
00<006</00003W__00D006</HbaS;00000Q:J@03000aQS6600@aQP03000H``0001l000PH``03000a
QS6600DaQP03001:JDYY00A:J@03001S;6</00AS;003001kkg__00Akk`03002Ldooo00Coo`40007o
o`005Ooo00<00?ooool00_oo00<009cCW=<00YcC00D007__Nnmkk`0000AS;003001:JDYY00A:J@03
000aQS6600@aQP03000H`aS300TH`b8000@aQP04001:JDYY0005Hb`00`00Nnmkk`05Nnl40002Hb`0
0`00Nnmkk`030003Nnl00`00HbaS;009Hb`00`00Hb`0000>Nnl2000?Nnl01@00HbaS;6</000024YY
00<00366<HH0136600<001S300007`0021S300<00366<HH0136600<004YYBVT01DYY00<006</Hb`0
16</00<007__Nnl017__00<009cCool01?oo0@000Ooo000Eool00`00ooooo`02ool00kFF002Ld`02
W=<00`00Nnmkk`02Nnl00`00HbaS;002Hb`00`00BVU:J@03BVT00`00<HHaQP04<HH00`006<<H``09
6<<R0003<HH01000BVU:J@001F</00<007__Nnl00g__00<007__Nnl017__0P0017__0P000g__00<0
06</Hb`01f</0P0000=kk`00000057__1`0017__00D006</HbaS;00000I:J@8000LaQP03000H``00
01l000PH``03000aQS6600@aQP03001:JDYY00A:J@03001S;6</00ES;003001kkg__00=kk`03002L
dicC00Goo`40007oo`005Ooo00<00?ooool00_oo00>eUP00W=<00YcC00<007__Nnl00W__00<006</
Hb`00V</00<004YYBVT00dYY00<00366<HH0136600<001S36<<02AS38P000c6600@004YYBVT000AS
;003001kkg__00=kk`04001S;000000?Nnl00`00HbaS;006Hb`00`00Nnmkk`0ENnl20007W=<01@00
Nnmkkg__00000f</00<004YYBVT010002C6600<001S300007`0021S300<00366<HH0136600<004YY
BVT014YY00<006</Hb`01F</00<007__Nnl00g__00<009cCW=<01Ooo0@000Ooo000Eool00`00oooo
o`02ool00kFF002Ld`03W=<01@00Nnmkkg__000016</00<004YYBVT00dYY00<00366<HH01C6600<0
01S36<<01aS38@0000DH``00<HHaQP00009:J@03001S;6</009S;003001kkg__00Ekk`8000mkk`03
001S;6</00QS;003001kkg__01=kk`03002LdicC00RLd`05001kkg__Nnl00002Hb`01000BVU:J@00
2c6600<001S300007`0021S300<00366<HH01C6600<004YYBVT014YY00<006</Hb`016</00<007__
Nnl017__00<009cCW=<01Ooo0@000Ooo000Eool00`00ooooo`02ool00kFF002Ld`03W=<01@00Nnmk
kg__000016</00<004YYBVT00dYY00<00366<HH01C6600<001S36<<01aS38@0000DH``00<HHaQP00
009:J@05001S;6</Hb`00008Nnl00`00Nnmkk`05Nnl00`00Nnmkk`06Nnl00`00HbaS;008Hb`00`00
Nnmkk`0BNnl2000:W=<01@00Nnmkkg__00000V</00@004YYBVT000/aQP03000H``0001l000PH``03
000aQS6600DaQP03001:JDYY00A:J@03001S;6</00AS;003001kkg__00Akk`03002LdicC00Goo`40
007oo`005Ooo00<00?ooool00_oo00>eUP00W=<00icC00<007__Nnl00W__00<006</Hb`00V</00<0
04YYBVT00dYY00<00366<HH0136600<001S36<<021S38@000c6600L004YYBVU:J@00Hb`0000?Nnl0
0`00Nnl00007Nnl00`00HbaS;009Hb`00`00Nnmkk`0ANnl00`00W=>Ld`0;W=<01P00Nnmkk`00Hb`0
00=:J@03000aQS6600TaQP03000H``0001h000TH``03000aQS6600@aQP03001:JDYY00E:J@03001S
;6</00AS;003001kkg__00=kk`04002LdicCW=<5ool10001ool001Goo`03003ooooo00;oo`03]IH0
09cC00>Ld`03001kkg__009kk`03001S;6</009S;003001:JDYY00=:J@03000aQS6600@aQP03000H
`aS300PH`al000036<<00366008aQP07001:JDYYBVT006</00003g__0`001g__00<006</Hb`026</
00<007__Nnl04G__00<009cCW=<039cC00H007__Nnl006</0003BVT00`00<HHaQP09<HHQ00096<<0
0`00<HHaQP04<HH00`00BVU:J@05BVT00`00HbaS;004Hb`00`00Nnmkk`03Nnl01000W=>LdicC1Ooo
0@000Ooo000Eool00`00ooooo`02ool2]IH01@00W=>LdicC000017__00<006</Hb`00V</00<004YY
BVT014YY00<00366<HH00c6600<001S36<<021S37P0000<H``00<HH00c6600@004YYBVT0009S;003
001kkg__00akk`04002LdicC0005Nnl2000:Hb`00`00Nnmkk`08Nnl30005Nnl2000@W=<01@00Nnl0
06</00000TYY00<00366<HH02C668P0021S300<00366<HH01C6600<004YYBVT014YY00<006</Hb`0
16</00<007__Nnl017__00@009cCW=>Ld`Goo`40007oo`005Ooo0P000ooo0[FF00D009cCW=>Ld`00
00Akk`03001S;6</009S;003001:JDYY00A:J@03000aQS6600<aQP03000H`aS300PH`ah000036<<0
036600<aQP04001:J@000002Hb`00`00Nnmkk`0;Nnl01@00W=>LdicC00000g__0P0016</00<006</
Hb`01F</00<007__Nnl01g__00@009cCW=>Ld`D001:Ld`05001kk`00Hb`00002BVT00`00<HHaQP08
<HH00`006<<0000P00086<<00`00<HHaQP05<HH00`00BVU:J@04BVT00`00HbaS;004Hb`00`00Nnmk
k`04Nnl01000W=>LdicC1?oo0P000Ooo000Eool00`00ooooo`02ool2]IH00`00W=>Ld`02W=<00`00
Nnmkk`02Nnl00`00HbaS;002Hb`00`00BVU:J@03BVT00`00<HHaQP04<HH00`006<<H``086<<M0000
0aS3000aQP02<HH00`00BVT00003Hb`00`00Nnmkk`0;Nnl00`00W=>Ld`03W=<00`00Nnl00004Hb`2
00000g__000000050009Nnl00`00W=>Ld`0HW=<00`00Nnmkk`020002BVT00`00<HHaQP09<HH00`00
6<<0000O00096<<00`00<HHaQP05<HH00`00BVU:J@03BVT00`00HbaS;005Hb`00`00Nnmkk`04Nnl0
1000W=>LdicC1Ooo0@000Ooo000Eool00`00ooooo`02ool2]IH00`00W=>Ld`02W=<00`00Nnmkk`02
Nnl00`00HbaS;002Hb`00`00BVU:J@03BVT00`00<HHaQP04<HH00`006<<H``086<<N0003<HH00`00
BVT00004Hb`00`00Nnmkk`0:Nnl00`00W=>Ld`04W=<20004Hb`00`00Nnmkk`0@Nnl00`00W=>Ld`0I
W=<00`00Nnmkk`020002BVT00`00<HHaQP09<HHR00096<<00`00<HHaQP04<HH00`00BVU:J@04BVT0
0`00HbaS;005Hb`00`00Nnmkk`04Nnl01000W=>LdicC1Ooo0@000Ooo000Eool00`00ooooo`02ool3
]IH01@00W=>LdicC000017__00<006</Hb`00f</00<004YYBVT00TYY00<00366<HH01C6600<001S3
6<<01aS3700000LH``00<HHaQP00BVT00004Hb`00`00Nnmkk`0;Nnl00`00W=>Ld`03W=<00`00Nnl0
0004Hb`00`00Nnmkk`0>Nnl2000KW=<02@00Nnmkkg__001S;000BVT0000:<HHR00096<<00`00<HHa
QP05<HH00`00BVU:J@04BVT00`00HbaS;004Hb`00`00Nnmkk`04Nnl00`00W=>Ld`02W=<5ool10001
ool001Goo`03003ooooo00;oo`>eUP04002LdicCW=<20003Nnl00`00HbaS;003Hb`00`00BVU:J@02
BVT00`00<HHaQP05<HH00`006<<H``076<<L000011S3000aQP000TYY00<006</Hb`00V</00<007__
Nnl00g__00<007__Nnl01G__00<009cCW=<00icC00<007__000016</00<007__Nnl02W__10007IcC
00H007__Nnmkk`00Hb`2000;<HHR00096<<00`00<HHaQP05<HH00`00BVU:J@04BVT00`00HbaS;004
Hb`00`00Nnmkk`04Nnl00`00W=>Ld`02W=<5ool10001ool001Goo`03003ooooo00;oo`>eUP03002L
dicC00:Ld`03001kkg__009kk`03001S;6</009S;003001:JDYY00=:J@03000aQS6600@aQP03000H
`aS300PH`aX000046<<003660002BVT01000HbaS;6</0P001G__00<009cC00001G__00<009cCW=<0
19cC0P0016</00<007__Nnl02W__00<009cCW=<07IcC0P0017__00@006</000000XaQP03000H``00
01l000XH``03000aQS6600@aQP03001:JDYY00E:J@03001S;6</00AS;003001kkg__00Akk`03002L
dicC00:Ld`03003ooooo00;oo`40007oo`005Ooo00<00?ooool00_oo0kFF0P000icC00<007__Nnl0
0W__00<006</Hb`00V</00<004YYBVT00dYY00<00366<HH0136600<001S36<<021S36P0000@H``00
<HH0009:J@05001S;6</Hb`00005Nnl01@00W=>LdicC00000g__00<009cCW=<01IcC0P0016</00<0
07__Nnl02W__00<009cCW=<079cC00<007__Nnl017__00@006</000000XaQR8000XH``03000aQS66
00@aQP03001:JDYY00A:J@03001S;6</00ES;003001kkg__00Akk`03002LdicC00:Ld`03003ooooo
00;oo`40007oo`005Ooo00<00?ooool00_oo00<00;FF]IH00[FF00D009cCW=>Ld`0000Akk`03001S
;6</009S;003001:JDYY00=:J@03000aQS6600@aQP03000H`aS300PH`aT000046<<003660002BVT0
1@00HbaS;6</00001G__00<009cCW=<00YcC0`0029cC00<007__000016</00<007__Nnl027__00<0
09cCW=<079cC00<007__Nnl01G__00@006</000000TaQP03000H``00020000XH``03000aQS6600@a
QP03001:JDYY00A:J@03001S;6</00AS;003001kkg__00Akk`03002LdicC00>Ld`03003ooooo00;o
o`40007oo`005Ooo00<00?ooool00_oo00<00;FF]IH00[FF00D009cCW=>Ld`0000Akk`03001S;6</
009S;003001:JDYY00=:J@03000aQS6600DaQP03000H`aS300LH`aT000046<<003660002BVT01@00
HbaS;6</00001G__00<009cCW=<03IcC00<007__000016</0P002G__00<009cCW=<079cC00<007__
Nnl01G__00@006</000000TaQP03000H``00020000XH``03000aQS6600@aQP03001:JDYY00A:J@03
001S;6</00AS;003001kkg__00Akk`03002LdicC00>Ld`03003ooooo00;oo`40007oo`005Ooo00<0
0?ooool00_oo00<00;FF]IH00[FF00D009cCW=>Ld`0000Akk`03001S;6</009S;003001:JDYY00=:
J@03000aQS6600DaQP03000H`aS300LH`aP000056<<00366<HH00002BVT01000HbaS;0001G__00<0
09cCW=<029cC00<009cCW=<00icC0P001f</0P001W__00<009cCW=<079cC00<007__Nnl01W__00@0
06</000000PaQP03000H``00020000XH``03000aQS6600DaQP03001:JDYY00=:J@03001S;6</00ES
;003001kkg__00=kk`03002LdicC00>Ld`03003ooooo00?oo`40007oo`005Ooo0P000ooo00<00;FF
]IH00[FF00@009cCW=>Ld`8000=kk`03001S;6</00=S;003001:JDYY009:J@03000aQS6600DaQP03
000H`aS300LH`aT0008aQP05001:JDYYBVT00002Hb`00`00Nnmkk`02Nnl20008W=<200000kFF002L
d`03W=<20009Hb`00`00Nnmkk`03Nnl00`00W=>Ld`0LW=<00`00Nnmkk`06Nnl01000Hb`000002366
8P002QS300<00366<HH01C6600<004YYBVT014YY00<006</Hb`016</00<007__Nnl017__00<009cC
W=<00icC00<00?ooool00_oo0P000Ooo000Eool00`00ooooo`02ool00lii002eUP02]IH00`00W=>L
d`02W=<00`00Nnmkk`02Nnl00`00HbaS;002Hb`00`00BVU:J@03BVT00`00<HHaQP05<HH00`006<<H
``076<<H0002<HH01000BVU:J@000f</00D007__Nnmkk`0000RLd`8000BeUP07002LdicCW=<007__
00002F</00<007__Nnl00W__00<009cCW=<07IcC00<007__Nnl01G__0P0000=:J@00<HH01S6600<0
01S300007`002QS300<00366<HH01C6600<004YYBVT014YY00<006</Hb`01F</00<007__Nnl017__
00<009cCW=<00icC00<00?ooool00ooo0@000Ooo000Eool00`00ooooo`02ool00lii002eUP02]IH2
0003W=<00`00Nnmkk`02Nnl00`00HbaS;002Hb`00`00BVU:J@04BVT00`00<HHaQP04<HH00`006<<H
``076<<H0002<HH01000BVU:J@000V</0P000g__00<009cCW=<01YcC00<00;FF]IH00kFF00L009cC
W=>Ld`00Nnl00003Hb`30004Hb`20002Nnl00`00W=>Ld`0MW=<00`00Nnmkk`05Nnl200000dYY000a
QP06<HH00`006<<0000O000:6<<00`00<HHaQP05<HH00`00BVU:J@04BVT00`00HbaS;005Hb`00`00
Nnmkk`04Nnl00`00W=>Ld`02W=<20005ool10001ool001Goo`03003ooooo00;oo`;>N@05002eU[FF
]IH00004W=<01@00Nnmkkg__00001F</00<004YYBVT00dYY00<00366<HH01C6600<001S36<<01aS3
5`0000<aQP00BVT00TYY00@006</Hb`000Akk`03002LdicC00BLd`8000FeUP03002LdicC00:Ld`03
001kk`00009S;005001kkg__Nnl00005Hb`00`00Nnl0000PW=<20005Nnl01000Hb`000001c668@00
2QS300<00366<HH01S6600<004YYBVT014YY00<006</Hb`016</00<007__Nnl017__00<009cCW=<0
0icC00<00;FFool01?oo0@000Ooo000Eool00`00ooooo`02ool2cWT01@00]IJeU[FF000019cC0P00
0g__00<006</Hb`00V</00<004YYBVT00dYY00<00366<HH01C6600<001S36<<021S35P0000<aQP00
BVT00TYY00@006</Hb`000Akk`03002LdicC00BLd`03002eU[FF00BeUP03002LdicC00:Ld`03001k
kg__008000Akk`03001S;6</00=S;004001kk`00000QW=<20004Nnl40006<HHP000;6<<00`00<HHa
QP06<HH00`00BVU:J@04BVT00`00HbaS;004Hb`00`00Nnmkk`04Nnl00`00W=>Ld`03W=<00`00]IKo
o`04ool10001ool001Goo`03003ooooo00;oo`?>N@05002eU[FF]IH00004W=<00`00Nnmkk`02Nnl0
0`00HbaS;002Hb`00`00BVU:J@03BVT00`00<HHaQP05<HH00`006<<H``086<<D000011S3000aQP00
0TYY00@006</Hb`000Akk`03002LdicC00BLd`05002eU[FF]IH00002]IH00`00W=>Ld`02W=<00`00
Nnmkk`07Nnl01@00HbaS;6</00000g__00<009cCW=<079cC0`000YcC0P000g__00<004YYBVT01000
0S6600<001S30000700031S300<00366<HH01C6600<004YYBVT014YY00<006</Hb`01F</00<007__
Nnl017__00<009cCW=<00icC00<00;FFool01?oo0@000Ooo000Eool00`00ooooo`02ool3cWT01@00
]IJeU[FF000019cC00<007__Nnl00W__00<006</Hb`00V</00<004YYBVT014YY00<00366<HH01366
00<001S36<<021S3500000DH``00<HH004YY0080009S;003001kkg__009kk`03002LdicC00BLd`05
002eU[FF]IH00002]IH00`00W=>Ld`02W=<00`00Nnmkk`08Nnl40003Nnl00`00W=>Ld`0LW=<00`00
]IJeUP020002W=<01000Nnmkk`001TYY00@00366000H`ad000`H``03000aQS6600DaQP03001:JDYY
00A:J@03001S;6</00ES;003001kkg__00Akk`03002LdicC00>Ld`03002eU_oo00Coo`40007oo`00
5Ooo00<00?ooool00_oo0lii00<00;FF]IH00[FF00<009cCW=<00YcC00D007__Nnmkk`0000ES;003
001:JDYY00=:J@03000aQS6600DaQP03000H`aS300PH`a@00006<HH004YYBVT006</0P0017__00<0
09cCW=<019cC00<00;FF]IH00P0000FLd`00]IJeUP0000BLd`03001kkg__00Akk`03001kkg__00Mk
k`03002LdicC01^Ld`03002eU[FF00>eUP03002LdicC00800003Hb`004YY00E:J@8000036<<00000
01X000`H``03000aQS6600DaQP03001:JDYY00A:J@03001S;6</00ES;003001kkg__00Akk`03002L
dicC00>Ld`03002eU[FF00Goo`40007oo`002?oo0P001?oo0P001Ooo00<00?ooool00_oo0lii00<0
0;FF]IH00[FF00<009cCW=<00YcC00<007__Nnl00W__00<006</Hb`00V</00<004YYBVT00dYY00<0
0366<HH01C6600<001S36<<021S3500000LaQP00BVU:J@00Hb`00005Nnl00`00W=>Ld`04W=<01000
]IJeUP000YcC00@00;FF]IH000BLd`03001kkg__009kk`<000Ukk`03002LdicC01^Ld`03002eU[FF
00>eUP800004W=<00000Hb`600000dYY0000000L000<6<<00`00<HHaQP06<HH00`00BVU:J@04BVT0
0`00HbaS;004Hb`00`00Nnmkk`04Nnl00`00W=>Ld`03W=<01000]IJeU[FF1Ooo0@000Ooo0007ool0
1000ooooo`000_oo00@00?ooool000Coo`03003ooooo00;oo`C>N@03002eU[FF00:eUP03002LdicC
00:Ld`03001kkg__009kk`03001S;6</009S;003001:JDYY00=:J@03000aQS6600DaQP03000H`aS3
00TH`a<00006<HH004YY001S;00017__00<009cCW=<019cC00D00;FF]IJeUP0000:Ld`04002eU[FF
]IH20003W=<01@00Nnmkkg__00000YcC0P001W__00<009cCW=<07IcC00<00;FF]IH01;FF00<009cC
00000`0016</7P003AS300<00366<HH01C6600<004YYBVT01DYY00<006</Hb`016</00<007__Nnl0
17__00<009cCW=<00icC00D00;FF]IJeUP0000Coo`40007oo`001ooo00@00?ooool000;oo`04003o
oooo0004ool20003ool4cWT00`00]IJeUP02]IH00`00W=>Ld`02W=<00`00Nnmkk`02Nnl00`00HbaS
;002Hb`00`00BVU:J@04BVT00`00<HHaQP05<HH00`006<<H``086<<C00001S66001:J@00Hb`000Ak
k`03002LdicC00BLd`05002eU[FF]IH00002W=<00`00]IJeUP03]IH20002W=<01000Nnmkk`0019cC
1P002icC0P004icC00<00;FF]IH01KFF00<009cC00000W__100000=S;00000006`0031S30P001c66
00<004YYBVT01DYY00<006</Hb`016</00<007__Nnl017__00<009cCW=<00icC00D00;FF]IJeUP00
00?oo`80007oo`002?oo0P000ooo00@00?ooool000Coo`03003ooooo00;oo`03003>NLii00;>N@05
002eU[FF]IH00004W=<00`00Nnmkk`02Nnl00`00HbaS;003Hb`00`00BVU:J@03BVT00`00<HHaQP06
<HH00`006<<H``086<<C000014YY001S;00017__00<009cCW=<019cC00<00;FF]IH00[FF00@009cC
W=<000NeUP03002LdicC008001FLd`03002eU[FF0080012Ld`03002eU[FF00NeUP04002Ld`000004
NnlM000<6<<00`00<HHaQP06<HH00`00BVU:J@05BVT00`00HbaS;005Hb`00`00Nnmkk`03Nnl00`00
W=>Ld`03W=<01@00]IJeU[FF00001Ooo0@000Ooo0007ool01000ooooo`000_oo00@00?ooool000Co
o`03003ooooo00;oo`03003>NLii00;>N@04002eU[FF]IH20003W=<00`00Nnmkk`03Nnl00`00HbaS
;002Hb`00`00BVU:J@03BVT00`00<HHaQP06<HH00`006<<H``086<<@00001aS3000004YY001S;000
00Akk`03002LdicC00>Ld`03002eU[FF00>eUP04002LdicC0007]IH2000HW=<00`00]IJeUP02]IH0
0`00W=>Ld`0<W=<20009]IH20002W=<20002NnlM000;6<<20008<HH00`00BVU:J@05BVT00`00HbaS
;004Hb`00`00Nnmkk`03Nnl00`00W=>Ld`03W=<20003]IH20004ool10001ool000Ooo`04003ooooo
0002ool01000ooooo`001?oo00<00?ooool00_oo00?W?000cWT00/ii00<00;FF]IH00[FF00<009cC
W=<00YcC00<007__Nnl00W__00<006</Hb`00V</00<004YYBVT014YY00<00366<HH01S6600<001S3
6<<021S33`0000LH``00001:J@00Hb`00002Nnl20005W=<00`00]IJeUP04]IH00`00W=<0000:]IH2
000CW=<30006]IH00`00W=>Ld`07W=<01000W=<000003KFF00H009cCW=>Ld`00NnlL000;6<<00`00
<HHaQP07<HH00`00BVU:J@05BVT00`00HbaS;004Hb`00`00Nnmkk`04Nnl00`00W=>Ld`03W=<01`00
]IJeU[FF003>N@0000Coo`40007oo`002?oo0P001?oo0P001Ooo00<00?ooool00_oo00?W?000cWT0
0/ii0P000kFF00<009cCW=<00YcC00<007__Nnl00W__00<006</Hb`00f</00<004YYBVT014YY00<0
0366<HH01C6600<001S36<<02AS33P0000LH``00001:J@00Hb`00002Nnl00`00W=>Ld`04W=<00`00
]IJeUP04]IH00`00W=<0000;]IH30007W=<01000W=>LdicC1P002[FF0P001IcC10003kFF00H009cC
W=>Ld`00NnlK000<6<<00`00<HHaQP07<HH00`00BVU:J@04BVT00`00HbaS;005Hb`00`00Nnmkk`04
Nnl00`00W=>Ld`03W=<01`00]IJeU[FF003>N@0000Coo`40007oo`005Ooo00<00?ooool00_oo0^Ll
00D00<iicWW>N@0000BeUP03002LdicC00:Ld`03001kkg__009kk`03001S;6</00=S;08000E:J@03
000aQS6600DaQP03000H`aS300TH``h00006<HH004YY001S;0000W__00<009cCW=<00icC00<00;FF
]IH01KFF0P003kFF00<009cCW=<00YcC0P0000BeUP00000001:eUPD001BeUP05002LdicC001kk`03
00000aS30000000D000;6<<20009<HH00`00BVU:J@04BVT20006Hb`00`00Nnmkk`04Nnl00`00W=>L
d`03W=<00`00]IJeUP02]IH20005ool10001ool001Goo`03003ooooo00;oo`;W?003003>NLii00;>
N@03002eU[FF00:eUP03002LdicC00:Ld`05001kkg__Nnl00006Hb`00`00BVU:J@04BVT00`00<HHa
QP05<HH00`006<<H``0;6<<;00002366001:J@00Hb`007__0006W=<00`00]IJeUP0G]IH01@00W=>L
dicC0000;kFF00D009cCW=<007__01T000dH``03000aQS6600LaQP03001:JDYY00A:J@03001S;6</
00ES;003001kkg__00Ekk`03002LdicC00>Ld`04002eU[FF]IH200000nLlooooo`03ool10001ool0
01Goo`03003ooooo00;oo`?W?005003>NLiicWT00004]IH00`00W=>Ld`02W=<00`00Nnmkk`02Nnl2
0005Hb`00`00BVU:J@03BVT20007<HH00`006<<H``0:6<<;00002366001:J@00Hb`007__0006W=<2
000I]IH3000_]IH01P00W=>LdicC001kkaP000hH``03000aQS6600HaQP03001:JDYY00E:J@03001S
;6</00ES;003001kkg__00Akk`03002LdicC00>Ld`08002eU[FF]IH00<ii003W?0Goo`40007oo`00
5Ooo00<00?ooool00_oo00@00>Llic`000C>N@03002eU[FF00:eUP05002LdicCW=<00005Nnl00`00
HbaS;003Hb`00`00BVU:J@05BVT00`00<HHaQP05<HH00`006<<H``0:6<<9000011S3000004YY0P00
0W__00<009cCW=<019cC00<00;FF]IH0B[FF00H009cCW=>Ld`00NnlG000>6<<00`00<HHaQP07<HH0
0`00BVU:J@05BVT00`00HbaS;004Hb`00`00Nnmkk`04Nnl00`00W=>Ld`03W=<01`00]IJeU[FF003>
N@0000;W?0Goo`40007oo`005Ooo0P000ooo00@00>Llic`000C>N@03002eU[FF00:eUP03002LdicC
00:Ld`8000=kk`8000AS;08000I:J@03000aQS6600HaQP03000H`aS300XH``P000036<<0000000<0
009kk`03002LdicC00BLd`03002eU[FF04VeUP03002LdicC00:Ld`03001kk`0001H000dH``03000a
QS6600LaQP03001:JDYY00E:J@03001S;6</00ES;003001kkg__00Akk`03002LdicC00>Ld`07002e
U[FF]IH00<ii00000^Ll1?oo0P000Ooo000Eool00`00ooooo`03ool01000iccW?0001<ii00<00;FF
]IH00[FF00<009cCW=<00YcC00<007__Nnl00g__00<006</Hb`00f</00<004YYBVT00dYY00<00366
<HH01c6600<001S36<<02QS31P0000<H``00<HH00P0000ES;000Nnmkk`0000FLd`03002eU[FF04Ze
UP06002LdicCW=<007__5`003AS300<00366<HH01c6600<004YYBVT01DYY00<006</Hb`01F</00<0
07__Nnl01G__00<009cCW=<00icC00H00;FF]IH00<ii0003ic`5ool10001ool001Goo`03003ooooo
00?oo`04003W?>Ll0004cWT00`00]IJeUP02]IH00`00W=>Ld`02W=<00`00Nnmkk`03Nnl00`00HbaS
;003Hb`00`00BVU:J@04BVT00`00<HHaQP06<HH00`006<<H``0;6<<500001AS3000004YY00000V</
00<007__000019cC00<00;FF]IH0?kFF10002;FF00H009cCW=>Ld`00NnlF000=6<<00`00<HHaQP08
<HH00`00BVU:J@05BVT00`00HbaS;004Hb`00`00Nnmkk`05Nnl00`00W=>Ld`03W=<01000]IJeU[FF
0P001>Ll1Ooo0@000Ooo000Eool00`00ooooo`04ool01000iccW?0001<ii00<00;FF]IH00[FF00<0
09cCW=<00YcC00<007__Nnl00W__00<006</Hb`00f</00<004YYBVT01DYY00<00366<HH01S660P00
31S3100000<H``0000000TYY00<006</00000W__00<009cCW=<00YcC00<00;FF]IH0?KFF00D00<ii
cWW>N@0000ReUP08002LdicCW=<007__001S;1@000`H``03000aQS6600PaQP03001:JDYY00E:J@03
001S;6</00ES;003001kkg__00Akk`03002LdicC00>Ld`03002eU[FF00:eUP03003>N@0000?W?0Go
o`40007oo`005Ooo00<00?ooool01Ooo00@00>Llic`000C>N@04002eU[FF]IH20004W=<00`00Nnmk
k`02Nnl20004Hb`20006BVT00`00<HHaQP07<HH00`006<<H``0>6<<20002BVT00`00Hb`00002Nnl0
0`00W=>Ld`02W=<00`00]IJeUP0Y]IH7000;]IH20005cWT20006]IH02000W=>LdicC001kk`00Hb`C
000=6<<00`00<HHaQP08<HH00`00BVU:J@05BVT00`00HbaS;005Hb`00`00Nnmkk`04Nnl00`00W=>L
d`03W=<00`00]IJeUP02]IH00`00cWT00003ic`5ool10001ool001Goo`03003ooooo00Goo`05003W
?>Llic`00003cWT00`00]IJeUP03]IH00`00W=>Ld`02W=<00`00Nnmkk`02Nnl00`00HbaS;003Hb`0
0`00BVU:J@05BVT00`00<HHaQP07<HH00`006<<H``0=6<<2000014YY001S;0000W__00<009cCW=<0
0YcC00<00;FF]IH0:[FF00<00<iicWT00lii00<00;FF]IH01KFF10002<ii00<00;FF]IH01;FF00L0
09cCW=<007__001S;00C000>6<<00`00<HHaQP07<HH00`00BVU:J@05BVT00`00HbaS;005Hb`00`00
Nnmkk`05Nnl00`00W=>Ld`03W=<01000]IJeU[FF0`001>Ll1Ooo0@000Ooo000Eool00`00ooooo`05
ool01@00iccW?>Ll00000lii00<00;FF]IH00kFF00<009cCW=<00YcC00<007__Nnl00g__00<006</
Hb`00f</00<004YYBVT01DYY00<00366<HH01c6600<001S36<<02aS300L00366001:J@00Hb`00002
Nnl00`00W=>Ld`02W=<00`00]IJeUP09]IH4000M]IH00`00cWW>N@04cWT20004]IH00`00cWW>N@0:
cWT00`00]IJeUP04]IH01`00W=>Ld`00Nnl006</018000dH``8000TaQP03001:JDYY00E:J@03001S
;6</00ES;08000Ekk`8000FLd`04002eU[FF]IH30005ic`5ool10001ool001Goo`03003ooooo00;o
o`05003oooooool00003ic`01@00cWW>NLii00001;FF00<009cCW=<00icC00<007__Nnl00g__00<0
06</Hb`00f</00<004YYBVT01DYY00<00366<HH01c6600<001S36<<02QS300L00366001:J@00Hb`0
0002Nnl00`00W=>Ld`02W=<00`00]IJeUP0:]IH2000M]IH00`00cWW>N@06cWT5000=cWT00`00]IJe
UP04]IH01`00W=>Ld`00Nnl006</010000lH``03000aQS6600LaQP03001:JDYY00E:J@03001S;6</
00ES;003001kkg__00Ekk`03002LdicC00>Ld`07002eU[FF]IH00<ii00001^Ll1Ooo0@000Ooo000E
ool00`00ooooo`02ool20003ool01000iccW?0000lii00<00;FF]IH00[FF0P0019cC00<007__Nnl0
0g__00<006</Hb`00f</00<004YYBVT01DYY0P0023660P002aS300L00366001:J@00Hb`00002Nnl0
0`00W=>Ld`02W=<00`00]IJeUP0;]IH00`00]IJeUP0K]IH00`00cWW>N@0HcWT00`00]IJeUP04]IH0
1`00W=>Ld`00Nnl006</00l000lH``03000aQS6600PaQP03001:JDYY00E:J@03001S;6</00AS;003
001kkg__00Ekk`03002LdicC00BLd`07002eU[FF]IH00<ii00001^Ll1Ooo0@000Ooo000Eool00`00
ooooo`02ool30003ool01000iccW?0000lii0P001;FF00<009cCW=<00YcC00<007__Nnl00g__00<0
06</Hb`00f</00<004YYBVT01TYY00<00366<HH01c6600<001S36<<02AS300H00366000006</0002
Nnl00`00W=>Ld`02W=<00`00]IJeUP0?]IH00`00]IJeUP0G]IH00`00cWW>N@0IcWT00`00]IJeUP04
]IH01P00W=<007__001S;0d0010H``03000aQS6600PaQP03001:JDYY00E:J@03001S;6</00AS;003
001kkg__00Ikk`03002LdicC00>Ld`03002eU[FF00:eUP03003>N@0000KW?0Goo`40007oo`005Ooo
0P000ooo0`000ooo00@00>Llic`000C>N@03002eU[FF00:eUP03002LdicC00>Ld`8000Akk`03001S
;6</00=S;003001:JDYY00E:J@8000TaQP03000H`aS300PH``06000aQP00001S;0000W__00<009cC
W=<00YcC00<00;FF]IH03[FF00<00<ii00000P005[FF00<00<iicWT06Lii00<00;FF]IH01;FF00H0
09cC001kk`00Hb`:000A6<<2000:<HH00`00BVU:J@06BVT00`00HbaS;004Hb`00`00Nnmkk`06Nnl0
0`00W=>Ld`03W=<01000]IJeU[FF0`001nLl1?oo0P000Ooo000Eool00`00ooooo`02ool40003ool0
1000iccW?0001<ii00D00;FF]IJeUP0000NLd`05001kkg__Nnl00006Hb`00`00BVU:J@06BVT00`00
<HHaQP07<HH00`006<<H``076<<20002BVT20002Nnl01@00W=>LdicC00002[FF00<00;FF]IH01;FF
00<00<iicWT00/ii00<00;FF]IH04kFF00<00<iicWT06<ii00<00;FF]IH01;FF00D009cCW=<007__
00<0008H``<001@H``03000aQS6600XaQP03001:JDYY00E:J@03001S;6</00=S;0<000Mkk`03002L
dicC00>Ld`07002eU[FF]IH00<ii00002>Ll1Ooo0@000Ooo000Eool00`00ooooo`02ool40003ool0
1000iccW?0001<ii00<00;FF]IH00[FF00<009cCW=<019cC00<007__Nnl00W__00<006</Hb`00f</
00<004YYBVT01TYY0P002C6600<001S36<<01QS30P000TYY0P000W__00D009cCW=>Ld`0000ReUP<0
00JeUP03003>NLii00?>N@H000>eUP03002eU[FF00NeUP8001W>N@8000NeUP04002Ld`00Nnl40003
6<<00`006<<H``0A6<<2000;<HH20007BVT00`00HbaS;002Hb`20009Nnl00`00W=>Ld`04W=<01`00
]IJeU[FF003>N@0000SW?0Goo`40007oo`005Ooo00<00?ooool00_oo00=kk`0000000P000ooo00@0
0>Llic`000?>N@03002eU[FF00>eUP03002LdicC00BLd`03001kkg__009kk`03001S;6</00=S;003
001:JDYY00M:J@03000aQS6600LaQP03000H`aS300DH``04000aQP00BVT20003Nnl01@00W=>LdicC
00001[FF00D00<iicWW>N@0000BeUP03003>NLii00[>N@<00003cWT0000000JeUP03003>NLii01O>
N@8000ReUP03002LdicC00800003Hb`0000001LH``03000aQS6600/aQP03001:JDYY00E:J@03001S
;6</00=S;005001kkg__Nnl00005Nnl00`00W=>Ld`04W=<00`00]IJeUP02]IH20009ic`5ool10001
ool001Goo`03003ooooo00;oo`D000?oo`04003W?>Ll0003cWT20005]IH01000W=>Ld`000icC00@0
07__Nnmkk`8000ES;003001:JDYY00M:J@03000aQS6600LaQP8000DH``04000aQP00BVT20003Nnl0
1000W=>LdicC0P001KFF00D00<iicWW>N@0000BeUP03003>NLii013>N@03002eU[FF00>eUP03003>
NLii00W>N@8000[>N@8000ZeUP03002LdicC00D001HH``03000aQS6600XaQP8000M:J@03001S;6</
00AS;005001kk`00002Ld`020002Nnl20005W=<00`00]IJeUP02]IH00`00cWT00009ic`00`00oooo
o`02ool10001ool001Goo`03003ooooo00;oo`03BVT0000000<000?oo`04003W?>Ll0004cWT00`00
]IJeUP03]IH200001KFF002LdicC00001G__00<006</Hb`00f</00<004YYBVT01dYY00<00366<HH0
236600<001S36<<00QS300L00366001:J@00Hb`00002Nnl00`00W=>Ld`02W=<00`00]IJeUP03]IH0
0`00cWW>N@02cWT01@00]IJeU[FF00004lii00<00;FF]IH00[FF00<00<iicWT01lii0P000[FF2P00
3;FF00L009cC001kk`00BVT0000F6<<00`00<HHaQP0:<HH00`00BVU:J@06BVT00`00HbaS;005Hb`0
1000Nnmkk`000icC0P000icC1@000kFF00<00<ii00002NLl0P001?oo0@000Ooo000Eool00`00oooo
o`02ool60003ool01000iccW?0001<ii00<00;FF]IH01kFF00<009cC00001G__00<006</Hb`016</
00<004YYBVT01dYY00<00366<HH0236600/001S36<<H``00<HH004YY001S;00000=kk`03002LdicC
00:Ld`03002eU[FF00:eUP03003>NLii00;>N@05002eU[FF]IH0000CcWT00`00]IJeUP02]IH01000
cWT000000/ii10006KFF00<009cCW=<01@0051S30P0033660P0024YY00<006</Hb`01F</00D007__
Nnmkk`0000FLd`8000NeUP<000[W?08000Coo`40007oo`005Ooo00<00?ooool00_oo1`000ooo00@0
0>Llic`000C>N@03002eU[FF00:eUP04002eU[FF0003W=<00`00Nnmkk`03Nnl00`00HbaS;004Hb`0
0`00BVU:J@07BVT00`00<HHaQP08<HH020006<<H``00<HH004YY0002Hb`01@00Nnmkkg__00000icC
00<00;FF]IH00kFF00<00<iicWT00/ii0P000[FF0P002Lii00<00<iicWT01/ii00<00;FF]IH00[FF
00<00<ii00000P007;FF00<009cCW=<00P0000AS;000000001<H``03000aQS6600/aQP03001:JDYY
00M:J@03001S;6</00ES;003001kkg__009kk`04002LdicCW=<20008]IH00`00cWT0000:ic`30004
ool10001ool001Goo`03003ooooo00;oo`P000;oo`04003W?>Ll0005cWT400001<ii002eUP0019cC
00<007__Nnl00g__00<006</Hb`016</0P0024YY00<00366<HH0236600L001S3000aQP00BVT00002
Hb`20002Nnl20002W=<00`00]IJeUP03]IH00`00cWW>N@04cWT01@00]IJeU[FF00001lii00<00;FF
00002<ii0P000[FF0`007[FF00@009cC001kk`800003BVT00000018H``03000aQS6600/aQP03001:
JDYY00M:J@03001S;6</00ES;003001kkg__00Akk`03002Ld`0000ZeUP03003>N@0000[W?0<000Co
o`40007oo`005Ooo00<00?ooool00_oo2@000_oo0P0000?W?000cWT02<ii00@00;FF]IH000BLd`80
00Akk`03001S;6</00ES;003001:JDYY00I:J@03000aQS6600PaQP80008aQP03001:J@0000=S;007
001kkg__Nnl009cC00001;FF00<00<iicWT01Lii00<00;FF]IH00[FF00<00<iicWT01<ii00@00;FF
]IH000W>N@03002eU[FF01neUP06002Ld`00Nnl006</0P0000<aQP006<<041S300<00366<HH02c66
00<004YYBVT024YY00<006</Hb`01F</00<007__Nnl017__00@009cCW=<000VeUP8000[W?0@000Co
o`40007oo`005Ooo0P000ooo2P000_oo00@00>Llic`000S>N@04002eU[FF0006W=<20003Nnl00`00
HbaS;005Hb`00`00BVU:J@06BVT2000<<HH30003Hb`01@00Nnmkkg__00000YcC00D00;FF]IJeUP00
00O>N@03002eU[FF00>eUP03003>NLii00?>N@05002eU[FF]IH00009cWT2000N]IH01`00W=>Ld`00
Nnl006</0080008aQP03000H`aS300`H``8000daQP8000U:J@03001S;6</00IS;003001kkg__00Ak
k`04002LdicC0008]IH00`00cWT0000:ic`40003ool20001ool001Goo`03003ooooo00;oo`T00007
ic`00?ooool00>Ll00001lii00<00;FF]IH00[FF00<009cCW=<00`0000>Ld`00Nnl00g__00<006</
Hb`01F</00<004YYBVT01dYY00<00366<HH02c6600D006</HbaS;00000=kk`04002LdicC0004]IH0
0`00cWW>N@03cWT00`00]IJeUP04]IH00`00cWW>N@04cWT3000:cWT00`00]IJeUP0K]IH20002W=<0
0`00Nnl00002Hb`00`00BVT00002<HH00`006<<H``0:6<<00`00<HHaQP0<<HH00`00BVU:J@08BVT0
0`00HbaS;006Hb`00`00Nnmkk`04Nnl01000W=>Ld`002;FF00<00<ii00002^Ll1@001?oo0@000Ooo
000Eool00`00ooooo`02ool900001>Ll003ooooo0P0000?W?000cWT01Lii00<00;FF]IH00kFF0P00
0kFF0P001G__00<006</Hb`01F</00<004YYBVT01dYY00<00366<HH02S660P000V</0P000W__00@0
09cCW=<000FeUP03003>NLii00;>N@03002eU[FF00BeUP03003>NLii013>N@03002eU[FF012eUP<0
00NeUP8000>Ld`04001kkg__0002Hb`00`00BVT00003<HH200086<<2000><HH00`00BVU:J@08BVT0
0`00HbaS;006Hb`00`00Nnmkk`05Nnl01000W=>Ld`002;FF0`002^Ll1@001?oo0@000Ooo000Eool0
0`00ooooo`02ool<0003ool00`00ic`00005cWT00`00]IJeUP07]IH01000W=>Ld`001G__00<006</
Hb`01F</0P0024YY00<00366<HH02C6600<004YY00000f</00@007__Nnl000:Ld`03002eU[FF00>e
UP04003>NLii0006]IH00`00cWW>N@03cWT00`00cWW>N@0;cWT00`00]IJeUP0>]IH20003W=<70004
W=<01@00Nnmkkg__00000f</00<004YY0000136600<001S36<<011S300<00366<HH033660P002TYY
00<006</Hb`00f</10001g__00D009cCW=>Ld`0000NeUP8000_W?0D000Goo`40007oo`005Ooo00<0
0?ooool00_oo2`0000GW?000ooooo`0000;W?003003>NLii00;>N@03002eU[FF00>eUP<00003]IH0
09cC00:Ld`03001kkg__00=kk`03001S;6</00IS;003001:JDYY00E:J@8000XaQP04001:J@000002
Hb`01000Nnmkk`000icC0P001;FF0P001[FF00<00<iicWT00/ii0P0000>eUP00cWT02lii00<00;FF
]IH00kFF1@000[FF10003icC00<007__Nnl00W__00D006</HbaS;000009:J@8000<aQP8000046<<0
0000000?<HH00`00BVU:J@07BVT20004Hb`2000:Nnl00`00W=>Ld`02W=<01000]IH000001;FF0P00
2^Ll1P001Ooo0@000Ooo000Eool00`00ooooo`02ool=0002ool01000iccW?0001Lii00<00;FF]IH0
0P000/ii00<00;FF000019cC0P0017__00<006</Hb`01V</00<004YYBVT01TYY00<00366<HH01c66
00L004YYBVU:J@00Hb`00003Nnl01@00W=>LdicC00002kFF00<00<iicWT00/ii00@00;FF]IH000g>
N@03002eU[FF00:eUP03002LdicC00:Ld`<001:Ld`03001kkg__00=kk`03001S;6</009S;005001:
JDYYBVT00004<HH00`00<HHaQP0><HH20009BVT00`00HbaS;003Hb`00`00Nnmkk`02Nnl00`00Nnmk
k`05Nnl00`00W=>Ld`03W=<00`00]IH00003]IH00`00cWT00009ic`70005ool10001ool001Goo`03
003ooooo00;oo`d000;oo`800003ic`00<ii00G>N@8000C>N@03002eU[FF00@000:Ld`03001kkg__
009kk`03001S;6</00ES;003001:JDYY00I:J@03000aQS6600PaQP04001:JDYY0002Hb`01000Nnmk
k`0019cC0`002;FF00D00<iicWW>N@0000>eUP03003>NLii00W>N@8000>eUP8001VLd`03001kkg__
00Akk`03001S;6</00=S;005001:JDYYBVT0000B<HH2000:BVT20004Hb`01000Nnmkkg__0P0000>L
d`0000000g__0P001YcC00<00;FF]IH00[FF0`002^Ll1`001Ooo0@000Ooo000Eool00`00ooooo`02
ool>0003ool00`00ic`00007cWT01@00cWW>NLii00001[FF00<009cC00001G__00<006</Hb`01F</
00<004YYBVT01TYY00<00366<HH0236600@004YYBVT0009S;003001kk`0000NLd`03002eU[FF00Je
UP03003>N@0000BeUP03003>NLii00O>N@8000BeUP03002LdicC01ZLd`03001kkg__00Akk`@0009S
;005001:JDYYBVT0000@<HH00`00BVU:J@09BVT00`00HbaS;003Hb`00`00Nnmkk`03Nnl01`00W=>L
dicC001kk`0000RLd`07002eU[FF]IH00<ii00002^Ll20001Ooo0@000Ooo00000ooo000000020003
ool20004ool20005ool00`00ooooo`02ool=00001nLl003ooooo003W?00000K>N@<000?>N@03002e
U[FF00BeUP8000Ikk`03001S;6</00ES;003001:JDYY00E:J@03000aQS6600TaQP800007BVT006</
Hb`007__00001icC00<00;FF]IH01KFF00<00<ii00001;FF00<00<iicWT01/ii00<00;FF]IH01;FF
00<009cCW=<049cC1@001YcC10001W__00<006</00000dYY00<00366<HH033660P002dYY00<006</
Hb`016</00<007__Nnl00g__00L009cCW=>Ld`00Nnl00007W=<01`00]IJeU[FF003>N@0000[W?0T0
00Goo`40007oo`000ooo00D00?ooooooo`0000;oo`04003ooooo0002ool00`00ooooo`02ool00`00
ooooo`02ool@0002ool00`00ic`0000:cWT00`00]IJeUP04]IH01000W=>Ld`001W__00<006</Hb`0
1F</0P001TYY0P002S6600@004YYBVT0009S;003001kk`0000NLd`03002eU[FF00FeUP03002eU[FF
00>eUP03003>NLii00?>N@<000NeUP03002LdicC012Ld`03001kkg__009kk`03002LdicC00NLd`@0
00=kk`03001S;00000=:J@03000aQS6600XaQP03001:JDYY00Y:J@03001S;6</00ES;003001kkg__
00=kk`03002LdicC00:Ld`03002LdicC00FLd`07002eU[FF]IH00<ii00002nLl2@001Ooo0@000Ooo
0003ool01@00oooooooo00000_oo00@00?ooool000;oo`03003ooooo00;oo`8000?ooa4000;oo`04
003W?0000006cWT20007]IH01000W=>Ld`001g__00<006</Hb`01F</00<004YYBVT01DYY00<00366
<HH02C660P0000I:J@00Hb`007__0008W=<00`00]IJeUP04]IH00`00]IJeUP03]IH6000:]IH00`00
W=>Ld`03W=<2000;W=<00`00Nnmkk`02Nnl00`00W=>Ld`0;W=<2000017__001S;0000dYY00<00366
<HH02C6600<004YYBVT02TYY0P001f</00<007__Nnl00g__00<009cCW=<02YcC00L00;FF]IJeUP00
cWT0000:ic`:0004ool20001ool000?oo`05003oooooool00002ool01000ooooo`000_oo00<00?oo
ool00_oo00<00?ooool00_oo400000GW?000ooooo`0000;W?003003>NLii00?>N@04002eU[FF]IH3
00000kFF002Ld`03W=<00`00Nnmkk`05Nnl00`00HbaS;005Hb`00`00BVU:J@05BVT2000:<HH02000
BVU:J@00Hb`007__0008W=<00`00]IJeUP0I]IH01000W=>LdicC0P000W__00<009cCW=<02IcC1000
3YcC00<007__00000f</00@004YYBVT000TaQP8000]:J@8000QS;003001kkg__00=kk`03002Ld`00
00FLd`04002LdicCW=<20003]IH00`00cWT0000:ic`;0005ool10001ool000?oo`05003oooooool0
0002ool01000ooooo`000_oo00<00?ooool00_oo00<00?ooool00_oo400000GW?000ooooo`0000;W
?003003>NLii00?>N@04002eU[FF0002cWT00`00]IH00004W=<00`00Nnmkk`05Nnl00`00HbaS;006
Hb`00`00BVU:J@05BVT00`00<HHaQP08<HH01P00BVU:J@00Hb`0009kk`03002LdicC00FLd`03002e
U[FF01VeUP04002LdicC0005Nnl00`00W=>Ld`0IW=<01000Nnmkk`000f</00<004YY00001c660`00
2dYY0P002F</00<007__Nnl017__00<009cC00000icC0P0000BeUP00W=<000BeUP03003>N@0000[W
?0`000Goo`40007oo`0000Coo`00000000?oo`04003ooooo0002ool01000ooooo`001?oo00<00?oo
ool00_oo4P000ooo00<00>Ll00001/ii0P000/ii00@00;FF]IH000FLd`03001kkg__00Ekk`03001S
;6</00IS;003001:JDYY00E:J@8000TaQP06001:JDYY001S;0000W__100019cC0P006KFF00<009cC
00001W__00<009cCW=<06IcC00<007__00000f</00@004YYBVT000HaQP03001:JDYY00]:J@03001S
;6</00QS;003001kkg__00Ekk`03002Ld`0000<000BeUP03002eU[FF00:eUP03003>N@0000[W?0d0
00Goo`40007oo`000ooo00<00?ooool00_oo0P001?oo0P001Ooo00<00?ooool00_oo4`000ooo00<0
0>Ll00002Lii00@00;FF]IH000JLd`03001kkg__00Ekk`8000MS;003001:JDYY00I:J@8000PaQP04
001:J@00Hb`20005Nnl20004W=<2000F]IH01000W=>Ld`001W__00<009cCW=<069cC00@007__Nnl0
009S;005001:JDYYBVT00004<HH2000=BVT00`00HbaS;003Hb`60008Nnl00`00W=<0000;]IH00`00
cWT0000:ic`>0005ool10001ool001Goo`03003ooooo00;ooa800003ic`00?oo00;oo`03003W?000
00O>N@03002eU[FF00:eUP03002LdicC00BLd`03001kkg__00Ikk`03001S;6</00ES;08000Q:J@03
000aQS6600HaQP@00004Hb`000000004Nnl20004W=<00`00]IJeUP0B]IH01@00W=>LdicC00001W__
00<009cCW=<02IcC00<009cCW=<02icC00@007__Nnl0009S;003001:JDYY009:J@03000aQS660080
00e:J@8000AS;08000ekk`04002LdicC000:]IH00`00cWT0000:ic`00`00cWT0000<0005ool10001
ool001Goo`03003ooooo00;ooaD000?oo`03003W?00000K>N@03002eU[FF00:eUP03002LdicC00FL
d`8000Ikk`8000MS;003001:JDYY00I:J@8000TaQP@0009S;0X00003W=<0000000L000^eUP04002L
dicC0007Nnl00`00W=>Ld`08W=<00`00Nnl000020009W=<01000Nnmkk`000V</00<004YYBVT00dYY
00<0036600003TYY00<006</Hb`016</00<007__Nnl037__00D009cCW=>Ld`0000ReUP03003>N@00
00_W?0l000Goo`40007oo`005Ooo00<00?ooool00_oo500000?W?000ool00_oo00<00>Ll00001Lii
00<00;FF]IH00kFF00<009cCW=<01YcC00<007__Nnl01G__0P001V</0P0024YY00<00366<HH02366
10001V</00@007__Nnmkk`8000RLd`03002eU[FF00ReUP05002LdicCW=<00007Nnl20009W=<01@00
Nnmkkg__00001icC00@007__Nnl000=S;003001:JDYY009:J@03001:J@0000e:J@8000IS;003001k
kg__00Akk`03001kkg__00Ekk`03002LdicC00>Ld`03002eU[FF00BeUP03003>N@0000_W?10000Go
o`40007oo`005Ooo00<00?ooool00_oo5P001?oo0`001Lii00<00;FF]IH00kFF00<009cCW=<01YcC
1`000W__00<006</Hb`01F</0P001dYY0P002S661P000f</00<007__Nnl00W__0P001icC00<00;FF
]IH00[FF1P000icC00<007__Nnl01g__00<009cCW=<01YcC00<007__Nnl00W__0P001IcC00@007__
Nnl000=S;004001:JDYYBVT2000>BVT00`00HbaS;005Hb`00`00Nnmkk`04Nnl01000W=<000001G__
00<009cCW=<019cC0P001;FF00<00<ii00002^Ll4@001Ooo0@000Ooo000Eool00`00ooooo`02oolG
00000ooo003oo`02ool20005cWT00`00]IJeUP03]IH00`00W=>Ld`0<W=<200000g__001S;007Hb`0
0`00BVU:J@06BVT00`00<HHaQP09<HH01000BVU:JDYY0P000V</0P0017__0P001YcC10002YcC0P00
27__00<009cCW=<01IcC00<007__Nnl017__00<009cCW=<00P000W__00D006</HbaS;00001=:J@03
001S;6</00ES;004001kkg__0005Nnl00`00W=>Ld`050007W=<00`00]IJeUP02]IH00`00cWT0000:
ic`B0005ool10001ool001Goo`8000?ooaP000Coo`03003W?00000G>N@03002eU[FF00>eUP8000NL
d`03002LdicC00BLd`04001kk`000006Hb`20008BVT00`00<HHaQP09<HH00`00BVU:J@02BVT01000
HbaS;6</0P0017__10004YcC0P001g__00<009cCW=<019cC00<007__Nnl01G__0P0017__00@006</
Hb`0019:J@8000QS;003001kkg__008000Ekk`03002LdicC00ZLd`04002eU[FF]IH200000lii003W
?009ic`C0004ool20001ool001Goo`03003ooooo00;ooaT000Coo`03003W?00000G>N@03002eU[FF
00BeUP03002LdicC00:Ld`800003]IH009cC00FLd`04001kkg__0007Hb`20006BVT00`00<HHaQP0:
<HH00`00BVU:J@02BVT00`00HbaS;002Hb`20006Nnl00`00W=>Ld`0AW=<00`00Nnmkk`05Nnl00`00
W=>Ld`03W=<00`00Nnmkk`0;Nnl00`00Hb`0000ABVT2000:Hb`00`00Nnl00002W=<00`00Nnmkk`02
Nnl01000W=>Ld`0029cC00D00;FF]IJeUP0000;>N@03003W?>Ll00SW?1@000Goo`40007oo`005Ooo
00<00?ooool00_oo6P001?oo0`001Lii00<00;FF]IH01;FF00@009cCW=<000>eUP03002LdicC00BL
d`03001kkg__008000MS;003001:JDYY00E:J@<000XaQP05001:JDYYBVT00006Hb`40002Nnl00`00
W=>Ld`0BW=<00`00Nnmkk`04Nnl00`00W=>Ld`03W=<01000Nnmkkg__2P000V</00<004YYBVT03DYY
0P002f</0P0000Ekk`00W=>Ld`0000Akk`03002LdicC008000JLd`8000>eUP03003>N@0000[W?003
003>N@00018000Goo`40007oo`005Ooo00<00?ooool00_oo6`001Ooo0P001Lii00<00;FF]IH01;FF
0P000kFF00<009cCW=<00icC00@009cCW=<000=kk`03001S;6</00ES;003001:JDYY00M:J@03000a
QS6600PaQP80009:J@03001S;6</00MS;004001kkg__000DW=<00`00Nnmkk`04Nnl50003Nnl00`00
HbaS;004Hb`6000>BVT2000;Hb`20004Nnl01000W=>Ld`000W__00L009cCW=>Ld`00]IH00003W=<2
0004]IH00`00cWT0000;ic`E0005ool10001ool001Goo`03003ooooo00;ooa`000Goo`8000C>N@03
002eU[FF00NeUP03002eUP0000BLd`03002eUP00008000=kk`8000MS;003001:JDYY00M:J@8000Ta
QP04001:JDYY0009Hb`01000Nnmkkg__100049cC00<007__Nnl02G__0`000f</100054YY00<006</
Hb`01F</1P001G__00@009cCW=>Ld`<000>Ld`04002eU[FF0002W=<01000]IJeU[FF10002^Ll5`00
1Ooo0@000Ooo000Eool00`00ooooo`02oolM0004ool00`00ic`00004cWT00`00]IJeUP05]IH20000
0kFF002Ld`02W=<00`00]IJeUP020006Nnl20006Hb`00`00BVU:J@08BVT20008<HH00`00BVU:J@07
0003Hb`00`00Nnmkk`04Nnl@000:Nnl20005Hb`00`00BVU:J@0DBVT20007Hb`00`00Nnmkk`09Nnl0
0`00W=>Ld`08W=<200000kFF00000003]IH00`00cWT0000;ic`H0005ool10001ool001Goo`03003o
oooo00;ooa`00003ic`00?oo00?oo`03003W?00000C>N@03002eU[FF00>eUP05003>N@00]IH00002
W=<20002]IH20007Nnl30005Hb`2000:BVT20006<HH00`00BVU:J@06BVT01000HbaS;6</0`006W__
1@000f</0`005DYY0P0026</00<007__Nnl02W__00<009cCW=<02YcC00<00;FF]IH00[FF00<00<ii
00002nLl6@001Ooo0@000Ooo000Eool00`00ooooo`02oolO0004ool00`00ic`00004cWT20003]IH0
0`00cWW>N@020004W=<20002W=<00`00Nnmkk`04Nnl50005Hb`00`00BVT00009BVT40003<HH30006
BVT00`00HbaS;003Hb`40003Nnl00`00Nnmkk`05Nnl30006Nnl20007Hb`00`00BVU:J@0DBVT20006
Hb`50003Nnl00`00Nnmkk`06Nnl01@00W=>LdicC00001icC00@00;FF]IJeUP@000_W?1X000Goo`40
007oo`005Ooo00<00?ooool00_oo7P0000?W?000ool00ooo00<00>Ll00001<ii1@000/ii00@00;FF
000000JLd`8000=kk`8000:Ld`04001kkg__0005Hb`3000<BVT70005BVT20008Hb`300000f</0000
0003Nnl20003Hb`30003Nnl00`00HbaS;006Hb`00`00BVU:J@0BBVT20007Hb`00`00Nnmkk`04Nnl3
0008Nnl01P00W=>Ld`00]IH000BLd`8000BeUP03003>N@0000_W?1/000Goo`40007oo`005Ooo00<0
0?ooool00_oo8P000ooo00<00>Ll00002lii00<00;FF]IH00P001YcC0`001IcC10001f</0P0064YY
0P0036</0`0026</0`0026</00<004YYBVT03dYY00@004YY000000QS;003001kkg__00Ekk`04002L
dicC0005Nnl20004W=<00`00]IH00002W=<00`00]IJeUP02]IH200000lii003W?00:ic`L0005ool1
0001ool001Goo`8000?oob8000Coo`@000[>N@8000:eUP03002LdicC00ZLd`04002LdicCW=<20008
Hb`2000HBVT4000DHb`00`00HbaS;005Hb`3000?BVT4000:Hb`01@00Nnmkkg__00000W__00@009cC
W=>Ld`80009kk`8000JLd`04002eUP00W=<20004]IH00`00cWT0000;ic`00`00cWT0000J0004ool2
0001ool001Goo`03003ooooo00;oob<000Goo`03003W?00000_>N@04002eU[FF0007W=<01@00W=>L
d`00Nnl00P0000BLd`00Nnl000US;08001Y:J@80015S;003001:J@0000H0011:J@8000eS;006001k
kg__Nnl009cC0P001YcC0P0029cC00@00;FF000000BeUP@000[W?1l000Goo`40007oo`005Ooo00<0
0?ooool00_oo700000<H``0000001@001Ooo0`002/ii00@00;FF]IH000FLd`<00003W=<007__009k
k`04002Ld`00Nnl2000:Hb`2000IBVT50005Hb`8000EBVT4000>Hb`01@00Nnmkkg__00005IcC0P00
0kFF10002^Ll8@001Ooo0@000Ooo000Eool00`00ooooo`02oolW0003ool40006cWT20004]IH20000
0icC00000002]IH00`00W=>Ld`030003W=<00`00Nnmkk`0:0002Hb`6000HBVT5000IBVT40008Hb`4
0002Hb`40005Nnl00`00W=>Ld`05W=<20008W=<40002]IH4000;ic`R0005ool10001ool001Goo`03
003ooooo00;oobH00003ic`00?oo00?oo`03003W?00000K>N@03002eU[FF00BeUP800004]IH00;FF
0008W=<00`00Nnmkk`05Nnl300000g__001S;007Hb`2000bBVT2000;Hb`00`00Nnmkk`02Nnl30008
Nnl01000W=>Ld`000icC00@00;FF]IH000JLd`03002eU[FF00>eUP04003>NLii000;ic`00`00cWT0
000P0005ool10001ool001Goo`03003ooooo00;oobT000Coo`@000G>N@03002eU[FF00FeUP800003
]IH009cC00NLd`03001kkg__00Akk`04002LdicCW=<50007Hb`4000XBVT6000=Hb`00`00Nnmkk`0=
Nnl01000W=<000000icC00@00;FF]IH000BLd`8000BeUP800003cWT0000000[W?2D000Goo`40007o
o`005Ooo00<00?ooool00_oo900000Ikk`00]IH00>Ll0005ool00`00ic`00005cWT00`00]IJeUP04
]IH01@00cWT00;FF000019cC00@009cCW=<000Ekk`03002LdicC00>Ld`80009kk`03001S;6</00QS
;0H001i:J@@0019S;005001kkg__Nnl0000;Nnl01@00W=>Ld`00]IH010000[FF00D009cCW=>Ld`00
00FeUP04003>N@00000<ic`500000c660000000M0005ool10001ool001Goo`03003ooooo00;oob`0
00Coo`@000C>N@8000BeUP03003>N@0000:eUP@00003]IH009cC008000Akk`04002LdicCW=<20000
0g__00000002000@Hb`9000?BVT6000DHb`30002Nnl00`00W=<00009Nnl20002W=<00`00]IJeUP05
]IH40004]IH200000lii003W?00;ic`W0005ool10001ool001Goo`03003ooooo00;oob`000Goo`03
003W?>Ll008000?>N@03002eU[FF00>eUP03003>N@0000FeUP03002LdicC00:Ld`@000BLd`07001k
kg__002Ld`00Nnl00P005f</3`005V</10001G__00@009cCW=<000Mkk`03002LdicC00:Ld`03002e
U[FF00beUP04003>NLii000<ic`600000aS30000000O0005ool10001ool001Goo`8000?oobl000?o
o`8000;W?004003>NLiicWT30002]IH00`00cWW>N@060009W=<200001icC001kkg__002Ld`0000=k
k`8003MS;0<000Ukk`04002LdicCW=<200000g__000000020005W=<00`00]IJeUP0:]IH5000;ic`Z
0004ool20001ool001Goo`03003ooooo00;oobX00006W=<00000003W?0001?oo00@00>Llic`000G>
N@04002eU[FF0004cWT01000]IJeUP001icC00L00;FF002Ld`00Nnl00003W=<00`00Nnmkk`02Nnl4
000=Hb`30005Hb`00`00HbaS;006Hb`7000;Hb`3000<Nnl00`00W=>Ld`02W=<2000:W=<00`00]IJe
UP08]IH00`00cWT0000=ic`00`00cWT0000X0005ool10001ool001Goo`03003ooooo00;ooc8000?o
o`800003ic`0000000C>N@L000>eUP03002LdicC00BLd`05002eU[FF002Ld`020002W=<00`00W=<0
0008Nnl60005Hb`20002Nnl3000016</000007__0P001F</00<007__Nnl01G__0P000f</1P003g__
00@009cCW=<000fLd`03002eU[FF00FeUPD000cW?2d000Goo`40007oo`005Ooo00<00?ooool00_oo
=00000?oo`00ic`00nLl0P001Lii00<00;FF]IH01;FF0`000icC00<00;FF]IH00[FF00H009cCW=>L
d`00]IH2000>Nnl50003Nnl01000W=<007__0P0000=kk`0000000P0016</00<007__Nnl01W__1000
57__00D009cCW=<00;FF00H000NLd`03002eU[FF00BeUP04003>NLii000<ic`_0005ool10001ool0
01Goo`03003ooooo00;oocH000KW?0<000?>N@8000NeUPH000:eUP04002LdicC0002]IH01000W=<0
00004g__00D009cCW=>Ld`00009kk`05002LdicC001kk`05000LNnl40003W=<00`00]IJeUP05]IH0
0`00W=>Ld`040005]IH200000lii0000000<ic`00`00cWT0000]0005ool10001ool001Goo`03003o
oooo00;ooc800004]IH000000009ic`00`00cWW>N@02cWT00`00]IJeUP08]IH00`00cWT00002]IH2
00000kFF00000003W=<3000@Nnl01000W=>Ld`000YcC0P0019cC00<007__Nnl00g__0`005G__1000
1YcC00<00;FF]IH01kFF0`001kFF00@00<iicWT000gW?003003>N@0002h000Goo`40007oo`005Ooo
00<00?ooool00_oo=@0000?>N@00ic`02>Ll0P000lii0P002;FF00@00<iicWT000FeUP03002LdicC
00BLd`@000]kk`06002Ld`00002eUP000icC0P000YcC00<007__Nnl00g__00<009cCW=<00P003g__
100029cC0P004KFF1P003>Ll<`001Ooo0@000Ooo000Eool00`00ooooo`02oolh000:ic`20003cWT0
0`00]IJeUP06]IH20006]IH00`00W=>Ld`08W=<=00001;FF00000;FF0`000[FF00@009cCW=<000=k
k`03002LdicC00>Ld`03001kkg__00Qkk`@000^Ld`03002eU[FF012eUP04003>N@00000=ic`e0005
ool10001ool00003ool00000008000;oo`@000?oo`8000Goo`03003ooooo00;ooc/000WW?08000;>
N@8000jeUP03002LdicC01BLd`05002eUP00W=<00006]IH00`00W=<00003Nnl00`00W=<000030000
0icC00000003Nnl5000?W=<00`00]IJeUP0<]IH6000=ic`g0005ool10001ool000?oo`05003ooooo
ool00005ool01000ooooo`001?oo00<00?ooool00_oo>P0000?>N@00ic`02NLl0P000/ii00<00;FF
]IH02kFF00<009cCW=<04icC00<00;FF]IH00P001KFF00D00;FF]IH009cC00D000:eUP03002LdicC
00:Ld`<001>Ld`03002eU[FF00^eUP8000;>N@<000cW?3T000Goo`40007oo`000ooo00<00?ooool0
0_oo00<00?ooool00_oo00@00?ooool000Coo`8000?ooch000[W?0800003cWT0000000<000VeUPH0
00jLd`04002eU[FF]IH20004]IH20002]IH00`00W=>Ld`03W=<01000]IJeUP005YcC10002kFF0`00
00C>N@00000000gW?3/000Coo`80007oo`000ooo00<00?ooool00ooo00D00?ooooooo`0000;oo`03
003ooooo00;oo`03003ooooo00;ood0000[W?0<000?>N@03002eU[FF00beUP@000VLd`03002eU[FF
00:eUP8000FeUP05002eU[FF]IH00003W=<00`00]IJeUP02]IH3000=W=<6000<]IH300001<ii0000
00003^Ll?@001Ooo0@000Ooo0003ool00`00ooooo`04ool01000ooooo`000_oo00<00?ooool00_oo
00<00?ooool00_oo@P002nLl0`0000?>N@0000000`003KFF2P001;FF0P001KFF00<00;FF]IH00[FF
00@009cCW=<000NeUP03002LdicC00JLd`@000neUP<000;>N@8000oW?3l000Goo`40007oo`0000Co
o`00000000?oo`04003ooooo0002ool01000ooooo`001?oo00<00?ooool00_ooA0003>Ll0`000lii
00<00;FF]IH07kFF00<00;FF]IH00kFF0`002;FF20004;FF0`0000?>N@0000000P004>Ll@0001Ooo
0@000Ooo0003ool00`00ooooo`02ool20004ool20005ool00`00ooooo`02oom6000=ic`20002cWT4
0012]IH40002cWT2000Aica30005ool10001ool001Goo`03003ooooo00;oodT000cW?0@000;>N@@0
03ReUPH000;>N@@001;W?003003>N@00044000Goo`40007oo`005Ooo00<00?ooool00_ooB`003^Ll
0P001<ii2P00:[FF10001<ii10004^LlB0001Ooo0@000Ooo000Eool00`00ooooo`02oom=000>ic`6
0008cWT8000J]IH80004cWT4000Dica:0005ool10001ool001Goo`03003ooooo00;ooe40013W?0H0
00[>NAX000S>N@@001CW?4h000Goo`40007oo`005Ooo00<00?ooool00_ooD`005>Ll2P005<ii3P00
5^LlD0001Ooo0@000Ooo000Eool20003oomG000Jic`D000PicaD0004ool20001ool001Goo`03003o
oooo00;ooe/004SW?5H000Goo`40007oo`005Ooo00<00?ooool00_ooFP0000?>N@0000000P00?^Ll
G0001Ooo0@000Ooo000Eool00`00ooooo`02oomU000bicaR0005ool10001ool001Goo`03003ooooo
00;oof/002KW?6P000Goo`40007oo`005Ooo00<00?ooool00_ooM`004>LlLP001Ooo0@000Ooo000E
ool00`00ooooo`02oom[0002]IH30007cWT70003ic`60005cWU]0005ool10001ool001Goo`03003o
oooo0?ooo`7oo`40007oo`005Ooo00<00?ooool0oooo0Ooo0@000Ooo000Eool01000ooooo`009_oo
00<00?ooool09?oo00<00?ooool09Ooo00<00?ooool09?oo00<00?ooool09?oo00<00?ooool09Ooo
00<00?ooool04Ooo0@000Ooo000Eool200000ooo003oo`08ool00`00ooooo`06ool00`00ooooo`07
ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`06
ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07
ool00`00ooooo`06ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07
ool00`00ooooo`07ool00`00ooooo`06ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07
ool00`00ooooo`07ool00`00ooooo`06ool00`00ooooo`07ool20001ool001Goool000D0007oo`00
oooo6ooo003ooolKool00?oooa_oo`00oooo6ooo0000\
\>"],
  ImageRangeCache->{{{0, 281}, {281, 0}} -> {-12.3488, -10.0913, 0.50873, \
0.50873}}]
}, Open  ]],

Cell["\<\
The ListPlot3D hasn't been computed here since it generates lots of \
PostScript and would make this notebook rather large. You can generate it if \
you want.....\
\>", "SmallText",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(ListPlot3D[penny, Mesh \[Rule] False];\)\)], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Coloring the Penny (Optional)", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  "Now we'll color the penny the same way as the MATLAB folks. Their formula \
is:\n",
  StyleBox["\tc = min(1,gray(m)*diag([1.2500 0.7812 0.4975]));",
    FontWeight->"Bold"],
  "\nOurs would be:"
}], "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \(CopperColor[val_] := 
      RGBColor[Min[1, 1.25\ val], 0.7812\ val, 0.4975\ val]\)], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[StyleBox["Note: ColorFunction->CopperColor looks good only at \
16 or 24-bit color (Thousands or Millions in Macintosh lingo). If running at \
less colors, omit this ColorFunction option to get a grey-scale image. \
Macintosh users can also choose \"Colors...\" from the File menu and pick \
\"Dither patterns\" for the dialog item entitled \"When rendering bitmap \
images (DensityPlots), use:\"",
  FontWeight->"Bold"]], "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(ListDensityPlot[penny, Mesh \[Rule] False, 
        ColorFunction \[Rule] CopperColor];\)\)], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(ListPlot3D[penny, Mesh \[Rule] False, 
        ColorFunction \[Rule] CopperColor];\)\)], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(ListContourPlot[penny, 
        ColorFunction \[Rule] CopperColor];\)\)], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Modifying the Penny", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  "Let's severely muddle the penny data by taking a modified Fourier \
transform. I follow a suggestion developed in the book ",
  StyleBox["Applied ",
    FontVariations->{"Underline"->True}],
  StyleBox["Mathematica",
    FontSlant->"Italic",
    FontVariations->{"Underline"->True}],
  " by Shaw and Tigg on page 412. ",
  StyleBox["centeredFourier[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " shifts the low-frequency components into the center of the picture and \
shifts the high-frequency components to the periphery."
}], "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(centeredFourier[x_List] := 
        Transpose[
          RotateRight[Transpose[RotateRight[Fourier[x], 64]], 
            64]];\)\)], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(pennyFourier = centeredFourier[penny];\)\)], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListDensityPlot[Abs[pennyFourier], Mesh \[Rule] False];\)\)], "Input",\

  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.16947 -0.0125 -6 -9 ]
[.16947 -0.0125 6 0 ]
[.31971 -0.0125 -6 -9 ]
[.31971 -0.0125 6 0 ]
[.46995 -0.0125 -6 -9 ]
[.46995 -0.0125 6 0 ]
[.62019 -0.0125 -6 -9 ]
[.62019 -0.0125 6 0 ]
[.77043 -0.0125 -9 -9 ]
[.77043 -0.0125 9 0 ]
[.92067 -0.0125 -9 -9 ]
[.92067 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .16947 -12 -4.5 ]
[-0.0125 .16947 0 4.5 ]
[-0.0125 .31971 -12 -4.5 ]
[-0.0125 .31971 0 4.5 ]
[-0.0125 .46995 -12 -4.5 ]
[-0.0125 .46995 0 4.5 ]
[-0.0125 .62019 -12 -4.5 ]
[-0.0125 .62019 0 4.5 ]
[-0.0125 .77043 -18 -4.5 ]
[-0.0125 .77043 0 4.5 ]
[-0.0125 .92067 -18 -4.5 ]
[-0.0125 .92067 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.16947 0 m
.16947 .00625 L
s
[(20)] .16947 -0.0125 0 1 Mshowa
.31971 0 m
.31971 .00625 L
s
[(40)] .31971 -0.0125 0 1 Mshowa
.46995 0 m
.46995 .00625 L
s
[(60)] .46995 -0.0125 0 1 Mshowa
.62019 0 m
.62019 .00625 L
s
[(80)] .62019 -0.0125 0 1 Mshowa
.77043 0 m
.77043 .00625 L
s
[(100)] .77043 -0.0125 0 1 Mshowa
.92067 0 m
.92067 .00625 L
s
[(120)] .92067 -0.0125 0 1 Mshowa
.125 Mabswid
.05679 0 m
.05679 .00375 L
s
.09435 0 m
.09435 .00375 L
s
.13191 0 m
.13191 .00375 L
s
.20703 0 m
.20703 .00375 L
s
.24459 0 m
.24459 .00375 L
s
.28215 0 m
.28215 .00375 L
s
.35727 0 m
.35727 .00375 L
s
.39483 0 m
.39483 .00375 L
s
.43239 0 m
.43239 .00375 L
s
.50751 0 m
.50751 .00375 L
s
.54507 0 m
.54507 .00375 L
s
.58263 0 m
.58263 .00375 L
s
.65775 0 m
.65775 .00375 L
s
.69531 0 m
.69531 .00375 L
s
.73287 0 m
.73287 .00375 L
s
.80799 0 m
.80799 .00375 L
s
.84555 0 m
.84555 .00375 L
s
.88311 0 m
.88311 .00375 L
s
.95823 0 m
.95823 .00375 L
s
.99579 0 m
.99579 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .16947 m
.00625 .16947 L
s
[(20)] -0.0125 .16947 1 0 Mshowa
0 .31971 m
.00625 .31971 L
s
[(40)] -0.0125 .31971 1 0 Mshowa
0 .46995 m
.00625 .46995 L
s
[(60)] -0.0125 .46995 1 0 Mshowa
0 .62019 m
.00625 .62019 L
s
[(80)] -0.0125 .62019 1 0 Mshowa
0 .77043 m
.00625 .77043 L
s
[(100)] -0.0125 .77043 1 0 Mshowa
0 .92067 m
.00625 .92067 L
s
[(120)] -0.0125 .92067 1 0 Mshowa
.125 Mabswid
0 .05679 m
.00375 .05679 L
s
0 .09435 m
.00375 .09435 L
s
0 .13191 m
.00375 .13191 L
s
0 .20703 m
.00375 .20703 L
s
0 .24459 m
.00375 .24459 L
s
0 .28215 m
.00375 .28215 L
s
0 .35727 m
.00375 .35727 L
s
0 .39483 m
.00375 .39483 L
s
0 .43239 m
.00375 .43239 L
s
0 .50751 m
.00375 .50751 L
s
0 .54507 m
.00375 .54507 L
s
0 .58263 m
.00375 .58263 L
s
0 .65775 m
.00375 .65775 L
s
0 .69531 m
.00375 .69531 L
s
0 .73287 m
.00375 .73287 L
s
0 .80799 m
.00375 .80799 L
s
0 .84555 m
.00375 .84555 L
s
0 .88311 m
.00375 .88311 L
s
0 .95823 m
.00375 .95823 L
s
0 .99579 m
.00375 .99579 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.16947 .99375 m
.16947 1 L
s
.31971 .99375 m
.31971 1 L
s
.46995 .99375 m
.46995 1 L
s
.62019 .99375 m
.62019 1 L
s
.77043 .99375 m
.77043 1 L
s
.92067 .99375 m
.92067 1 L
s
.125 Mabswid
.05679 .99625 m
.05679 1 L
s
.09435 .99625 m
.09435 1 L
s
.13191 .99625 m
.13191 1 L
s
.20703 .99625 m
.20703 1 L
s
.24459 .99625 m
.24459 1 L
s
.28215 .99625 m
.28215 1 L
s
.35727 .99625 m
.35727 1 L
s
.39483 .99625 m
.39483 1 L
s
.43239 .99625 m
.43239 1 L
s
.50751 .99625 m
.50751 1 L
s
.54507 .99625 m
.54507 1 L
s
.58263 .99625 m
.58263 1 L
s
.65775 .99625 m
.65775 1 L
s
.69531 .99625 m
.69531 1 L
s
.73287 .99625 m
.73287 1 L
s
.80799 .99625 m
.80799 1 L
s
.84555 .99625 m
.84555 1 L
s
.88311 .99625 m
.88311 1 L
s
.95823 .99625 m
.95823 1 L
s
.99579 .99625 m
.99579 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .16947 m
1 .16947 L
s
.99375 .31971 m
1 .31971 L
s
.99375 .46995 m
1 .46995 L
s
.99375 .62019 m
1 .62019 L
s
.99375 .77043 m
1 .77043 L
s
.99375 .92067 m
1 .92067 L
s
.125 Mabswid
.99625 .05679 m
1 .05679 L
s
.99625 .09435 m
1 .09435 L
s
.99625 .13191 m
1 .13191 L
s
.99625 .20703 m
1 .20703 L
s
.99625 .24459 m
1 .24459 L
s
.99625 .28215 m
1 .28215 L
s
.99625 .35727 m
1 .35727 L
s
.99625 .39483 m
1 .39483 L
s
.99625 .43239 m
1 .43239 L
s
.99625 .50751 m
1 .50751 L
s
.99625 .54507 m
1 .54507 L
s
.99625 .58263 m
1 .58263 L
s
.99625 .65775 m
1 .65775 L
s
.99625 .69531 m
1 .69531 L
s
.99625 .73287 m
1 .73287 L
s
.99625 .80799 m
1 .80799 L
s
.99625 .84555 m
1 .84555 L
s
.99625 .88311 m
1 .88311 L
s
.99625 .95823 m
1 .95823 L
s
.99625 .99579 m
1 .99579 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
10120E08101516150D110F10070C110009111011140A110A0E1612100A0F180B05101E0F
141E10110D140409110B0D1810121313261E260D18233234683EAB5DFF5DAB3E68343223
180D261E2613131210180D0B110904140D11101E140F1E10050B180F0A1012160E0A110A
141110110900110C07100F110D15161510080E12
10080F0B120713120704150B090F1A060812040816140E0E14130808091112070E0A150F
111D0C11020C0C2514081D0D192D2123241E2A041D191B2C7F43A144FF4FCA2F6F232841
0A110F16260E0D14100A260C172B1906141203151408280B0F07180216020E100A1C0C0F
0D0F16201C090A0210120A0C071014120C0B0410
17090D050C0713020B0A08160B101D1103020D07150D17101610160D0E12050713141114
110F200F070E062D09101B0F0E222D1D2A1F080C21111D377F56C441FF48AA4C61182942
1107132A2B130E23201B141B0B0E19070C12160B1A0F16021514120B2207080D14221A15
08071717160F0503080A0F0C090D1B130F04040E
040604060D01111405060E100A0E150B0706080813150F16100D0A0B1D1710160E0E1411
0E052115040905081C080804041B1726251E1E1617211E2C8A5BA344FF52C9506F224135
0A0C0F272021111612071A17151613040E0D101B0818140E24071515220E0B0A13230D14
130D0A090D08070705080D0C070416201404070D
07030B07030E100B0F0F170B05180E0E0307100B060305090811060D14031D10120E1713
0C08071213121D1F1919171010201E1F212C20220B27281D822ACF45FF3FA63A8D0B2E46
101E1A11120D0E060B0E0910131027050408091810061C0925032406130D041C0F16090D
13150E090E040D040702080A0D0C160A0C0B0C10
090D0F0B100C0A0F1713090E021008000A0B0A06080E0314041605080A061A061A081619
10170A09120916221817081312162610312A261F14252537754BA54DFF59DC466F323D2B
0F16111304160411220520201820140B1112140A110B17060A0C1C0F1301131E12090F11
1E170D02131411180F010A05070E110606060E10
19111314110C0A091A0D0907081116020E110B0805060311190F1B09131A200C0F12060C
1809090B2B09101A160B0B0015041C1F2621300E0B3F35389347CF44FF58C124712B202B
281007071B0A00081D091B1C0615031A161D1B1114101A0E100712181102201013080814
14220A030B0F091D0C02010B070C190E050A0C1A
151309131804030512100303140A18160D16040C0F0B090F0A061F0E070C140919220709
200908051E1110220712240B080A190C2C230F082F4E46299256D937FF62C02D82392026
2829292C20031B170511100D070F091A0E0C110D0F110A1113011216130C130F050B0F07
0E0C120A0F16081509090D0E0F0E1011070D1518
0F1808060805080D020E10080D0F0E0C0E140A0D0109070E0713050C16110F060D0E0E15
0A0D1B0C130A0D21091B24130F1B1209220E1F143933272E8E3DBD40FF59C1248C384033
24152A161F031821152A0601161B0F190B0A150C19120D120E051913110E031111162310
0506121C12131213100909110D0E0F08040A1719
1009090D100E0E130F160D10190A0B06050D02190C060C130C090A070E1E091A0D040B11
0109070F190A1D100B151F0E180D1E0D19140E2225350D25923DDB2BFF4BCF1BA5243D45
210D231A2413130E081E0720100B1013150219111B130312200B0C0B0E11060B12082119
031602231D0A031308061317140C090C08010C17
0A0C11131C1306130E1007190103090D1213090C0C14090F08071A0E1112100B02092317
1110152612121E14040A110F1920090F1113230E1046333E905AF255FF68D73F60341D16
2D04422A2332071E0708160E1D120614111F0D052A09140514120E010A231615110A1110
0B180616181606100809181A180D0C06050E0E09
13221B0F0E160D080D07031407060505061A1015100C04030A0A10120A0C140C1306190C
170D25180D15192404161B0B151E1F1423121D1C03634829A059BC54FF48DC3C69162E2C
350A211B382D210D14080D04101E030C1A1915022108080611170F0A0E18131D080E0E0A
15221116170713050F0B281F2114060D1113190E
1E1620131202090108070708070F0D080C0A140010120F0A0611120D0E12110925181317
17291E151C26241F0D120C020E130F22382328101B4436369855CE3FFF51D134981A153F
2D1A0C15181F1819030F110E1623121B0713090913190802052109180814102A110E080A
0619081B2210080A0A0C18141D1306090C110C16
0910111610050B0703060D0B0510131C0B08140E0804060F0D0C0D0B06020510151B0E03
091F2B110C280A0A0E090C051221101A361F37250D1C41489D2AD164FF74BF29902D272B
2F182834091F151A13011F130E0A0B0B06260D291A1C0B1E0910171B0D0E1017110A0116
01220E091A0E031117121D11180F03080C130409
020A060303050C070804071207131E180E030B04110F021009150E0E170703261411130B
131F190A19080E04151D0A04250812282228332D224619378B299A5AFF4FEF0E703B3740
2A281C2A071B1F121716260D0F1D011A130C191C0C1C140210161A1C150D19020E120C14
081D0E0D0514151A1E100A17190518060807150F
12151E0C1A0E0D110E0914130A0E1B0C01070B0C050E11090B0F101115101A07191E1810
250629162110161C1A09111420032C300A291D352C5C0D1D944CFA33FF2AB7236B173C52
4507343B29242A0E11052B3E1715130E0D110B070A0D0C0A171209230F101E13120B030A
0E1C140508100B17212B19050F0808121B18131F
14120D131B11151814190F180F040A0C0F1514050D080A15070C0114131A1B1E10152B0E
1D10060B1A29090E1816041110151F2B202229473F4C1A2C8F5EEB6AFF4AC63372232B4B
1B13212D261D1727290F1A3815120F051F100618100318101117140F17170E03140F0A12
101018060D0A100F0614170E020D031915162021
0F190A080D0F0C13110E0B10080B0E0A080C1D07090802060A0C14201519231B1D071905
26280E241114212D14271A080C0221222123291130442F397E5BDE68FF57BE4598353949
011D1919181C2B1103081706141C252C0D0C130A090A160909041704121D24071C150A05
0D0A151B0B0D130D1412071106070807010A080B
090D0F04080507090A1A1B10061718040F0D06120D1A12101B0C0B1709210C1B0B0E1B15
1714131132101D1F211F19121C0F2B152E3E171E345C4925A56AEC41FF64D441A0432838
28252A37170A23080A091D0834163A1E080C1C0F150C022012090B1806110E0D13040B19
1B051B1F0C112109050816050C0D04101608120B
21011717180F0C0A0E141521140C201A0E040C1A09120F0E200C0D130F1D10242C20210D
151A0E0E0A190D2627142B14240A21301447101B1C6D5933D246E05EFF7FDF3BAA460939
37131B380A0B121C1D2E42232F1319190F04183608050816100D13241A1B0517220F0916
2615101410101B1D050E0E0B040E14120F151B16
1A17161A1510090D151909100B0C0A02060A06170C0E0E03100D100312291A0E24330F13
0D12243A241A180F1A1F1612161839211D412F17175B3E699344FF5AFF3DED418C2A152E
492B1A2230300E181C2B1F1A19270F291E1D0A1D100C120E131D0505260F0A051E110E1D
270D1D2814000F190F0E0A05080D060C1E151B12
101004051D0B08130F09190D10121209050A11141F17170B0E0D11130E11110C2019170B
0A200A140B2F2C042D1B110A171E4E10043A342B655B40319925F653FF5DFF2391451C4A
4137192A47341D101311132A2E06191F0C1A100C14190D181228091F0B140317070E0D01
130C1419070305080D0A1107110C09060907010B
0C0B09080E1215030B01141A190411190B0E0F14270D0B1C0E1E1D0D082F2B081C281F21
1A191410252224211B3326150B4121061C3728183D502A57B11BFF7CFF61DC15CC2E3252
34280C1A190E3F29293C192C2616180F2B1011131923111122042009250D161E150A110F
1D1E141A1308060415061D1B0A081B15230E0A10
0D05201D20121E1D080C1A0C0E19120D0F130B0B120C1A1D09181B020E0F221E15211E0D
1312172721283C16202C1C30111641092C471C35414E31465E49FC43FF6CDE559B49242E
1C3E3B360F05460D3E331A1E170808171410112223111727241D1317160B060A20110708
11040C0F120709100403190B080E101512121E1C
0B0F0F110A121B1A0D09090F090E160F1B1A081B1115181408292A0F0618362110050A13
05160F0E2B29093326241B2D110B3B042A49113D307022419C6FD841FF57F262862D3260
103C40632D1C3E361519112A2E262409161A25273D1E1A100E22270E2020220824121F29
0E1214030C18180A03180E0E0B0A070D0F0C080B
0B100B05121307051B180D10140416160815050D1231341F1B0A051A1C0927171D190B23
1E0E2A2E3C06220F1C2E1F20253E2437135311404D823764BE4CC48FFF4AEA5BAD2A217E
392B18591941243924401C23201B16311128021D170F23200B232B1508020C1C2F031104
0B120A0F0F3815070B18060E131B0D110D080E03
1407041012110E102411141C0B04011B130C1A10090D1E210D11210A1311240F26121C20
2D3A3112203518054D2B0F1C3D284519194916373747324EA052E879FF4DF448A74A1F4A
2E302D3E3E2950200A413032250C131108102D162213200F0604182C1918161C1B1D1320
1C051A0E071805080E111C0E0F131D0513180408
0C0C190814160B04090C0F0F0E12110D0210091126430C200E131435180312141D270821
421120241A0D122637221A1E394D54412A67504F4275303CDA33FF58FF68E63FC2232B43
2E241C40661551251C451C24392B23172D172A191703470F292E161814132D1805081913
080C0A1A0618060B0D0B0D0A060106091A160604
050906030C10141403141013101A1F0C0F161F1620271E152003261A150E1E1917212C17
263516291B281C333B2B31433941533132723B2E32671A56AD12FF36FF67EB23A9441563
231E12285C111F2B354B19351E39140E1D25221611122C0C1416141F1C191E1E170D1525
0F172B240E061F23200A0E0E0C020B04150F100F
050B06020D151A140918140F16030906071C1D120D09191C25251D0B140B0D091F2D1E30
354234502B0C32325615363A434B532F5E6424402C744040645EFF44FF7AF355AA472B71
4C151C572F28244610191C1C254C1C1A052C3734160B1E3E291F203C23210E05101B1307
0F05160C240B0D18100C0C0E10161A1414050016
06090F06170C140D0504141B1B0912171404211208202F372019322406071A3608262328
20283841271549441E2F135A5754715356721040656248407D4DE863FF5FFB57BB79677F
18332C474B173142333F2A03293328301104261710040D293A1D271D261F280F1128302B
181F120304170811110F060E1215060F0410111C
0613090102081008071104170F10161F121E0E131E1C19222A1D0D1B301D223A261D1325
191E1C27372E274545213E714C6F774A606307405B7A25699F74FD52FF54FF68D1624198
0F521E2D4A1C390A2A2924251329232A14230F27191B14212F2229201A100E380D190910
1B08281815200B07050D10030E06051104090F17
091A060611161615140F050314170D071D1C211E141F1A04041C23211823322F3A0B1F1B
33272C3A394F6648374D687472555A436E6930684C8F2A76FF6FFF1AFF69FF52CD342568
046811515E252B1339262817202B3D2C09191716221C15161610183149140F1D182E2F18
0F25071726150E0D100B190B081011120B0C060D
05070B12070614120E13051512161D032724211E1B1C10211813305222281A290E342008
335D22515F5C736444335C704D5F544B8C75557B38632B4CED39FF8BFFB9FF8BCF261751
361A18434A3932421F361A37121E2151100A092820161F2A18191F3A19231E252C030E0F
1A29130811140E2012100E151609170C0C100509
130E0F070D0A130D11110C0F0B1D25101C1B0A1A1F1C21201C3316592A3A192F473D1C18
191D48264E61684D53604E746687714F9B6B34696A91585CD558FF35FF50FF4DF638297B
2B0637355B2F0B3D242A3A17320211182F09112D4B1D1F0F1D07271D2711162435331103
120506071212161B0614090B0F010D051C061013
060D19010912030A0A131A02171902201D142A0F2D191E2C1E0E2825281B450F31544710
503A2744413D397053698C516E4AA6829286305430B64764B621FF82FFBCFF49FF6B6491
4A2A152961313959071A5C2F071C2A1F1D24300A1A1F152D263F17241F0F171E171A2123
2E2B361018231A1D031C1E091212041A110E0A19
0A11110E1E06060C091611102213141418211D1B311F1D040C0643274F185F24243B3D3B
4C6263427A475437A66089496152797A98794134348C323DF753FF9BFF74FF40E48780A8
466008416E2112404F153E401A23130F3D2A2418231347221C45360F1E0F151727040611
2026090810160110100D1F050E0813141A090E19
030C0610151817041F1B061F1C150D2202110610090F16120C30134B51283A443C42491C
2145695845576176887C783AAC404A7E8A32525449783E54EAB8FF57FF82FF86E45634BA
6944154E8B300C4C6925065A2D16141E0617261A3449293A1B2F404927351F0E24242422
140A0D0A10040E12060A0F06081605010F0D0604
0A110618100E0C0A03131A12171C1809071F18261B3419171B37122F34472A33424B2952
33583B264F36514B7E9DAB73818934A099297FA792A12885FF9DFF87FFFBFF83FB5C14CB
2B3927605537266A640A22085F29200A08343D3E4D240C0C11170B1F1F244A29221E2605
25270B35130D1122100C0B0819020B081E200E0A
0F0A0F14101A100810131F13150A2D241C0F160F09383F10100F292711513524255D2330
466F9A4E755C384B9E7C823CC8A4858EA5277A836F725C96B27AFFE5FFFFFF5BFFA14FC6
738D356C7A2E4013395940061D6E2C391110314D1F2A42453F100C1D162024151A37261E
1711210C19151D0C0310121102080C0B1A120911
0C070E00080A050D0C171B1D11081E0D0D0E321D1623121A1420281D3E3F274B276B396A
2E559C683DA5977F7A3BB05A6AB42E7E8B738DCE8FE37BA6FF97FF8CFFA0FF1EFF877D9E
68865486C0A64151383E401C2D5E391929162D32392034584D550733312C0F2113180A19
2A1418090B110B16111218030E080D1205090702
0D150E0B0B080B11141E191B13122D2B131C140F1F140C0D370E4132263620155E364168
8D5C50A24467A1B09F51B2857B5D8F6893888D8F3CBB514CFF47FFB1FFE4FF5DFFA4B7FB
DF9AAB7DFF9740867E7C20224B416C1637531C3B2A0B164C322E1E171F29341C05381343
0C11071921100401030815080A0A0A190115120C
120B04061B0E180C1206170D1210081A0C300F141618282818091F083328181F50406026
746884A48BAB6EB5983BA1D3CA917283BD5DD1B821FF7296FF95FFF3FFE3FFCDFFC382EB
A275C5BEF5C4664E7BCE1E3E39443C81515935203D3A20192D4F15291A2E19220C0B3722
1816030F11061905140F04071013160B06071108
11060F091A0A0B111D1719160D070313080322210A010D3211151F3B2333172C492F6136
6E4CA5A5ACBC7FB2909B6AC5589191919347A3BE5FFF94BAFFBFFFE3FFFFFFFFFFFFB0FF
CAC8FF7FE0C8AF6040D967412C0B417C255057274B463B173C673248382802240218390E
1A2A12131F0A0B021A0D04120C0D0A05140D0B16
061009180C110E2018210E23200F120A22081F23171D2F2A1713133E424312294F474362
9A82A59DA86340EBFB90D1607C3084CA5FCAFBC1EBDDB6FFFF48FFFFFFFFFFCDFFE672FF
E9FFFFA9AAE2ABAA6299C79068611F201343753F5555372174261B481A042A1A2D0F170B
3F15090D172920040713040A04140C1709181310
0D070E0B020C080D14071F0917030D120308320C0C171D192B0947495128332973554C95
3CBE59CB4FC19CFEEFD4C17130DD8AD09AB8FFA2A7FFFFFFFF9CFFFFFFFFFFFFFFFF76FF
F9FFFFFF9FFFE0CB8447ACA18AB683545833615A3A234B5240226350370425242210093E
071B2E181C190E050712060E08220C2104010508
0603181005091F050B1F2228060F151C0E2114202B270911481B3B4A0D2D1D442949301C
4A6378E768F9F3F1D9868A1FB2AAFF623EFFFF99C8FFAEFFFF9CFFFFFFFFFFFFFFFFA7FF
FFFFFFCBCDFFFF8C96747A9F9D85B482963629632635632F5A2F314B360A1D1F2E1C132D
102C37121D2D1516011811061320170D131E060B
10131B0F06090E0F09170B16100C110F0B4421152A151B23242D405239286E2515621483
31C1B2C5F64CD663877EBF55E6F4CD7D46FDFFFFAAFFC1FFFF5EFFFFFFFFFFFFFFFFFFFF
FFFFFFFFDFB7DEFF87E28D426D5E44778F926355778F5D21123F3E1E1720110929452B24
1E1D050E0B050F0B160B1202060B1A09090E0620
1F1212190917291918101C1824071927091C2C2D15311E28472F6D553936544766516A74
8C636EA2D54CA04FCBFB8DFFE6FF69A4FFFFE7F2FFFFFFFFFFCAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCB89FFFFFFD2805B48483D597D374D967759382C433A3B23381D4A33300D02
2E451B06261525252A1218271F08121B1E0C0702
0E140117101B121C270F1C3335050C1E2A3B233F100832283E6C4E351A4C2F187E0A4003
5F16848F5F7ABFFCDDFFFFE6CE54BBFFFFFFFFFFFFFFFFFFFFE4FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFE1B6FFFFFFD5E9C85B59572F2B1B154029302156020D1A401E2421342109
22261822130C330710142010230F081D1414260B
180C1E160221161205101B17181409232A22542F1C19380F3549213A181B5046554D2F4E
8C32AEFF31CDE6D7B890DA6189AFFFFFFFD1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FF
FFFFFFFFFFFFFFFF8B68F5AFAAE1D9E4A03F9F597C50614716155C3E350B3B151B0E2B17
140C251813181117121C0A23160D10210B13050F
2817192C1E1F1F1C360F0B31222D24202F1D2422322127316D1F4A495D484B533957616A
356887597E7C3981AD1777BCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF8BB7763465F31D4F48575E4D2822664831564008184B052F312631
33245319252A162E1E201F2A1732110524201219
12130D1C1312100E190F101411221D18053B0B1D310A3211262A051D38184336304E1F50
6671634E4AB96567A9E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF8FF4B8ED10D135324344B4B51101C0D1F401F0E361012261F2B
0B252B0D1C070D0C080E18170B1B1B0012140D18
19251F240E111A282610132929202A2624333F4E424B4257142A37484132114876726E1E
528A8D702CD92BD294FFFFCFFF34FF53FFC9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFA6EBFFFFFFDEFF8EFFA87FC30EC5A249274440684F0E594C2543491C2F3738
231E1F1B1D251C2016211D15321B140F2A222514
152E2406101F181E2034180C142A2B243320272A0C131730353D3439267D2123384E4738
5E752E787B9330BD53518436AF4A95FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFEAB84A8CE784418A447377363A58622F3D355629114F141F2B1C290815
3740254A0D2E201F17331403211F361E081C2106
0D05110A310B0B112F1D0C331D0F123318133735181104193E141F23103C220771566840
41131F6964A97CA4627DF1F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE4889FC275659D1815430C412C866C6017310F36222C2A1408290A
1C193111122D19060E0E1C2F27240A0C201C1216
24221B092A1C0E292F1D161920142239113E150F4D4838544B225D4C45745622141D46B9
698971F98BF01A11EF9AC9FFFFFFFFFFFFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF80FFFFFFD27B38B6A9AA4AB76E6F2326486B691E266E31673C1A3447
432A261A212436212808281C041F2A1419251921
081F121512170910161125141E160E2D444832400A114728203827281B24147B43484A31
3A4C69431E9841F6173FDEED8D934CFF78FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF66FFFF6137527C565537537662291D51404333231A424F324340362C1F1124
0F2B13082A1C240B1F09261D140C15251C0C0D15
151E1E100D29120A0C2C283317242D0F3850162E472F1965151A2F1B2B4B39210D229389
5041C75541839348FF6543FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFDAB9B57B82C1B3691EA08A72345426487468471942191A292E08102C
150D1647161B2B1D27240E16062320261214241C
1A2B2C4C241628170F2F2915032C18393D17162226164B322E40381D6067627F5A433D62
519B9F79A3DC5AE56043FFE5FFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFEF55F6FFF2961824497E77390F4BC2542D3F292D473E442C51362938
50672937431F213F233337302E1B221B19101020
0C15171015130E1D0E18021F080F1815121D3B3135213A2F18281D2E171961422145727B
4A2F8837355D83FF60B79C9DFFFFFF3C4EFF84FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8D54FFACFF7B6574498E6C2E3744501672483C31411813332D1A551E312E3C05
2B14211429051B112F1514041628150D190E070D
2B213C2B231C4A371B07343A2F2C230D325178442C663A2E792631386B453F76A93F517B
75913376E0612EFFB553FFFF89FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC93AFFE91BB453A05068FB8F60A1786C383D82711A5C4721584E3247
302A091D4231242F430E292C26161D2B2F1D2338
120F222B331F232D2B13261728182B272E42453D111B29200B29142C24532B2D606D3F5B
4693468B42A8E76758461C93FFFFEEA1FFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
85FFFFFFFFFFFFB79251D5CCE1769B5F4787486522221FC0623B2114241E183726190E29
31515D2916201D22262826293D35121123160E0A
211B2B412627373F291F222B1D35271032622A171410111A2B2B1C18094408C0934B2A2E
5159773E97A275C1D27D64FFD24556FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE5FFFFFF26419694C7FF5F8016F23E4B8078334A2E6C1B351B511B2A663341
3950463B3A3C33192C582B423324194330120A2F
170C191A110D0C1B031A18050F1F1211351F1443152634231A42131720283847553A9843
816B615D747CC8B38DA9A21D8F58B1B0FFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF8FFB0B1588F1DA2A98DB3C87C745D616B8143983A55473828201713421A233426
1543141F3511121F0F05181A031B0C0D111A190C
212F0A123043192433422B582C19333C3A3B4650394133662A1B511B351B6C2E4A337880
4B3EF216805FFFC794964126FFFFFFE5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF5645D2FF647DD2C175A2973E7759512E2A4B93C0084409181C2B2B1A1110
14172A62321027351D2B221F293F372726412B1B
120A0E16231112353D29262826221D2016295D5131290E192637181E2414213B62C01F22
22654887475F9B76E1CCD55192B7FFFFFFFFFFFF85FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCFFFFFFFA1EEFFFF931C465867E7A8428B4693465B3F6D602D2B53242C14290B20291B
113D45422E272B18281726132B2D231F332B220F
2B38231D2F2B1D16262C290E432F2431421D092A3047324E5821475C1A71823D386C78A1
608FFB6850A053B41BE9FF3AC9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF89FFFF53B5FF2E61E0763391757B513FA9763F456B383126792E3A66
2C447851320D232C2F3A34071B374A1C232B3C21
0C0D070E190D1528160414152F111B05291421142B053C2E311E551A2D33131841313C48
72165044372E6C8E4974657BFFACFF548DFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF84FF4E3CFFFFFF9D9CB760FF835D3537882F4A7B724521426119172E1D28182F3A21
35313B1D1215180F081F02180E1D0E1315101715
1A201010191B221B2E303733233F211F4337296750382936512C443E472D293F2D54C24B
0F39777E49241896F2FFF655EFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF6FFE5FF4360E55ADCA3799F9B51623D435A7F6267601D38402E324B16
262216173D39182C0315292F0F172816244C2C2B
151C24141226202306160E24271D2B1B1647160D152C10082E291A194219476874482654
34728AA01E69B3C1827BB5B9DAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF4365FF4893834155C741508993220D21394B2B1B2F1A1565192F
472E1650380F2D241733282C0C0A12290D101E1E
08150D0C1C25150C141D26091F0B241C2A08132B0F24111F2C364043324F421A23334340
511D296276533755567C523761FFFF66FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF78FF4C938DEDDE3F17F641981E43694C3A314A48437B14241B28273820284711
0A403248442D0E161E142511161009171215121F
2421192519142A1F041C280828213624211A262A4347341A3C67316E261E696B4826236F
6EB74AAAA9B6387BD2FFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF6FFFFFFFFFFFFC99AEF111AF08BF9718969B9461D14225674454C5D224B543848
4D0F153E113922142019161D2F290E1C2A091B22
0D16121C200C0A24272F1C0E0E06192D121131191C0A2908142A2C22360F3117606C862C
410C4315189D6575C29F88E4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF4F17D62A47CA964691F13414068567107223C10231F143E190411
183537131833120F1D330C1D2F110B0B310A1105
1506211C081E361F21031433171F202E0D4A2540371508291C2B1F144F112956353D2F62
583A367773448A4184E78C4AB8EAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF954AAF36845153BD30937B782E755E38474E3823217D2639343D35301713
0C2A272033242B2A140C1834201E181F1006242E
191425222A0F141B32151D2116201C251D1B1F1E2338372F1C4943254C590E4F68404427
49A2C50EC37FA8FF8EFFDEFFFFFFEBA6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFC9FF53FF34FFCFFFFF94D22BD92C708D8A521E6E72764811324148372A1457424B
424E3F3324262A202929131026281A110E241F25
12180D1412001B1B0B17180E080C0D071C0D2B250B2B1F261210360E1F401F0D1C10514B
4B342453130DD18E4BFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFE3A96765B94A4E637166501F4E30364318381D052A2611320A
311D0B3B05181D221114100F190E1012131C0D13
2819122024051132172A1F201E2E162A25195324333126312F054B180840563148662228
4D5E57484F1DF3653476B78BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFBC7717AD81397C7E598768356A615739534B485D494A1F6D312721
3222241D2F20242D22310B0F361C1F1F1E2C1917
180F05130B21100D16230A1C121711181318250C14172B0E1B153B0B353E5C1516476150
7C599F3FA0E4D9E1AAAFF5688BFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFD1FFFFFFAF8961DA90B8D7E6CD31FFAE328C4E2F4D5546501B183A2149350F3819
1C2F54222A23091418171B100512162102161E0C
0E0B2614141D080F231020141007330C132218262209213421241E401A0D025621302940
151B2B2F57595BC8E9D5FFFFFFB6E1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE4FFFFFFFF
FFFFFFFFFFFFBB54CEE6FFFFDDFCBF7A5F8F84165F03400A7E182F4C1A354E6C3E283208
103F233B2A1E0C0535331C0F271C121B10170114
1F02070C1E1B12081F2718122A25251526061B452E020D30334A1D38233B3A432C385977
964D377D593D48485B80D2FFFFFF89CBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCAFFFFFFFF
FFF2E7FFFFA469FFE6FF8DFBCB4FA04CD5A26E638C746A516647543639556D2F47281E31
152D2C1C0927190724181C101819291709191212
1020060E09091A0B0602120B160B0F050B0E051D1E242B4529091120171E3E3F12215D8F
775563928F77445E6D428DE287FFDEB7DFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5EFFFFC1FF
AAFFFFFD467DCDF4E655BF7E8763D64CF6C5B2C13183146215256E283952402D24231B15
2A1521440B0F110C10160B17090F0E09060F1B13
060B061E130D1720130611180116152D1D12372C102D131C2E1F1D0A364B312F5A2F6335
266329369682B4859D9F7A74968CFFFFCDCBFFFFFFFFA7FFFFFFFFFFFFFFFF9CFFFFAEFF
C899FFFF3E62FFAAB21F8A86D9F1F3F968E778634A1C304929441D2D0D4A3B1B48110927
2B2014210E1C150F0628221F0B051F0905101803
0D08050104210C22080E061207050E191C182E1B073E0910222425043750632240524B23
3A5A6133585483B68AA1AC4784CBE0FF9FFFFFFFF9FF76FFFFFFFFFFFFFFFF9CFFFFFFFF
A7A2FFB89AD08ADD3071C1D4EFFE9CC14FCB59BE3C954C5573293328514947092B191D17
0C0C320803120D0317091F07140D080C020B0E07
0610131809170C14040A041307042029170D09153F0B170F2D1A2A041A481B2674213755
553F754313201F616890C79962AAABE2AAA9FFFFE9FF72E6FFCDFFFFFFFFFF48FFFFB6DD
EBC1FBCA5FCA84307C60D190FBEB4063A89DA5829A6243474F291243423E1313172A2F1D
17231F08220A120F20230E2118200E110C180910
11160B0D14050A0D0C12040D1A020B0A1F13122A1A0E391802240228384832673C173B46
4B275750257C410B2C4167D94060AFC8E07FFFC8CAFFB0FFFFFFFFFFFFE3FFBFFFBA94FF
5FBEA3479391919158C56A9B90B27FBCACA5A54C6E36612F492C1733233B1F1511320D01
0A212203081303070D1619171D110B0A1A090F06
12081107060B16131007040F14051906110F03161822370B0C22192E1A29154F2D19203A
3D20355951813C44393E1ECE7B4E66C4F5BEC575A2EB82C3FFCDFFE3FFF3FF95FF9672FF
21B8D15DBD837291CAD3A13B98B56EAB8BA4846874266040501F182833081F0918282818
16140F300C1A0810120D1706120C180E1B06040B
0D0C121501190A0A0A08150803010410211907110C431338051C34291F171E2E324C160B
2A3B1C5337166C414B22207C7E864097FF7DAB9ADFFBB7A4FF5DFFE4FFB1FF47FF4C51BB
3C8F8D8893688F5D7B85B2519FB0A16744A2505C8D6841365E1520362632410E370D0C14
1F0F141C132B2D12131B191E14110B080B0B0E15
0C02070905120D080E03181211160B110B0918142A190A1813210F2C313307554D583420
39322D162919395E2D1C403E385141A6C0865486689E7D87FF1EFFA0FF8CFF97FFA67BE3
8FCE8D738B7E2EB46A5AB03B7A7F97A53D689C552E6A396B274B273F3E1D2820141A1223
161D320E0D0D1E08111D1B170C0D050A08000E07
0F1109121A0B0C0802111210030C1D15190C2111171E26371A152420161D0C103F45422A
1F4D311011392C6E1D0640593913402E7A6C358D73C64FA1FF5BFFFFFFE5FF7AB2965C72
6F837A27A58E85A4C83C827C9E4B385C754E9A6F4630235D252435511127290F10103F38
090F160F1C242D0A15131F131008101A10140F0A
0A0A0E201E080B0219080B0C1022110D13350B272505261E22294A241F1F0B17110C0C24
4D3E3D34080A20295F08220A646A2637556027392BCB145CFB83FFFBFF87FF9DFF8528A1
92A77F2999A034898173AB9D7E4B51364F263B583352294B42332A47342F12371B171934
1B26181F0709181C17121A13030A0C0E10180611
0304060D0F01051608060F0A06120E04100A0D0A14222424240E1F352749402F1B3A2949
341A2617061E14162D5A0625694C0C308B4E154469BA3456E486FF82FF57FFB8EA543E78
495452328A7E4A40AC3A787C8876615745586945211C49423C443A28514B13300C12160F
0910061102220D151C1F061B1F0417181510060C
0A190E091A1413080E051F0D1010011610080926201106042717150F1E0F36451C224713
2318242A3D0F13231A403E154F4012216E41086046A88087E440FF74FF9BFF53F73D328C
34344179987A795261498960A63754477A4263624C3B3D3B24245F184F2743060C041D1F
311B1D211814141322101116090C06061E0E1111
06190A0E111A041212091E1C031D1A231810362B2E23211A171E170F1F24173F262D151F
1A0A30241D1F2A1C072F5C1A075939316129152A4A91646BFF49FFBCFF82FF21B66447B6
305430869282A64A6E518C695370393D4144273A50104754310F451B2825280E1E2C1E19
2D0F2A141D20021917021A130A0A03120901190D
131310061C050D010F0B0914061B1612120706051203113335241611271D27071D0F1F1D
4B2D11092F18110232173A2A243D0B2F5B3537062B7B2938F64DFF50FF35FF58D55C5891
6A69346B9B4F718766744E60534D68614E26481D19181C3D472F193A2A5916331C20211C
1F1A0A1B1C10251D0B0F0C11110D130A0D070F0E
050905100C0C170916150E1012200E14110813291A0F0E032C251E23193A1F19182A1F16
2028090A1051211E12371A361F4232394A43181A36511726CF8BFFB9FF8BFF39ED4C2B63
387B55758C4B545F4D705C334464735C5F51225D330820340E291A28225230131821101C
1B1E212427031D16121505130E12140607120B07
090D060C0B121110080B190B100D0E15261707250F182F2E181D0F14493118101616151C
22161719092C3D2B2017282639132B255E51116804682534CD52FF69FF1AFF6FFF762A8F
4C6830696E435A557274684D3748664F393A2C27331B1F0B3A2F32231821231C04041A1F
141E211C1D070D171403050F141516161106061A
06170F09041105060E03100D05070B20151828081B1009190D380E101A2029222F21141B
19270F23142A2329132524292A0A391C4A2D1E520F984162D168FF54FF52FD749F69257A
5B400763604A776F4C713E214545272E37271C1E1925131D263A221D301B0D1D2A22191C
1E130E1E121F16100F1704110708100802010913
061C1110040F0615120E060F111108170403121F182B3028110F281F261D271D3A290D04
101726041130283329032A3F334231174B472C33187F6779BB57FB5FFF63E84D7D404862
6540107256537154575A132F1E444915274138282028232608361A070624321920372F20
08122104141712091B1B1404050D140C17060F09
0516000514141A16100E0C0C10180D0B240C16050F07131B10050E21233C201F293E1E0B
1634372C051A1C4C251C1C19104624282F571C154C712B47AA55F37AFF44FF5E64404074
2C4024645E2F534B433A36155632320C2B50344235301E2D1F090D0B140B1D25251C1909
0D121D1C07060903160F141809141A150D02060B
050F100F15040B020C0E0E0A20231F060E242B170F25150D171E1E191C1F1416140C2C12
111622251D0E14391E35194B352B1F115C28121E23631544A923EB67FF36FF12AD561A67
322E3B72323153413943312B3B331C281B29163526172C2117191E0E151A260320151E27
20161F160F0C1F1A10131014031414100C030609
0C0406161A090601060A0D0B0D0B0618061A0A0C0813190805182D131418162E290F4703
17192A172D17232B39241C451C25511566401C242E432B23C23FE668FF58FF33DA3C3075
424F50672A41544D391E1A223726120D1A242011422108271D141203183514130E200C43
26110910020D11120E0F0F0C09040B161408190C
1408041813051D130F0E1C110E080518070E1A051C20131D1B1C1618192C1804060F2013
22162D100811130C253230410A2050293E3E2D302E4A1F4AA748F44DFF79E852A04E3247
37371649191945283D1C0F2B4D0518352012313A2D201C12260F2411130A21110D211E0D
09101A0C131B01040B1C141124100E1112100407
0B030E080D110D1B130E06180B0715380F0F0A120B0411032F1C0C0208152B230B20230F
171D02281131161B20231C40243924411959182B397E212AAD5BEA4AFF8FC44CBE643782
4D4011531337243E25201F2E1C0F22063C2E2A0E1E230B191D1727091C1A050A1B1F3431
120D05150816160414100D181B05071312050B10
0B0B080C0F0D070A0B0E0E18030A18180C0314120E291F1224082220200E27220E101A1E
3D27251A160924262E2A111915363E1C2D63403C1060322D8662F257FF41D86F9C412270
303D11492A043B0B112D1B24263309292B0E0F1605130A0510213618060F2A2908141815
111B081A1B0F160E090F09090D1A1B120A110F0F
0D1C1E121215100E080B190304100907120F0C0411080711200A060B1617131D24271711
2322111014170808171E1A333E0D46050F363B3E1C2E24499B55DE6CFF43FC495E46314E
41351C472C09411611301C2C20163C2821271712130D1E21151E220F0E021B18091D1A0C
120B0B130F0D12190E0C1A0C081D1E12201D2005
0C100A0E23151B080A1B1D0615040608131A141E1D0F110A151E160D2509200422111123
191311102B0F1816262C193C29293F0E191A0C283452322ECC15DC61FF7CFF1BB1572A50
3D1828371C0621410B1526331B212422251014191A211F281C082B2F080D1D1E0E1C0B0D
27140F0E0B191104191A14010B0315120E08090B
100B01070906090C1107110A0D0805030719140C13010D0E071703140B1F092812180D19
140C101A0C1F19062E2A131113101D34472A1937414A1C459123FF5DFF53F6259931405B
652B343A04104E1E170A111B2D042C2F0B140A200A0B1719200C11110E13110D0E0B1717
1F14110A05091212100D19090F13080B1D050410
1A121B151E0C060D08050A0E0F190F0014281D0D271D0E111E050A0F2605051D130E120C
101D0A1D1E290F27191A1F2B1C180E3030221A2B492E152A8C41ED3DFF5AFF4493693E5B
17172F411D2139181612161F1A0F181A243A24120D130F33240E1A291203100D10030E0E
0C17060A06020A0C0B100919150D0910151A1617
21161B150F12140E040B0E0E051D1B10101410152616090F2217051B1A24130D10160805
083618040F1919132F23422E1D1C120B0A381B1337390946AA3BDF7FFF5EE046D233596D
1C1B10471430210A24142B1427260D190A0E0E1A150D21202C24101D0F130D0C200E0F12
091A0C040E1A200C142115140E0A0C0F18171701
090B12081610040D0C051608050921110C1F1B051B190B04130D0E1106180B091220020C
150F1C0C081E3A1634081D090A08230A17372A2528382843A041D464FF41EC6AA525495C
341E173E2E152B0F1C12191F211F1D103211131417151B0E0B1B0C2109170B0C1B10121A
0D12060D0F04181706101B1A0A09070508040F0D
0F0B080A0107080706110712140D130D0B1B150A0D050A151C07241D120417040909160A
090A130C0D2C251C1406170803112B1C1819191D014939359845BE57FF68DE5B7E392F44
30112923212221020C081A27142D211411240E28260519071D1B23191520140C0A060208
09071D0C080A0E0B08100B0E11130C0F0D080A19
142120161519030D020E1714060F100A0D06181010120A0F14030E17170F141711101803
101806101F050F1215381A0F2927171D262D21131B4B2B237233C64AFF6AEB5E8F2C1A4C
3F472922202B1F1510110416180E09291A0B06101D0E2B15101E1B1A1314010C07150A08
0D0514150F0C0A040F180F19141815111B130D12
121F13181B1208080F05192B21170B100805141C0E0A030B12131E100F230912170A0C0D
0A070B110D0E1315173E2B05110E2A24293B340745523C176B23B72AFF33FA4C941D0D5C
2C351D290A302C03201411091A1C1610211629062510181E19071A101511100F0B09110E
050C0B07010C1B0E0A1314090E110D0E1A0C1E15
020F15070806180519170A101E1A1514050D0E1D08140C120E02190D151C1A161002141C
0C1C190C131A011D0F0D261617121F1B072A1C282A40373B700EEF4FFF5A9A298B371946
222D33282228120825040A1D15040E08190A191F130B131114260307170E0E150910020F
11040B030E181E130712070408070C050303060A
090904130C08030F18111D121711030E1A090E220116010A1117100E0D1B1710091E0B1C
1A290D26060B0B0A0E131F01131A151F093428182F2B272D9029BF74FF64D12A9D48411C
0D25371F361A102112050C090E0A0A280C112B1F09030E1B15100502060B0D0C0D0F0604
080E14080B1C1310050B0D0603070B0510161110
1E160C110C0906131D14180C0A0A0810221B0819060A080E112A10140818092105020819
13090913071B1223160E110F0319181F18150C1A2D3F151A9834D151FF3FCE5598363644
1B10282338220F130E020C120D1F24261C151E2917171318250911120E0D1211060A0F12
1000140A0C080D0F070807070801090212132016
130E1913110D0614211F280B0F05130717161122150A0E0E081D13180E0A0F1711060808
210215191A0C031E10040D08140D212D381B210A352C2E16693CDC48FF54BC59A0294863
031C1D1223141F1E150B1B16042419150D18250D170C1906130C140C0A12100A0A03040C
1015101A06050506071403070D080D160E0F1B22
0A090E0E05060C0D181A180908100616181606180B10110A111516230A010E1214051409
2A050D1F111406121D0E1608071E0732232A42042D161D34603FD768FF55F25A903E3346
100E2313110F0920190F110A04141E121226151011172309020B1012110E1A07080F0914
0C0C0913120D0903011907100E1306131C13110C
10170C01080C090C141713060813030A1D23021603192108120B06110E0B0C0B20120313
1B1119021513100B1020071E080E1313241A230D21453D24A51BCF4BFF2BDB3D92250D35
25220E14190D1E0D180E1F150B101D0A190F070901110B040D1A091E0E070A090C130C06
0C19020D05060B0A19100D160F130E0E100D0909
0F19170A04080F0E0D11090910131213121C1206051023161111030E111319050E120D12
190C150A0B190F1B1601062A152118031F162A15243340388C24C159FF40BD3D8E2E2733
39141F0E2209121B0F13241B09210D0A130C1B0D0A150E0E0D060F11160C0513070E0709
010D0A140E0C0E0F0D08100E020D080508060818
1518150D0711100E0F0E0D09091508160F0A120C0E070F0B050F130C1316120113110A11
0F0D110C0E1A090F070D101105171B03202C292928262039822DC062FF37D9569229464E
2F080F232C0C190A080B2412072210111E050809200907221909140C070E1F060A0F090B
0F0C04160D16180A140303101205030418130913
191A0C0A050E190C070B01020C1D090F0B030A22141408081310200211181207100E1A10
14111B1D161A0315061C1B091D08000A1B070710282B202B7124C158FF44CF479338353F
0B0E3021261F1C0415000B0B161A10092B0B0909180C06120F0C201A13091B0F19110306
05080B110E0216110807090D1A090A0C11141311
09100E060606110E07050A010F18111413020D171E110F09121E1301130F1C0C0A06170B
110A1412110B14201820200522110416041311160F2B3D326F46DC59FF4DA54B75372525
141F262A31102616121308171822160912090A17101916081A061A060A0805160414030E
08060A0B0A000810020E0913170F0A0C100B0F0D
07100C0B0C0A160C0D0A080207040D040E090E15130D09160F1C040D1306240325091C06
10180908040527101310090E0B060E0D12111A1E10462E0B8D3AA63FFF45CF2A821D2827
0B22202C211F1E2010101719191F1D12131207080C13170E12101D03140D061108090503
060B1007030E0E18050B170F0F0B100E03070B03
040D070414201604070C0D08050707080D090A0D13140D23130A0B0E22151507240E1418
081B100D0E04131615171A071216112120270F0C0A3541226F50C952FF44A35B8A2C1E21
17161E1E2526171B040408081C080509041521050E11140E0E1610171D0B0A0D10160F15
13080806070B150E0A100E06051411010D060406
170E04040F131B0D090C0F0A0803050F1617170708151A22140D0807220B12141502160F
1A0B16120C07190E0B1B141B20230E132B2A130711422918614CAA48FF41C4567F371D11
210C081F2A1D2D220E0F1B10092D060E070F200F11141114130705120E0D16101610170D
15070D0203111D100B16080A0B0213070C050D09
1010040B0C121410070C0A1210020A091C20160F0D0F0C1C0A100E02160218070F0B2808
141503121406192B170C260A10140D0E26160F110A4128236F2FCA4FFF44A1437F2C1B19
1D042A1E2423212D190D1D0814250C0C02110C1D110F150A0E07121109080813140E0E14
1608041208061A0F090B150407121307120B0F08
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282, 282},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{-0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J00016Q000`40n007h00Ooooo6ooo003ooolK
ool00?oooa_oo`00oooo6ooo003ooolKool00?oooa_oo`00oooo6ooo000Iool2000Qool40003ool2
000Pool00`00ooooo`02ool2000Oool20004ool2000Oool20004ool2000Kool40003ool20004ool2
000Hool40002ool40003ool2000?ool001Soo`04003ooooo000Pool00`00ooooo`03ool01000oooo
o`007ooo00D00?ooooooo`0000;oo`03003ooooo01_oo`04003ooooo0002ool01000ooooo`007Ooo
00@00?ooool000;oo`04003ooooo000Lool01@00oooooooo00000_oo00@00?ooool000;oo`03003o
oooo01Ooo`05003oooooool00005ool01000ooooo`003_oo000Hool01000ooooo`008Ooo00<00?oo
ool00_oo00@00?ooool001coo`D000;oo`04003ooooo000Mool01000ooooo`000_oo00@00?ooool0
01goo`04003ooooo0002ool01000ooooo`007?oo00D00?ooooooo`0000;oo`04003ooooo0002ool0
0`00ooooo`0Gool00`00ooooo`02ool00`00ooooo`02ool01000ooooo`003_oo000Hool01000oooo
o`008_oo00D00?ooooooo`0000;oo`03003ooooo01[oo`04003ooooo0003ool01000ooooo`007Ooo
0`000ooo00@00?ooool001koo`8000?oo`04003ooooo000Lool01@00oooooooo00000_oo00@00?oo
ool000;oo`03003ooooo01Ooo`03003ooooo00?oo`05003oooooool00002ool00`00ooooo`0<ool0
01Soo`04003ooooo000Sool01000ooooo`000_oo00<00?ooool06ooo00<00?oo00000ooo00@00?oo
ool001goo`03003ooooo00?oo`04003ooooo000Mool01000ooooo`000_oo00@00?ooool001coo`05
003oooooool00002ool01000ooooo`000_oo00<00?ooool05ooo00<00?ooool01?oo00@00?ooool0
00;oo`03003ooooo00coo`006?oo00@00?ooool0023oo`04003ooooo0002ool01000ooooo`007_oo
0P000ooo00@00?ooool001goo`03003ooooo00?oo`04003ooooo000Mool01000ooooo`000_oo00@0
0?ooool001[oo`<000?oo`04003ooooo0002ool01000ooooo`005ooo0`000ooo00@00?ooool000;o
o`04003ooooo000>ool001Woo`8002;oo`8000Coo`80023oo`03003ooooo00;oo`8001ooo`<000?o
o`8001ooo`8000Coo`8001goo`03003ooooo00;oo`8000Coo`8001[oo`03003ooooo00;oo`8000Co
o`8000ooo`00oooo6ooo003ooolKool00?oooa_oo`005Oooo`001@000Ooo000Eool00`00ooooo`02
ool00`00ooooo`06ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`06
ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`06
ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`06ool00`00ooooo`07
ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`06ool00`00ooooo`07ool00`00ooooo`07
ool00`00ooooo`07ool00`00ooooo`06ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07
ool00`00ooooo`06ool20001ool001Goo`03003ooooo00;oo`03003ooooo02Coo`03003ooooo02Co
o`03003ooooo02Coo`03003ooooo02Coo`03003ooooo02Coo`03003ooooo02Coo`03003ooooo017o
o`40007oo`003_oo0P001Ooo00<00?ooool0oooo0Ooo0@000Ooo000=ool01000ooooo`001?oo00<0
0?ooool0oooo0Ooo0@000Ooo000=ool01000ooooo`001?oo0P00oooo0Ooo0P000Ooo000=ool01000
ooooo`001?oo00<00?ooool00_oo11220PQQ0PQ100<@PQ2R4:80112R0PQQ0Q220PQQ0Q220P0P0PQQ
0Q220P000PQ11Q220Q2R0PQ10Q220PQ10PQQ0Q2R112200<8@@QQ26400QS30PQ10P0P0Q220QSS0PQQ
0Q2R0QSS11220PQQ0Q2R0P0P0PQ10Q220PQ10PQQ0QS3212200<Q91SS6><00R4T0PQQ0QS30R440S66
0S6V0V]=0SWW0ZeE0U[[0_oo0U[[0ZeE0SWW0V]=0S6V0S660R440QS30PQQ0R4T0QSS00<Q91224880
1Q220QS30PQQ0PQ10Q220PQ10P0P0Q2R0PQQ11220QSS0Q2R0PQQ0QSS0Q220P0P0PQ10QS30PQQ00<8
@A2248800Q220Q2R0PQQ0PQ10Q220PQ10Q2R1Q220PQ10P000Q220PQQ0P0P0Q220PQQ0Q220PQQ1Q2R
00<@PPQ124400PQQ0Q221?oo0@000Ooo000=ool01000ooooo`001?oo00<00?ooool00_oo11220PQQ
0PQ100<@PQ2R4:80112R0PQQ0Q220PQQ0Q220P0P0PQQ0Q220P000PQ11Q220Q2R0PQ10Q220PQ10PQQ
0Q2R112200<8@@QQ26400QS30PQ10P0P0Q220QSS0PQQ0Q2R0QSS11220PQQ0Q2R0P0P0PQ10Q220PQ1
0PQQ0QS3212200<Q91SS6><00R4T0PQQ0QS30R440S660S6V0V]=0SWW0ZeE0U[[0_oo0U[[0ZeE0SWW
0V]=0S6V0S660R440QS30PQQ0R4T0QSS00<Q912248801Q220QS30PQQ0PQ10Q220PQ10P0P0Q2R0PQQ
11220QSS0Q2R0PQQ0QSS0Q220P0P0PQ10QS30PQQ00<8@A2248800Q220Q2R0PQQ0PQ10Q220PQ10Q2R
1Q220PQ10P000Q220PQQ0P0P0Q220PQQ0Q220PQQ1Q2R00<@PPQ124400PQQ0Q221?oo0@000Ooo000=
ool01000ooooo`001?oo00<00?ooool00_oo0Q220PQ10PQQ0PQ100<@PP0P02001122100P0Q2R10Q1
0PQQ0QS30P0P0PQ10Q220P0P0PQ1112R10QQ0Q2R0Q221@Q111220P0P0PQQ0PQ10Q2R0PQQ0Q220QSS
0PQQ0Q220P0010QQ0R4T0Q2R0PQ10QSS0PQQ0QS30RUU124400<Q91SS6><00RU50P0P0QSS11S30RUU
0W__0T880ZDD0T8X0_oo0TYY0/iI0RUU0V]]0R440RU50T880PQ10Q220PQQ0Q2R00<Q90QQ26400PQQ
0Q2R0Q220PQ10R4T0PQQ0Q2R0RU50QS30P0P0Q2R0Q220P00112R0PQ10RU50PQ10PQQ0P0P0QS30P00
00<@XP0000000PQQ0Q220PQ10QSS20QQ0Q2R0R440QSS10Q10P0011220PQ10PQQ0P0P0Q220Q2R0Q22
00<8H@Q124400P0P0Q221?oo0@000Ooo000>ool20005ool00`00ooooo`02ool24882244226422440
0a2202008004488402024:84244226426<<2020224424882020224444:8426424:82488524444882
0202264224424:82264248826><226424882000426428B@24:8224426><226426<<2:FD48@@00b4T
6><Hh`02:DD202026><46<<2:FD2Nnl2@PP2YA@2@RP2ool2BVT2cUT2:FD2Jfd28@@2:DD2@PP22442
488226424:800b4T2648H@0226424:82488224428B@226424:82:DD26<<202024:82488200044:82
2442:DD22442264202026<<200000a2R000000022642488224426><826424:828@@26><424420004
488224422642020248824:8248800`QQ2448@@0202024884ool10001ool001Goo`03003ooooo00;o
o`8@XP88@@88H@8080032640800P008@PP8000H8@@8@XP88@@8@PP8Hh`8@PP@00088H@80808@XP88
H@8@XP8@PP8@XP8@PP8@XP<8H@8@PP@0808@PP8@XP8@PP8@XP8@PP88H@8Q1088H@808088H@80808Y
I@88@@8@PP8H``@8H@8Q108YI@8Hh`03:DDHhaSS0088@@88H@8Q108@PP8Hh`8aYP9kk`9BZP;6>092
20;oo`9:B@:]E@9:J@9S308H``8YA@92208@PP80808@PP<YA@8@PP88H@@Q108H``8@XP8H``88@@88
H@8H``808088H@8@PP8@XP88@@8H``88H@8@XP8000@@XP8@PP88@@038@@0800P0088@@88H@8@XP8Q
108H``8@XP88@@8080H@XP88H@80808000@8@@@8H@88@@88H@8H``8@PP032640800P00808088H@Co
o`40007oo`005Ooo00<00?ooool00_oo0Q2R0PQ10PQQ0P0P00<8H@0P02000Q220P001PQ10Q2R0PQ1
0Q220QSS0Q2210000PQQ0P0P0Q2R0PQQ0Q2R0Q220Q2R0Q220Q2R0`QQ0Q22100P0Q220Q2R0Q220Q2R
0Q220PQQ0R440PQQ0P0P0PQQ0P0P0RUU0PQ10Q220QS310QQ0R440RUU0QSS00<YAASS6><00PQ10PQQ
0R440Q220QSS0S6V0W__0U:Z0/Hh0T880_oo0TY90ZeE0TYY0V<<0QS30RU50T880Q220P0P0Q220bU5
0Q220PQQ12440QS30Q2R0QS30PQ10PQQ0QS30P0P0PQQ0Q220Q2R0PQ10QS30PQQ0Q2R0P00112R0Q22
0PQ100<Q100P02000PQ10PQQ0Q2R0R440QS30Q2R0PQ10P0P1Q2R0PQQ0P0P0P0010Q110QQ0PQ10PQQ
0QS30Q2200<8H@0P02000P0P0PQQ1?oo0@000Ooo000Eool00`00ooooo`02ool802000`QQ00000002
48824:84020226424882244226424:8224440204244248824:8226424:824882264424400aSS4:8@
XP0248824:8426424:824882264202028@@24:8202022442020224426><4244402026<<24:838B@4
6><44:828@@26><2:FD2S542F//2YA@2@RP2ool2DXX2cUT2DXX2Jfd28@@2@PP2<JH2244426428B@3
8@@248824:82488202026<<64:8248820204264248826<<224426<<24:8226428B@202044:800b44
2648H@04244248828@@226424:824882264424422642244602022444264402024:828@@00a2R0200
800202022644ool10001ool001Goo`03003ooooo00;oo`P0800326400000008@PP8@XP@08088H@8@
PP88@@88H@8@XP88@@@080@8@@8@PP8@XP88H@8@XP8@PP88H@@8@@036><@XQ2R008@PP8@XP@8H@8@
XP8@PP88H@80808Q108@XP808088@@808088@@8Hh`@8@@@0808H``8@XP<Q90@Hh`@@XP8Q108Hh`8Y
I@:<D@9Jb`:U5092:0;oo`9BRP;>F@9BRP9[K@8Q1092208aYP88@@@8H@8Q90<Q108@PP8@XP8@PP80
808H``H@XP8@PP8080@8H@8@PP8H``88@@8H``8@XP88H@8Q908080@@XP038@@8H@QQ00@8@@8@PP8Q
1088H@8@XP8@PP88H@@8@@88H@88@@H08088@@@8H@@0808@XP8Q10034:80800P00808088H@Coo`40
007oo`005Ooo00<00?ooool00_oo0P0P0P000PQ10P0P00<000QQ26400Q220PQ110QQ0Q2R0PQ10P0P
0QS310QQ0P000P0P0Q220PQ10P0P0P000P0P10Q10Q220P0P0PQQ00<@XP0000000QSS11220PQQ0Q2R
0Q220PQQ0PQ10P0P1Q2211SS11S30Q2R11220R4411SS00<Q12UU:FD012440PQ10R4T0RU50QSS0X@@
0RU50/ii0T8X0_oo0SWW0ZDd0SW70Xaa0PQ10RUU0T8X0Q220QSS0QS30a2210QQ0P0P0PQ10PQQ0PQ1
1Q220R4T100P10Q10QS30Q220P0P0QSS0PQ10R4T0P000R4T0P0P00<@PPQQ26400P0P0QSS0PQQ0Q2R
0PQ10PQQ0Q220Q2R0PQQ0PQ10PQQ0P0P0PQQ100P0P0010Q110QQ0Q2R0PQ100<8H@Q124400PQQ0Q22
1?oo0@000Ooo000Eool20003ool202020002244202000`002648H@024882244426424:8224420202
6<<42642000202024882244202020002020424424882020226400a2R000000026><4488226424:82
488226422442020648846><46<<24:8448828@@46><00b44:FDYI@048@@224428B@2:DD26><2Q102
:DD2cWT2@RP2ool2>NL2YC@2>LL2S7422442:FD2@RP248826><26<<3488426420202244226422446
48828B@4020424426<<2488202026><224428B@200028B@202000a222648H@0202026><226424:82
2442264248824:822642244226420202264402020004244426424:8224400`QQ2448@@0226424883
ool20001ool001Goo`03003ooooo00;oo`88@@@8H@88@@034888H@QQ0088@@88H@8@XP8@PP88@@88
H@80008@PP88@@8000H8@@808088@@88H@80008@XP80808@XP8080<8@@80808H``80808H``88@@8@
XP8H``8@PP8@XP@8@@8@PP88@@8@XP8Q108H``8@XP88@@@@PP8@XP8Q908@PP03<HHYABU5008Q908H
h`8@XP@Q908aYP9c[P9:B@:U=09:J@;oo`9Jb`;Nn`92:09[K@8aQP8ii`8YA@88H@8@XP@@PP03020@
XQ2R0080808@PP8Q108080@Q108H``8Q108@XP88@@@@PP8@XP88@@8@PP88@@8@XP808088@@88H@8H
h`88H@0348800000008@PP8Hh`8@PP88@@88H@8@PP8Hh`8@XP88H@80008@PP8@XP8@PP8H``88H@80
0088@@@08088H@8@PPD08088H@8@PPCoo`40007oo`005Ooo00<00?ooool00_oo0PQ110QQ0PQ100<@
PPQQ26400PQ10PQQ0Q2R0Q220PQ10PQQ0P000Q220PQ10P001PQ10P0P0PQ10PQQ0P000Q2R0P0P0Q2R
0P0P0`Q10P0P0QS30P0P0QS30PQ10Q2R0QS30Q220Q2R10Q10Q220PQ10Q2R0R440QS30Q2R0PQ11122
0Q2R0R4T0Q2200<aQRU5:DD00R4T0QSS0Q2R124T0S6V0W>^0TY90ZDd0TYY0_oo0U[;0]kk0T8X0V]]
0S660SWW0RU50PQQ0Q2R112200<0812R4:800P0P0Q220R440P0P12440QS30R440Q2R0PQ111220Q2R
0PQ10Q220PQ10Q2R0P0P0PQ10PQQ0QSS0PQQ00<@PP0000000Q220QSS0Q220PQ10PQQ0Q220QSS0Q2R
0PQQ0P000Q220Q2R0Q220QS30PQQ0P000PQ1100P0PQQ0Q221@0P0PQQ0Q221?oo0@000Ooo000Eool0
0`00ooooo`02ool26<<448824:800a222648H@0424426<<2264224420202244248824:8200022642
488424440202000248826<<226426<<224400a226<<H``028@@426424882020226426<<62442:DD2
244248826<<24:84244200024:8202046><00b4T8@@Q1002<HH226422442>NL2<JH2>LL2U982@RP2
cWT2@RP2ool2F//2aQP28B@2Lhh2:DD28@@4:DD2488402000aS32448@@02000224426><224426<<2
6><202024:8200026<<24:826><26<<248824:8248826<<226424882020248826<<00a2200000002
8@@4488424444:828@@2244200022442264224426><2264400022442020226426<<226400`0P2448
@@0226426<<4ool10001ool001Goo`03003ooooo00;oo`8H``@@PP8@XP034888H@QQ00@8@@8H``88
H@88@@808088@@8@PP8@XP800088H@8@PP@8@@@08080008@PP8H``88H@8H``88@@03488H`aS3008Q
10@8H@8@PP808088H@8H``H8@@8YA@88@@8@PP8H``8@XP@8@@80008@XP8080@Hh`038B@Q1244008a
QP88H@88@@8ii`8aYP8ia`:DTP92:0;>N@92:0;oo`9Jb`;6608Q909cSP8YA@8Q10@YA@8@PP@08003
6<<8@@Q100800088@@8Hh`88@@8H``8Hh`80808@XP80008H``8@XP8Hh`8H``8@PP8@XP8@PP8H``88
H@8@PP80808@PP8H``0348800000008Q10@@PP@8@@@@XP8Q1088@@800088@@88H@88@@8Hh`88H@@0
0088@@808088H@8H``88H@030208@@Q10088H@8H``Coo`40007oo`005Ooo00<00?ooool00_oo0Q2R
0Q220PQ10Q2200<H``0P02000P000P0P112210000Q2R0PQ10QS30Q2R0PQQ0Q2R0P0P10QQ10Q10PQQ
0PQ10P0P0QSS0PQQ00<080QQ26400Q2R0PQ10QS30R440P0P0PQ10R4410Q10P0P0QSS11220R440P0P
0Q220R4T1PQ10QS30PQQ00<YIB448@@00PQQ0PQ10RUU0TYY0T8X0RU50YBB0U:Z0]kK0S6V0_oo0V<<
0/HH0RUU0X@@0SW70R440R4T1RU50RUU00<Q100000000QS30Q2R0P0P11220PQQ0P0P0PQQ0PQ10QS3
10QQ0Q2210QQ0Q220PQ111220P000Q220Q2R00<@PPQQ26400Q220PQQ0P0P0PQ10PQQ0P0P10QQ0Q22
0PQ10PQQ0Q2R0PQ10Q2R10Q120QQ112200<080QQ26400Q2R0QS31?oo0@000Ooo000Eool00`00oooo
o`02ool24:824882244248800aS30200800200020204488400024:8224426<<24:8226424:820204
264424422642244202026><226400`0P2648H@024:8224426<<28@@2020224428@@4244202026><4
48828@@2020248828B@624426<<226400bUU8@@Q100226422442:FD2BVT2@RP2:DD2U982DZX2g]/2
<JH2ool2H``2aQP2:FD2Q102>LL28@@28B@6:DD2:FD00b44000000026<<24:820204488226420202
264224426<<4264248842642488224444882000248824:800a222648H@0248822642020224422642
020426424882244226424:8224424:842448264448800`0P2648H@024:826<<4ool10001ool001Go
o`03003ooooo00;oo`88H@8H``88@@8080032440800P0088@@88H@800088H@8@PP88@@X8H@8@XP88
@@88H@800088@@808088H@80808@PP808088H@034:8@PQ220088H@8080H8H@8@XP88@@88H@8H``88
H@8@PP88@@88H@8Q1088@@8H``8Q908@PP88H@8H``8@PP88@@038@@8H@QQ008Hh`8@XP8ia`8aQP8Q
908YI@:<L@8ii`:mm`9220;oo`9Jb`;6608Q90:<L@8ia`92208aQP8Q908@XP8YA@8@XP036><00000
008H``8Q108@XP8YA@808080008@XP8H``88H@8H``@8@@8@XP88H@8H``8@PP88H@8@PP88H@80808H
``<@PP88H@8000@@PP8@XP8Q108@PP@0808@PP8Hh`X@PP@8@@8@PPH8H@88@@030208@@Q1008@XP8H
``Coo`40007oo`005Ooo00<00?ooool00_oo0PQQ0QS30PQ10P0P00<8@@0P02000PQ10PQQ0P000PQQ
0Q220PQ12PQQ0Q2R0PQ10PQQ0P000PQ10P0P0PQQ0P0P0Q220P0P0PQQ00<@XQ2248800PQQ0P0P1PQQ
0Q2R0PQ10PQQ0QS30PQQ0Q220PQ10PQQ0R440PQ10QS30R4T0Q220PQQ0QS30Q220PQ100<Q10QQ2640
0QSS0Q2R0SW70S660R4T0RUU0Xaa0SWW0[gg0T880_oo0U[;0/HH0R4T0Xaa0SW70T880S660R4T0Q2R
0RU50Q2R00<Hh`0000000QS30R440Q2R0RU50P0P0P000Q2R0QS30PQQ0QS310Q10Q2R0PQQ0QS30Q22
0PQQ0Q220PQQ0P0P0QS30a220PQQ0P0011220Q2R0R440Q22100P0Q220QSS2Q2210Q10Q221PQQ0PQ1
00<080Q124400Q2R0QS31?oo0@000Ooo000Eool00`00ooooo`02ool24884244226400a222648H@02
2642488226424:82264248826<<424440202264200026<<226420202264248822644244202000`QQ
6><Hh`0224426<<2264202022442488200022442020226426<<224426><2488224424:826><22642
6<<226426><226400aS34:8@XP0226428@@28B@2<JH226428B@2U982>NL2g]/2:DD2ool2BTT2cWT2
6<<2YC@28B@2>NL2@RP28@@226428@@26<<00b4T488@PP024882264224426><202028@@248822444
48824:8200026<<248826<<24882000248828@@22442264224400`QQ488@PP020202244248822442
8@@26<<200024:8200028@@26><22442000248822442020248844:822642244226400`Q100000002
26424:84ool10001ool001Goo`8000?oo`8@PP@8@@88H@034888H@QQ0088H@8@PP88H@8@XP88H@8@
PP8H``@8@@@08088H@80008H``88H@808088H@8@PP88H@@8@@808003264HhaSS0088@@8H``88H@80
8088@@8@PP800088@@808088H@8H``88@@8Hh`8@PP88@@8@XP8Hh`88H@8H``88H@8Hh`88H@036<<@
XQ2R0088H@8Q108Q908aYP88H@8Q90:DTP8ii`;Nf`8YA@;oo`9:B@;>N@8H``:U=08Q908ii`92:08Q
1088H@8Q108H``038B@@PQ22008@PP88H@88@@8Hh`80808Q108@PP88@@@@PP8@XP80008H``8@PP8H
``8@PP80008@PP8Q1088@@88H@88@@03264@PQ2200808088@@8@PP88@@8Q108H``80008@XP80008Q
108Hh`88@@80008@PP88@@80808@PP@@XP88H@88@@88H@03244000000088H@8@XP?oo`80007oo`00
5Ooo00<00?ooool00_oo0PQ10PQQ112200<Hha2248800P0P0Q220PQQ0Q220P0P0QS310000PQ10PQQ
11220PQ110QQ0Q2R0PQ10PQQ0PQ10P0P0QS30PQQ1A220PQ10P000PQ10R440Q2R11220Q2R0R4T1122
0QSS0Q2R0P0P0PQ10Q220PQQ0QS30R440PQ10PQQ0a220R440PQQ0Q220T8X0S660SWW0YBB0U[;0_NN
0U:Z0_oo0V]=0]Jj0SWW0V<<0S6V0QSS0Q2R0RUU0P0P0T880RU500<Q1366<HH00P0P0QSS0P0P0PQ1
0Q2R0PQQ0QSS0Q220P0P0Q2R0Q220QSS0PQQ0P0P0RU50PQ10Q2R0P0P0Q2R0Q220PQQ0P0000<8@B44
8@@0112R0Q220PQ111220PQ10QS30P0P0Q2R0QS30Q2R0P0P0Q2210Q11QS310QQ0`0P10QQ0PQ11?oo
0@000Ooo000Eool00`00ooooo`02ool22442264448800aSS488@PP02020248822642488202026<<4
0002244226444882244426424:8224422642244202026<<2264548822442000224428@@24:844882
4:828B@448826><24:8202022442488226426<<28@@22442264348828@@226424882@RP2<HH2>NL2
U982F//2mih2DZX2ool2Jdd2e[X2>NL2H``2<JH26><24:82:FD20202@PP2:DD00b44<HHaQP020202
6><2020224424:8226426><2488202024:8248826><226420202:DD224424:8202024:8248822642
00000`Q18@@Q10044:8248822444488224426<<202024:826<<24:820202488424466<<426430204
26422444ool10001ool001Goo`03003ooooo00;oo`8@PP8Q108H``<8H@8@XP88H@88@@88H@808080
008@XPX0808H``8@PP8@XP8@PP88H@80808000@8@@@@PP032448H@QQ008@XP88H@8@PP80808H``88
H@8@XP88H@8Q908H``88H@8@XP8H``8Q9080808@XP8H``88@@8@XP@Hh`8@XP038@@@PQ2200@Hh`80
009S309:B@8YA@:U509Jb`:mm`9BZP;oo`9:B@;Nn`8ii`9[C@8@XP@YI@8aYP88@@8Q108H``03>LLY
IBUU008Q1088H@8@XP88@@88H@80808@PP8Hh`800088H@@H``8@XP80008Q10@8@@80808@PP8@XP88
H@88@@03264H`aS3008@PP8Hh`88@@@8H@88@@8@XP8Q108@PP@@XP80808@PP808088H@88@@8YA@8H
h`8Q108@XP808088H@<@PP8H``88H@Coo`40007oo`005Ooo00<00?ooool00_oo0Q220R440QS30`QQ
0Q2R0PQQ0PQ10PQQ0P0P0P000Q2R2P0P0QS30Q220Q2R0Q220PQQ0P0P0P0010Q1112200<8@@QQ2640
0Q2R0PQQ0Q220P0P0QS30PQQ0Q2R0PQQ0R4T0QS30PQQ0Q2R0QS30R4T0P0P0Q2R0QS30PQ10Q2R11SS
0Q2R00<Q1122488011SS0P000V<<0TY90RU50ZDD0U[;0[gg0U:Z0_oo0TY90]kk0SWW0V]=0Q2R12UU
0S6V0PQ10R440QS300<iabUU:FD00R440PQQ0Q2R0PQ10PQQ0P0P0Q220QSS0P000PQQ11S30Q2R0P00
0R4410Q10P0P0Q220Q2R0PQQ0PQ100<8HAS36<<00Q220QSS0PQ110QQ0PQ10Q2R0R440Q22112R0P0P
0Q220P0P0PQQ0PQ10RU50QSS0R440Q2R0P0P0PQQ0a220QS30PQQ1?oo0@000Ooo000Eool00`00oooo
o`02ool26><24:828@@34882000224420002244402022442020426422442264224424:8200044882
26422442020448832644488224428B@26<<248844:82:DD26><24:826><48B@26><2264248822642
00022642488226428@@00cW78@@Q1002:DD248826<<2@RP4<JH2W=<2DZX2cWT2>NL2ool2DXX2eYX2
<JH2W=<26<<24:82>NL2:FD26<<226424:800aS36><Hh`046<<200022642488226424:828@@24882
6<<202024884244248826<<22442000202028@@224426<<00`Q14:8@XP024882:DD2488226442442
02026<<224426<<28@@24886244226426<<24:826><24882020224400`QQ488@PP0226424:84ool1
0001ool001Goo`03003ooooo00;oo`8Hh`8@XP8Q10<@PP800088@@800088@@@08088@@8080@8H@88
@@88H@88@@8@XP8000@@PP88H@88@@8080@@PP<8H@@@PP88@@8Q908H``8@PP@@XP8YA@8Hh`8@XP8H
h`@Q908Hh`88H@8@PP88H@800088H@8@PP88H@8Q1003>LLQ1244008YA@8@PP8H``92:0@aYP:Ld`9B
ZP;>N@8ii`;oo`9BRP;FVP8aYP:Ld`8H``8@XP8ii`8YI@8H``88H@8@XP036<<HhaSS00@H``800088
H@8@PP88H@8@XP8Q108@PP8H``80808@PP@8@@8@PP8H``88@@800080808Q1088@@8H``03244@XQ2R
008@PP8YA@8@PP88H@@8@@80808H``88@@8H``8Q108@PPH8@@88H@8H``8@XP8Hh`8@PP808088@@03
264@PQ220088H@8@XPCoo`40007oo`005Ooo00<00?ooool00_oo0PQ111220Q2R00<@PP0P02000PQ1
0P0P0P000P0P0PQQ0PQ10P0P11220QSS10Q10Q2R0PQQ0PQ1100P20QQ0PQ100<0800000000P0P0Q22
0Q2R0QS30PQQ0P000PQ10QSS0RU50Q220PQQ0RU510Q10PQQ0PQ10PQQ0P0P0Q220R440Q220QS300<a
YQSS6><00S6V0R4T0PQQ0QSS0T880TY90Ycc0RU50]JJ0V</0_oo0W>^0[gg0RU50YBB0RUU0R4T0RU5
0RUU0QS30RU50S6V00<8@ASS6><00Q2R0QS30Q220P000QSS0Q220PQQ1PQ10P0P0R4T0PQQ0RU50QS3
0QSS0PQ10QSS0PQ10Q220Q2R0QS30`QQ0Q220Q2R0Q220PQ10P000Q2R0P000R440PQQ0PQ10QS30PQQ
0P000Q220Q2R0Q220QSS0Q220QS30PQQ0P000PQ100<8HA2248800P0P0PQ11?oo0@000Ooo000Eool0
0`00ooooo`02ool2244448824:800a2202008002244202020002020226422442020448826><42442
4:82264224440208264224400`0P00000002020248824:826<<22642000224426><2:DD248822642
:DD42442264224422642020248828@@248826<<00c6V6><Hh`02<JH28B@226426><2@PP2BTT2W?<2
:DD2eYX2Hb`2ool2Ljh2_OL2:DD2U982:FD28B@2:DD2:FD26<<2:DD2<JH00`Q16><Hh`024:826<<2
488200026><248822646244202028B@22642:DD26<<26><224426><2244248824:826<<326424882
4:824882244200024:8200028@@2264224426<<22642000248824:8248826><248826<<226420002
24400`QQ488@PP0202022444ool10001ool001Goo`03003ooooo00;oo`800088@@8080<000808088
H@808088@@@0808@PP80808@PP8Hh`8H``88H@800088@@80808@PP88H@80008@PP88@@8@XP@8H@03
4:80800P0080008Q908@XP@@PP88@@8@PP8Hh`8H``88@@8H``88@@88H@80808@XP8Hh`88@@80808Q
9088@@8@PP8YA@038@@YABU5008aQP8YI@8Q1092:08H``8aYP:<D@8YA@:Ld`9Jb`;oo`9:J@;_O@88
H@9cSP8ia`8aYP9220@YA@8Hh`8YA@03020H`aS3008Hh`8@PP@@XP8Q90@8H@8Hh`80008H``8@PP88
H@8H``8Hh`88H@8Hh`8@XP80008@PP8@XP8H``8Hh`034:88H@QQ008H``800088H@8@PP88H@8@XP88
@@8Hh`@8H@8080@@XP8H``8Hh`8@PP88@@8@XP8H``80808H``8080032440800P008@XP88H@Coo`40
007oo`005Ooo0P000ooo0Q220Q2R0QSS0PQQ00<H``QQ26400PQQ0Q220PQQ0PQ10Q2R0Q220PQ10PQQ
0QS30PQQ0P000P0P0PQ10PQQ0P0P0PQQ0Q2210Q10PQQ112200<@XQ2248800QS30P0P0QS30QSS0QS3
0Q220R4T0P0P0RU50Q2R0R440Q220Q2R0QSS0QS30PQ10Q220Q2R0R440P000RUU0S6600<8@BU5:DD0
0QSS0S6V0RUU0U[[0PQQ0QSS0YBb0TYY0_oO0S660_oo0RU50[Ff0R440V]=0Q2R0SWW0U::0T8X0P0P
0S6V0SW700<YAB4T8B@00RU50PQQ0Q220P0P0RU50SWW112R0Q2210QQ0Q220PQ10P0P0PQ110QQ0PQ1
0Q2R0Q220PQ10R4400<8HA2248800QSS11220PQ10P000PQ10PQQ0QSS0Q2R0P0P0PQ10Q220PQ10Q2R
0R440RU50QS30P0P0PQQ10Q10Q220aS30Q220QSS0ooo0P000Ooo000Eool00`00ooooo`02ool24882
4:826><226400aS32648H@0226424882264224424:824882244226426<<226420002020224422642
0202264248842442264448800a2R488@PP026<<202026<<26><26<<248828B@20202:DD24:828@@2
48824:826><26<<2244248824:828@@20002:FD2<HH00`Q1:DDYA@026><2<JH2:FD2F^/226426><2
U;82BVT2oml2<HH2ool2:DD2]KH28@@2Jdd24:82>NL2DXX2@RP20202<JH2>LL00bU58B@Q9002:DD2
264248820202:DD2>NL44:82488426424882244202022444264224424:82488224428@@00`QQ488@
PP026><4488224420002244226426><24:8202022442488224424:828@@2:DD26<<2020226442442
48836<<248826><4ool10001ool001Goo`03003ooooo00;oo`8@XP8@PP88H@8@PP036<<@PQ22008@
XP8H``8@XP8H``88H@8H``88H@808088@@@8H@@@XP808088H@@8@@8@XP808088H@80008@XP03488H
`aS3008H``8Hh`8@PP8@XP8YA@88H@8Hh`8@PP808088@@8H``8YA@88@@88H@8H``8@XP8080@@PP8@
XP8Hh`8YA@<Q108YA@92:08ii`9:J@8H``8YI@:<L@9Jj`;_G@9[C@;oo`9:B@;6>08aQP9cSP8Q108Y
A@9:B@8H``8@PP8Q108YI@038B@HhaSS008@XP8Q908YA@88H@8H``8ia`8@XP8@PP88H@80808Hh`8@
PP80808H``8@PP80008H``@@PP@@XP88H@<@XP88H@80008@XP88H@88@@H@PP8H``808088H@88@@8@
PP88H@8080@@XP88H@800088H@80008H``<@XP@Q10Coo`40007oo`005Ooo00<00?ooool00_oo0Q2R
0Q220PQQ0Q2200<H`a2248800Q2R0QS30Q2R0QS30PQQ0QS30PQQ0P0P0PQ110QQ112R0P0P0PQQ10Q1
0Q2R0P0P0PQQ0P000Q2R00<@PQS36<<00QS30QSS0Q220Q2R0RU50PQQ0QSS0Q220P0P0PQ10QS30RU5
0PQ10PQQ0QS30Q2R0P0P11220Q2R0QSS0RU50b440RU50T8X0SWW0TYY0QS30RUU0Xaa0U[[0^mM0V]=
0_oo0TY90/Hh0S660W>>0R440RU50TY90QS30Q220R440RUU00<Q91SS6><00Q2R0R4T0RU50PQQ0QS3
0SW70Q2R0Q220PQQ0P0P0QSS0Q220P0P0QS30Q220P000QS31122112R0PQQ0a2R0PQQ0P000Q2R0PQQ
0PQ11Q220QS30P0P0PQQ0PQ10Q220PQQ0P0P112R0PQQ0P000PQQ0P000QS30a2R12441?oo0@000Ooo
000Eool00`00ooooo`02ool226426<<424452644488226422442488424422644244226426><20204
244200020202244226424:828@@00a2R6<<H``028@@26<<26><202026<<202028B@2:DD226428B@2
48824:828@@2:FD24:828B@26<<22442264200078@@2:DD24882<HH2@RP2:FD2>LL2Nnl2F//2g_/2
Jdd2ool2DZX2_OL2@RP2W=<2<JH2>LL2BTT200026><56<<26><2:DD24882000224424:8202024:82
6><28B@2:FD42642488624424:84244202024:8202000a226><Hh`028B@202026><24:8224420202
264224424:826<<224422642488226424:824882020248840202244202000`002448@@042444ool1
0001ool001Goo`03003ooooo00;oo`88H@8H``@8@@D8H@@@PP88H@88@@8@PP@8@@88H@@8@@88H@8H
h`8080@8@@8000808088@@88H@8@XP8Q10034:8H`aS3008Q108H``8Hh`80808H``80808Q908YA@88
H@8Q908@PP8@XP8Q108YI@8@XP8Q908H``88@@88H@8000LQ108YA@8@PP8aQP92:08YI@8ia`9kk`9J
b`;Nn`9[C@;oo`9BZP:mm`92:0:Ld`8aYP8ia`9:B@80008Hh`DH``8Hh`8YA@8@PP800088@@8@XP80
808@XP8Hh`8Q908YI@@8H@8@PPH8@@8@XP@8@@80808@XP808003488HhaSS008Q9080808Hh`8@XP88
@@808088H@88@@8@XP8H``88@@88H@8@PP88H@8@XP8@PP80808@PP@08088@@8080030008@@Q100@8
@@Coo`40007oo`005Ooo00<00?ooool00_oo0PQ110QQ0P0P00<8@@0P02000P0P10Q111S30Q220P0P
0Q2R0QS30P0P10QQ0P0P0Q220PQQ0QS311220QS30PQQ0PQ10Q2R00<8@B448@@00PQQ0QS30PQ10PQQ
0QS31Q2R11220S660Q2211SS0R440QSS0QS30Q220QSS0PQQ0RU50Q2R00<YICWW>NL00Q2R0QSS0S6V
0U[[0TY90R4T0ZDd0V]=0^mm0T880_oo0V</0]Jj0T880ZDD0T880RU50SW70RU50R4T0RU50S6V00<@
XPQ124400R441PQ10QSS0PQ10S6V0Q2R0SW70QSS0PQ10PQQ0QSS0PQQ0Q2R0PQQ0P000R440Q2210Q1
0QS300<08122488010QQ0Q220P0P0PQ111S30P0P0QS30QSS0PQQ0Q220R440PQ10P0P0PQ10Q2R0P0P
10QQ0P0P0Q2200<@XPQ124400Q220PQ11?oo0@000Ooo0007ool40003ool20005ool00`00ooooo`02
ool22444264202000`Q102008002020424446<<2488202024:826<<2020426420202488226426<<4
48826<<2264224424:800`Q18@@Q100226426<<2244226426<<64:844882<HH248846><28@@26><2
6<<248826><22642:DD24:800bUU>NLii`024:826><2<JH2F^/2BTT28B@2YC@2Jdd2kgd2@PP2ool2
Hb`2e[X2@PP2YA@2@PP2:DD2>LL2:DD28B@2:DD2<JH00a2R2448@@028@@624426><22442<JH24:82
>LL26><2244226426><226424:82264200028@@2488424426<<00`0P488@PP042642488202022444
6<<202026<<26><2264248828@@22442020224424:8202042642020248800a2R2448@@0248822444
ool10001ool000Ooo`03003ooooo00?oo`04003ooooo0004ool00`00ooooo`02ool28@@200044:80
0aS32648H@022642244226444:828@@24:8226428@@26<<22642020226426<<22442488426428@@4
264248800`QQ6><Hh`0248828B@2:FD48@@226424:826<<4264224426<<226448B@24:82:DD24:82
8B@224428@@2<HH00a2R@RQ2:00248826<<26><2Jfd2F//2<HH2eYX2@RP2ia`2F^/2ool2Nnl2g_/2
>LL2[ED2@RP22442>LL2<JH248826<<2>LL3244248846><2:FD2@PP28@@2:FD248846<<226420202
6<<2<JH22442020224424:824882264248828B@36<<202024:828@@2264224424:828B@24:824882
4:8448826<<26><2020426422442020226424:8248800`QQ4:8@XP026<<24:84ool10001ool000So
o`03003ooooo00;oo`04003ooooo0004ool20003ool28@@200044:800aS32648H@02264224422644
4:828@@24:8226428@@26<<22642020226426<<22442488426428@@4264248800`QQ6><Hh`024882
8B@2:FD48@@226424:826<<4264224426<<226448B@24:82:DD24:828B@224428@@2<HH00a2R@RQ2
:00248826<<26><2Jfd2F//2<HH2eYX2@RP2ia`2F^/2ool2Nnl2g_/2>LL2[ED2@RP22442>LL2<JH2
48826<<2>LL3244248846><2:FD2@PP28@@2:FD248846<<2264202026<<2<JH22442020224424:82
4882264248828B@36<<202024:828@@2264224424:828B@24:8248824:8448826<<26><202042642
2442020226424:8248800`QQ4:8@XP026<<24:83ool20001ool000Woo`05003oooooool00002ool0
0`00ooooo`02ool00`00ooooo`02ool26<<44:826<<00a2R488@PP02244226424:826<<224424882
24422642244200020202244202024:862642000248822642488200000a22:DDYA@026<<226428B@2
<HH226424882264248828B@2>LL28B@46<<226426<<26><24:8248824:826<<2>LL28@@00aSS@PQ2
2002:FD44:82F//2>NL2Jdd2U982@RP2ool2F//2ool2>NL2kgd2@PP2S742:DD24:82:FD2BTT2:DD2
6<<28@@3<HH226426<<26><2:DD26><46<<28B@22642:DD46><224426><248822642488226424882
6><402000b4T2648H@02244202026><2488226426><28B@226426><2:DD24:82000226426<<42642
2442020224422642020226400aSS4:8@XP026<<24884ool10001ool000[oo`04003ooooo0002ool0
0`00ooooo`02ool00`00ooooo`02ool26<<44:826<<00a2R488@PP02244226424:826<<224424882
24422642244200020202244202024:862642000248822642488200000a22:DDYA@026<<226428B@2
<HH226424882264248828B@2>LL28B@46<<226426<<26><24:8248824:826<<2>LL28@@00aSS@PQ2
2002:FD44:82F//2>NL2Jdd2U982@RP2ool2F//2ool2>NL2kgd2@PP2S742:DD24:82:FD2BTT2:DD2
6<<28@@3<HH226426<<26><2:DD26><46<<28B@22642:DD46><224426><248822642488226424882
6><402000b4T2648H@02244202026><2488226426><28B@226426><2:DD24:82000226426<<42642
2442020224422642020226400aSS4:8@XP026<<24884ool10001ool000Ooo`04003ooooo0002ool0
1000ooooo`001?oo00<00?ooool00_oo1122100P00<Hh`Q124400PQ10Q220PQQ0PQ10QS30PQQ1Q22
0PQ10P0P0PQ10Q220Q2R0QSS112R0PQ110QQ112200<8HA2248800Q220PQQ0R440QS30Q2R10Q10R44
0PQ10Q2R0PQ112UU0P0P0RUU0QS30Q220PQ10Q2R0QSS0TYY0Q2200<083W7>LL00S6V0RU50V</0U[;
0T880S660YcC0R4T0_Nn0U::0_oo0U[[0_oo0R440YBB0T8X0QSS0TY90T880S6V0QS30RU500=2:36V
<JH00QSS21220RU50RUU0P0P0QS30QSS0PQQ0QS30Q220PQQ0Q2R0QS30PQQ0QS30Q220RU50PQ10QSS
00<8@A2R4:800P000Q2R0P0P10QQ0P000Q220PQQ0Q2R0QS30P0P0P000P0P0PQ10PQQ0PQ10Q220P0P
0Q220PQQ0PQ10P0P00<8@@0P02000P000PQ11?oo0@000Ooo0008ool20004ool20005ool00`00oooo
o`02ool4488402000aSS2448@@0224424882264224426<<22646488224420202244248824:826><4
4:822444264448800`QQ488@PP02488226428@@26<<24:8424428@@224424:822444:FD20202:FD2
6<<2488224424:826><2BVT248800`0P>LLia`02<JH2:DD2Hb`2F//2@PP2<HH2W=<28B@2mkh2DXX2
ool2F^/2ool28@@2U982@RP26><2BTT2@PP2<JH26<<2:DD00d8X<JHaYP026><84882:DD2:FD20202
6<<26><226426<<2488226424:826<<226426<<24882:DD224426><00`Q14:8@XP0200024:820204
26420002488226424:826<<20202000202022442264224424882020248822642244202000`Q10200
800200022444ool10001ool001Goo`03003ooooo00;oo`88H@H8@@03264@PQ22008@XP800088@@80
008@XP@H``80808@PP8H``88@@@8H@8@XP8Q9088H@88@@8Hh`88H@@Hh`88H@03244YIBUU008YA@88
@@8Hh`8YA@8Hh`8Q10@H``8@XP8@PP8Q908Q108Q908Q108H``8aQP8Q908@XP88@@92208Q10808003
6><aYS6V008YA@8H``8ii`9BRP8YA@9BZP:eUP8H``;oo`9kk`;oo`9S30;Nn`8@XP;>N@8YI@8aQP9B
RP8aYP8YA@88H@<H``88H@8ii`@YA@8ii`8H``8YI@8Q908@XP8H``88H@8YA@H@PP8H``8Q10@@PP8Q
1080808Q1088@@038B@8H@QQ008@XP8Hh`8@XP88@@8@PP88H@@Hh`8@XP8H``8@PP88@@@0808@XP80
808Hh`8H``@8@@8H``8@XP038@@8H@QQ0088@@8@PPCoo`40007oo`005Ooo00<00?ooool00_oo0PQQ
1PQ100<8HA2248800Q2R0P000PQ10P000Q2R11S30P0P0Q220QS30PQ110QQ0Q2R0R4T0PQQ0PQ10QSS
0PQQ11SS0PQQ00<8@BUU:FD00RU50PQ10QSS0RU50QSS0R4411S30Q2R0Q220R4T0R440R4T0R440QS3
0S660R4T0Q2R0PQ10T880R440P0P00<Hhc6V<JH00RU50QS30SWW0U::0RU50U:Z0[FF0QS30_oo0W__
0_oo0V<<0]kk0Q2R0/ii0RUU0S660U::0S6V0RU50PQQ0aS30PQQ0SWW12U50SWW0QS30RUU0R4T0Q2R
0QS30PQQ0RU51Q220QS30R4411220R440P0P0R440PQ100<Q90QQ26400Q2R0QSS0Q2R0PQ10Q220PQQ
11SS0Q2R0QS30Q220PQ1100P0Q2R0P0P0QSS0QS310Q10QS30Q2R00<Q10QQ26400PQ10Q221?oo0@00
0Ooo000Eool00`00ooooo`02ool2264202028@@26><00b44488@PP046><2244226426<<426426<<2
4884264248842442488226426<<26><224446<<2000326428@@26><24:828@@26><2264448824:82
8B@28@@2:DD2>NL24:828@@2:FD26><2<HH248824:82@PP224400bUU@RQ2:0026><2<JH2@PP2BVT2
<HH2@RP2F^/2BTT2ool2@PP2ool2Jfd2g_/2DZX2W=<2BTT28B@2:FD26><2>NL2>LL2<JH00`QQ0200
8002@RP22642>NL2<HH26<<26><24:8424444:8448848@@248824:848B@26><248834:8224420202
24428@@24882020224424882020426424882020224424882020200026<<42442264248824:834884
6><4ool10001ool001Goo`03003ooooo00;oo`88H@80808Q108Hh`038@@@PQ2200@Hh`88@@88H@8H
``@8H@8H``8@PP@8H@8@PP@8@@8@PP88H@8H``8Hh`88@@@H``8000<8H@8Q108Hh`8@XP8Q108Hh`88
H@@@PP8@XP8Q908Q108YA@8ii`8@XP8Q108YI@8Hh`8aQP8@PP8@XP922088@@03:FE2:48X008Hh`8a
YP92209:J@8aQP92:09Jj`9:B@;oo`9220;oo`9[K@;Nn`9BZP:Ld`9:B@8Q908YI@8Hh`8ii`8ia`8a
YP032640800P0092:088H@8ii`8aQP8H``8Hh`8@XP@8@@@@XP@@PP@Q108@PP8@XP@Q908Hh`8@PP<@
XP88@@808088@@8Q108@PP808088@@8@PP8080@8H@8@PP808088@@8@PP808080008H``@8@@88H@8@
PP8@XP<@PP@Hh`Coo`40007oo`005Ooo00<00?ooool00_oo0PQ110QQ0Q2200<8@A22488011S30PQQ
10Q10PQQ0PQ10PQQ0Q2R0PQQ11S30PQ10QS30Q220Q2R0QS30Q2R0PQ112U50PQQ00<081S36<<00S6V
0R440Q220P0P0PQ10Q220P0P0Q2R10QQ12U50PQ10S66124T0QS30RUU0Q220PQ10SW70P0P00<YADY9
BTT00Q220SWW0S660W>>0R440T880Ycc0V]]0]kK0T880_oo0U:Z0_NN0V<<0X@`0RUU0S660V<<0Q22
0SWW0T880V<<00<YIASS6><00SWW0S6V0Q2R0QS30Q220RU50RUU124T0PQ10Q2R0QS3124T0SWW0QSS
0QS30Q220PQQ0R440R4T0PQQ1B440PQ10R4T0Q220QSS0RU50PQQ0Q220Q2R0P000PQQ11S30PQ10P00
0QS310QQ10Q10P0P1@QQ10Q11?oo0@000Ooo000Eool20003ool22444264248800`Q1488@PP046<<2
264424422642244226424:8226446<<224426<<248824:826<<24:822444:DD226400`0P6<<H``02
<JH28@@2488202022442488202024:842644:DD22442<HH48B@26<<2:FD248822442>LL202000bU5
BTU:B@024882>NL2<HH2Lhh28@@2@PP2W?<2Jfd2g]/2@PP2ool2DZX2mih2H``2Q302:FD2<HH2H``2
4882>NL2@PP2H``00bUU6><Hh`02>NL2<JH24:826<<24882:DD2:FD48B@224424:826<<48B@2>NL2
6><26<<2488226428@@28B@226458@@224428B@248826><2:DD2264248824:82000226446<<22442
00026<<426442442020526442443ool20001ool001Goo`03003ooooo00;oo`88@@8@PP88@@8080<@
PP@080@H``88H@8@PP8@XP8080@@XP88@@8@XP808088H@8@PP8aQP8aYP8Hh`8H``88@@80808H``03
6><8@@Q1008Q908@XP8Hh`8H``88@@8Q108Hh`88H@8YA@8YI@8ii`80808Q1088H@8Hh`8YI@8Hh`8Q
108Q908ii`8Q908aYP03489BRU::008@PP92209:J@:4408aYP9S;0:mm`9:J@;6>0:<L@;oo`9:B@;_
G@9Jb`:]M@8YA@8Q109kk`8ia`8YA@8H``9Jb`036<=22488008Q908ia`8Q9092208Hh`@Q108H``8@
XP8aQP8@PP8YA@80008Hh`8@XP88H@@Q1088@@8Q108YA@8@XP03244000000088H@8Hh`8YI@80008@
PP808088@@8@PP88@@@8H@8ia`8@XP808088@@8H``808088H@8@PP8H``88H@8@PP032648@@Q10088
H@8000Coo`40007oo`005Ooo00<00?ooool00_oo0PQ10Q220PQ10P0P0a22100P11S30PQQ0Q220Q2R
0P0P112R0PQ10Q2R0P0P0PQQ0Q220S660S6V0QSS0QS30PQ10P0P0QS300<Hh`Q124400R4T0Q2R0QSS
0QS30PQ10R440QSS0PQQ0RU50RUU0SWW0P0P0R440PQQ0QSS0RUU0QSS0R440R4T0SWW0R4T0S6V00<@
PU::DXX00Q220T880TYY0X@@0S6V0V</0[gg0TYY0/Hh0Xaa0_oo0TY90^mM0U[;0Zee0RU50R440W__
0SW70RU50QS30U[;00<H`d88@PP00R4T0SW70R4T0T880QSS12440QS30Q2R0S660Q220RU50P000QSS
0Q2R0PQQ12440PQ10R440RU50Q2R00<8@@0000000PQQ0QSS0RUU0P000Q220P0P0PQ10Q220PQ110QQ
0SW70Q2R0P0P0PQ10QS30P0P0PQQ0Q220QS30PQQ0Q2200<8H@Q124400PQQ0P001?oo0@000Ooo000E
ool00`00ooooo`02ool24:8402054882264248828B@248824:826><22442020200026<<248822642
6<<24882244226426><28@@2264248828@@2244348828B@226428B@248826><28@@2:FD2>LL2<HH2
48828@@2<JH26<<20202BVT2:DD226426><2>NL2:DD2@RP36<<2BTT24:84<JH2@RP2<HH2BVT2YA@2
DXX2ked2Nll2ool2BVT2mkh2BTT2YC@2BTT26><2BTT2:FD2<HH2:FD3>NL2:DD2DXX28@@22442@PP4
<HH28B@22644488224424882:FD24:828@@248828@@2264402026<<2:FD36<<24:826><26<<26><2
48828@@26><202026<<2264202026<<202022442264248826><4264248826><202000a226<<H``02
02022444ool10001ool001Goo`03003ooooo00;oo`8@XP@080D@PP88H@8@PP8Q908@PP8@XP8Hh`88
@@808080008H``8@PP88H@8H``8@PP88@@88H@8Hh`8Q1088H@8@PP8Q1088@@<@PP8Q9088H@8Q908@
PP8Hh`8Q108YI@8ia`8aQP8@PP8Q108aYP8H``80809:J@8YA@88H@8Hh`8ii`8YA@92:0<H``9:B@8@
XP@aYP92:08aQP9:J@:U509BRP;_G@9kc`;oo`9:J@;g_P9:B@:U=09:B@8Hh`9:B@8YI@8aQP8YI@<i
i`8YA@9BRP8Q1088@@9220@aQP8Q9088H@@@PP88@@8@PP8YI@8@XP8Q108@PP8Q1088H@@0808H``8Y
I@<H``8@XP8Hh`8H``8Hh`8@PP8Q108Hh`80808H``88H@80808H``808088@@88H@8@PP8Hh`@8H@8@
PP8Hh`808003488H`aS300808088@@Coo`40007oo`005Ooo00<00?ooool00_oo10QQ0QS30PQ10a2R
0PQ10P0P0PQ120QQ11220PQQ0P000Q220PQ10Q220R4T0T880PQQ0R440PQQ0Q220Q2R0S6V00<H``00
00000Q220Q2R0QSS0R4T0PQ10R440T880Q220R440R4T0QS30PQQ0Q220R4T0S6V0R440QS30QSS0SW7
0TYY0U:Z0T8800<YAF</Hb`00U::0TYY0T880W>^0S660SWW0]kK0S660_oo0U[;0_oo0V]=0^Ll0SWW
0/HH0R440RU50T880RUU0R4T0QSS0T8800=S;12R4:800U::0R4T0QSS0T8X0QSS0R4T0SW70RU50R44
0Q2R0RUU0Q2R0RU50QS30Q2R0P000T8X0PQQ0RU50RUU0Q2R0QS300<@XQ2248800RUU0QS30P0P0PQ1
0QS30Q220PQ10PQQ0PQ10QS30P0P0QS30P0P0PQ10PQQ0PQ10PQQ0PQ10P0P0P000P0P0PQ100<H`a2R
4:80100P1?oo0@000Ooo000Eool00`00ooooo`02ool426426<<224434:8224420202244826444882
264200024882244248828B@2@PP226428@@2264248824:82<JH00aS30000000248824:826><28B@2
24428@@2@PP248828@@28B@26<<2264248828B@2<JH28@@26<<26><2>LL2BVT2DZX2@PP00bU5HbaS
;002DXX2BVT2@PP2Ljh2<HH2>NL2g]/2<HH2ool2F//2ool2Jdd2ic`2>NL2aQP28@@2:DD2@PP2:FD2
8B@26><2@PP00f</4:8@XP02DXX28B@26><2@RP26><28B@2>LL2:DD28@@24:82:FD24:82:DD26<<2
4:820002@RP22642:DD2:FD24:826<<00a2R488@PP02:FD26<<2020224426<<24882244226422442
6<<202026<<202022442264224422642244202020002020224400aS34:8@XP040204ool10001ool0
01Goo`03003ooooo00;oo`808088@@8080800003264@PQ2200@@XP80008@XPH@PP8H``8Hh`@8H@8@
XP8Hh`8@XP8Q108Q908Hh`8@XP8Q1080008Q908H``034:88H@QQ008Hh`8H``8@XP8Q108YI@8@XP8Q
908aYP8@XP8YA@8H``8YA@8Hh`8aQP8ia`8YA@8aQP92208ia`92209BRP<aQP9cSP8ia`8YI@8aQP9S
;08H``9BZP:]M@8@PP;oo`8aYP;oo`9S;0;_G@8Q10:]E@92:08@XP9S308Q108Hh`8@PP8YA@03F^/@
PQ22008Hh`8YA@8aYP9:B@8H``8aYP8Hh`8ia`8@XP88H@8Hh`8Q908Q108@XP@@PP8YI@88H@H@XP<H
h`8H``@Hh`8@XP88H@8@XP8Q9088H@8@XP8YA@8Q9088H@80808Hh`@Q1088@@H8H@800088@@808003
4:88H@QQ008@PP88H@Coo`40007oo`005Ooo00<00?ooool00_oo0P0P0PQ10P0P0P0000<8HA224880
112R0P000Q2R1Q220QS30QSS10QQ0Q2R0QSS0Q2R0R440R4T0QSS0Q2R0R440P000R4T0QS300<@XPQQ
26400QSS0QS30Q2R0R440RUU0Q2R0R4T0S6V0Q2R0RU50QS30RU50QSS0S660SW70RU50S660T880SW7
0T880U::0c660W>>0SW70RUU0S660V</0QS30U:Z0Zee0Q220_oo0S6V0_oo0V</0^mM0R440ZeE0T8X
0Q2R0V<<0R440QSS0Q220RU500=Jja2248800QSS0RU50S6V0TY90QS30S6V0QSS0SW70Q2R0PQQ0QSS
0R4T0R440Q2R11220RUU0PQQ1Q2R0aSS0QS311SS0Q2R0PQQ0Q2R0R4T0PQQ0Q2R0RU50R4T0PQQ0P0P
0QSS12440PQ11PQQ0P000PQ10P0P00<@XPQQ26400Q220PQQ1?oo0@000Ooo000Eool00`00ooooo`02
ool202022442020200000`QQ4:8@XP026<<24:8224426<<24:8226424:820002244402046><24882
264224426<<26><48B@26><224400a2R2448@@02264224426><2:FD26><2<HH2<JH2@PP2<JH2DXX2
:DD22644<HH2DZX24:82<JH2>LL2@PP2BTT2DXX2:FD00e[[HbaS;0028B@2@PP2:FD2Ljh4@PP2Hb`2
F^/2ool2@RP2ool2Nll2mih2DZX2[ED2@RP2:DD2Lhh2BVT24:826><2DZX00bUU:DDYA@028B@2@RP2
48826<<46><28B@2BVT26><26<<20202:FD4<JH24:8224426><2>NL2:DD26><28@@2>NL38@@22642
020248826<<248820202264202024:8226428B@2244226426<<24886264248824:826<<34:820202
00024:84ool10001ool001Goo`8000?oo`808088@@8080800003264@XQ2R008H``8@XP88@@8H``8@
XP88H@8@XP800088@@@080@Hh`8@PP88H@88@@8H``8Hh`@Q908Hh`88@@034:88@@Q10088H@88@@8H
h`8YI@8Hh`8aQP8aYP92208aYP9BRP8YA@88H@@aQP9BZP8@XP8aYP8ia`92209:B@9BRP8YI@03F^]S
;6</008Q9092208YI@9c[PA2209S;09Jj`;oo`92:0;oo`9kc`;gWP9BZP:]E@92:08YA@9cSP9:J@8@
XP8Hh`9BZP03:FDYABU5008Q9092:08@PP8H``@Hh`8Q909:J@8Hh`8H``80808YI@@aYP8@XP88@@8H
h`8ii`8YA@8Hh`8Q108ii`<Q1088H@80808@PP8H``8@PP808088H@80808@XP88H@8Q9088@@88H@8H
``8@PPH8H@8@PP8@XP8H``<@XP808080008@XP?oo`80007oo`005Ooo00<00?ooool00_oo0P0P0PQ1
0PQQ0P0P00<@XPQQ26400Q2R0PQQ100P0Q2R11S30PQ10Q22112R0P0P0R440Q220PQ10R440RUU0S6V
0R440QS30S660R4T0`0P0QS30S6V0PQ10R4T0R440RU50R440RU50SW70T880R4T0Q2R0TY90T8X0QSS
0RUU0Q220U[;15:Z0W>>0U::00=BZW>>Lhh00Q220T880V</0V<<0TY90T880W__0TYY0^mM0V<<0_oo
0U[[0_oO0U:Z0[gG0W_?0V</0W__0QS30S660RUU0T8X00=:BA2R4:800S660T880S660SWW0RU50P00
0RU50S660RU50S660Q220P0P0R4T0Q2R0Q220P0P0PQQ0RU50SW70QSS0R4T0QSS00<Q91SS6><00RU5
0PQQ0Q220RU50S660RU50QS30QSS0Q220P000P0P0Q2R0PQ111220PQQ0P0P0PQQ0Q220Q2R0P0P0PQQ
00<0812248800Q220QSS1?oo0@000Ooo000Eool00`00ooooo`02ool202022442264202000a2R2648
H@024:82264402024:846<<2244248844:8202028@@2488224428@@2:FD2<JH28@@26<<2<HH28B@3
02026<<2<JH224428B@28@@2:DD28@@2:DD2>LL2@PP28B@24:82BTT2@RP26><2:FD24882F//4DZX2
Lhh2DXX00e:ZLhicSP024882@PP2Hb`2H``2BTT2@PP2Nnl2BVT2ked2H``2ool2F^/2oml2DZX2_ML2
Nll2Hb`2Nnl26<<2<HH2:FD2@RP00dY94:8@XP02<HH2@PP2<HH2>NL2:DD20002:DD2<HH2:DD2<HH2
488202028B@24:82488202022642:DD2>LL26><28B@26><00b4T6><Hh`02:DD226424882:DD2<HH2
:DD26<<26><24882000202024:822444488226420202264248824:82020226400`0P488@PP024882
6><4ool10001ool001Goo`03003ooooo00;oo`80808@PP88@@<00088@@8@PP88@@80808@PP80808@
XP88H@8@PP8@XP8Hh`8@PP8Hh`88H@8@PP@Hh`8H``8Q108YA@8Hh`88H@8H``03<HHHhaSS008Q108i
a`8Q908Hh`8@PP8Q908H``@Hh`8Q908aYP8YI@8Q90A2:08Q108ii`9cSP9:J@9[K@9c[P9:B@=S3080
8092209Jb`9kc`8Q909[C@:Ll`9c[P;oo`9BRP;oo`9BZP;oo`9[C@;FVP9S309220:Ld`88H@9BRP8H
h`8YI@03BTTHhaSS008ia`88@@@YA@@Q908@PP8YA@8Q108YA@8@XP8Q1088H@8Q90@H``8@XP8Q108Y
I@8Q108YA@8Q10036<<@PQ220088H@8ia`88H@8H``88@@8@PP8H``88@@8YA@8H``8@XP8Q1088@@@0
8088H@8@PP800088H@@0808@PP030208@@Q10088H@8@XPCoo`40007oo`005Ooo00<00?ooool00_oo
0PQ10QS3100P00<@PQ2R4:801Q2R0PQQ0P0P0P00112R0PQQ0P0P11SS0R440QSS0Q2R0QSS0QS3100P
0QSS124400<H`b448@@00S660RUU0SW70PQ10QSS0QS30S660R4T0RUU13W70TYY0V</0TY90S6V0TYY
0V]=0W>^0W>>0U:Z0U[;0T8800=[KF]=Jdd00S660V]=0TYY0Xaa0RU50W>^0_oo0V]]0_oo0QS30_oo
0V]=0_oo0U::0/ii0S6V0R4T0V]=0P0P0V]=0Q220U::00=Jjb4T8B@00RU50Q220SW70R4T0RU50Q2R
0R440RU50SWW0RUU0PQ10QS3112R0R440QSS1Q2R0Q220QS30S6600=:BA2R4:800PQQ0QSS0QS312UU
0QS30PQQ0R4T0P0P0Q2R0R4T0Q2R10QQ0Q220PQ10QS310Q11Q2200<8@@QQ26400P0P0PQQ1?oo0@00
0Ooo000Eool00`00ooooo`02ool224426<<402000a224:8@XP064:822642020200044:8226420204
6><28@@26><24:826><26<<402026><48@@00aS38@@Q1002<HH2:FD2>LL224426><26<<2<HH28B@2
:FD4>LL2BVT2Hb`2BTT2<JH2BVT2Jdd2Ljh2Lhh2DZX2F//2@PP00f]]Jde[C@02<HH2Jdd2BVT2S742
:DD2Ljh2ool2Jfd2ool26<<2ool2Jdd2ool2DXX2cWT2<JH28B@2Jdd20202Jdd24882DXX00e[[8B@Q
9002:DD24882>LL28B@2:DD24:828@@2:DD2>NL2:FD224426<<44:828@@26><64:8248826<<2<HH0
0dY94:8@XP0226426><26<<4:FD26<<226428B@202024:828B@24:842642488224426<<424464880
0`Q12648H@0202022644ool10001ool001Goo`03003ooooo00;oo`@08088@@8@PP<0808@XP8@PP88
H@8@PP80808@XP8@PP8@XP8Hh`8000@Q908Q108Hh`8H``8Hh`8@PP8Q108H``8@PP8aQP9BRP038@@Y
ABU5008H``8YA@88H@8aYP8Q1088@@8aQP9Jj`8Q109BRPAJj`9cSP9S;092:08aQP9Jj`9cSP9:J@9J
j`9BZP9:B@03S75c[W>^009BZP9kc`8ia`9S308YA@9:J@;_O@8ia`;oo`:<D@;oo`:me`;oo`:<D@;>
N@8Q908@XP9BRP8aYP@H``922003BTTiacW7008aQP92208Hh`8aYP8H``8aYP8@PP8Hh`8Q109BRP8@
PP@8@@8YA@8Q108@XP8Hh`8YA@@H``8Hh`8ia`036<<Q1244008Hh`8Q908YI@8000@8H@8H``8YA@8@
PP88@@8@PP8@XP88H@8Q10@@PP88H@@@XP88@@8@XP<8H@8@PP808088@@Coo`40007oo`005Ooo00<0
0?ooool00_oo100P0PQ10Q220`0P0Q2R0Q220PQQ0Q220P0P0Q2R0Q220Q2R0QSS0P00124T0R440QSS
0QS30QSS0Q220R440QS30Q220S660U::00<Q12U5:DD00QS30RU50PQQ0S6V0R440PQ10S660U[[0R44
0U::15[[0W>>0V</0T8X0S660U[[0W>>0TYY0U[[0U:Z0TY900><LG>^Ljh00U:Z0W_?0SW70V<<0RU5
0TYY0^mm0SW70_oo0XaA0_oo0[gG0_oo0XaA0/ii0R4T0Q2R0U::0S6V11S30T8800=:BCW7>LL00S66
0T880QSS0S6V0QS30S6V0Q220QSS0R440U::0Q2210Q10RU50R440Q2R0QSS0RU511S30QSS0SW700<H
`b448@@00QSS0R4T0RUU0P0010QQ0QS30RU50Q220PQ10Q220Q2R0PQQ0R4411220PQQ112R0PQ10Q2R
0`QQ0Q220P0P0PQ11?oo0@000Ooo000Eool00`00ooooo`02ool24884264202000`QQ2448@@024882
26444884264224426><28B@248826><26<<224426<<46><48@@26><2<HH24:82F//00bU5>LLia`02
6<<2:FD2@RP2>NL26><46<<26><2BTT28B@2BVT2H``2Jdd2BVT2DXX2H``2BVT2Ljh2Hb`2Q302Lhh2
BVT00icCJde[C@02<JH4Jdd2U982F//2F^/2e[X2F//2ool2<JH2ool2DXX2ool2BVT2mkh2>LL2:DD2
Nll2:DD20204<JH00e[;:FDYI@022442>NL28B@2:DD2>LL24:82<HH2000248826<<2:FD224424882
:FD2BTT46><226426><202028B@26><00b4T488@PP024:828B@2<JH2<HH248820002488602044882
4:826<<202024:84244226420002264202000aSS020080044884ool10001ool001Goo`03003ooooo
00;oo`8@PP@8H@8080032648@@Q1008@PP88H@@@PP@8H@88@@8Hh`8Q908@PP8Hh`8H``88@@8H``@H
h`@Q108Hh`8aQP8@XP9Jb`03:DDiacW7008H``8YI@92:08ii`8Hh`@H``8Hh`9:B@8Q909:J@9S309[
C@9:J@9BRP9S309:J@9c[P9S;0:4<09cSP9:J@03W==[CF]=008aYPA[C@:DTP9Jb`9Jj`;F^P9Jb`;o
o`8aYP;oo`9BRP;oo`9:J@;g_P8ia`8YA@9kc`8YA@8080@aYP03F//YIBUU0088@@8ii`8Q908YA@8i
a`8@XP8aQP80008@PP8H``8YI@88@@8@PP8YI@9:B@@Hh`88H@8Hh`80808Q908Hh`038B@@PQ22008@
XP8Q908aYP8aQP8@PP80008@PPH080@@PP8@XP8H``80808@XP@8@@88H@800088H@8080036><0800P
00@@PPCoo`40007oo`005Ooo0P000ooo0P0P0PQQ0QS30P0000<8@A2248800P0010Q10Q220QS30P00
0Q2R0QS30P000R440QSS0Q2R0RU50PQQ0RUU0QS30QSS0RUU0QSS0PQQ0RU50R4T00<YAAS36<<00T8X
0PQQ0S660U:Z0T8X0Q220U::0SW70R4T0T8X0T880SWW0SW70W>>0U::0V]=0Xaa0U::0V]]0TY90ZDd
0X@@00>DTX@`Q3000S660U:Z0S660[Ff0T8X0V</0[Ff0R440_oo0X@@0_oo0[gg0_oo0TY90_oo0V]=
0V</0YBB0TY90RU50Q2R0RU500=S3366<HH00SW70U[;0P0P0QS30U[[0RUU0P0P0QSS0RU511SS0R4T
0S660PQ10QS30QSS0Q2R0RUU0R4T0SWW0Q2R0R4T00<Hh`QQ26400Q2R0QSS0Q2R0QS312440RUU0RU5
0S6V0Q220QS30R440QS30QSS0P0011SS0PQ111220P0P0QS300<@PPQQ26400PQ10QS30ooo0P000Ooo
000Eool00`00ooooo`02ool2020226426<<200000`Q1488@PP020004244248826<<200024:826<<2
00028@@26><24:82:DD22642:FD26<<26><2:FD26><22642:DD28B@00bU56<<H``02@RP22642<HH2
DZX2@RP24882DXX2>LL28B@2@RP2@PP2>NL2>LL2Lhh2DXX2Jdd2S742DXX2Jfd2BTT2YC@2Q1000iBB
Q324<002<HH2DZX2<HH2]KH2@RP2Hb`2]KH28@@2ool2Q102ool2_OL2ool2BTT2ool2Jdd2Hb`2U982
BTT2:DD24:82:DD00f<<<HHaQP02>LL2F//202026<<2F^/2:FD202026><2:DD46><28B@2<HH22442
6<<26><24:82:FD28B@2>NL24:828B@00aSS2648H@024:826><24:826<<48@@2:FD2:DD2<JH24882
6<<28@@26<<26><200046><22444488202026<<00a222648H@0224426<<4ool10001ool001Goo`03
003ooooo00;oo`88@@@@PP88H@036><0800P00808088H@88@@8@XP@@PP8Q108@PP@@XP8H``8Q108H
h`8H``8aQP@Hh`808088H@808092208Q9003BVTH`aS3009Jj`@Q908ia`8ii`8ia`9:J@AS3092209k
c`92:09BZP8aYP:U=09S30:<D@9:B@9S309BRPAkc`03W==kcg_?009220@aYP:<L@8aQP8ii`;g_P9B
RP;oo`:Ld`;oo`9c[P;oo`9220;W?0:4<0:440:]E@92:09S3088@@922003JfdQ1244008@PP92209:
J@8@XP8ii`92208H``8Q108@PP88H@8ii`8YA@8Q908H``8Q108@PP92:08Q108Hh`92:08aYP88H@03
6><8H@QQ00@@XP8Q90@0808@PP8Q108Q90@8@@8@PP8@XP8000@@PP88H@8Hh`808088H@88@@8@PP8@
XP036<<8@@Q10088H@8H``Coo`40007oo`005Ooo00<00?ooool00_oo0PQ111220PQQ00<Hh`0P0200
0P0P0PQQ0PQ10Q2R11220R440Q22112R0QS30R440QSS0QS30S6611SS0P0P0PQQ0P0P0T880R4T00=:
JAS36<<00U[[124T0SW70SWW0SW70TYY16<<0T880W_?0T8X0U:Z0S6V0ZDd0V<<0XaA0TY90V<<0U::
17_?00>Ldg_?Nll00T88136V0Xaa0S660SWW0_Nn0U::0_oo0YcC0_oo0W>^0_oo0T880^Ll0X@`0X@@
0ZeE0T8X0V<<0PQ10T8800=[KB448@@00Q220T880TYY0Q2R0SWW0T880QS30R440Q220PQQ0SWW0RU5
0R4T0QS30R440Q220T8X0R440QSS0T8X0S6V0PQQ00<Hh`QQ2640112R0R4T100P0Q220R440R4T10Q1
0Q220Q2R0P0011220PQQ0QSS0P0P0PQQ0PQ10Q220Q2R00<H``Q124400PQQ0QS31?oo0@000Ooo000E
ool00`00ooooo`02ool200022642020248800a2R6<<H``024:8202026><26<<202046><24:822642
8@@20002488202024882244226424:8248822642<HH24882BTT00e:::DDYA@02>LL2@RP2>NL2@PP2
BTT26><28@@2@RP2Jdd2F//2@RP2DZX2H``2Ljh2S542Nnl2Nll2>LL2[GD2@PP2BTT2Nnl00haA<HHa
QP02DXX2DZX2BTT2Nll2>NL2DZX2ked2_ML2ool2DZX2ool2Q102ool2Q302ic`2DZX2<JH2_ML2Jdd2
@RP24:82BVT00haA<HHaQP022642BVT2Jdd28B@20202F//2:FD44:826><202024:828B@26<<2<JH2
BTT2:DD2>LL26<<2:FD2@PP2BTT00b4T<JHaYP026><226468B@28@@24:8224422642244248820202
26424882020224422642020224424:820202000326440204ool10001ool001Goo`03003ooooo00;o
o`800088H@80808@PP034:8H`aS3008@XP80808Hh`8H``8080@Hh`8@XP88H@8Q1080008@PP80808@
PP88@@88H@8@XP8@PP88H@8aQP8@PP9:B@03DXXYABU5008ia`92:08ii`92209:B@8Hh`8Q1092:09[
C@9Jb`92:09BZP9S309c[P:<D@9kk`9kc`8ia`:]M@92209:B@9kk`03S54aQS66009BRP9BZP9:B@9k
c`8ii`9BZP;_G@:me`;oo`9BZP;oo`:440;oo`:4<0;W?09BZP8aYP:me`9[C@92:08@XP9:J@03S54a
QS660088H@9:J@9[C@8Q9080809Jb`8YI@@@XP8Hh`80808@XP8Q908H``8aYP9:B@8YA@8ia`8H``8Y
I@92209:B@038B@aYS6V008Hh`88H@HQ908Q108@XP88@@88H@88@@8@PP808088H@8@PP808088@@88
H@808088@@8@XP80808000<8H@@080Coo`40007oo`005Ooo00<00?ooool00_oo0PQ10Q220P0P0QS3
00<@PPQQ26400PQQ0PQ10P000Q220QS30Q220Q2R0QSS0QS30PQ10P0P0QSS0QS30R4T0QS30S6V0QS3
0Q2R0QS30S6V0Q220RUU00<aYT8X@RP00RU50S660T880TY90RU50U::0S660U[;0SW70R4T0TYY0S6V
0U::0TY90W__0Ycc0ZeE0W>>0X@@0XaA0S6V0ZDD00>LdbU5:DD00W__0ZDd0YBB0ZDD0RU50X@`0_oo
0Ycc0_oo0X@`0_oo0_oO0_oo0X@@0_oO0U[[0Q2R0/iI0RU50SW70R4T0V<<00=BZS6V<JH00R4T0V]=
0V</0PQ10R440PQ10U[[0RU50R4410Q10S6V13WW0TYY0R4T10QQ0Q220Q2R0PQ10aSS0R4T0TY90RU5
0R440QSS0R4T0P0P124T0PQ10S6V0Q220PQQ0Q220R440Q220PQQ10Q10QS30P0010Q100<Hhb448@@0
0PQQ0PQ11?oo0@000Ooo0009ool00`00ooooo`02ool20005ool00`00ooooo`02ool2244248820202
6<<00a222648H@0226422442000248826<<248824:826><26<<2244202026><26<<28B@26<<2<JH2
6<<24:826<<2<JH24882:FD00c6V@RQ2:002:DD2<HH2@PP2BTT2:DD2DXX2<HH2F//2>LL28B@2BVT2
<JH2DXX2BTT2Nnl2W?<2[ED2Lhh2Q102S542<JH2YA@00icC:DDYA@02Nnl2YC@2U982YA@2:DD2Q302
ool2W?<2ool2Q302ool2oml2ool2Q102oml2F^/24:82cUT2:DD2>LL28B@2H``00e:Z<JHaYP028B@2
Jdd2Hb`224428@@22442F^/2:DD28@@42442<JH4>NL2BVT28B@4264248824:8224436><28B@2BTT2
:DD28@@26><28B@202048B@22442<JH24882264248828@@24882264424426<<2000424400aSS8@@Q
100226422444ool10001ool000Woo`05003oooooool00002ool00`00ooooo`02ool00`00ooooo`02
ool22642244226424:800a226<<H``024882244448826><248824:822442:FD28B@26><226424:82
26422442>LL2>NL448822642:DD28B@00a22DXYBRP02<JH48B@2F^/28@@2<HH2@RP2Jfd2W=<2BVT2
Ljh2F^/2>LL2BTT2W?<2Nnl2Q102>NL2cUT2YC@2Q302S7400jDd8B@Q9002Nll2Q102Jfd2Lhh2F^/2
U;82]IH2Nll2ool2ic`6ool2F//2ool2YA@2BVT2aSP2Lhh2S742<JH2Jfd00g_?:FDYI@02@PP24882
>LL2F//2@PP202026><2Jfd2:FD2>LL44882<HH2BVT26><2:DD2@PP2@RP2>NL2488226426><00a2R
8@@Q10028B@24:826<<2<JH28B@26><24:8248828@@226426<<24:826><226420006488200022442
264224400aS3488@PP0224424884ool10001ool000Koo`D000;oo`04003ooooo0004ool20003ool2
2642244226424:800a226<<H``024882244448826><248824:822442:FD28B@26><226424:822642
2442>LL2>NL448822642:DD28B@00a22DXYBRP02<JH48B@2F^/28@@2<HH2@RP2Jfd2W=<2BVT2Ljh2
F^/2>LL2BTT2W?<2Nnl2Q102>NL2cUT2YC@2Q302S7400jDd8B@Q9002Nll2Q102Jfd2Lhh2F^/2U;82
]IH2Nll2ool2ic`6ool2F//2ool2YA@2BVT2aSP2Lhh2S742<JH2Jfd00g_?:FDYI@02@PP24882>LL2
F//2@PP202026><2Jfd2:FD2>LL44882<HH2BVT26><2:DD2@PP2@RP2>NL2488226426><00a2R8@@Q
10028B@24:826<<2<JH28B@26><24:8248828@@226426<<24:826><2264200064882000224422642
24400aS3488@PP0224424883ool20001ool000Koo`04003ooooo0003ool01000ooooo`001?oo00<0
0?ooool00_oo0PQQ0P0P0PQQ0P000`Q10P0P10QQ0Q2R0QS30QSS0Q220PQ10QSS1PQQ0S660QSS0Q2R
0R440Q220QS30Q2R0R440RU50QSS0cWW0R4T0TY90R4T0V]=0SW70V]=0RUU0U:Z0Ycc0V]=0SWW0ZDd
0YBb0W__0W_?0SW70[FF0U[;0V]=0[Ff0RUU0W__00><DG>>Lhh00Xaa0/ii0Xaa0^LL0W_?0ZDd0_oo
0YBb0_oo0Xaa0_oo0ZDD0_oo0QSS0_oo0X@`0W__0Ycc0V]=0X@`0U:Z0X@`00?66:DdYC@00T880U::
0SW70SWW0T880QSS0RUU0U[[0SW70QS30RU50Q2R0RUU0S660SW70R440S6V0U[;0TYY0U:Z0P0P0c66
0RUU0PQQ0R440Q220QS30PQ10QS30RU50Q2R0QS310Q10Q220PQ10Q2R11220QS30P000PQQ0PQ10PQQ
0Q2200<080Q124400P0P0P001?oo0@000Ooo0007ool00`00ool00003ool01000ooooo`001?oo00<0
0?ooool00_oo0PQQ0P0P0PQQ0P000`Q10P0P10QQ0Q2R0QS30QSS0Q220PQ10QSS1PQQ0S660QSS0Q2R
0R440Q220QS30Q2R0R440RU50QSS0cWW0R4T0TY90R4T0V]=0SW70V]=0RUU0U:Z0Ycc0V]=0SWW0ZDd
0YBb0W__0W_?0SW70[FF0U[;0V]=0[Ff0RUU0W__00><DG>>Lhh00Xaa0/ii0Xaa0^LL0W_?0ZDd0_oo
0YBb0_oo0Xaa0_oo0ZDD0_oo0QSS0_oo0X@`0W__0Ycc0V]=0X@`0U:Z0X@`00?66:DdYC@00T880U::
0SW70SWW0T880QSS0RUU0U[[0SW70QS30RU50Q2R0RUU0S660SW70R440S6V0U[;0TYY0U:Z0P0P0c66
0RUU0PQQ0R440Q220QS30PQ10QS30RU50Q2R0QS310Q10Q220PQ10Q2R11220QS30P000PQQ0PQ10PQQ
0Q2200<080Q124400P0P0P001?oo0@000Ooo0008ool20003ool01000ooooo`001?oo00<00?ooool0
0_oo0PQQ0Q2R0PQQ1`Q10Q220Q2R0QSS11S311220RUU0RU50Q220QSS0Q2R0PQQ0QSS0Q2R10QQ0S6V
0PQQ0T880S6600<Q936V<JH00R440Q2R0U[[0S6V0T880V]=0Xaa0U[[0U::0ZDD0T8X0V</0ZDD0[FF
0Ycc0U::0[FF0X@`0W_?0U[[0Xaa0V]=00>DTXaAS54018aa0SWW0[gG0U::0TYY0_oo0T8X0_oo0[FF
0_oo0^Ll0_oo0U[[0_oo0ZDd0[Ff0_oO0]kk0YcC0ZeE0W__00?ooiBbU;800T880X@`17__12440TY9
0T880V]]0Q2R0S6V0U::0QSS0SW70RU50PQ10Q2R0TYY0S660RUU0QSS0Q2R00<HhbU5:DD00S6V0QSS
0P0P0SW70Q220T880PQQ0Q220P0P0QS30R440Q220P0P10000PQ10Q2R20Q10QS300<0012R4:800Q22
0PQQ1?oo0@000Ooo0009ool00`00ooooo`02ool20005ool00`00ooooo`02ool226424:8226472442
48824:826><46<<44882:FD2:DD248826><24:8226426><24:842642<JH22642@PP2<HH00b4T<JHa
YP028@@24:82F^/2<JH2@PP2Jdd2S742F^/2DXX2YA@2@RP2Hb`2YA@2]IH2W?<2DXX2]IH2Q302Nll2
F^/2S742Jdd00iBBS56<D@04S742>NL2_ML2DXX2BVT2ool2@RP2ool2]IH2ool2ic`2ool2F^/2ool2
YC@2]KH2oml2g_/2W=<2[ED2Nnl00oooU;:D/P02@PP2Q304Nnl48@@2BTT2@PP2Jfd24:82<JH2DXX2
6><2>LL2:DD224424:82BVT2<HH2:FD26><24:800aSS:DDYA@02<JH26><20202>LL24882@PP22642
488202026<<28@@248820204000224424:8824426<<00`004:8@XP0248822644ool10001ool001Go
o`03003ooooo00;oo`8@PP88@@@080036<<8H@QQ008H``88H@8@PP80808@XP88H@@@PP88@@8H``88
H@8aQP88H@@@XP8H``@YA@8H``88@@8Hh`88@@03<HHYABU5008H``8Hh`9BRP92209S308Q909c[P9[
C@:4<0:U=0:<D@:]E@9[K@:e]P:Ld`8ia`:U50;FVP;>F@:DTP9cSP:44003_OMJje[[00;FVP:me`8Q
10;oo`9cSP:D/P;oo`:D/P;oo`;gWP;oo`;W70;oo`;>N@;oo`;660:440;_G@:U509c[P;6>0:mm`03
mkk6><Hh009S;09:J@9kc`;>N@8Hh`8ii`8ia`92:08ii`:4409BRP9Jb`8aYP8Q108ii`8ia`8Q108H
``8YI@9:J@8@XP8YA@036<<YIBUU008H``8Q1088H@88@@8aYP8Q108H``8@XP800088H@8@PP80808H
``80808@XP88H@@080@@PP8@XP88@@<0808@PP88@@Coo`40007oo`005Ooo00<00?ooool00_oo0Q22
0PQ1100P00<H``QQ26400QS30PQQ0Q220P0P0Q2R0PQQ11220PQ10QS30PQQ0S660PQQ112R0QS312U5
0QS30PQ10QSS0PQ100<aQRU5:DD00QS30QSS0U::0T880V<<0R4T0W>^0V]=0X@`0ZDd0XaA0ZeE0V]]
0[Ff0YcC0SW70ZDD0]JJ0/iI0YBB0W>>0X@@00>mme[[F^/00]JJ0[gG0R440_oo0W>>0YBb0_oo0YBb
0_oo0_NN0_oo0^LL0_oo0/ii0_oo0/HH0X@@0^mM0ZDD0W>^0/Hh0[gg00?g_/HhaSP00V</0TYY0W_?
0/ii0QSS0SWW0SW70T8X0SWW0X@@0U::0U[;0S6V0R440SWW0SW70R440QS30RUU0TYY0Q2R0RU500<H
`bUU:FD00QS30R440PQQ0PQ10S6V0R440QS30Q2R0P000PQQ0Q220P0P0QS30P0P0Q2R0PQQ100P1122
0Q2R0PQ10`0P0Q220PQ11?oo0@000Ooo000Eool00`00ooooo`02ool248820202264224400aS32448
@@02244248826><24:826<<24:822642020200024882244200048@@2244200022642<HH248824:82
6><2>LL00b44<HHaQP024:82:FD2BTT2:FD2H``2<JH2Jfd2BVT4YC@2[GD2_OL2Nnl2]IH2U982W=<2
Jdd2aSP2F//7U982@RP2YA@2_OL2F^/2ool2U;82_ML2ool2_OL2ool2ia`<ool2]IH2ool4cUT2ool2
Nnl00nLLcUW>F@02[GD2H``2@PP2g]/2Hb`2@PP2:FD22442@PP2Nnl28B@2DXX2DZX28B@2BTT2@RP2
>LL24:82>NL2Hb`2<HH2BTT00cW7:DDYA@0200028B@200026<<2>LL226426<<2:DD448826><42442
00026<<22642020248842642244202000a2R2648H@0224424:84ool10001ool001Goo`03003ooooo
00;oo`8@PP808088H@88@@036<<8@@Q10088@@8@PP8Hh`8@XP8H``8@XP88H@808080008@PP88@@80
00@Q1088@@800088H@8aQP8@PP8@XP8Hh`8ia`038@@aQS66008@XP8YI@9:B@8YI@9S308aYP9[K@9:
J@BU=0:]M@:mm`9kk`:eUP:DTP:Ld`9[C@;6>09Jb`NDTP92:0:U50:mm`9Jj`;oo`:D/P:me`;oo`:m
m`;oo`;W70coo`:eUP;oo`C>F@;oo`9kk`03iac>FLiI00:]M@9S309220;Nf`9S;092208YI@88@@92
209kk`8Q909BRP9BZP8Q909:B@92:08ia`8@XP8ii`9S;08aQP9:B@03>LLYABU50080008Q9080008H
``8ia`88H@8H``8YA@@@PP8Hh`@8@@80008H``88H@80808@PP@8H@88@@8080034:88H@QQ0088@@8@
XPCoo`40007oo`005Ooo00<00?ooool00_oo0P0P0Q220PQ10QS300<8HA2248800PQQ0R440QS30R44
0PQQ12440PQQ0Q220PQ10R440PQ10QSS0R440Q2R0QSS0RUU0RU50Q2R11220SWW0d880Q220RU50TYY
0T8X0T880V<<0YcC0X@@0ZDd0Ycc0ZeE0V<<0T880^mM0_oO0YBB0]JJ0V<<0W__0S660X@`0/iI00=J
jliIcUT00_oO0/HH0^mM0]kk0[Ff1?oo0TY92_oo0/ii0_oo0^Ll0W>>0_oo0^mM1?oo0jeE0^LL1:eE
0V<<0YcC0/Hh0YBB0V]=0V<<0QSS0R440Q220T880W>^0SWW15:Z0S6V0R440W>^0R4T0QS30TY900<H
``0P02000RU50QS30RUU0PQQ0Q2R0PQ10SWW0Q2R0PQ10PQQ0Q2R0RU50R44100P0Q220P0P0PQ10P0P
0Q2R0PQQ0Q2R00<8@AS36<<011221?oo0@000Ooo000Eool20003ool20202488224426<<00`QQ488@
PP0226428@@26<<28@@226448@@22642488224428@@224426><28@@24:826><2:FD2:DD24:844882
>NL3@PP24882:DD2BVT2@RP2@PP2H``2W=<2Q102YC@2W?<2[ED2H``2@PP2ked2oml2U982eYX2H``2
Nnl2<HH2Q302cUT00e[[cUW>F@02oml2aQP2ked2g_/2]KH4ool2BTT:ool2cWT2ool2ic`2Lhh2ool2
ked4ool3[ED2ia`4[ED2H``2W=<2aSP2U982Jdd2H``26><28@@24882@PP2Ljh2>NL4DZX2<JH28@@2
Ljh28B@26<<2BTT00aS302008002:DD26<<2:FD226424:822442>NL24:82244226424:82:DD28@@4
020248820202244202024:8226424:800`Q16<<H``044883ool20001ool001Goo`03003ooooo00;o
o`88H@808088H@88@@030008H@QQ0088@@88H@8@XP80808Hh`88@@8@XP800088H@8@PP800088@@8a
QP@8H@8@XP8Hh`8H``8YA@88@@92:09:B@03DXXYABU5008aQP8YA@9cSP9BZP9:J@:D/P8ii`:mm`9J
b`;>F@9:J@;660:Ll`;oo`;_O@;F^P;6609cSP8aQP;Nn`:<D@;FVP03W=>mekgG00;oo`:U50:U=0So
o`:Lla3oo`9c[P;oo`;og`Koo`03W??ooooo00;W70;>F@:4<092:0:]M@:U50:<D@:e]P:4409BZP9J
b`8aQP9S309Jb`8ia`8Q109:B@9BRP92208Q109S309BRP03<JH0800P00@Q908Q108@PP88@@8ii`80
808H``8YI@8H``8Hh`8H``88H@@0808@PP808088H@88@@8Q1088H@8Q10030200000000808088@@Co
o`40007oo`005Ooo00<00?ooool00_oo0PQQ0P0P0PQQ0PQ100<000QQ26400PQ10PQQ0Q2R0P0P0QSS
0PQ10Q2R0P000PQQ0Q220P000PQ10S6610QQ0Q2R0QSS0QS30RU50PQ10T8X0TY900=BRRU5:DD00S66
0RU50W>>0U:Z0TYY0YBb0SWW0[gg0U[;0/iI0TYY0/HH0Ycc0_oo0^mm0]Jj0/HH0W>>0S660]kk0XaA
0]JJ00>LdkgG_ML00_oo0ZDD0ZDd2?oo0Ycc4?oo0W>^0_oo0_oO1_oo00>Lloooool00^LL0/iI0X@`
0T8X0Zee0ZDD0XaA0[Ff0X@@0U:Z0U[;0S660V<<0U[;0SW70R440TY90U::0T880R440V<<0U::00<a
YP0P0200124T0R440Q220PQ10SWW0P0P0QS30RUU0QS30QSS0QS30PQQ100P0Q220P0P0PQQ0PQ10R44
0PQQ0R4400<0800000000P0P0PQ11?oo0@000Ooo000Eool00`00ooooo`02ool2020200026<<24880
0`0P2448@@026><2020224426><28@@2:DD2020226424:826><226428@@24:828@@2:DD28B@22442
4882BTT26<<2>LL2BTT00`QQ:FDYI@026><2@RP2:DD2BTT2<HH26><2BTT2H``2Nll2ic`2Jdd2oml4
mih2g]/2Q302S5426><2]IH2[ED2ool2H``00cWWooooo`02ool2W=<2cUT2ool2[GD4ool2W?<@ool2
YC@8ool2cUT00liiooooo`02ool2S742U;82Ljh2Nll4W?<2Q302]KH2Q102U;82<JH2:DD2H``28B@2
<JH2H``2:FD2F//2:FD2<HH2BTT00c6V2448@@046><2:FD26><24882:FD24882:FD2<JH248826><2
:FD44:8200026<<24882020248828@@24:8226400a226><Hh`0202022444ool10001ool001Goo`03
003ooooo00;oo`808080008H``8@PP030208@@Q1008Hh`808088@@8Hh`8Q108YA@808088H@8@XP8H
h`88H@8Q108@XP8Q108YA@8Q9088@@8@PP9:B@8H``8ia`9:B@03264YIBUU008Hh`92:08YA@9:B@8a
QP8Hh`9:B@9S309kc`;W?09[C@;og`CgWP;Nf`:4<0:<D@8Hh`:eUP:]E@;oo`9S3003>NOooooo00;o
o`:Ld`;>F@;oo`:]M@Coo`:Lla3oo`:U=0Soo`;>F@03cWWooooo00;oo`:<L@:D/P9c[P9kc`BLl`:4
<0:e]P:440:D/P8aYP8YA@9S308Q908aYP9S308YI@9Jb`8YI@8aQP9:B@03<JH8@@Q100@Hh`8YI@8H
h`8@PP8YI@8@PP8YI@8aYP8@PP8Hh`8YI@@@XP80008H``8@PP80808@PP8Q108@XP88H@03488HhaSS
00808088@@Coo`40007oo`005Ooo00<00?ooool00_oo11220QS30PQQ00<080Q1244010QQ0PQ10Q2R
0PQ10Q2R0Q220PQQ0Q220PQQ0PQ10T8X0R440Q2R0RU50Q2R0QS30R440R4T0RUU0T880U::00<iabU5
:DD00V]]0R4T0Q2R0V<<0Q2R0X@@0S660/HH0[FF0/Hh0_Nn0TYY0]Jj0V<<0X@`0W__0[gg0U:Z0^Ll
0_Nn0/ii0W__00=2:?ooool01?oo0ZeE0_oo0/HH1?oo0U[[7?oo00?NnkFf]KH00]kk0_oo0X@`0^LL
0Xaa0T880V]]0U[[0T8X0W>^0Xaa0YBB0V<<0U:Z0W>^0Xaa0U[[0R440Q2213WW0QSS00<@XR448@@0
0Q220PQ10RU50T8X0RU50R4T11SS0P0P0PQQ0PQ10P0P0PQQ0PQ10Q2R0PQ10Q220P000P0P0PQ10QS3
0`Q10PQQ0P0P0R441?oo0@000Ooo000Eool00`00ooooo`02ool448826<<226400`0P2448@@042642
24424:8224424:8248822642488226422442@RP28@@24:82:DD24:826<<28@@28B@2:FD2@PP2DXX0
0cW7:DDYA@02Jfd28B@24:82H``24:82Q102<HH2aQP2]IH2aSP2mkh2BVT2e[X2H``2Q302Nnl2_OL2
DZX2ic`2mkh2cWT2Nnl00d8Xooooo`04ool2[ED2ool2aQP4ool2F^/Lool00mkk]KJe]P02g_/2ool2
Q302ia`2S742@PP2Jfd2F^/2@RP2Ljh2S742U982H``2DZX2Ljh2S742F^/28@@24884>NL26><00a2R
8@@Q100248822442:DD2@RP2:DD28B@46><20202264224420202264224424:822442488200020202
24426<<32442264202028@@4ool10001ool001Goo`03003ooooo00;oo`8Hh`@@PP8H``03244@XQ2R
008YA@@H``8@PP8Hh`8H``8Q9080808H``8Q9088@@8Hh`@YI@8@XP8aQP8Hh`8YA@92:08YI@9[K@9B
ZP03>LLaYS6V009BZP92:09S;09BRP9[C@9c[P:<L@9S309[K@:U50;F^P9:J@:U509:J@;>F@;og`:<
L@;oo`;W?0;oo`9[C@:U=0?oo`;W?0;gWP[oo`;>FAgoo`;>F@:<D@Koo`;FVP:4409Jb`A:B@8ii`9J
b`9kk`8aYP9:J@:D/P9c[P9Jb`8ia`8YI@9220@ia`038@@iacW7008Hh`9:B@@aQP88H@80008YI@92
:08H``80808Q908@XP@Q908YA@8@PP8H``8Q908Hh`88@@8@PP8H``036><8H@QQ0080808000Coo`40
007oo`005Ooo00<00?ooool00_oo0QSS11220QS300<8@A2R4:800RU511S30Q220QSS0QS30R4T0P0P
0QS30R4T0PQ10QSS12UU0Q2R0S660QSS0RU50T8X0RUU0V]]0U:Z00<iac6V<JH00U:Z0T8X0V</0U::
0V]=0W>^0Xaa0V<<0V]]0ZDD0]Jj0TYY0ZDD0TYY0/iI0_oO0Xaa0_oo0^Ll0_oo0V]=0ZDd0ooo0^Ll
0_NN2_oo0/iI7Ooo0/iI0XaA1_oo0]JJ0X@@0U[;14Y90SWW0U[;0W__0S6V0TYY0YBb0W>^0U[;0SW7
0RUU0T8813W700<Q13W7>LL00QSS0TY913660PQQ0P000RUU0T8X0QS30P0P0R4T0Q2R124T0RU50Q22
0QS30R4T0QSS0PQ10Q220QS300<Hh`QQ26400P0P0P001?oo0@000Ooo000Eool00`00ooooo`02ool2
26424:8200024:800a226<<H``0248826><28B@226426><2<HH2<JH2020226426><2:DD2>LL28@@2
>NL248822442<HH2:DD2>NL2Jfd2BVT2<JH00aS3BVU:J@02:FD26<<2Nnl22442@PP20002F^/24:82
Q302S742F^/2Nll2_OL2ool2g_/4ool2ic`2cWT2DZX2_MLCool2ic`Oool2ia`2]KH6ool2e[X2ked2
cUT4F//2DZX2:FD2:DD26<<24:82@PP2:DD2<HH28@@2DZX2000226400aS3@PQ220026><28B@28@@2
<JH28@@224428@@28B@26<<28@@248822642<HH2020248824:828@@248828@@2264224426><34:82
8B@22444ool10001ool001Goo`8000?oo`8H``88H@8Hh`8@XP03000Q1244008@XP8@PP80808@PP8H
``8@XP8H``8@XP88@@8Q108YA@8Q109BZP8YI@8Hh`8H``8ia`88H@8aYP9:B@8Q108ia`<H``9BRP92
:09BZP9:J@8YI@9:J@:<L@8aQP:]M@;oo`8aQP;>N@;W?0;F^P:me`:DTP;Nf`9S30:<D@:]M@Goo`;F
VR3oo`;gWQ7oo`:<D@9[C@;g_P:]M@:]E@;W70;Nf`;W?0:U508ii`:Ll`9Jb`9kk`9BRP9S3092:0@@
XP9Jj`8ii`03<JH8@@Q1008ia`8@XP8H``88H@8YA@@@XP88H@8Q908H``8@PP8H``8@PP8@XP8@PP8H
h`88@@8Q108@XP88H@8@PP8Q1003244@PQ2200808088H@?oo`80007oo`005Ooo00<00?ooool00_oo
0QS30PQQ0QSS0Q2R00<002448@@00Q2R0Q220P0P0Q220QS30Q2R0QS30Q2R0PQ10R440RU50R440U:Z
0RUU0QSS0QS30SW70PQQ0S6V0TY90R440SW70aS30U::0T8X0U:Z0TYY0RUU0TYY0Xaa0S660Zee0_oo
0S660/ii0^Ll0]Jj0[gG0YBB0]kK0V<<0XaA0Zee1Ooo0]JJ8?oo0_NN4Ooo0XaA0V]=0_Nn0Zee0ZeE
0^LL0]kK0^Ll0ZDD0SWW0Ycc0U[;0W__0U::0V<<0T8X112R0U[[0SWW00<aYPQ124400SW70Q2R0QS3
0PQQ0RU5112R0PQQ0R4T0QS30Q220QS30Q220Q2R0Q220QSS0PQ10R440Q2R0PQQ0Q220R4400<8@A22
48800P0P0PQQ1?oo0@000Ooo000Eool00`00ooooo`02ool2:DD24:826<<2:FD76><2<JH226422442
<HH28@@2:FD28B@28@@2:FD26><28B@28@@2<HH28@@28B@2<HH2Jfd26><4BTT00e[[BTU:B@02BTT2
DXX2>LL2DZX2H``2Jdd2<JH2Jdd2Q302F//4Nnl2>LL2Q102[GD24:82Ljh2_OM0ool2S542]KH2Ljh2
<JH2Hb`2mih26><2BVT2BTT2DZX2F^/2BVT2:DD28@@2Hb`2BTT2<HH2DZX2@PP00`Q16<<H``02BTT2
0202:FD2<HH28B@4<HH28B@2DXX26<<28B@2:DD24:82:FD26><28@@26><2:DD24:82<HH248820200
0b4T8@@Q100248826<<4ool10001ool001Goo`03003ooooo00;oo`8YA@8@XP8H``8YI@LHh`8aYP88
H@88@@8aQP8Q108YI@8Q908Q108YI@8Hh`8Q908Q108aQP8Q108Q908aQP9[K@8Hh`A:B@03F^]:BDY9
009:B@9BRP8ia`9BZP9S309[C@8aYP9[C@:4<09Jb`Akk`8ia`:440:]M@8@XP9c[P:mmd3oo`:<D@:e
]P9c[P8aYP9S;0;gWP8Hh`9:J@9:B@9BZP9Jj`9:J@8YA@8Q109S;09:B@8aQP9BZP922003244H`aS3
009:B@80808YI@8aQP8Q90@aQP8Q909BRP8H``8Q908YA@8@XP8YI@8Hh`8Q108Hh`8YA@8@XP8aQP8@
PP8080038B@Q1244008@PP8H``Coo`40007oo`005Ooo00<00?ooool00_oo11220PQQ0QSS1A220PQQ
0QS30PQQ0Q220Q2R0Q220R440QSS0QS30P0P0SW70PQ10QSS0S660PQ10S660Q220R4T0RU50P0P0QSS
00<iaaS36<<00T880S6V0S660TYY0QSS0U::0V</0W>>0V<<0TYY0TY90[gG16</0ZeE0^LLA_oo0_oO
0_oo0TY90Xaa0]JJ0PQQ0Q220U::0R4T0S6V14Y90U::0Q220QSS0PQQ0QSS0T8800<Hh`QQ26400S6V
11220R4T0QSS0RU50PQ10R4T0RU50PQQ0QSS0P0P10QQ0PQ10PQQ0QS30Q2R0PQ111S30P0000<@PQ2R
4:800PQQ0QS31?oo0@000Ooo000Eool00`00ooooo`02ool4488226426><5488226426<<226424882
4:8248828@@26><26<<20202>LL224426><2<HH22442<HH248828B@2:DD202026><00cW76<<H``02
@PP2<JH2<HH2BVT26><2DXX2Hb`2Lhh2H``2BVT2BTT2_ML4Hb`2[ED2iaa6ool2oml2ool2BTT2S742
eYX226424882DXX28B@2<JH4BTT2DXX248826><226426><2@PP00aSS2648H@02<JH448828B@26><2
:DD224428B@2:DD226426><202042642244226426<<24:8224446<<200000a224:8@XP0226426<<4
ool10001ool001Goo`03003ooooo00;oo`8H``8Q908Hh`8Q9003264@PQ22008H``8YA@8Q90@@PP@Y
A@8Q108YA@@Q908aQP8ii`9:J@92209:B@92209BZP8@XP8YA@8aYP9:B@03@PPaQS66008@PP9:B@9c
[P9cSP9[K@8Hh`9BRP:<D@:<L@9cSP8YI@;Nf`8YA@;FVP:D/PCoo`;>N@;oo`8aYP;oo`9BRP03ooo>
FLiI02goo`:U=0;_G@Koo`;Nn`;oo`:<L@;oo`:]E@9kk`;66088H@;6>0:U509:B@8Q9092:092209[
C@9:J@88H@9Jb`03BVTQ924T0092209:B@8Hh`8YI@8aYP8ia`8Q10@Hh`8H``8Hh`8Q908Hh`8Q108@
XP8Q108Hh`8@XP8aQP8H``8@XP88H@03:DDQ1244008Q908@XPCoo`40007oo`005Ooo00<00?ooool0
0_oo0QS30R4T0QSS0R4T00<8HA2248800QS30RU50R4T112212U50R440RU5124T0S660SWW0TYY0T88
0TY90T880U:Z0Q2R0RU50S6V0TY900=22366<HH00Q220TY90W>^0W>>0V]]0QSS0U::0XaA0Xaa0W>>
0RUU0]kK0RU50]JJ0YBb1?oo0/ii0_oo0S6V0_oo0U::00?ooliIcUT0;Ooo0ZDd0^mM1_oo0]kk0_oo
0Xaa0_oo0ZeE0W__0/HH0PQQ0/Hh0ZDD0TY90R4T0T8X0T880V]=0TYY0PQQ0U[;00=:JB4T8B@00T88
0TY90QSS0RUU0S6V0SW70R4411SS0QS30QSS0R4T0QSS0R440Q2R0R440QSS0Q2R0S660QS30Q2R0PQQ
00<YAB448@@00R4T0Q2R1?oo0@000Ooo000Eool00`00ooooo`02ool24:82:FD28B@202000a226><H
h`026<<26><28@@2<JH26<<226424:84:DD28B@2<HH28@@28B@2:DD2264248824:82<HH2<JH2>NL2
<JH2>LL00b4TNnmkk`048@@2>LL2BVT2@RP2>LL2F^/2Ljh2:FD4Nll2U982<HH2_OL4DXX2Q302<JH2
[GD2BTT2U;8fool2ked2_ML2BTT2S742ic`2Q302@PP2S542@RP2Lhh2Ljh2<JH2>LL2F//2H``2:FD2
>NL2<JH2DZX2:DD248800dYY4:8@XP026><2:DD26><2:DD224424:82<JH2@PP28B@2BTT22642:FD2
8@@26><24:82<HH24:8200028@@26><2<JH26><00`Q16><Hh`028@@20204ool10001ool001Goo`03
003ooooo00;oo`8@XP8YI@8Q90808003488HhaSS008H``8Hh`8Q108aYP8H``88H@8@XP@YA@8Q908a
QP8Q108Q908YA@88H@8@PP8@XP8aQP8aYP8ii`8aYP8ia`038BAkkg__00@Q108ia`9:J@92:08ia`9J
j`9c[P8YI@Akc`:DTP8aQP:mm`ABRP:4<08aYP:]M@9:B@:D/SKoo`;_G@:me`9:B@:<L@;W?0:4<092
20:<D@92:09cSP9c[P8aYP8ia`9Jb`9S308YI@8ii`8aYP9BZP8YA@8@PP03BVT@XQ2R008Hh`8YA@8H
h`8YA@88@@8@XP8aYP92208Q909:B@88H@8YI@8Q108Hh`8@XP8aQP8@XP80008Q108Hh`8aYP8Hh`03
244HhaSS008Q108080Coo`40007oo`005Ooo0P000ooo0PQQ0P0P0Q220PQ100<aQPQ124400PQ10Q22
0RUU0QSS0PQQ0S660QSS0PQQ0Q220S660QS30Q22136V0QS30Q220P0P0QS30SWW0Q2R0QSS0R4400<@
PSWW>NL00R440P0P0W>>0U:Z0V]=14880Q220QSS0V]=0V</0ZeE0W__0ZDd0V<<0W__0_NN0_Nn@?oo
0^Ll0XaA0Ycc0/HH0W>^0V</0Ycc0QS30Q2R0T880PQQ0T880RUU0X@`0V]]0V<<0Q2R0S660PQQ00<a
YR448@@00RUU0RU50Q2R0PQ10RU50PQ10QSS0QS30S6611220RUU0QS30P0P10QQ0QSS0RUU124T0PQ1
0PQQ00<Q11SS6><00Q220Q2R0ooo0P000Ooo000Eool00`00ooooo`02ool226420202488224400c66
2448@@0224424882:FD26><22642<HH26><226424882<HH26<<24884<JH26<<2488202026<<2>NL2
4:826><28@@00a22>NLii`028@@20202Lhh2DZX2Jdd4@PP248826><2Jdd2Hb`2[ED2Nnl2YC@2H``2
Nnl2mih2mki0ool2ic`2S542W?<2aQP2Ljh2Hb`2W?<26<<24:82@PP22642@PP2:FD2Q302Jfd2H``2
4:82<HH226400c6V8@@Q1002:FD2:DD24:822442:DD224426><26<<2<HH44882:FD26<<202042642
6><2:FD48B@2244226400b446><Hh`0248824:84ool10001ool001Goo`03003ooooo00;oo`8Q908Q
108H``88@@03:DDHhaSS0088H@8YA@8YI@8Hh`8@XP8H``8Q108@XP8Q108ia`8@PP8ii`8@XP88H@9:
J@9:B@8ia`9BZP9:B@8Q109Jj`9:J@03@RQc[W>^009BZP8Q108@XP8Hh`92:0:me`9[C@:<D@9cSP;o
g`:<D@;gWP8H``8@PP;_O@:Ld`;>F@_oo`;g_S?oo`:440Koo`;FVP9kc`8ia`:e]PB]E@9:B@:e]PA[
K@8Q108Q909:B@A[C@8Hh`038BA[KF]]008aQP9S;08ii`8H``8aYP92:092208YA@8Q908H``8Q108Q
908aYP8Q108YA@88@@8YA@8Hh`80808Hh`8YA@8@XP036<<Q924T008H``8Q10Coo`40007oo`005Ooo
00<00?ooool00_oo0R4T0R440QS30PQ100<YAASS6><00PQQ0RU50RUU0QSS0Q2R0QS30R440Q2R0R44
0SW70Q220SWW0Q2R0PQQ0TYY0TY90SW70U:Z0TY90R440U[[0TYY00=2:7>^Ljh00U:Z0R440Q2R0QSS
0T8X0[gG0V]=0XaA0W>>0_oO0XaA0_NN0QS30Q220^mm0YcC0/iI2ooo0_Nn<ooo0X@@1_oo0]JJ0W_?
0SW70[Ff1:eE0TY90[Ff16]]0R440R4T0TY916]=0QSS00<Q96]]Jfd00S660V</0SWW0QS30S6V0T8X
0T880RU50R4T0QS30R440R4T0S6V0R440RU50PQ10RU50QSS0P0P0QSS0RU50Q2R00<H`b4T8B@00QS3
0R441?oo0@000Ooo000Eool00`00ooooo`02ool224426><248824:800a224:8@XP02244248824:82
48828B@24:826><24:822642:FD2@RP2BTT2<HH2@PP224424882@RP2:DD28@@2>LL28B@2:DD00aS3
8B@Q90024:82Nll2@PP4BTT2<HH2>LL2BVT2Jdd2@PP26><2W=<2@PP2mkh24:82>NL2g_/2kgd2S742
U982BVT2ool00g_?ooooo`0]ool2Hb`4ool2H``2<JH2DXX2Nnl4DZX2<JH2DXX2Ljh2H``2:DD26><2
DXX4@PP2<HH28@@26<<2@PP2BVT00c66@PQ22002@PP2<JH2:FD26><248828B@22642:DD248822442
:DD26><28B@224426><224428B@26><24:8226424:828B@00aSS2648H@0226424:84ool10001ool0
01Goo`03003ooooo00;oo`88@@8Hh`8@PP8@XP03488@XQ2R0088@@8@PP8@XP8@PP8Q908@XP8Hh`8@
XP88H@8YI@92:09:B@8aQP922088@@8@PP92:08YA@8Q108ia`8Q908YA@036<<Q924T008@XP9kc`92
20A:B@8aQP8ia`9:J@9[C@92208Hh`:Ld`9220;g_P8@XP8ii`;Nn`;_O@:<L@:DTP9:J@;oo`03Nloo
oooo02goo`9S;0Coo`9S308aYP9BRP9kk`ABZP8aYP9BRP9c[P9S308YA@8Hh`9BRPA2208aQP8Q108H
``92209:J@03<HI224880092208aYP8YI@8Hh`8@PP8Q9088H@8YA@8@PP88@@8YA@8Hh`8Q9088@@8H
h`88@@8Q908Hh`8@XP88H@8@XP8Q90036><8H@QQ0088H@8@XPCoo`40007oo`005Ooo00<00?ooool0
0_oo0Q2R11SS0Q2200<8HBU5:DD00Q220PQ10PQQ0RUU0RU50S660Q2R0R4T0RUU0PQQ0SW70U::0Q2R
0RUU0T8X0RUU0QS30V</0Q2R0QS30RUU0QS300<YADY9BTT00SW70R440PQQ0R440YBB0XaA0U::0T88
0/Hh0U:Z0T880X@@0YBB0TY90_oo0V</0T88@?oo0]kK0[gG0[Ff0W_?0X@@0/HH0[FF0V]=0QSS0ZDD
0XaA0W>>0S6V0U:Z0R4T0TY90W>^0V]=0T8X0QS300=221S36<<00QS30RU50RUU0PQ10Q220RUU0Q2R
0PQQ0Q2R0T8X0Q2R0QS30RU50QSS124T0PQQ0Q2R0P0P12440R4T00<@PQ2R4:800R4T0QSS1?oo0@00
0Ooo0008ool20004ool20005ool00`00ooooo`02ool24:846><248800`QQ:DDYA@02488224422642
:FD2:DD2<HH24:828B@2:FD22642>LL2DXX24:82:FD2@RP2:FD26<<2Hb`24:826<<2:FD26<<00bU5
BTU:B@02>LL28@@226428@@2U982S542DXX2@PP2aSP2DZX2@PP2Q102U982BTT2ool2Hb`2@PQ0ool2
g]/2_ML2]KH2Nll2Q102aQP2]IH2Jdd26><2YA@2S542Lhh2<JH2DZX28B@2BTT2Ljh2Jdd2@RP26<<0
0d886<<H``026<<2:DD2:FD224424882:FD24:8226424:82@RP24:826<<2:DD26><48B@226424:82
02048@@28B@00a224:8@XP028B@26><4ool10001ool000Ooo`04003ooooo0002ool01000ooooo`00
1?oo00<00?ooool00_oo0QS30RU50RUU0TYY00<Q912R4:800RU50Q2R0PQQ0RUU0RU50Q2R0P000RUU
0QS30SW70SWW112R0R440R4T0Q2R0TY90S660RUU0T880SW70QSS00=S36</Hb`00V<<0W__0U[;0T88
0SWW0V<<0U::0YcC0Ycc0W_?0ZDD0]kk0U[;0^Ll0V<<0T880_oo0^Ll0_oo0_Nn;ooo0^LL2Ooo0^mm
0U:Z0_Nn0_oo0_NN0YBb0QS30R4T0TY90W__0W>^0SW70PQQ0TY90/HH0U:Z0RUU0SWW0RU50RUU00=2
:3WW>NL00T8X0RUU0U::0S6V0RU50SW70U::0V</0RU50S6V0T880QSS0R440SWW0R440S660S6V0S66
0RUU0QS30R440aS311220R441?oo0@000Ooo0007ool01000ooooo`000_oo00@00?ooool000Coo`80
00?oo`8H``8YA@8YI@9:J@038B@@XQ2R008YA@8@XP88H@8YI@8YA@8@XP80008YI@8H``8ia`8ii`@@
XP8Q108Q908@XP9:B@8aQP8YI@92208ia`8Hh`03H`aS;6</009S309kk`9Jb`92208ii`9S309BRP:L
d`:Ll`9kc`:U50;Nn`9Jb`;W?09S309220;oo`;W?0;oo`;g_Rooo`;W70Woo`;_O@9BZP;g_P;oo`;g
WP:D/P8H``8Q909:B@9kk`9c[P8ia`88H@9:B@;6609BZP8YI@8ii`8YA@8YI@03@RPiicWW0092:08Y
I@9BRP8aYP8YA@8ia`9BRP9S;08YA@8aYP92208Hh`8Q108ii`8Q108aQP8aYP8aQP8YI@8H``8Q10<H
``@@PP8Q10?oo`80007oo`001ooo0`000ooo00@00?ooool000Coo`03003ooooo00;oo`88H@@@XP8@
PP034:8@PQ220088H@8Hh`88H@8H``80008Hh`88@@88H@8H``8@XP8@PP8Hh`8ia`8aQP8aYP8Q108i
a`8YI@8H``8YA@8Hh`8YI@034:8H`aS3009S3092208Q1092:09cSP9kc`9:B@8YI@:<D@@aYP9Jj`:4
40;oo`9S30:e]PBLl`Koo`8ii`03BVWooooo00:4<2[oo`03S75BZU:Z00;oo`:]M@;oo`9kc`9S;09c
[P9:B@:<L@9[K@8YI@8aYP92:09BRP8@XP9cSP9:B@8ii`8aQP92208H``8@PP8aQP03:FDH`aS3009B
ZP8Hh`8aQP8YI@8ii`80808YA@8@XP8Q108@XP8YA@80808H``8@PP8YI@@@XP80808@XP8YA@8@XP88
H@036<<8H@QQ00808088H@Coo`40007oo`001ooo00<00?ooool00ooo00@00?ooool000Coo`03003o
oooo00;oo`88H@@@XP8@PP034:8@PQ220088H@8Hh`88H@8H``80008Hh`88@@88H@8H``8@XP8@PP8H
h`8ia`8aQP8aYP8Q108ia`8YI@8H``8YA@8Hh`8YI@034:8H`aS3009S3092208Q1092:09cSP9kc`9:
B@8YI@:<D@@aYP9Jj`:440;oo`9S30:e]PBLl`Koo`8ii`03BVWooooo00:4<2[oo`03S75BZU:Z00;o
o`:]M@;oo`9kc`9S;09c[P9:B@:<L@9[K@8YI@8aYP92:09BRP8@XP9cSP9:B@8ii`8aQP92208H``8@
PP8aQP03:FDH`aS3009BZP8Hh`8aQP8YI@8ii`80808YA@8@XP8Q108@XP8YA@80808H``8@PP8YI@@@
XP80808@XP8YA@8@XP88H@036<<8H@QQ00808088H@Coo`40007oo`001ooo00<00?ooool00ooo00@0
0?ooool000Coo`03003ooooo00;oo`8YA@8Q108ii`8YA@038@@HhaSS009:B@8aYP8H``80808aYP8i
a`@YI@8Q1088H@8aQP9BRP9kc`92:08YI@9S;08ia`8YI@9kc`8Q908aQP8ia`03Jde2:48X008ii`9c
[P:]E@8ii`9BRP9kc`9c[P:DTP8aQP9c[P;W709S308YI@;oo`:e]P9BRPCoo`:<DCcoo`;>F@8ia`;o
o`;_G@8H``:e]P9BRP:U509BRP9[C@;og`:<L@9S30:U509kc`9[K@8ia`8ii`:4409cSP036<=Jje[[
0092:08Q109Jb`9:J@8aQP92:08aQP8YA@88@@8Hh`92208aQP8Q908YI@922088H@8YA@8YI@8Q908@
XP8Hh`8YA@03:FDHhaSS008Q108ia`Coo`40007oo`002?oo0`000ooo0P001Ooo00<00?ooool00_oo
0RU50R440SWW0RU500<Q11SS6><00TY90S6V0QS30P0P0S6V0SW712UU0R440PQQ0S660U::0W_?0T8X
0RUU0V</0SW70RUU0W_?0R4T0S660SW700=[CD8X@RP00SWW0W>^0ZeE0SWW0U::0W_?0W>^0YBB0S66
0W>^0^LL0V<<0RUU0_oo0[Ff0U::1?oo0XaA??oo0/iI0SW70_oo0^mM0QS30[Ff0U::0ZDD0U::0V]=
0_oO0Xaa0V<<0ZDD0W_?0V]]0SW70SWW0X@@0W>>00<H`e[[F^/00T8X0R440U[;0TYY0S660T8X0S66
0RU50PQ10QSS0T880S660R4T0RUU0T880PQQ0RU50RUU0R4T0Q2R0QSS0RU500<YIASS6><00R440SW7
1?oo0@000Ooo000Eool00`00ooooo`02ool2488226428@@2:DD00c666><Hh`028@@2:FD2:DD24882
8B@24:82:DD26<<2:DD28B@2:FD2@PP2@RP2>NL248826<<2:DD28@@22442:DD24:82:FD00b4TDXYB
RP02:DD2:FD2H``2Jfd2>NL2F//2@RP2U982@RP2S542@PP2[ED2ic`2Hb`2F//2@RP26><2U984ool2
kgd2YA@5ool2cWTPool2Q30;ool2]KH2U982DXX2e[X2cWT2ia`2Ljh2W=<2F^/2@RP2Q302BTT2Hb`4
8@@26><2aQP2H``2>LL28@@24:800b4T6><Hh`026<<2<JH28B@26<<22642:DD2<HH2DXX2F^/2:DD2
4:828@@26><28@@28B@2:DD28B@2:DD2>NL2<JH448800b444:8@XP0226422444ool10001ool001Go
o`03003ooooo00;oo`8@PP88H@8Q108YA@03<HHHhaSS008Q108YI@8YA@8@PP8Q908@XP8YA@8H``8Y
A@8Q908YI@922092:08ii`8@PP8H``8YA@8Q1088@@8YA@8@XP8YI@038BABRU::008YA@8YI@9S309[
K@8ii`9Jb`92:0:DTP92:0:<D@9220:]E@;W?09S;09Jb`92:08Hh`:DTPCoo`;_O@:U50Goo`;>NB3o
o`:4<0_oo`:e]P:DTP9BRP;F^P;>N@;W709c[P:Ld`9Jj`92:0:4<09:B@9S;0@Q108Hh`;6609S308i
a`8Q108@XP038B@HhaSS008H``8aYP8Q908H``88H@8YA@8aQP9BRP9Jj`8YA@8@XP8Q108Hh`8Q108Q
908YA@8Q908YA@8ii`8aYP@@PP038@@@XQ2R0088H@88@@Coo`40007oo`005Ooo00<00?ooool00_oo
0R440QS30RU50T880b4T0S6V0SWW0RU50QSS0R440RU50QSS0S6V0R4T0Q220S660V<<0RU5112R1122
0QS312U50QSS0QS300<8@D8X@RP00PQ10/HH0YBB0TY90RU50RUU0U::0U[;0W>^0SWW0YBb0ZDD0W>^
0/HH0]JJ0W__0V</0_oo0]JJ0T8X0U:Z<_oo0^Ll1_oo0R4T0T8819Bb0/Hh0_oo0U[[0X@@0Q2R0_NN
0SWW0TY90X@@0W_?0S660TY90RUU0V]]0QS300<aYQS36<<00U::0QS30RU50V</0S660T880SW70U::
0T8X13W70SWW0S660QS30RUU0U[;0RU50T880S660R4T0QS30T8800<aQQ2248800PQ10RUU1?oo0@00
0Ooo000Eool00`00ooooo`02ool28@@26<<2:DD2@PP38B@2<JH2>NL2:DD26><28@@2:DD26><2<JH2
8B@24882<HH2H``2:DD44:8448826<<4:DD26><26<<00`Q1@RQ2:0022442aQP2U982BTT2:DD2:FD2
DXX2F//2Ljh2>NL2U;82YA@2Ljh2aQP2eYX2Nnl2Hb`2ool2eYX2@RP2DZXbool2ic`6ool28B@2@PP4
U;82aSP2ool2F^/2Q1024:82mih2>NL2BTT2Q102Nll2<HH2BTT2:FD2Jfd26<<00c6V6<<H``02DXX2
6<<2:DD2Hb`2<HH2@PP2>LL2DXX2@RP4>LL2>NL2<HH26<<2:FD2F//2:DD2@PP2<HH28B@26<<2@PP0
0c66488@PP022442:FD4ool10001ool001Goo`03003ooooo00;oo`8@XP88H@@H``034888H@QQ0088
H@8H``8000@H``808088H@8Hh`@@PP8aYP8Hh`8@XP92208@XP8Q908aYP8Q108H``92208@PP8@XP03
8@@YABU5008ia`92:09BZP8ia`:Ld`9220:4409[C@9S309Jj`9c[P9kk`;>F@:eUP:<L@:]E@:U508H
h`:<L@9Jb`BeUP03oooogooO02[oo`;og`03ooneU[FF00:eUP9Jb`:<L@8Hh`:U50:]E@:<L@:eUP;>
F@9kk`9c[P9Jj`9S309[C@:4409220:Ld`8ia`9BZP92:08ia`8YA@038@@@XQ2R008@PP92208H``8Q
108aYP8Q908@XP92208@XP8Hh`8aYP@@PP8Hh`88H@8080@H``80008H``@8H@03488H`aS3008H``88
H@Coo`40007oo`005Ooo0P000ooo0Q2R0PQQ11S300<@PPQQ26400PQQ0QS30P0011S30P0P0PQQ0QSS
11220S6V0QSS0Q2R0T880Q2R0R4T0S6V0R440QS30T880Q220Q2R00<Q12U5:DD00SW70T8X0U:Z0SW7
0YcC0T880X@@0V]=0V<<0U[[0W>^0W__0/iI0[FF0Xaa0ZeE0ZDD0QSS0Xaa0U[;1;FF00?ooooOoml0
:_oo0_oO00?ookFF]IH00[FF0U[;0Xaa0QSS0ZDD0ZeE0Xaa0[FF0/iI0W__0W>^0U[[0V<<0V]=0X@@
0T880YcC0SW70U:Z0T8X0SW70RU500<Q112R4:800Q220T880QS30R440S6V0R4T0Q2R0T880Q2R0QSS
0S6V11220QSS0PQQ0P0P11S30P000QS310QQ00<@PQS36<<00QS30PQQ0ooo0P000Ooo000Eool00`00
ooooo`02ool28@@2:FD2244248800c66@PQ220026<<28B@2<HH2@PP2:DD2F//2:FD26<<2<HH2>NL4
>LL2@RP2DXX2>LL2@PP2<HH2Hb`2:DD26<<2DXX26<<00c6V6<<H``02Jfd2:FD2BTT2<HH2Nll2Q102
BTT2>NL2mih24:82Q102F^/2ool2aSP4U;82@PP28B@6ool2ic`bool2DZX2@RP2eYX2ool2Hb`2Nnl2
eYX2aQP2Ljh2YA@2U;82>NL2Ljh2F//2DXX2:FD2:DD2BTT2U982aQP22442@RP00`Q16<<H``026><4
:DD26<<448844:82:DD2H``2<HH248828B@2<JH26><2:DD28@@26><2:DD2>NL2<JH38B@2@PP2:DD2
6<<4ool10001ool001Goo`03003ooooo00;oo`8Q108YI@88@@8@PP03<HI22488008H``8Q908aQP92
208YA@9Jb`8YI@8H``8aQP8ii`@ia`92:09BRP8ia`92208aQP9S;08YA@8H``9BRP8H``03<JHH`aS3
009[K@8YI@9:B@8aQP9kc`:4409:B@8ii`;gWP8@XP:4409Jj`;oo`;6>0BD/P92208Q90Koo`;W?3;o
o`9BZP92:0;FVP;oo`9S;09kk`;FVP;6609c[P:U50:D/P8ii`9c[P9Jb`9BRP8YI@8YA@9:B@:DTP;6
6088@@92:003244H`aS3008Hh`@YA@8H``@@PP@@XP8YA@9S308aQP8@PP8Q908aYP8Hh`8YA@8Q108H
h`8YA@8ii`8aYP<Q9092208YA@8H``Coo`40007oo`005Ooo00<00?ooool00_oo0Q220PQ10PQQ0Q2R
00<Q112248800Q220S6V0SWW0RU50R4T0RU50R4T0R440QSS0R440Q2R0RU50U[[0U::0S660RU50PQQ
0QS30R4T0S6V0QS30QSS00<Q912R4:800R440SW70V<<0/HH0QSS12440V</0TY90X@`0T8X0U[[0YcC
0W>^0^LL0/ii0]Jj0U::0YBB0[Ff2ooo0X@`8?oo0/ii1Ooo0ZDD0^mm1?oo0YBB0QSS0T8X0U[;0V</
0^Ll0ZeE0T880XaA0T8X0YBB0T8X0U[;0SWW0V]]0V<<0RUU0RU50U::00<Q92UU:FD00Q2R0RU50PQ1
0R440RU50QS30Q220SWW0T8X0T880RUU0R4T0RU50QS30RU50Q2R0R4T0Q220RU50RUU0R440QSS00<a
QRU5:DD00R440PQQ1?oo0@000Ooo000Eool00`00ooooo`02ool2:DD2>LL28@@26><00bUU:DDYA@02
6><24:828B@2:FD2:DD22642@PP2:FD28B@2<HH2@PP26><22442:DD2<HH2@RP2<HH2BVT2F//28@@2
@RP2F^/00aS3LhicSP02Q102>NL2>LL2Jfd2Nll2YA@2H``2S742oml2Jdd2DXX2YA@2DXX2]KH26<<2
ked2ool2>LL2cUTlool2S544ool2DXX2]KH2ool2:FD2H``2ia`2Ljh2<HH2U982Ljh2Nll2DXX2>NL2
[ED2Ljh2>NL2@RP00f]=>LLia`02<HH28B@2Nll2:FD2>LL2Hb`2:FD2@RP2Nll2DXX2<HH226428@@4
:FD2>LL2<JH202026<<2<JH2BTT26><00b44:DDYA@02>NL28@@4ool10001ool001Goo`03003ooooo
00;oo`8YA@8ia`8Q108Hh`03:FDYABU5008Hh`8@XP8Q908YI@8YA@88H@92208YI@8Q908aQP92208H
h`88@@8YA@8aQP92:08aQP9:J@9Jb`8Q1092:09Jj`036<=cSW>>00:4408ii`8ia`9[K@9kc`:U509S
30:<L@;og`9[C@9BRP:U509BRP:e]P8H``;_G@;oo`8ia`;>FCcoo`:<D@Coo`9BRP:e]P;oo`8YI@9S
30;W709c[P8aQP:DTP9c[P9kc`9BRP8ii`:]E@9c[P8ii`92:003JddiacW7008aQP8Q909kc`8YI@8i
a`9S;08YI@92:09kc`9BRP8aQP88H@8Q10@YI@8ia`8aYP80808H``8aYP9:B@8Hh`038@@YABU5008i
i`8Q10Coo`40007oo`005Ooo00<00?ooool00_oo10QQ0P0P0PQQ00<H``QQ26400Q2R0RU50Q2R0P0P
112R0RUU0Q220QS30P0P0RU50Q2R0R440Q2R0RU50P0P0SWW0RUU0S660QSS0U:Z0QS300<YIC66<HH0
0Q220QS30T880S660SWW0TY90W>>0Q2R0U::0T8X0S6V0RUU0V]]0Xaa0TY90W>^0V</0W_?0_oo0Zee
0_oo0U:Z00><LOooool0:?oo0X@`0_oo00=:JCWW>NL01_oo19cc0[Ff0V<<0_oo0X@@0U[[136V0XaA
0RUU0TY90W_?0W>>0T8X0R440T880V<<0QS300<@XRUU:FD00QSS0RU50QS30RUU0SW70R440S6V0S66
0SW70QSS0Q220Q2R0QS30PQQ0PQ10QSS0P000QS30PQQ0QSS0PQQ0Q2200<@XQ224880112R1?oo0@00
0Ooo000Eool00`00ooooo`02ool42642020226400aS32648H@024:82:DD24:8202044:82:FD24882
6<<20202:DD24:828@@24:82:DD20202>NL2:FD2<HH26><2DZX26<<00bUU<HHaQP0248826<<2@PP2
<HH2>NL2BTT2Lhh24:82DXX2@RP2<JH2:FD2Jfd2S742BTT2Ljh2Hb`2Nll2ool2[GD2ool2DZX00haa
ooooo`0Xool2Q302ool00dYY>NLii`06ool4W?<2]KH2H``2ool2Q102F^/4<JH2S542:FD2BTT2Nll2
Lhh2@RP28@@2@PP2H``26<<00a2R:FDYI@026><2:DD26<<2:FD2>LL28@@2<JH2<HH2>LL26><24882
4:826<<2264224426><200026<<226426><2264248800a2R488@PP044:84ool10001ool001Goo`03
003ooooo00;oo`8H``8Q10@@PP<H``8Q108H``8YI@8aQP8aYP8aQP8Q108ii`8Q108Hh`92208aYP8Y
A@9S;09BRP8ia`8YA@8aYP9BRP8YI@92:08ii`03@RPYIBUU008YA@8ii`8YI@9BZP;6609:B@88H@8i
a`9c[P9kk`9:B@8Q908H``:D/P;gWP;oo`;g_P9BZP;_O@Woo`;W72ooo`;g_P;oo`;W?0;oo`92209S
30;W?09Jb`;Nn`:U509kc`:Ll`:Ld`9BRP9S308ii`92209Jb`9kk`9S309S;003H``HhaSS008ia`92
208YI@8aQP9:B@8@XP8Q908Q10@@XP8ii`8ia`8H``8YI@80008@XP8YA@8YI@88H@8@XP8YA@8@XP03
8BA:JDYY008YI@8YA@Coo`40007oo`005Ooo00<00?ooool00_oo0QS30R4411220aS30R440QS30RUU
0S660S6V0S660R440SWW0R440QSS0T880S6V0RU50V</0U::0SW70RU50S6V0U::0RUU0T8X0SWW00=2
:2UU:FD00RU50SWW0RUU0U:Z0/HH0TY90PQQ0SW70W>^0W__0TY90R4T0QS30YBb0_NN0_oo0_Nn0U:Z
0^mm2Ooo0^LL;ooo0_Nn0_oo0^Ll0_oo0T880V<<0^Ll0U[;0]kk0ZDD0W_?0Ycc0YcC0U::0V<<0SWW
0T880U[;0W__0V<<0V</00=S31SS6><00SW70T880RUU0S660TY90Q2R0R4T0R44112R0SWW0SW70QS3
0RUU0P000Q2R0RU50RUU0PQQ0Q2R0RU50Q2R00<Q94YYBVT00RUU0RU51?oo0@000Ooo000Eool20003
ool24:826><28B@24:800a228B@Q90048@@202024:8226448B@26><2:DD26<<24:82@RP24:822642
4:82:FD248822442:FD2:DD46<<00d886<<H``02@RP2Jdd2Ljh2BTT28B@2DZX2<JH2Lhh2S542YA@2
6><2Jdd2]IH2aQP2Q102Nll2]KH2_ML2g]]0ool2@PP2Hb`2ool2BTT2U982Q102@PP2DZX2aSP2@PP2
DXX2S542U9828@@226428@@2>LL2BTT00bU56<<H``02:FD26<<24:82Hb`26<<2:FD2@RP2:FD24:82
DXX2>LL22642:FD28B@24:82<HH2:DD2:FD2264224424882:DD00`QQ488@PP046><3ool20001ool0
01Goo`03003ooooo00;oo`8@XP8Hh`8Q908@XP03488Q924T00@Q1080808@XP88H@@Q908Hh`8YA@8H
``8@XP92:08@XP88H@8@XP8YI@8@PP88@@8YI@8YA@@H``03@PPH`aS30092:09[C@9c[P9:B@8Q909B
ZP8aYP9cSP:<D@:U508Hh`9[C@:eUP;660:4409kc`:e]P:me`;Nfd3oo`92209S;0;oo`9:B@:DTP:4
4092209BZP;6>092209BRP:<D@:DTP8Q1088H@8Q108ia`9:B@03:DDH`aS3008YI@8H``8@XP9S;08H
``8YI@92:08YI@8@XP9BRP8ia`88H@8YI@8Q908@XP8aQP8YA@8YI@88H@88@@8@PP8YA@03264@PQ22
00@Hh`Coo`40007oo`005Ooo00<00?ooool00_oo0PQ10Q2R10QQ00<Hhb4T8B@00Q2R0PQQ0Q2R0QSS
0R4T0PQ10QSS0PQ10R4T0QSS0RU50PQ10Q220RU50PQQ0R4T0Q220QSS0RUU0S6V148800<aQTYYBVT0
0T880QS30R440S6614880U::0QSS0RU50V<<0W>^0U::0S6V15:Z0W__0U::0S6V0V<<1?oo0V</;ooo
00=kcoooool00TYY0YBB0Xaa0^mm0]kk0SWW0Q2R0_Nn0T880YcC0QSS0T880V]=0TYY0SW70S6614Y9
0T880W_?0Q2R0R4T00<H`bU5:DD00R4T0SW70R440RU50T8X0Q220PQ10T880S660TY90T8X0RUU0PQQ
0Q2R0QSS0Q2R0R4T0Q220Q2R0Q220PQ10Q2R00<@PQ2R4:800Q220QSS1?oo0@000Ooo000Eool00`00
ooooo`02ool224424:8426400aSS8B@Q90024:8226424:826><28B@224426><224428B@26><2:DD2
24424882:DD226428B@248826><2:FD2<JH4@PP00c66BVU:J@02@PP26<<28@@2<HH4@PP2DXX26><2
:DD2H``2Ljh2DXX2<JH4DZX2Nnl2DXX2<JH2H``4ool2Hb`_ool00g_?ooooo`02BVT2U982S742kgd2
g_/2>NL24:82mkh2@PP2W=<26><2@PP2Jdd2BVT2>LL2<HH4BTT2@PP2Nll24:828B@00aS3:DDYA@02
8B@2>LL28@@2:DD2@RP248822442@PP2<HH2BTT2@RP2:FD226424:826><24:828B@248824:824882
24424:800a224:8@XP0248826><4ool10001ool001Goo`03003ooooo00;oo`8Q908Q108H``8Q9003
6<<@XQ2R008YA@8Hh`80808Hh`8YA@88@@8YA@8Q108aYP8Q908Q108H``8Q908YA@922092:08aYP8H
``8ii`9S;08aQP9[K@038B@HhaSS00A[C@9:B@8Q908Q10A[K@:e]P9:B@B]E@:e]P8ia`9kc`;FVPKo
o`:443?oo`;g_P_oo`;>F@:Ld`;_O@8@PP8H``;gWP:<D@;og`9cSP:<D@9[C@:me`92:08Hh`8@XP8Q
109BZP9c[P03@RQ:JDYY009Jj`8Q109:B@9BZP8ia`9:B@9:J@88H@8@XP8ii`8@PP8ia`8Q108@XP8Q
108H``8@XP8Hh`8YI@8YA@88H@8Hh`03:DD8@@Q1008H``8Q10Coo`40007oo`005Ooo00<00?ooool0
0_oo0R4T0R440QS30R4T00<H`a2R4:800RU50QSS0P0P0QSS0RU50PQ10RU50R440S6V0R4T0R440QS3
0R4T0RU50T880T8X0S6V0QS30SWW0V</0S660V]]00<Q91SS6><016]=0TY90R4T0R4416]]0[Ff0TY9
1:eE0[Ff0SW70W_?0]JJ1_oo0X@@<ooo0_Nn2ooo0/iI0YcC0^mm0Q220QS30_NN0XaA0_oO0W>>0XaA
0V]=0[gG0T8X0QSS0Q2R0R440U:Z0W>^00=2:4YYBVT00U[[0R440TY90U:Z0SW70TY90TYY0PQQ0Q2R
0SWW0Q220SW70R440Q2R0R440QS30Q2R0QSS0RUU0RU50PQQ0QSS00<YA@Q124400QS30R441?oo0@00
0Ooo000Eool00`00ooooo`02ool226424:8248826><00b442648H@0224448B@2:FD26><426420202
6<<2:FD44882<HH26<<26><22442:DD224424:82:DD2:FD28@@00c6V2648H@02<HH24:82H``2Jfd2
Q302:FD2@PP22642@PP24:826<<2W?<2Hb`2Ljh2aQP2W?<2S542ica0ool2mkh2mih2Nnl2H``2YC@2
Nnl2[ED2Hb`2Jdd26><24884@PP2Jdd2DZX2Lhh202028@@2>NL00a228@@Q10026><24:82>NL26<<2
020248826<<4<JH248826<<2<HH2488226426><2<HH226426><2:FD2488424400c662448@@024882
0204ool10001ool001Goo`03003ooooo00;oo`88H@8@XP8@PP8Hh`038@@8H@QQ0088@@@Q908YI@8H
h`@8H@80808H``8YI@@@PP8aQP8H``8Hh`88@@8YA@88@@8@XP8YA@8YI@8Q1003<JH8H@QQ008aQP8@
XP9S309[K@:4<08YI@922088H@92208@XP8H``:Ll`9S;09c[P;660:Ll`:<D@;W?43oo`;g_P;gWP9k
k`9S30:U=09kk`:]E@9S;09[C@8Hh`8@PPA2209[C@9BZP9cSP80808Q108ii`03488Q1244008Hh`8@
XP8ii`8H``80808@PP8H``@aYP8@PP8H``8aQP8@PP88H@8Hh`8aQP88H@8Hh`8YI@8@PP@8@@03<HH8
@@Q1008@PP8080Coo`40007oo`005Ooo00<00?ooool00_oo0Q2R0P0P0R440QSS00<8@ASS6><00S6V
0QSS0R440P000Q2R0S660Q2R0QSS0R440RUU0PQQ0TY90R4T0T880S6V0Q2R0PQ10RU50QSS0RU50QSS
0Q2R00=:JA2248800RU50U:Z0S6V0SWW0RUU0V<<0U[;0SW70S6V0W>^0W>>0T8X0XaA0T880X@`0^Ll
0Xaa0TY90[gG0^mM=_oo0YBb0TY90Zee0S6V0X@`15::0[gg0S660YBB17_?0RUU0W>^0U[[0SW70T8X
0TYY0SW712440W__00<Q93W7>LL00S6V0SWW0S6V0S660Q2R0Q220PQQ0RU50R4T0R440S660R4T12U5
0Q2R0PQQ0QS30S6V0R440QSS0QS30QSS00<@PP0P02000R4T0RUU1?oo0@000Ooo000Eool00`00oooo
o`02ool24:8202028@@26><00`Q16><Hh`02<JH26><28@@200024:82<HH24:826><28@@2:FD22642
BTT28B@2@PP2<JH24:822442:DD26><2:DD26><24:800dYY488@PP02:DD2DZX2<JH2>NL2:FD2H``2
F//2>LL2<JH2Ljh2Lhh2@RP2S542@PP2Q302ic`2S742BTT2_ML2kedfool2U;82BTT2[GD2<JH2Q304
DXX2_OL2<HH2U984Nll2:FD2Ljh2F^/2>LL2@RP2BVT2>LL48@@2Nnl00b4T>LLia`02<JH2>NL2<JH2
<HH24:8248822642:DD28B@28@@2<HH28B@4:DD24:8226426<<2<JH28@@26><26<<26><00a220200
80028B@2:FD4ool10001ool001Goo`8000?oo`8H``8@XP8Q908Q1003:DD8H@QQ008@XP8H``8aQP8@
XP8Hh`8Q108@XP8Q108Hh`8Q908Hh`8H``@Hh`8Q108ia`8aYP8YI@8Hh`9:B@92208Q9003BVUJbe[;
0088H@9:J@9[C@922092:08Q909:B@:U50;6>088H@;6609kk`:]E@;oo`:<L@;oo`;Nn`Koo`;_G@:U
=2goo`;>F@03oomBRU::00;oo`8aYP;oo`;>N@Coo`:D/P;FVP8YA@;Nf`8YI@9cSP:<L@:<D@9BRP8H
h`9[K@9cSP9c[P9:B@8@PP8aQP03@PQ:BDY9008aYP8YA@8@XP9BZP92209:B@92209:J@8ii`8aQP@Q
908YA@8Q10@YA@@@PP8Q908YA@8H``8@PP03264Q924T008Hh`8Q90?oo`80007oo`005Ooo00<00?oo
ool00_oo0QS30Q2R0R4T0R4400<YA@QQ26400Q2R0QS30S660Q2R0QSS0R440Q2R0R440QSS0R4T0QSS
0QS311SS0R440SW70S6V0RUU0QSS0TY90T880R4T00=:JE[;F//00PQQ0TYY0V]=0T880T8X0R4T0TY9
0ZDD0/Hh0PQQ0/HH0W__0ZeE0_oo0Xaa0_oo0]kk1_oo0^mM0ZDd;Ooo0/iI00?ooe::DXX00_oo0S6V
0_oo0/ii1?oo0YBb0]JJ0RU50]kK0RUU0W>>0Xaa0XaA0U::0QSS0V]]0W>>0W>^0TY90Q220S6600=2
24Y9BTT00S6V0RU50Q2R0U:Z0T880TY90T880TYY0SWW0S66124T0RU50R4412U511220R4T0RU50QS3
0Q2200<8HB4T8B@00QSS0R4T1?oo0@000Ooo000Eool00`00ooooo`02ool248826<<226424:800a22
000000046<<224424:826<<226422444264202026><22642:DD28B@22442:DD26><28B@44882<JH2
26400aSS@PQ220026><226426><24882DXX4BTT2<JH28B@2DXX248822642eYX2S742BTT2ool2omm6
ool2ia`2[ED4Hb`2_ML2BTT2BVT2H``2Lhh2Hb`2DXX26><2BVT2<HH2<JH2@PP26<<00cW76><Hh`02
0202:DD28B@24882<HH22442<HH26><22442>LL202026<<26><28@@248824:82488226426<<22645
48826><226424884ool10001ool001Goo`03003ooooo00;oo`8@PP8H``88H@8@XP034880000000@H
``88@@8@XP8H``88H@88@@@8H@80808Hh`88H@8YA@8Q9088@@8YA@8Hh`8Q90@@PP8aYP88H@036>=2
2488008Hh`88H@8Hh`8@PP9BRPA:B@8aYP8Q909BRP8@PP88H@;FVP:<L@9:B@;oo`;ogdKoo`;W70:]
E@AS;0:me`9:B@9:J@9S309cSP9S;09BRP8Hh`9:J@8aQP8aYP92208H``03>LLHhaSS0080808YA@8Q
908@PP8aQP88@@8aQP8Hh`88@@8ia`80808H``8Hh`8Q108@PP8@XP8@PP88H@8H``88H@D@PP8Hh`88
H@8@PPCoo`40007oo`005Ooo00<00?ooool00_oo0RU50QS30Q220R4400<Q900P02000Q220S660Q2R
0RU50QSS0R440QSS0RUU0Q2R0RU50R4T0QS30U::0R4T13660R4T0S660RUU0P0P0TY90QS300<8@D88
@PP00U:Z0S660TY90V</0R440RU50TYY0U[[0U:Z0TY90TYY0QSS0_NN0V</0S6V0W>^0[Ff0XaA@?oo
0[gg0W>^0Q2R0Zee0X@@0SW717__0U[;0X@`0V]=0S6V0V]=0V<<0U:Z0SW70U::14Y900=JjdY9BTT0
0TY90QSS0V]]0S660R4T0R440S660R440R4T0QSS0RUU0R440R4T0RUU0R440S660PQ10PQQ0S6V1aSS
0RUU0QS30Q2R1?oo0@000Ooo000Eool00`00ooooo`02ool2:DD26<<248828@@00b4T020080024882
<HH24:82:DD26><28@@26><2:FD24:82:DD28B@26<<2DXX28B@4<HH28B@2<HH2:FD20202BTT26<<0
0`Q1@PQ22002DZX2<HH2BTT2Hb`28@@2:DD2BVT2F^/2DZX2BTT2BVT26><2mih2Hb`2<JH2Ljh2]KH2
S550ool2_OL2Ljh24:82[GD2Q102>LL4Nnl2F//2Q302Jdd2<JH2Jdd2H``2DZX2>LL2DXX4BTT00e[[
BTU:B@02BTT26><2Jfd2<HH28B@28@@2<HH28@@28B@26><2:FD28@@28B@2:FD28@@2<HH224422642
<JH76><2:FD26<<24:84ool10001ool001Goo`03003ooooo00;oo`8H``88H@80808@PP03244Q1244
008@PP88H@8@XP8Q1088@@8Hh`8@PP8@XP8@PP8H``8@PP8H``8Q9088H@@@XP8YA@88H@8H``8@XP8i
a`88@@03<JHiicWW009Jj`@@XP92:09S309BRP9kk`9Jb`:Ll`8ii`:U50;W?0;Nf`;W70:]E@:]M@;g
_P9[C@:<DA7oo`;gWR3oo`;FVPGoo`:]M@:<D@9S30;Nf`:DTP:me`;F^P;W?0;>N@8aQP;oo`:]M@8a
QP:<L@9:J@8YI@9:J@9BZP92:09BRP<H``8ia`8Q109:B@8aYP88H@8ia`8H``8Hh`8YI@9BZP8Q108Y
A@8Q1088@@8@XP8H``8@XP8H``8@PP80808@PP8@XP8Q1003000@XQ2R008Hh`88H@Coo`40007oo`00
2?oo0P001?oo0P001Ooo00<00?ooool00_oo0QS30PQQ0P0P0Q2200<8@B448@@00Q220PQQ0Q2R0R44
0PQ10QSS0Q220Q2R0Q220QS30Q220QS30R4T0PQQ112R0RU50PQQ0QS30Q2R0SW70PQ100<aYSWW>NL0
0U[[112R0T8X0V<<0U::0W__0U[;0Ycc0SWW0ZDD0^Ll0]kK0^LL0ZeE0Zee0_Nn0V]=0XaA4Ooo0_NN
8?oo0]JJ1Ooo0Zee0XaA0V<<0]kK0YBB0[gG0]Jj0^Ll0/ii0S660_oo0Zee0S660Xaa0TYY0RUU0TYY
0U:Z0T8X0U::0aS30SW70R440TY90S6V0PQQ0SW70QS30QSS0RUU0U:Z0R440RU50R440PQ10Q2R0QS3
0Q2R0QS30Q220P0P0Q220Q2R0R4400<0012R4:800QSS0PQQ1?oo0@000Ooo0007ool01000ooooo`00
0_oo00@00?ooool000Coo`03003ooooo00;oo`88H@88@@8Q90<@XP8Hh`88@@88H@8Q108@PP8Q108@
XP8@PP80808aQP88H@8@PP8Q108H``8Q908Q1088@@8Q108aYP8Q108Q908Hh`9220036<<8H@QQ0080
009BZP8Q108aQP8YA@92208@XP8H``8YA@8YI@9BZPAJb`;>F@;_G@;F^PKoo`:e]P;W71ooo`;W?1?o
o`:me`9BZP;>N@;W?0Coo`;Nn`;oo`:mm`9kc`9Jj`:<L@:4<08@XP9Jj`8000922088@@9kk`8H``8Y
I@9:J@036<<aYS6V009:J@9[K@8ii`8YA@8aQP88@@8@PP8ii`8Q108ia`8YA@8Hh`88H@80808aYP8a
QP8Hh`88H@8Q908Hh`8@PP8H``03488@XQ2R0080008@XPCoo`40007oo`001ooo00@00?ooool000;o
o`04003ooooo0004ool20003ool2264224428B@34:826><2244226428@@248828@@24:8248820202
<HH2264248828@@26<<28B@28@@224428@@2<JH28@@28B@26><2@PP00aS32648H@020002DZX28@@2
<HH2:DD2@PP24:826<<2:DD2:FD2DZX4F//2cUT2ked2e[X6ool2]KH2ia`Oool2ic`Cool2_ML2DZX2
cWT2ic`4ool2g_/2ool2_OL2Nll2F^/2S742Q3024:82F^/20002@PP22442Nnl26<<2:FD2BVT00aS3
<JHaYP02BVT2Jfd2>NL2:DD2<HH224424882>NL28@@2>LL2:DD26><226420202<JH2<HH26><22642
8B@26><248826<<00a224:8@XP0200024:83ool20001ool000Soo`8000?oo`04003ooooo0004ool0
0`00ooooo`02ool26><20002020226400aSS6<<H``02488224426><28B@26<<24882:DD48B@24:82
8B@202026<<2@RP2:FD200022644<HH2BTT26><2>LL00b44>LLia`02>LL2@PP2:FD2>LL2F//2Ljh2
U;82BVT2<JH2Nnl2F//2>NL4BTT2F//2Q102eYX6ool2S542cUTMool2cUT:ool2mih2ic`3ool2YC@2
Jdd2ool2ic`2ool2S742oml2cUT2BVT2YA@2BVT2e[X2YA@2Jfd2H``2S742Ljh2Jdd2DXX2Hb`2@RP2
DZX2<JH00cW7DZYBZP02Jfd2:FD2@RP2:DD26><2<HH24:84:FD26><224428B@26<<202028B@26<<2
6><248846<<2:DD24:800`Q16<<H``044884ool10001ool000Ooo`04003ooooo0002ool01000oooo
o`001?oo00<00?ooool00_oo0QSS0P000P0P0PQQ00<HhaS36<<00Q220PQ10QSS0R4T0QS30Q220RU5
124T0Q2R0R4T0P0P0QS30T8X0RUU0P000PQQ13660TY90QSS0SW700<Q13W7>LL00SW70T880RUU0SW7
0U[;0W>^0YBb0TYY0S6V0W__0U[;0SWW14Y90U[;0X@@0]JJ1_oo0XaA0/iI7Ooo0/iI2_oo0_NN0^Ll
0ooo0ZDd0V]=0_oo0^Ll0_oo0Xaa0_oO0/iI0TYY0ZDD0TYY0]Jj0ZDD0V]]0V<<0Xaa0W>^0V]=0U::
0V</0T8X0U:Z0S6V00<iae:ZDZX00V]]0RUU0T8X0RU50QSS0S660Q2R12UU0QSS0PQ10R4T0QS30P0P
0R4T0QS30QSS0Q2211S30RU50Q2R00<8@AS36<<011221?oo0@000Ooo0007ool01000ooooo`000_oo
00@00?ooool000Coo`03003ooooo00;oo`8@PP8Q10808088H@<8@@8H``88@@808080008@PP88@@8@
XP88@@88H@808088@@88H@8080@Hh`8Q908YA@92:08YA@88@@8@PP8Q10034:8HhaSS00@ii`8@PP8Q
109Jj`:<L@9c[P9BZP9S30:DTP:<L@9c[P92:09Jj`9[K@9220:<L@;W70:4<0;oo`;Nn`:e]P03g__o
oooo01[oo`9Jj`Coo`;660;oo`:]E@Koo`03@RQkkg__00;>N@;g_P;W?09BZP:mm`9kk`:4<09S30;F
^P9:J@;g_P;6>0:eUP;6608aQP:4408@XP9S308@XP8Q909[K@8YA@03>LMBRU::0092208YI@8Q908Q
108H``8@XP8YA@8@XP8Q1092:088@@88H@8@PP88H@8@PP8@XP88@@8@XP88@@@8H@88@@030208H@QQ
008H``8@PPCoo`40007oo`002?oo0P001?oo0P001Ooo00<00?ooool00_oo0Q220R440P0P0PQQ0`Q1
0QS30PQ10P0P0P000Q220PQ10Q2R0PQ10PQQ0P0P0PQ10PQQ0P0P11SS0R4T0RU50T8X0RU50PQ10Q22
0R4400<@XQSS6><013WW0Q220R440U[[0Xaa0W>^0U:Z0V<<0YBB0Xaa0W>^0T8X0U[[0V]]0T880Xaa
0^LL0X@`0_oo0]kk0[Ff00?Nnoooool06_oo0U[[1?oo0/HH0_oo0ZeE1_oo00=2:7__Nnl00/ii0_Nn
0^Ll0U:Z0[gg0W__0X@`0V<<0]Jj0TYY0_Nn0/Hh0[FF0/HH0S660X@@0Q2R0V<<0Q2R0R4T0V]]0RU5
00<iae::DXX00T880RUU0R4T0R440QS30Q2R0RU50Q2R0R440T8X0PQ10PQQ0Q220PQQ0Q220Q2R0PQ1
0Q2R0PQ110QQ0PQ100<080QQ26400QS30Q221?oo0@000Ooo000Eool00`00ooooo`02ool202022442
02026><00a222648H@024:828@@24882020248826<<200044:82:FD26><24882<JH2:FD24882:FD2
48826><2:FD46><224400c6VBTU:B@02<HH2:FD2F//2:FD2H``2<JH28B@2H``2:DD2<JH2U;82Q102
]KH2Q304W?<2Nll2Ljh2U;82S744ool00liicUW>F@08ool2YC@@ool2W?<4ool2[GD2ool2cUT2W=<4
ool00cWWH`aS3002ool2[ED2]IH26><2S542Q302g]/4mih2oml2Jdd2ic`2Nll2H``2BTT26><2<HH2
BTT2:DD2@RP26><2:FD00`QQBTU:B@02>LL26<<2BTT2488224428B@2:DD28@@24:828@@226426><2
4:8226420202:DD28@@26><2244202026><224400`0P488@PP026<<20004ool10001ool001Goo`03
003ooooo00;oo`808088@@80808Hh`034888H@QQ008@XP8Q108@PP80808@PP8H``8000@@XP8YI@8H
h`8@PP8aYP8YI@8@PP8YI@8@PP8Hh`8YI@@Hh`88@@03<JI:BDY9008aQP8YI@9Jb`8YI@9S308aYP8Q
909S308YA@8aYP:D/P:440:e]P:4<0BLl`9kc`9c[P:D/P:<L@Coo`03cWW>FLiI00Soo`:U=13oo`:L
l`Coo`:]M@;oo`;>F@:Ld`Coo`03>NMS36<<00;oo`:]E@:eUP8Hh`:<D@:4<0;Nf`CgWP;og`9[C@;W
?09kc`9S309:B@8Hh`8aQP9:B@8YA@92:08Hh`8YI@03265:BDY9008ia`8H``9:B@8@PP88@@8Q908Y
A@8Q108@XP8Q1088H@8Hh`8@XP88H@80808YA@8Q108Hh`88@@80808Hh`88@@03020@PQ22008H``80
00Coo`40007oo`005Ooo00<00?ooool00_oo0PQQ0PQ10P0P0P0000<082448@@00PQQ0R440PQ10PQQ
0P0P0Q22100P0PQQ0QS30QSS0QS30RUU0QS30P0P0SWW0PQ10Q220R44124T0P0P00<aYU::DXX00V<<
0R440T880U::0TY90R440SW70U[;0V<<0S660U[;0U:Z0X@@0[Ff0XaA0ZDD0Zee0T8X0X@`0/iI0^LL
0_oo00>Lloooool01?oo0_oO0_oo0W>^4?oo0Ycc2?oo0ZDd0ZDD0_oo0[gG00>LdmJJeYX00XaA0]kk
0S660W>>0/HH0]Jj0^mm0_oo0Ycc0/HH0TYY0/iI0U[;0[gg0SWW0YBb0TYY0U:Z0W>>0RU50S660RU5
00=BRTY9BTT00T8X0PQ10RU50QS30QSS0Q2R10QQ0S660PQ10P000Q220PQQ0P000Q2R0PQ10QSS0P0P
0Q2R0PQQ0PQ10PQQ00<000Q124400PQQ0P0P1?oo0@000Ooo000Eool00`00ooooo`02ool226422442
020200000`0P8@@Q100226428@@22442264202024884020226426<<26><26<<2:FD26<<20202>NL2
244248828@@48B@202000c6VDXYBRP02H``28@@2@PP2DXX2BTT28@@2>LL2F//2H``2<HH2F//2DZX2
Q102]KH2S542YA@2[GD2@RP2Q302cUT2ia`2ool00iccooooo`04ool2oml2ool2Ljh@ool2W?<8ool2
YC@2YA@2ool2_ML00icCeY[FVP02S542g_/2<HH2Lhh2aQP2e[X2kgd2ool2W?<2aQP2BVT2cUT2F//2
_OL2>NL2U;82BVT2DZX2Lhh2:DD2<HH2:DD00e::BTU:B@02@RP22442:DD26<<26><24:842642<HH2
244200024882264200024:8224426><202024:822642244226400`002448@@0226420204ool10001
ool001Goo`03003ooooo00;oo`8080@@PP8H``03244@XQ2R0088H@8@XP808088@@80808@PP@0808Q
108YA@8@XP88H@88@@8@XP8ii`88@@8@XP88H@8YI@8H``8YA@8080036<=:BDY9008H``8Q909c[P8Q
108aYPABZP8ii`9c[P92208@PP8Q108Hh`9S309[C@:DTP;6>0:Ld`9S30B]E@;W70>]E@Coo`;_G@;o
o`9cSP;W?0;oo`;>N@[oo`9:B@Coo`:e]P;Nn`;_G@;660;og`;>F@03F^_>FLiI00:4<08aQP9kk`9S
30;FVP:DTP;og`;_G@92209S30:]E@:Ll`:U=0:440:Ld`9S30922092:09:J@8YA@8@PP=2208ii`@@
PP8@XP8YA@8YI@8Hh`8@XP8Q108Hh`88@@8Q1088@@8@PP88H@@Q1088H@8Q108H``8Q1088H@8@PP03
264H`aS30088@@8@PPCoo`40007oo`005Ooo0P000ooo0Q220Q2R0PQ10PQQ00<@XP0P02000PQ110QQ
0Q220P0P0PQQ0QS30P0010Q10QSS11220RU50QS30PQQ0SW70QS30P000R4T0P000RU500<iadY9BTT0
0S660V</0SWW0Q2R0SW70T8X0TY90R4T0U:Z0U::0R4T0W__0T880PQ10RUU0T880V</0]kK0T880V<<
0Zee0/iI00?W77__Nnl00_oo1<iI0_oo0[FF3?oo0^LL0_oo0[gg0_oo0[gG0YBb0_oo0U[[0[gg0ZDD
0T8X1iBB0U[;0/Hh0V]=0YcC0YBB0[FF0W__0[gg0Zee1:Dd0TYY0V]]0S6V0V<<0RUU0TY90RUU0Q2R
0S6600<Q13W7>LL00QSS0Q2R0Q220S660PQQ0P000PQ112440P000PQ10Q220P000P0P0PQQ0Q2R0QS3
0Q2R0QSS0Q2210Q100<H``Q124400PQQ0P0P0ooo0P000Ooo000Eool00`00ooooo`02ool248824:82
244226400a2R02008002244426424882020226426<<2000424426><44882:DD26<<22642>LL26<<2
00028B@20002:DD00cW7BTU:B@02<HH2Hb`2>NL24:82>LL2@RP2BTT28B@2DZX2DXX28B@2Nnl2@PP2
2442:FD2@PP2Hb`2g]/2@PP2H``2[GD2cUT00nLLNnmkk`02ool4cUT2ool2]IH<ool2ia`2ool2_OL2
ool2_ML2U;82ool2F^/2_OL2YA@2@RP7U982F//2aSP2Jdd2W=<2U982]IH2Nnl2_OL2[GD4YC@2BVT2
Jfd2<JH2H``2:FD2BTT2:FD24:82<HH00b44>LLia`026><24:824882<HH22642000224448@@20002
244248820002020226424:826<<24:826><2488424400aS32448@@0226420204ool10001ool001Go
o`03003ooooo00;oo`8@PP88@@8@PP<08088@@8@XP@@PP@08088H@8@XP80808H``80808@PP88H@80
008@XP8H``8Q108aYP88@@88H@8Q108H``8YI@036<<YABU5008@XP9:J@8YI@8H``8Q108ia`8ii`8Q
108aYP9Jb`9BRP:4408ii`92:08ia`8ii`8Hh`;>N@9kc`9:J@9S;0;6>003mkjmmkgg00;6>09c[P:U
50;_G@:440;660;oo`;>N@;oo`;W70;oo`;gWP;oo`:D/P;oo`:D/P9cSP;oo`8Q10:me`;FVP9Jj`03
_ON448@@009cSP:DTP;>F@;FVP:U508ia`:Ld`:e]P9[K@:]E@:<D@:U=0:4<09[C@9c[P8Q909S3092
209BRP8Hh`8H``8YA@03<HH8@@Q1008Hh`88@@8H``@YA@8H``@@XP88H@8aQP88H@8H``88@@@@PP88
H@8@XP80808@PP88H@8H``88H@036<<0800P00808088@@Coo`40007oo`005Ooo00<00?ooool00_oo
0Q220PQ10Q220`0P0PQ10Q2R1122100P0PQQ0Q2R0P0P0QS30P0P0Q220PQQ0P000Q2R0QS30R440S6V
0PQ10PQQ0R440QS30RUU00<H`bU5:DD00Q2R0TYY0RUU0QS30R440SW70SWW0R440S6V0U[;0U::0X@@
0SWW0T8X0SW70SWW0QSS0/ii0W_?0TYY0V</0/Hh00?g_[gg_OL00/Hh0W>^0ZDD0^mM0X@@0/HH0_oo
0/ii0_oo0^LL0_oo0_NN0_oo0YBb0_oo0YBb0W>>0_oo0R440[gG0]JJ0U[[00>mmh@@Q1000W>>0YBB
0/iI0]JJ0ZDD0SW70YcC0[Ff0V]]0ZeE0XaA0ZDd0X@`0V]=0W>^0R4T0V<<0T880U::0QSS0QS30RU5
00<aQPQ124400QSS0PQ10QS312U50QS3112R0PQQ0S660PQQ0QS30PQ111220PQQ0Q2R0P0P0Q220PQQ
0QS30PQQ00<H``0P02000P0P0PQ11?oo0@000Ooo000Eool00`00ooooo`02ool4264248824:800`00
6<<H``0824424:8224440002020248828@@26<<2020248822642@PP24882>LL202026><2<JH2:DD0
0aSS4:8@XP026><2:FD2<HH2BVT24:822442:DD2>LL26><2DXX2<JH24:82Jfd2@PP2BTT48@@4Nnl2
Q302@PP2U;800oooNnmkk`02[ED2W=<2g_/2oml2]KH2YC@2ool2F^/2ool2ic`2ool2]IH2ool2@RP2
ool2BVT2DXX2_ML2>NL4S742S5400iBBJde[C@02S742F^/2Nll2Q302]IH2DXX2W?<2]IH2YA@2Hb`2
@RP2YA@2DXX2F^/2S742Jdd2@PP2<JH2F^/24:828@@2<JH00b4T<HHaQP02@PP22642<JH426424:82
6><226424:826><24882:DD2:FD448846<<26><24:824887244226424:84ool10001ool001Goo`03
003ooooo00;oo`@8H@8@PP8@XP03000H`aS300P8@@8@XP88@@@00080808@PP8Q108H``80808@PP88
H@92208@PP8ia`80808Hh`8aYP8YA@036><@XQ2R008Hh`8YI@8aQP9:J@8@XP88@@8YA@8ia`8Hh`9B
RP8aYP8@XP9[K@92209:B@@Q10Akk`:4<09220:D/P03oomkkg__00:]E@:Ld`;Nn`;og`:e]P:U=0;o
o`9Jj`;oo`;W?0;oo`:eUP;oo`92:0;oo`9:J@9BRP:me`8ii`B<L@:<D@03U99[CF]=00:<L@9Jj`9k
c`:4<0:eUP9BRP:Ll`:eUP:U509S;092:0:U509BRP9Jj`:<L@9[C@92208aYP9Jj`8@XP8Q108aYP03
8B@aQS6600922088H@8aYP@8H@8@XP8Hh`88H@8@XP8Hh`8@PP8YA@8YI@@@PP@H``8Hh`8@XP8@PPL8
@@88H@8@XPCoo`40007oo`005Ooo00<00?ooool00_oo0PQQ0P000P0P0PQ100<0812248800PQQ0PQ1
0PQQ0P000QS311220Q2R0PQ10Q2210Q10QS30Q2R0RU50QS30PQ10QS30Q220R440PQQ0RUU0c660P0P
0U:Z0TYY0U[;0S6V0R440SW70S660RUU0Q2R0RU50QS30SW70U[[0RUU0QSS0T880SWW0SW70U::0T88
0ZDd00?668@`Q3000U:Z0X@`0V]=0Ycc0W__0X@`0_oo0QSS0_oo0ZDD0_oo0Xaa0_oo0YBb0_oo0ZDd
0W_?0^LL0Xaa0/ii0Xaa0W>>00><DG__Nnl00RUU0[Ff0V]=0U[;0[FF0SW70W_?0W__0YBb0ZDd0SWW
0V]=0Ycc0U:Z0RUU0V]=0SW70V]=0R4T0TY90R4T0cWW0QSS0RU50R440Q2R0QS30Q220R440Q2R0QSS
0S661PQQ0QSS0PQ10Q220QSS0QS30Q2R10QQ0P0P0`Q10P000PQQ0P0P1?oo0@000Ooo000Eool00`00
ooooo`02ool226420002020224400`0P488@PP0226422442264200026<<448824:82244248842442
6<<24:82:DD26<<224426<<248828@@22642:FD3<HH20202DZX2BVT2F//2<JH28@@2>LL2<HH2:FD2
4:82:DD26<<2>LL2F^/2:FD26><2@PP2>NL2>LL2DXX2@PP2YC@00lHHQ324<002DZX2Q302Jdd2W?<2
Nnl2Q302ool26><2ool2YA@2ool2S742ool2U;82ool2YC@2Nll2ia`2S742cWT2S742Lhh00haANnmk
k`02:FD2]KH2Jdd2F//2]IH2>LL2Nll2Nnl2U;82YC@2>NL2Jdd2W?<2DZX2:FD2Jdd2>LL2Jdd28B@2
BTT28B@3>NL26><2:DD28@@24:826<<248828@@24:826><2<HH626426><2244248826><26<<24:84
264202032442000226420204ool10001ool001Goo`03003ooooo00;oo`88H@8@PP88@@8@PP036<<8
@@Q10088H@88@@8000H@PP800088H@8Hh`8@XP8H``88H@8Q108@PP8@XP8Hh`8Q908aYP8H``8@XP8Q
908Q10034:8HhaSS0088H@8@PP8ii`92:092208YA@8Hh`9:J@8aQP@@PP8ia`8YI@9[K@8Hh`808092
209Jb`8ia`8@PP92208YI@03Nlm[KF]]008aYP:<L@9cSP;6>09:J@:U50;oo`9Jb`Koo`;W?0;oo`9k
c`:eUP:D/P9Jj`9cSP9[K@:4409kc`8Q9003YCB<LHaa00:4<0:U=0;>F@8ii`:4409kk`:Ll`9:B@8i
a`9Jj`9c[P9:J@:Ld`9[K@92:08aQP8Q109Jj`@Q908aYP9BRP03488Q924T008YA@88H@@@PP8ii`8i
a`88@@88H@8@XP88H@8Hh`8Q908YI@88@@8@XP8@PP8Hh`@@PP88@@8@PP8H``03488@XQ2R0088H@88
@@Coo`40007oo`005Ooo00<00?ooool00_oo0PQQ0Q220PQ10Q2200<H``Q124400PQQ0PQ10P001Q22
0P000PQQ0QSS0Q2R0QS30PQQ0R440Q220Q2R0QSS0R4T0S6V0QS30Q2R0R4T0R4400<@XQSS6><00PQQ
0Q220SWW0T8X0T880RU50QSS0TYY0S6611220SW70RUU0V]]0QSS0P0P0T880U[;0SW70Q220T880RUU
00=kcf]]Jfd00S6V0Xaa0W>>0/Hh0TYY0ZDD0_oo0U[;1_oo0^Ll0_oo0W_?0[FF0YBb0U[[0W>>0V]]
0X@@0W_?0R4T00>U=8aaS7400X@`0ZDd0/iI0SWW0X@@0W__0Ycc0TY90SW70U[[0W>^0TYY0YcC0V]]
0T8X0S660R440U[[124T0S6V0U::00<@PR4T8B@00RU50PQQ11220SWW0SW70PQ10PQQ0Q2R0PQQ0QSS
0R4T0RUU0PQ10Q2R0Q220QSS11220PQ10Q220QS300<@PQ2R4:800PQQ0PQ11?oo0@000Ooo000Eool2
0003ool4244226428@@00aSS2448@@02244200026<<42442264248828@@2488226424882<JH22444
8B@202028B@26><28@@2:DD2BTT28B@36><224424:82488426428B@2BVT4>NL2<JH424428@@2:DD2
F^/224428@@22442Hb`2Jdd28B@2<JH00e:ZH`aS30028B@2>LL2:DD2cUT24:82F^/2oml2Q102ool2
oml2ool2Q302ool2W?<2ool2Q302:DD2YA@2U982YC@2Nnl2:DD00icCYABU5002<JH2S542Q102Lhh2
[ED2W?<2Nnl2BTT2DXX2<JH2BVT28B@2>LL2F//2<HH2DXX2:DD2BTT2@PP2<HH2:DD2@RP00c6V:FDY
I@024882<JH26<<24:826<<2<JH26<<28B@26<<26><2020224426<<26><24:8248826<<248820002
244426400a226<<H``0202024883ool20001ool001Goo`03003ooooo00;oo`@8@@88H@8Q10036><8
@@Q10088@@80008H``@8@@88H@8@PP8Q108@PP88H@8@PP8aYP88@@@Q9080808Q908Hh`8Q108YA@9:
B@8Q90<Hh`88@@8@XP8@PP@8H@8Q909:J@@ii`8aYP@8@@8Q108YA@9Jj`88@@8Q1088@@9S;09[C@8Q
908aYP03DZYS36<<008Q908ia`8YA@;>F@8@XP9Jj`;og`:440;oo`;og`;oo`:4<0;oo`:Ll`;oo`:4
<08YA@:U50:DTP:U=09kk`8YA@03W=>U5:DD008aYP:<D@:4409cSP:]E@:Ll`9kk`9:B@9BRP8aYP9:
J@8Q908ia`9Jb`8aQP9BRP8YA@9:B@92208aQP8YA@92:003<JHYIBUU008@PP8aYP8H``8@XP8H``8a
YP8H``8Q908H``8Hh`808088@@8H``8Hh`8@XP8@PP8H``8@PP800088@@@8H@03488H`aS30080808@
PPCoo`40007oo`005Ooo00<00?ooool00_oo0P00100P0`QQ0P000P0P0Q2R0PQ10P0P0PQQ0PQ10P0P
0Q220PQQ0P0P0Q220PQ10PQQ0PQ10Q2R0R441R4T0PQQ0QSS0S6V00<Q94Y9BTT00T880RUU0QS30SW7
0RU50TY90S6V0QS30R4T0Q2R0P0P0QSS112R0RUU0U[;0P0P0R4T0V]=0TYY0PQQ0S6600><DDYYBVT0
0Q2R0T8X0V]=0[gG0S6V0U:Z0^Ll0X@`0_oo0X@@0_oo0U:Z0_oo0[gG0^mM0U:Z0SWW0W_?0TY90U:Z
0U::0S6600><DG__Nnl00TY90T880Zee0SW70W_?0W__0XaA0W>^0V<<0U:Z0T8X0U[;0V]=0T8X0R44
0QSS0TY90T880SWW0T8X0SW70RU500=BRTY9BTT00Q220S660PQQ0Q220Q2R0PQQ0PQ10Q220P0P0Q22
0P000R440PQQ0Q2R11SS0P0P0QS30QSS0P0P0Q2R0QS300<@XQ2248800P0P0PQQ1?oo0@000Ooo000E
ool00`00ooooo`02ool2000402032642000202024:82244202022642244202024882264202024882
2442264224424:828@@68B@226426><2<JH00b4TBTU:B@02@PP2:FD26<<2>LL2:DD2BTT2<JH26<<2
8B@24:8202026><44:82:FD2F//202028B@2Jdd2BVT22642<HH00haABVU:J@024:82@RP2Jdd2_ML2
<JH2DZX2ic`2Q302ool2Q102ool2DZX2ool2_ML2ked2DZX2>NL2Nll2BTT2DZX2DXX2<HH00haANnmk
k`02BTT2@PP2[GD2>LL2Nll2Nnl2S542Ljh2H``2DZX2@RP2F//2Jdd2@RP28@@26><2BTT2@PP2>NL2
@RP2>LL2:DD00e::BTU:B@024882<HH2264248824:822642244248820202488200028@@226424:84
6><202026<<26><202024:826<<00a2R488@PP0202022644ool10001ool001Goo`03003ooooo00;o
o`88@@8H``88H@88@@036<<@XQ2R008@PP88@@88H@80808Hh`88H@@@PP80008@XP8@PP@8@@8Q908Q
108@PP@0808Q90@@XP88H@036><8H@QQ008aYP92:08Hh`8Q1092:08@PP8Q108H``8Q908YA@8ii`88
H@8@PP8Q108H``92208ii`8@XP9:J@92208@PP8Q1003Jfe224880088@@9S3092:0:]E@:440:4<0;W
?09220;oo`9c[P;oo`:Ld`;oo`9BRP;g_P8ii`8aQP:<L@@aYP92209kc`03W==kcg_?009kc`9BRP9S
309:B@:<D@9S30:U=08aYP9BZP92:09kc`9220AS309:J@8ia`8ii`8ia`@Q909Jj`8H``03BVTQ924T
009220808088H@8080@Hh`8aQP8H``8Hh`8Q108H``@@XP8@PP8Q10@@PP8@XP88@@88H@@080036><8
H@QQ00@@PPCoo`40007oo`005Ooo00<00?ooool00_oo0PQ10QS30PQQ0PQ100<H`a2R4:800Q220PQ1
0PQQ0P0P0QSS0PQQ11220P000Q2R0Q2210Q10R4T0R440Q22100P0R4T112R0PQQ00<Hh`QQ26400S6V
0T8X0QSS0R440T8X0Q220R440QS30R4T0RU50SWW0PQQ0Q220R440QS30T880SWW0Q2R0TYY0T880Q22
0R4400=[KD88@PP00PQ10V<<0T8X0ZeE0X@@0X@`0^Ll0T880_oo0W>^0_oo0YcC0_oo0U::0_Nn0SWW
0S660Xaa136V0T880W_?00>Ldg_?Nll00W_?0U::0V<<0TY90XaA0V<<0ZDd0S6V0U:Z0T8X0W_?0T88
16<<0TYY0SW70SWW0SW7124T0U[[0QS300=:JB4T8B@00T880P0P0PQQ0P0P11SS0S660QS30QSS0R44
0QS3112R0Q220R4411220Q2R0PQ10PQQ100P00<Hh`QQ264011221?oo0@000Ooo000Eool00`00oooo
o`02ool202026<<2244226400a226<<H``020204488224446><200026><26<<28@@26<<24882<JH2
:DD2:FD48@@26<<24:826><24:8226400aSS8B@Q90024:82>NL28B@2:FD24:826><26<<22442<HH2
8B@46><2:DD26><20202:FD2F^/26<<20202F//2>LL2<HH00f<<:DDYA@024:82:DD2BTT2U982Hb`2
Jdd2ool2BTT2ool2_OL2ool2Q102ool28@@2]KH2Hb`2@RP2]KH2<HH2DZX2<HH2Q3000iBBQ1244002
YC@2BTT2Jfd2DXX2S742Jdd2DXX2Lhh2>LL2>NL2@PP2@RP28B@2>LL2DXX24882@RP2DZX2<HH22642
@RP26<<00bU58B@Q9002:DD226426><2:FD26><26<<2:FD22642:DD24:826><28@@200026<<24:82
00026<<248842442000248800`Q1000000026<<22644ool10001ool001Goo`03003ooooo00;oo`80
808H``88@@88H@03488H`aS3008080@@PP88@@@Hh`80008Hh`8H``8Q108H``8@PP8aYP8YA@8YI@@Q
108H``8@XP8Hh`8@XP88H@036><Q924T008@XP8ii`8Q908YI@8@XP8Hh`8H``88@@8aQP8Q90@Hh`8Y
A@8Hh`80808YI@9Jj`8H``80809Jb`8ia`8aQP03H``YABU5008@XP8YA@9:B@:DTP9S;09[C@;oo`9:
B@;oo`:mm`;oo`:440;oo`8Q10:e]P9S;092:0:e]P8aQP9BZP8aQP:4<003U9:448@@00:U=09:B@9[
K@9BRP:<L@9[C@9BRP9cSP8ia`8ii`922092:08Q908ia`9BRP8@PP92:09BZP8aQP88H@92:08H``03
:DDQ924T008YA@88H@8Hh`8YI@8Hh`8H``8YI@88H@8YA@8@XP8Hh`8Q1080008H``8@XP80008H``8@
PP@8@@80008@PP0324400000008H``88H@Coo`40007oo`005Ooo00<00?ooool00_oo1Q220P0P00<H
h`0P02000PQQ0P000PQQ10Q10Q2R0P0P0QS30Q2R11221P0P0Q220P000Q220S660S6V0R4T0Q2R0Q22
00<Q91SS6><00R4T0P0P0QSS0PQQ11SS0TY90RUU0Q220PQ10RUU0QS30Q220P000S660Q2R0SW70RU5
0R4T0SWW0PQ10RUU00=Jbc6V<JH00S6V0P0P0RU50W_?0RU50SW70_Nn0TYY0_oo0U::0_oo0S6V0_oo
0U[;0]Jj0U[[0U[;0YBB16]=0S6V0V]=00>LddYYBVT00W>>0X@`0V</0W>^0TYY0V<<0U::0TYY0V]=
0V<<0TYY0R4T0TY90QSS11S30QSS0SWW0T8X0RUU0QS30SW700<YAE[;F//00Q2R0S660QSS124411SS
0QS30PQ10QS30QSS0Q220R4T0QSS0PQ110QQ11220PQQ0Q220PQ100<8H@0P020010QQ1?oo0@000Ooo
000Eool00`00ooooo`02ool6488202000aSS0200800226420002264424424:8202026<<24:844886
0202488200024882<HH2<JH28B@24:8248800b4T6><Hh`028B@202026><226446><2BTT2:FD24882
2442:FD26<<248820002<HH24:82>LL2:DD28B@2>NL22442:FD00e[;<JHaYP02<JH20202:DD2Nll2
:DD2>LL2mkh2BVT2ool2DXX2ool2<JH2ool2F//2e[X2F^/2F//2U984Jdd2<JH2Jdd00icCBVU:J@02
Lhh2Q302Hb`2Ljh2BVT2H``2DXX2BVT2Jdd2H``2BVT28B@2BTT26><46<<26><2>NL2@RP2:FD26<<2
>LL00bU5F/]Jb`024:82<HH26><48@@46><26<<224426<<26><248828B@26><22444264448822642
488224400`QQ020080042644ool10001ool001Goo`8000?oo`808088@@80808@PP<8H@8@XP88@@@@
XP88H@@@PP8Q1088H@8@XP8@PP88@@8@PP8YA@8H``@8H@80008YI@8Q908Hh`8Q10036<<iacW7008H
h`@H``8YA@8Hh`8@XP8Q108YA@@8@@8@PP9BRP8Q108Hh`8@PP8aYP8H``8aYP8Hh`92208aQP8ia`03
BTU2248800@H``8aYP9BRP8@XP8Q90;>N@:<D@;oo`:me`;oo`:<D@;oo`8ia`;_O@9:J@8YA@9S308i
a`9kc`9BZP9c[P03S75:BDY9009BZP9Jj`9:J@9cSP9Jj`8aQP92:09S;09cSPAJj`9BRP8Q109Jj`8a
QP88@@8Q108aYP88H@8YA@8H``8YA@038@ABRU::008aQP8@PP8H``8Q108@PP8Hh`8H``8Hh`8Q10@Q
9080008Hh`8@XP8@PP8@XP80808@PP88H@8@PP8@XP<0808@PP88@@8080?oo`80007oo`005Ooo00<0
0?ooool00_oo0P0P0PQ10P0P0Q220`QQ0Q2R0PQ1112R0PQQ11220R440PQQ0Q2R0Q220PQ10Q220RU5
0QS310QQ0P000RUU0R4T0QSS0R4400<H`cW7>LL00QSS11S30RU50QSS0Q2R0R440RU510Q10Q220U::
0R440QSS0Q220S6V0QS30S6V0QSS0T880S660SW700=:BD88@PP011S30S6V0U::0Q2R0R4T0/ii0XaA
0_oo0[gG0_oo0XaA0_oo0SW70^mm0TYY0RU50V<<0SW70W_?0U:Z0W>^00><LDY9BTT00U:Z0U[[0TYY
0W>>0U[[0S660T8X0V</0W>>15[[0U::0R440U[[0S660PQ10R440S6V0PQQ0RU50QS30RU500<Q15::
DXX00S660Q220QS30R440Q220QSS0QS30QSS0R44124T0P000QSS0Q2R0Q220Q2R0P0P0Q220PQQ0Q22
0Q2R0`0P0Q220PQ10P0P1?oo0@000Ooo000Eool00`00ooooo`02ool224422642020226400`Q1488@
PP04488424426<<22442488426424:828B@24:8202028B@226426<<4:FD26<<26><226424:800dY9
<HHaQP026<<248864:826><28@@44:826<<22442:FD2>NL2:DD28@@24:82:DD28B@2>LL24882:DD2
8B@00e[[DXYBRP024882Jdd20202Jdd28B@2<JH2cWT2DXX2ool2Jdd2ool26<<2ool2Jfd2ool2Ljh2
:DD2S742BVT2Jdd2<HH2Jdd00f]]@PQ22002F//2DZX2Lhh2Ljh2Jdd2BVT2<JH2BTT2Hb`2BVT4>LL2
:FD28B@2<HH26<<26><22442>LL2:FD2<HH28@@00aS38@@Q10028@@26><402026<<26><24:826><2
8@@46><2020226444:820002020226484:800a220200800202026<<4ool10001ool001Goo`03003o
oooo00;oo`88@@88H@808088H@03244@PQ2200@@PP@8@@8H``88@@8@PP@8H@8@XP8Q908@XP80808Q
9088H@8H``@YI@8H``8Hh`88H@8@XP03BTTaQS66008H``8@PPH@XP8Hh`8Q10@@XP8H``88@@8YI@8i
i`8YA@8Q108@XP8YA@8Q908ia`8@PP8YA@8Q9003F^]BRU::008@PP9[C@80809[C@8Q908aYP;>N@9B
RP;oo`9[C@;oo`8H``;oo`9[K@;oo`9c[P8YA@:<L@9:J@9[C@8aQP9[C@03Jfe22488009Jb`9BZP9c
SP9c[P9[C@9:J@8aYP9:B@9S;09:J@@ia`8YI@8Q908aQP8H``8Hh`88@@8ia`8YI@8aQP8Q10036<<Q
1244008Q108Hh`@0808H``8Hh`8@XP8Hh`8Q10@Hh`808088H@@@XP8000808088H@P@XP034880800P
0080808H``Coo`40007oo`005Ooo00<00?ooool00_oo0P0P0Q2R0PQQ0PQ100<081224880100P0PQQ
0P000Q220PQQ100P0PQ10R440Q2R0QS30RU50PQ10QS30Q220PQ10QS30PQQ0SW70PQQ0Q2200<H`b44
8@@00RU50R440RUU0R440Q2R11S30R4T0PQQ0R440Q2R0RU50R440RU50Q22124T12U50PQ10SW70QSS
00=:BBUU:FD00QSS0U::0PQQ0YcC0T880V<<0]JJ0V]=0_oo0U:Z0_oo0U::0_oo0W>^0Ycc0V]=0R4T
0W_?0U[;0T880P0P0f<<0TY90W>^0V]]0TYY0W>>0SWW0R44148X0R4T0RUU0S6V0R4T11SS0QS30R4T
0Q220QSS0R4T0SW70R440QSS00<aQQS36<<00PQQ0QSS0RU50R440QS311SS0Q220PQQ0QSS0Q220QSS
0Q2R0Q220PQQ0Q2R0P0P0Q220P0P0PQ10Q220PQ10`000PQ10Q221?oo0@000Ooo000Eool00`00oooo
o`02ool202024:82264224400`0P488@PP0402022642000248822644020224428@@24:826<<2:DD2
24426<<2488224426<<22642>LL2264248800aS38@@Q1002:DD28@@2:FD28@@24:846<<28B@22642
8@@24:82:DD28@@2:DD248848B@4:DD22442>LL26><00dY9:FDYI@026><2DXX22642W=<2@PP2H``2
eYX2Jdd2ool2DZX2ool2DXX2ool2Ljh2W?<2Jdd28B@2Nll2F//2@PP20203H``2BTT2Ljh2Jfd2BVT2
Lhh2>NL28@@4@RP28B@2:FD2<JH28B@46><26<<28B@248826><28B@2>LL28@@26><00c666<<H``02
26426><2:DD28@@26<<46><2488226426><248826><24:82488226424:8202024882020224424882
2443000224424884ool10001ool001Goo`03003ooooo00;oo`80808Hh`@@PP030208H@QQ0080808@
XP8@PP88H@808088H@@@PP88@@8@XP808080008@PP8Hh`8H``8YA@8aQP8YA@8@PP88H@8YA@8Hh`03
8B@HhaSS008Q908Hh`8ia`8YA@88H@80808@PP8@XP8Q9080808@PP8aQP8YA@8aQP8YA@80008YA@8i
i`8aQP92208aQP8@XP03BTU2:48X008YI@8aQP8H``9kk`9S;09kc`:me`9BZP;og`9Jj`;oo`9S30;_
G@9:J@9kk`92209:B@9S309S;092208@PP9cSP03DZYBRU::009cSPABZP9Jb`8@PP8YI@8Hh`92:09:
B@8@XP8Q9092208ia`8YA@8Q108YA@8Q108Q9088@@8aYP8H``<0808Q908aQP8H``8Q108aYP8YI@8Q
1088@@8@PP8Q108080@@XP8@PP88@@@H``8@XP@08088H@8@XP88H@034:80800P0088H@88@@Coo`40
007oo`0000?oo`0000000P000ooo0P001?oo0P001Ooo00<00?ooool00_oo0P0P0QSS112200<080QQ
26400P0P0Q2R0Q220PQQ0P0P0PQQ11220PQ10Q2R0P0P0P000Q220QSS0QS30RU50S660RU50Q220PQQ
0RU50QSS00<Q91SS6><00R4T0QSS0SW70RU50PQQ0P0P0Q220Q2R0R4T0P0P0Q220S660RU50S660RU5
0P000RU50SWW0S660T880S660Q2R00=:BD8X@RP00RUU0S660QS30W__0V</0W_?0[gG0U:Z0_oO0U[[
0_oo0V<<0^mM0TYY0W__0T880TY90V<<0V</0T880Q220W>>00=BZU::DXX00W>>15:Z0U[;0Q220RUU
0QSS0T8X0TY90Q2R0R4T0T880SW70RU50R440RU50R440R4T0PQ10S6V0QS30`0P0R4T0S660QS30R44
0S6V0RUU0R440PQ10Q220R440P0P112R0Q220PQ111S30Q2R100P0PQQ0Q2R0PQQ00<@XP0P02000PQQ
0PQ11?oo0@000Ooo0003ool01@00oooooooo00000_oo00@00?ooool000;oo`03003ooooo00;oo`03
003ooooo00;oo`80808@XP80008080<@XP8H``8@XP8@PPH8H@8@PP8H``88H@88@@8Q9088H@8@XP80
8088H@80808@PP8H``8@PP808088H@<Q108ii`8Q108Hh`8YA@8ii`8Hh`88@@8@XP@aYP8YI@80808H
``8Hh`9:J@8Q90@Hh`8H``8@PP92:08Q908YA@03:FEBZU:Z008Hh`8@XP9:J@9cSP8YA@92:0:]E@9B
ZP;gWP9kc`;oo`92:0;oo`9Jj`9S;0A2209c[P8YI@92208Q909S;003F^/YIBUU009BRP9:B@92208i
a`8aYP8@XP9BZP@aQP88H@8YA@9BRP8aYP92208aYP8aQP8Hh`8YI@8Hh`88@@88H@88@@034:88@@Q1
008Hh`@Q908Hh`8H``88@@88H@8@PP@Hh`@08088@@80008@XP88H@8@XP8H``88@@8@XP8H``8@XP03
2640000000808088@@Coo`40007oo`000ooo00D00?ooooooo`0000;oo`04003ooooo0002ool00`00
ooooo`02ool20003ool202024:82000202034:826<<24:824886264248826<<2264224428B@22642
4:8202022642020248826<<24882020226438@@2>NL28@@26><2:DD2>NL26><224424:84<JH2:FD2
02026<<26><2BVT28B@46><26<<24882@RP28B@2:DD00bUUDZYBZP026><24:82BVT2Lhh2:DD2@RP2
[ED2DZX2mih2Nll2ool2@RP2ool2F^/2Hb`4@PP2Ljh2:FD2@PP28B@2Hb`00e[[:FDYI@02DXX2BTT2
@PP2>LL2<JH24:82DZX4<HH22642:DD2DXX2<JH2@PP2<JH2<HH26><2:FD26><22442264224400a2R
2448@@026><48B@26><26<<22442264248846><40202244200024:8226424:826<<224424:826<<2
4:800`QQ0000000202022443ool20001ool000?oo`05003oooooool00002ool01000ooooo`000_oo
00<00?ooool00_oo00<00?ooool00_oo0P0P0PQQ0Q220PQQ00<@XP0P02000PQ10P001PQQ0PQ11244
0QSS0P0P0PQQ0R4T0RU50Q2R0PQQ0R4T0Q2R0PQQ0Q2R11SS0QS30aSS1Q2R0PQQ0RUU11220Q2R0R44
0R4T0QSS0PQQ0Q2R0SW70QSS0S6V0QS30TY90S6V0RU50QSS0Q2200=JjbU5:DD00Q220QSS0R440V<<
0Q2R0T8X0ZeE0R440^mM0V</0_oo0S6V0_oo0Q220Zee0U:Z0QS30V</0S660RUU0SW70W>>0c660U::
0T880SW70T880S660RU50SW70S660QSS0RU50QS30RU50Q2R0S6V0R4T0Q2R0RUU0R440Q2R0QS30QSS
0PQQ00<@XQS36<<00R4T0P000R440Q2R0QSS0R4T0R440Q2R0QSS0Q2R10QQ0QSS0QS31Q220Q2R0P00
112R0Q2200<8H@0000000P0P0PQ11?oo0@000Ooo0003ool01@00oooooooo00000_oo00@00?ooool0
00;oo`03003ooooo00;oo`03003ooooo00;oo`808088H@8@PP88H@034:80800P0088@@8000H8H@88
@@@Q108Hh`808088H@8Q908YA@8@XP88H@8Q908@XP88H@8@XP@Hh`8H``<Hh`H@XP88H@8YI@@@PP8@
XP8Q108Q908Hh`88H@8@XP8ia`8Hh`8aYP8H``9:B@8aYP8YA@8Hh`8@PP03F^/YABU5008@PP8Hh`8Q
109S308@XP92:0:]E@8Q10;_G@9S;0;oo`8aYP;oo`8@PP:]M@9BZP8H``9S;08aQP8YI@8ia`9cSP<a
QP9BRP92208ia`92208aQP8YA@8ia`8aQP8Hh`8YA@8H``8YA@8@XP8aYP8Q908@XP8YI@8Q108@XP8H
``8Hh`88H@034:8H`aS3008Q9080008Q108@XP8Hh`8Q908Q108@XP8Hh`8@XP@8H@8Hh`8H``H@PP8@
XP8000@@XP8@PP032640000000808088@@Coo`40007oo`0000Coo`00000000?oo`04003ooooo0002
ool01000ooooo`001?oo00<00?ooool00_oo0PQQ100P0Q2R00<H``Q124400P0P0P000P0P0PQ10PQQ
0PQ10PQQ0PQ10P0P0QS30P0P0QS30PQ10PQQ0PQ10Q220QS30PQ10P0P0QS30RUU0Q2200<@XQS36<<0
0Q2R0RUU0RU50PQQ0T8X0P000Q2R0QS30RU50Q2R0RUU0Q2R0R440RU50SW70R4T0QSS0T8X0QSS0R4T
0U::0Q2R00=S;488@PP00QSS0R4T0RUU0T880RU50R440/HH0SWW0^Ll0V]=0_oo0U[;0_oo0S660]kK
0SWW0S660W>^0T880TYY0U::0V</00<YAD88@PP00U:Z0TYY0SW70QSS0QS30R440S6V0R4T0Q220PQQ
0QS30R4T0R440Q220T880R440PQ10R4T0QSS0Q2R0Q220P0000<H`c6V<JH00Q2R0Q220PQQ0R440PQQ
0T880R4T0Q220PQ10Q220P000PQQ112220QQ0PQ10P0P0PQ10a2R0PQ10QS30PQQ1?oo0@000Ooo0003
ool00`00ooooo`02ool20004ool20005ool00`00ooooo`02ool24:82244202026<<00a2202008002
6><2488426426><248822642244202026<<2020226426<<202026><28@@248826><26<<26><24:83
6<<2:FD26<<4020226428@@248828@@24:82:FD248822444488226428B@4<HH2@PP224428@@2DXX2
:DD3>NL2:FD2<HH2:FD2BTT26><2BTT2YC@2BTT2mkh2BVT2ool2Nll2ked2DXX2YA@2BVT2<HH2@RP4
<JH24:82BTT36<<2@RP2:DD2>NL26><22642:DD2BVT202026<<2<JH28@@24882<HH2>LL2:FD28@@2
6><248828B@226428B@3488224428@@2488226428@@26><22642244248826<<2264248826<<20002
020224426><24:8248828B@24882264548840204ool10001ool001Goo`03003ooooo00;oo`8@XP88
@@80808H``034880800P008Hh`8@PP@8H@8Hh`8@PP88H@88@@80808H``808088H@8H``80808Hh`8Q
108@PP8Hh`8H``8Hh`8@XP<H``8YI@8H``@08088H@8Q108@PP8Q108@XP8YI@8@PP88@@@@PP88H@8Q
90@aQP922088@@8Q109BRP8YA@<ii`8YI@8aQP8YI@9:B@8Hh`9:B@:U=09:B@;g_P9:J@;oo`9kc`;_
G@9BRP:U509:J@8aQP92:0@aYP8@XP9:B@<H``92:08YA@8ii`8Hh`88H@8YA@9:J@80808H``8aYP8Q
108@PP8aQP8ia`8YI@8Q108Hh`8@PP8Q9088H@8Q90<@PP88@@8Q108@PP88H@8Q108Hh`88H@88@@8@
PP8H``88H@8@PP8H``8000808088@@8Hh`8@XP8@PP8Q908@PP88H@D@PP@080Coo`40007oo`005Ooo
00<00?ooool00_oo0PQ10P000PQQ0PQ100<8HA2248800PQQ0QS30Q220PQQ0P0P0QS30PQ10P0P0Q2R
0SW710QQ0PQ10Q220PQ10P0P0Q220P000RUU0QSS0PQQ0P0000<8@A2R4:800RU50R440PQ112440PQQ
0Q2R0QSS0P000RU50Q220S660Q2R0QS312440QSS0T880R4T0SW70R4T0T8800<H`e[;F//00QS30RU5
0SW70W__0R440RU50Zee0U[;0^mM0TY90_oo0Xaa0/Hh0TYY0[gg0V</0S6V0X@@0TYY0T880Q220U::
00<@PS6V<JH00R4T0SWW0R4T0R440QSS0RUU0QSS0PQQ0R440P0P0SWW0RUU0RU50PQQ0QSS0R440PQ1
0QS30QSS0Q2R0R4T0PQ100<HhaS36<<00P0P0PQ10QS30QSS0S6V0S660Q220PQQ0P0P0Q2R0PQ1112R
0P0P0Q2R0Q220PQQ11S3100P0a220P0P0PQ10Q221?oo0@000Ooo000Eool00`00ooooo`02ool22442
0002264224400`QQ488@PP0226426<<24882264202026<<2244202024:82>LL42642244248822442
020248820002:FD26><2264200000`Q14:8@XP02:DD28@@224448@@226424:826><20002:DD24882
<HH24:826<<48@@26><2@PP28B@2>LL28B@2@PP00aS3F/]Jb`026<<2:DD2>LL2Nnl28@@2:DD2[GD2
F//2ked2BTT2ool2S742aSP2BVT2_OL2Hb`2<JH2Q102BVT2@PP24882DXX00a22<JHaYP028B@2>NL2
8B@28@@26><2:FD26><226428@@20202>NL2:FD2:DD226426><28@@224426<<26><24:828B@22440
0aSS6<<H``02020224426<<26><2<JH2<HH24882264202024:8224444:8202024:82488226446<<4
02034882020224424884ool10001ool001Goo`03003ooooo00;oo`H8@@D8H@8080@8@@@8H@8H``80
0088@@@H``88H@80008@XP8@PP88H@8YA@8Hh`8@PP8Q9088@@DQ1088H@8Q908Q1088H@8@PP8H``8H
h`8ii`@Q908H``8@XP88@@@Q908YI@8YA@8@PP8H``8@XP8aYP8ii`8Hh`03:FES36<<0092208ii`8@
PP9S308aQP8YI@:4<09S30;gWP9BZP;oo`9220;Nf`9[K@:Ll`92208Q109cSP8aQP8ii`8@PP9:B@03
:DD0800P008ia`88@@8@PP8YI@8H``@Q908aQP88@@@YA@@8H@8@XP80808@PP88@@80808@PP8Q108a
YP8H``030208H@QQ00@YA@88@@8@XP8H``8@XP8@PP8H``88@@@H``88H@8@XP88H@88@@88H@@8@@88
H@@H``8@PP03244@PQ2200@8H@Coo`40007oo`005Ooo00<00?ooool00_oo1PQ11@QQ0P0P10Q110QQ
0QS30P000PQ111S30PQQ0P000Q2R0Q220PQQ0RU50QSS0Q220R4T0PQ11B440PQQ0R4T0R440PQQ0Q22
0QS30QSS0SWW124T0QS30Q2R0PQ1124T0RUU0RU50Q220QS30Q2R0S6V0SWW0QSS00<YIF<<H``00T88
0SWW0Q220V<<0S660RUU0X@`0V<<0_NN0U:Z0_oo0T880]kK0V]]0Ycc0T880R440W>>0S660SWW0Q22
0TY900<YA@0P02000SW70PQ10Q220RUU0QS3124T0S660PQ112U510QQ0Q2R0P0P0Q220PQ10P0P0Q22
0R440S6V0QS300<080QQ264012U50PQ10Q2R0QS30Q2R0Q220QS30PQ111S30PQQ0Q2R0PQQ0PQ10PQQ
10Q10PQQ11S30Q2200<8@A22488010QQ1?oo0@000Ooo000Eool20003ool226446><348824:824882
264424426<<20002020248822442020248842642020248822442020248828@@22442020224434:82
48826><48B@24:8248848@@448844:8424424:826><26<<2<HH2>NL22642@RP202000`QQ<JHaYP02
>LL2>NL26><2:FD28B@2BTT2W=<2DZX2g_/2Jfd2ool2@PP2ool2BTT2F^/2@RP2<HH2BVT2@PP2<JH2
6><2@RP00bUU2448@@02@PP24:824882<HH26><2:FD28@@24:82>NL2:DD28@@28B@24:8448822642
6><28@@24:826><28@@3264200046<<224426><26<<22642488424424884264248826<<426426<<2
264224446><248800b446><Hh`028@@20203ool20001ool001Goo`03003ooooo00;oo`88H@@Hh`<@
PP8@XP8@PP88H@@8@@8H``800080808@PP88@@80808@PP@8H@80808@PP88@@80808@PP8Q1088@@80
8088@@<@XP8@PP8Hh`@Q908@XP8@PP@Q10@@PP@@XP@8@@8@XP8Hh`8H``8aQP8ii`88H@92:0808003
264aYS6V008ia`8ii`8Hh`8YI@8Q909:B@:Ld`9BZP;Nn`9[K@;oo`9220;oo`9:B@9Jj`92:08aQP9:
J@92208aYP8Hh`92:003:FD8@@Q10092208@XP8@PP8aQP8Hh`8YI@8Q108@XP8ii`8YA@8Q108Q908@
XP@@PP88H@8Hh`8Q108@XP8Hh`8Q10<8H@8000@H``88@@8Hh`8H``88H@8@PP@8@@8@PP@8H@8@PP8H
``@8H@8H``88H@88@@@Hh`8@PP038@@HhaSS008Q108080Coo`40007oo`005Ooo00<00?ooool00_oo
0PQQ0Q220PQ10PQQ00<Q112R4:800QS310Q10QS30QSS0P0P0Q2R100P0PQ10Q220QS30Q2R11SS0PQQ
0Q220PQ10Q2R0QSS0Q2R0PQQ00<Q90Q124400R440P0P0R4411220R440QS31Q220RU50PQQ0QS30Q2R
0R4T0RUU0QS30SWW12U50SWW0PQQ0aS30PQQ0RU50S6V0U::0S660RUU0/ii0Q2R0]kk0V<<0_oo0W__
0_oo0QS30[FF0U:Z0RU50U::0SWW0QS30RU50S6V00<Hh`0P02000R440T880PQ10Q2R0R4T0S660QS3
0R440R4T0R440R4T0Q220Q2R11S30R440QSS0RU50QSS0PQ10RU50RUU00<8@@QQ264011SS0PQQ0QSS
0PQ10PQQ0R4T0Q2R10QQ0PQ10QS30Q220P0P11S30Q2R0P000PQ10P000Q2R0Q2200<8H@Q1244010Q1
1?oo0@000Ooo000Eool00`00ooooo`02ool226424882244226400b444:8@XP026<<424426<<26><2
02024:840202244248826<<24:846><22642488224424:826><24:8226400b4T2448@@028@@20202
8@@448828@@26<<64882:DD226426<<24:828B@2:FD26<<2>NL4:DD2>NL226436<<22642:DD2<JH2
DXX2<HH2:FD2cWT24:82g_/2H``2ool2Nnl2ool26<<2]IH2DZX2:DD2DXX2>NL26<<2:DD2<JH00aSS
020080028@@2@PP224424:828B@2<HH26<<28@@28B@28@@28B@248824:846<<28@@26><2:DD26><2
2442:DD2:FD00`Q12648H@046><226426><2244226428B@24:84264224426<<2488202046<<24:82
0002244200024:8248800`QQ2448@@042444ool10001ool001Goo`03003ooooo00;oo`8@PP88@@80
008080032440800P0088@@88H@8@PP80808@PP88@@88H@88@@8080800080808H``8@XP88H@8@PP80
00@8H@80808@XP80008@XP03244HhaSS0088@@8YA@8@PP8H``88H@8H``8@XP88H@8@PP8H``88H@8H
h`8H``80808YI@8YA@P@PP8Hh`8aYP03@RPYABU5008H``8aYP92209:B@8Hh`92:0:DTP8Q10;oo`9J
j`;oo`9BRP;g_P8Q90:Ld`8aQP92209Jb`9S;08YA@8aYP8ia`03020@PQ22009:J@8Hh`8@XP88@@8@
PP8H``8YI@8080@YI@88@@8@XP88@@8Q10@8@@8@XP8H``8Q1088H@@@PP03264@PQ22008@PP@8H@88
@@@@XP8Hh`8@XP8@PP88@@808088@@H@PP88H@8H``88@@88H@8@PP@8@@036><0800P0080808@PPCo
o`40007oo`005Ooo00<00?ooool00_oo0Q220PQ10P000P0P00<8@@0P02000PQ10PQQ0Q220P0P0Q22
0PQ10PQQ0PQ10P0P0P000P0P0QS30Q2R0PQQ0Q220P0010QQ0P0P0Q2R0P000Q2R00<8@ASS6><00PQ1
0RU50Q220QS30PQQ0QS30Q2R0PQQ0Q220QS30PQQ0QSS0QS30P0P0RUU0RU521220QSS0S6V00=2:2U5
:DD00QS30S6V0T880TY90QSS0T8X0YBB0R440_oo0U[[0_oo0U::0_Nn0R4T0YcC0S660T880U[;0V</
0RU50S6V0SW700<0812248800TYY0QSS0Q2R0PQ10Q220QS30RUU0P0P12UU0PQ10Q2R0PQ10R4410Q1
0Q2R0QS30R440PQQ112200<8HA2248800Q2210QQ0PQ1112R0QSS0Q2R0Q220PQ10P0P0PQ11Q220PQQ
0QS30PQ10PQQ0Q2210Q100<Hh`0P02000P0P0Q221?oo0@000Ooo000Eool00`00ooooo`02ool26<<2
48826<<24:800aSS2648H@020202264224420202244426426<<2264200024:82:DD26><226428B@2
6><2264248826><20202244226400b4T0200800202026><2488226424882264248826><224446><2
:DD226428B@46<<26><2:DD26><26<<22643<HH28@@26<<2:DD2BTT2:FD24:82:DD2S742@PP2kgd2
>NL2ool2F//2ool2@RP2U982Jdd2>NL2F//44:82:FD2@PP00aSS8@@Q1002>LL26<<24:8248824:82
6><26<<226446<<28B@2>LL28B@24882264248822642<HH28B@226426<<2:DD00a22000000024882
26424882000626424:820202244202020002244226422442488224426<<24:822642244248800a2R
6<<H``044:84ool10001ool001Goo`03003ooooo00;oo`8H``8@PP8H``8@XP036><8H@QQ00808088
H@88@@808088@@@8H@8H``88H@80008@XP8YA@8Hh`88H@8Q908Hh`88H@8@PP8Hh`808088@@88H@03
8B@0800P0080808Hh`8@PP88H@8@PP88H@8@PP8Hh`88@@@Hh`8YA@88H@8Q90@H``8Hh`8YA@8Hh`8H
``88H@<aQP8Q108H``8YA@9:B@8YI@8@XP8YA@:<L@9220;_O@8ii`;oo`9Jb`;oo`92:0:DTP9[C@8i
i`9Jb`@@XP8YI@9220036><Q1244008ia`8H``8@XP8@PP8@XP8Hh`8H``88H@@H``8Q908ia`8Q908@
PP88H@8@PP88H@8aQP8Q9088H@8H``8YA@0348800000008@PP88H@8@PP8000H8H@8@XP808088@@80
80800088@@88H@88@@8@PP88@@8H``8@XP88H@88@@8@PP034:8H`aS300@@XPCoo`40007oo`005Ooo
00<00?ooool00_oo0R440Q2R0QS30Q2R00<8HA2248800Q2R0PQQ0P0P0PQ110QQ0P0P0QSS0QS31122
0Q2R0Q220Q2R0R4T0Q2R0PQ10PQQ0R440Q2R0P0P0aS30R4T0Q220PQQ0Q220Q2R0PQ10P0P0PQ10S6V
0QS30P0P0PQQ11S30Q220RUU0R440T880RUU11SS0Q220`Q10SW70QS30Q220S6V0SW70PQ10T8X0ZeE
0SW70]kk0W__0_oo0U[[0^LL0T8X0]JJ0S660U[;0V]]0QSS0QS30Q220T8X00<@XS66<HH00R440PQ1
0R4T0Q2R0RU50Q2R124T0PQQ0QS30PQ110QQ0QS30Q2R0PQQ12440RUU0R4T0Q220QSS00<8HA224880
10QQ0R4410QQ0Q220PQ10QS30PQQ0P0P0PQQ0QS30R440PQQ0Q2R0R44112R0PQQ0PQ110QQ00<H`a2R
4:800Q2R0P001?oo0@000Ooo000Eool00`00ooooo`02ool28@@24:826<<24:800`QQ488@PP024:82
264202022444264202026><26<<448824:8248824:828B@24:82244226428@@24:8202036<<28B@2
4882264248824:82244202022442<JH26<<2020226446<<24882:FD28@@2@PP2:FD46><248832442
>LL26<<24882<JH2>LL22442@RP2[ED2>LL2g_/2Nnl2ool2F^/2ia`2@RP2eYX2<HH2F//2Jfd26><2
6<<24882@RP00a2R<HHaQP028@@224428B@24:82:DD24:848B@226426<<2244426426<<24:822644
8@@2:FD28B@248826><00`QQ488@PP0426428@@42642488224426<<22642020226426<<28@@22642
4:828@@44:822642244426400aS34:8@XP024:820004ool10001ool001Goo`8000?oo`@8@@8@PP88
@@034:8@PQ22008080@8H@80808@XP88@@808088@@8Q108@PP88H@8Hh`8H``8080@H``88@@80808@
PP@8H@8@PP03020H`aS300@8@@8@PP8Q10800088H@8@XP88H@8Hh`88H@88@@8Hh`8ia`8@XP8aYP88
@@8Hh`H8@@8Q1088@@034:8aYS6V008YA@8Q908YA@8ia`8YA@9220:U509220;F^P9S;0;oo`9220;_
O@9[C@:U=08Q909:B@9Jj`8aYP8Hh`8@XP8ii`03:FD@XQ2R008YA@88H@8Hh`8@PP8H``8Hh`8Q10@H
h`8@PP8aQP@@PPH@XP8H``88H@88@@8H``88H@8Q1003244@XQ2R0088@@88H@8H``@@PP8H``88H@8@
PP8080@8H@80808H``8@XP80808@PP@H``@8@@@080032440800P00@8H@?oo`80007oo`005Ooo00<0
0?ooool00_oo10Q10Q220PQ100<@XQ2248800P0P10QQ0P0P0Q2R0PQ10P0P0PQ10R440Q220PQQ0QSS
0QS30P0P11S30PQ10P0P0Q2210QQ0Q2200<081S36<<010Q10Q220R440P000PQQ0Q2R0PQQ0QSS0PQQ
0PQ10QSS0SW70Q2R0S6V0PQ10QSS1PQ10R440PQ100<@XS6V<JH00RU50R4T0RU50SW70RU50T880ZDD
0T880]Jj0V</0_oo0T880^mm0V]=0ZDd0R4T0TY90U[[0S6V0QSS0Q2R0SWW00<YIA2R4:800RU50PQQ
0QSS0Q220QS30QSS0R4411SS0Q220S6611221Q2R0QS30PQQ0PQ10QS30PQQ0R4400<8@A2R4:800PQ1
0PQQ0QS311220QS30PQQ0Q220P0P10QQ0P0P0QS30Q2R0P0P0Q2211S310Q1100P00<8@@0P020010QQ
1?oo0@000Ooo000Eool00`00ooooo`02ool2264624400`0002008002244402024882020248824:82
26424882264224426<<24:8224422642020224424:826><202028B@26><00a22020080024:820204
24424:86244248842642:FD28B@26><24:8202024:82244200024882:DD26><56<<26><20002BTT2
>LL2<JH2W=<2@RP2_OL2DZX2ool2Jdd2g_/2F//2Nnl2>LL2:FD2@RP2<HH24882:DD78@@200022642
24426<<28B@24:82:FD28@@24:8248828B@22642:DD28B@202026<<202026><26<<28@@26<<00a2R
8@@Q10024:822642244202020004244202026><22644244226442442488224422644488526442442
6<<4ool10001ool001Goo`03003ooooo00;oo`88H@H8@@030000800P0088@@@0808@PP80808@PP8@
XP88H@8@PP88H@88@@8H``8@XP88@@88H@808088@@8@XP8Hh`80808Q908Hh`034880800P008@XP80
80@8@@8@XPH8@@8@PP@8H@8YI@8Q908Hh`8@XP80808@XP88@@80008@PP8YA@8Hh`DH``8Hh`80009:
B@8ia`8aYP:Ld`92:0:mm`9BZP;oo`9[C@;Nn`9Jb`9kk`8ia`8YI@92:08aQP8@PP8YA@LQ10800088
H@88@@8H``8Q908@XP8YI@8Q108@XP8@PP8Q9088H@8YA@8Q9080808H``80808Hh`8H``8Q108H``03
4:8Q1244008@XP88H@88@@80808000@8@@80808Hh`88H@@8@@88H@@8@@8@PP88@@88H@@@PPD8H@@8
@@8H``Coo`40007oo`005Ooo00<00?ooool00_oo0Q2R12440a2R0QS30P000PQQ0P000PQQ112R0P0P
0PQQ0Q220PQ10PQQ0P0P0QS31Q220PQ10PQQ0Q2R0P000PQQ0a2R0PQQ112R11220QS30P000Q220QS3
0P0P0Q220QSS0P0P0PQQ0Q220Q2R0SW70QS30PQQ0RU50R4T0Q2R0QSS00<Q92UU:FD00R440Q220QS3
0TY90RU50R440W>>0S660/Hh0TY90_oo0V]=0^mM0U[[0Xaa0RUU0QS30TYY0SWW0T8X0RU50b440RU5
0QSS0Q2R11220P0P0Q2R0QS30PQQ0PQ10RU50QS30PQ10P0P0Q220QSS0PQQ0RU50Q2R0Q220QSS11S3
00<@PQ2R4:800P000PQQ0P0P0Q2R10Q10PQQ0P0P112R10QQ0PQ10P0P0PQQ0QS30PQQ0QS30Q2R0QS3
0Q2R0Q2200<H`a2248800PQQ0Q221?oo0@000Ooo000Eool00`00ooooo`02ool24:848@@34:826<<2
00022642000226444:820202264248822442264202026<<64882244226424:82000226434:822644
4:8448826<<2000248826<<2020248826><20202264248824:82>LL26<<22642:DD28B@24:826><0
0b4T:FDYI@028@@248826<<2BTT2:DD28@@2Lhh2<HH2aSP2BTT2ool2Jdd2ked2F^/2S742:FD26<<2
BVT2>NL2@RP2:DD38@@2:DD26><24:84488202024:826<<226422442:DD26<<22442020248826><2
2642:DD24:8248826><46<<00a224:8@XP020002264202024:842442264202044:84264224420202
26426<<226426<<24:826<<24:8248800aS3488@PP0226424884ool10001ool001Goo`03003ooooo
00;oo`8@PP8Hh`8@PP<H``8@PP@8@@88H@80808H``8YA@8Q108@XP88@@8@PP88@@80808@XP8Hh`88
H@88@@800088@@@@PP8Hh`8@PP03264Q12440088@@8@PP8@XP88@@@8H@88@@808088@@8@PP@8H@8@
PP@@XP8ii`8YA@80808@PP88H@8YA@8Q9003:DDiacW7008aYP808092:09BRP8ii`8@XP9[C@8Q10:e
]P8YA@;oo`8aQP;og`9:J@:D/P8Hh`88H@9Jj`8YI@8aYP8Hh`8YA@03244aQS66008YI@80008Q108@
XP8@PP88@@8H``8Hh`8@XP8@PP8Q108@XP8YA@80808Q908@PP8H``8Hh`8H``80808H``8@PP034:8@
PQ22008@PP88H@@8@@8@PP88H@808088H@88@@8080800088H@8H``88H@88@@8@PP8@XP88@@88H@8@
PP@8H@036<<8H@QQ008Hh`8@XPCoo`40007oo`005Ooo00<00?ooool00_oo0Q220QSS0Q220aS30Q22
10Q10PQQ0P0P0QS30RU50R440Q2R0PQ10Q220PQ10P0P0Q2R0QSS0PQQ0PQ10P000PQ111220QSS0Q22
00<8HB448@@00PQ10Q220Q2R0PQ110QQ0PQ10P0P0PQ10Q2210QQ0Q22112R0SWW0RU50P0P0Q220PQQ
0RU50R4T00<YACW7>LL00S6V0P0P0T8X0U::0SWW0Q2R0V]=0R440[Ff0RU50_oo0S660_oO0TYY0YBb
0QSS0PQQ0U[[0RUU0S6V0QSS0RU500<8@C66<HH00RUU0P000R440Q2R0Q220PQ10QS30QSS0Q2R0Q22
0R440Q2R0RU50P0P0R4T0Q220QS30QSS0QS30P0P0QS30Q2200<@XQ2248800Q220PQQ10Q10Q220PQQ
0P0P0PQQ0PQ10P0P0P000PQQ0QS30PQQ0PQ10Q220Q2R0PQ10PQQ0Q2210QQ00<H``QQ26400QSS0Q2R
1?oo0@000Ooo000Eool00`00ooooo`02ool2000226424:8202000`Q1020080026<<202026<<24:82
244248826><26<<44:82020426426><224424:8226424882264200026<<226400a2R6><Hh`026<<2
4:82488200024:826><226426><26<<2264248826<<200026><426428B@44:8248826><26<<00`0P
:DDYA@026><4:DD2@PP2<JH2>LL2Lhh22642kgd2BVT2ool2F//2W=<2:DD2S542<JH26<<2@RP28@@2
:FD2<HH2:DD00b44:DDYA@02488224428B@2020224426><24:820202264224426<<224426<<26><2
4882244448824:828B@2000202000a2R2648H@0226424:8224424882000226424882020224420002
26426<<26><248820202488402022442020226420203000202022444ool10001ool001Goo`03003o
oooo00;oo`800088H@8@XP8080032440800P008H``80808H``8@XP88@@8@PP8Hh`8H``@@XP8080@8
H@8Hh`88@@8@XP88H@8@PP88H@80008H``88H@034:8HhaSS008H``8@XP8@PP80008@XP8Hh`88H@8H
h`8H``88H@8@PP8H``80008Hh`@8H@8Q90@@XP8@PP8Hh`8H``03020YABU5008Hh`@YA@92208aYP8i
a`9cSP88H@;_O@9:J@;oo`9Jb`:Ld`8YA@:<D@8aYP8H``92:08Q108YI@8aQP8YA@038@@YABU5008@
PP88@@8Q90808088@@8Hh`8@XP808088H@88@@8H``88@@8H``8Hh`8@PP88@@@@PP8@XP8Q90800080
80034:88H@QQ0088H@8@XP88@@8@PP800088H@8@PP808088@@800088H@8H``8Hh`8@PP80808@PP@0
8088@@808088H@8080<000808088@@Coo`40007oo`005Ooo0P000ooo10Q10P0P0Q2200<8H@Q12440
0P000PQQ0QS30Q220QSS0Q220Q2R0Q220P000PQQ0QS30PQ10PQQ0R440P000Q2R0P000PQ10Q220Q2R
0Q220`QQ0QS30Q2R0Q220PQ10QSS0PQ10QSS0QS30RU50PQQ0R4T0P0P1PQ10PQQ0Q220QSS0P000Q22
0QS30Q2R0QSS00<8@C6V<JH00RU50QS30RUU0RU50R4T0RUU0YBB0RU50[gg0W>^0_oo0V</0]JJ0RU5
0Ycc0TY90T880QSS0PQQ0R4T0S6V0QSS00<aYQS36<<00Q220R440Q220P0P0PQQ0PQ10PQQ10Q10RU5
0PQQ0Q220RU50QSS0PQ10P000PQQ0QS30Q2R0Q220P0P0P0000<080Q1244020QQ100P0PQ10PQQ0Q2R
10Q10QSS11220P0P0PQ10PQQ0P0P0P000P0P0PQ10P0P00<@PQ2R4:8011220ooo0P000Ooo000Eool0
0`00ooooo`02ool42442020248800`QQ2448@@02000226426<<248826><248824:82488200022642
6<<2244226428@@200024:820002244248824:82488326426<<24:82488224426><224426><26<<2
:DD226428B@202062442264248826><2000248826<<24:826><00`Q1<JHaYP02:DD26<<2:FD2:DD2
8B@2:FD2U982:DD2_OL2Ljh2ool2Hb`2eYX2:DD2W?<2BTT2@PP26><226428B@2<JH26><00c6V6<<H
``0248828@@2488202022642244226442442:DD226424882:DD26><22442000226426<<24:824882
020200000`0P2448@@0826440202244226424:8424426><448820202244226420202000202022442
02000a224:8@XP044884ool10001ool001Goo`03003ooooo00;oo`8Hh`8@XP88H@8@PP032648@@Q1
0080808@PP8Hh`8@XP8H``88H@H8@@8@PP8Q108H``88@@8H``8080@8@@88H@8@PP8YA@8@PP8@XP03
244H`aS30088@@8Q108080800088@@8H``8@PP@8@@8@PP80808H``8@PP8Q108@XP88H@8@PP88H@80
00@H``8Hh`036<<@XQ2R0088H@8H``8YI@8ii`8@XP8H``:Ld`8aYP;FVP9BRP;oo`8ii`;>N@9BZP:L
d`@aYP92:08H``8@PP8YA@8Q1003>LLQ12440088H@8@PP88H@800088H@8@PP88H@8Hh`@Q908Hh`8@
XP8Hh`8YA@@@XP8@PP8H``8Q9088@@@@PP<8H@@@PP808088@@88H@@@PP80008@XP88@@88H@88@@@8
H@808088@@@08088@@800088@@8000<@PP8Q108@XPCoo`40007oo`005Ooo00<00?ooool00_oo0QSS
0Q2R0PQQ0Q2200<8H@Q124400P0P0Q220QSS0Q2R0QS30PQQ1PQ10Q220R440QS30PQ10QS30P0P10Q1
0PQQ0Q220RU50Q220Q2R00<8@AS36<<00PQ10R440P0P0P000PQ10QS30Q2210Q10Q220P0P0QS30Q22
0R440Q2R0PQQ0Q220PQQ0P0011S30QSS00<H`a2R4:800PQQ0QS30RUU0SWW0Q2R0QS30YcC0S6V0]JJ
0U::0_oo0SWW0/ii0U:Z0YcC136V0T8X0QS30Q220RU50R4400<iab448@@00PQQ0Q220PQQ0P000PQQ
0Q220PQQ0QSS124T0QSS0Q2R0QSS0RU5112R0Q220QS30R4T0PQ111220`QQ11220P0P0PQ10PQQ1122
0P000Q2R0PQ10PQQ0PQ110QQ0P0P0PQ1100P0PQ10P000PQ10P000a220R440Q2R1?oo0@000Ooo000E
ool00`00ooooo`02ool2488226426<<34882264202024:828@@26><2:DD224422642020248820204
4:8248828@@24:822444264224426><248826<<00`QQ2448@@0226424:824882020424428@@20002
4:846<<2264200026><248820202264224424:8226428@@2:FD00cW76<<H``028@@22442<JH4:FD2
4:82Jdd2>NL2g_/2BTT2ool2DZX2_OL2F//2YA@2:DD2BTT2H``200046><248800b444:8@XP046><2
4:8224426<<24:8202028B@26<<24:8226426<<28B@226424:8226426<<20202488226424:822640
0`Q1488@PP024884244200020202264248824:8248826<<:02024:82000202022642244226424:83
26426<<28@@4ool10001ool001Goo`03003ooooo00;oo`8@PP88H@8H``<@PP88H@80808@XP8Q108H
h`8YA@88@@88H@80808@PP8080@@XP8@PP8Q108@XP88@@@8H@88@@8Hh`8@PP8H``032648@@Q10088
H@8@XP8@PP8080@8@@8Q1080008@XP@H``88H@80008Hh`8@PP808088H@88@@8@XP88H@8Q108YI@03
>LLH`aS3008Q1088@@8aYP@YI@8@XP9[C@8ii`;Nn`9:B@;oo`9BZP:mm`9Jb`:U508YA@9:B@9S3080
00@Hh`8@PP038@@@XQ2R00@Hh`8@XP88@@8H``8@XP80808Q908H``8@XP88H@8H``8Q9088H@8@XP88
H@8H``80808@PP88H@8@XP88H@03244@PQ22008@PP@8@@8000808088H@8@PP8@XP8@PP8H``X0808@
XP8000808088H@88@@88H@8@XP<8H@8H``8Q10Coo`40007oo`005Ooo00<00?ooool00_oo10Q110QQ
0`0P10QQ1QS310Q10Q220P0P0Q2R0QS30Q2R0P0P0QS30PQ111220PQ10Q22112R0R4400<8@@000000
0PQQ0Q220Q2R0P0P0Q2R0PQ10RU50P0P0PQQ0QSS0Q220Q2R0P0P0Q220QSS0PQQ0Q2R0PQ10P0P0QSS
0P0P0S6600<Q12U5:DD00T880P0P0RUU0Q2R0QSS0S6V0V<<0SWW0]Jj0V]=0_oo0U:Z0_NN0U[;0YBB
0SWW0S660T8X0Q220PQQ0R440a220PQQ0PQ10R440QS30PQQ0Q220PQ10P0P0Q2R0QSS11220R4T0Q2R
11220Q2R0R440PQ10P000PQ11A220PQQ0QS30P0P0PQ10PQQ0PQ10Q2R10QQ0PQ111220PQQ0PQ11000
0QS30P0P0Q220PQQ0Q220P0P0Q2200<Hha2248800Q220PQQ1?oo0@000Ooo00000ooo000000020002
ool40003ool20005ool00`00ooooo`02ool424442643020426466<<42442488202024:826<<24:82
02026<<224444882244248844:828@@00`Q100000002264248824:8202024:822442:DD202022642
6><248824:82020248826><226424:82244202026><20202<HH00b44:DDYA@02@PP20202:FD24:82
6><2<JH2H``2>NL2e[X2Jdd2ool2DZX2mih2F//2U982>NL2<HH2@RP2488226428@@3488226422442
8@@26<<226424882244202024:826><448828B@24:8448824:828@@2244200022445488226426<<2
02022442264224424:842642244448822642244400026<<20202488226424882020248800aSS488@
PP0248822644ool10001ool000?oo`05003oooooool00005ool01000ooooo`001?oo00<00?ooool0
0_oo0Q220Q2R0PQQ0P0000<8@@QQ26400PQ10PQQ112R0Q220P0P0PQ10Q220P000PQ10QSS0R440P00
0Q2R0P000QS30R440PQ10Q220PQ10P0P0Q2200<8H@Q124400PQQ0PQ10R440Q220P000Q220QS30Q22
0QS30P000Q2R11220PQ10Q220R440P0P0QSS0PQ10PQQ112200<Q91S36<<00R440PQQ0R440T8X0SWW
0R4T0ZDd0QS30/ii0TY90_oo0RU50]kK0SWW0YBB0R4T0PQQ0S6V0R4T0R440PQQ0Q2R00<H``QQ2640
0QSS0PQQ0QS30PQQ0QSS0Q2R0PQ10Q220QSS0PQ10QS30PQQ0P0P0PQ10P000Q220PQ10P0P0PQQ0QS3
0PQ10QSS00<8H@0P020010Q10PQQ0Q220PQQ0P0P0PQQ0QS30P000PQQ100P10Q10QS30Q220PQQ0Q2R
0PQQ0Q2210QQ00<@PPQQ264010Q11?oo0@000Ooo0003ool00`00ooooo`02ool00`00ooooo`02ool0
1000ooooo`001?oo0P000ooo0PQQ0QS30Q2R0PQ100<080Q124401PQQ0Q2210Q12Q220QSS0Q22100P
0Q220R440Q2R11220P000PQQ0a220QS30P0P0PQQ0Q220PQQ0Q220QS30PQQ0Q2R10Q10QS30PQQ0QS3
0Q2R0P000P0P0RU50Q2R0R440QS30P0000<Hha2R4:800RU50Q2R0R4T0S660T880SW70Xaa0R4T0/HH
0U[;0_oo0T880[gg0SWW0Xaa0RUU0R4T0S660SW70Q2R0QSS0PQQ00<Q10Q124400Q220QS30PQQ0Q22
0R4T0QS30PQ10R440PQQ0PQ10Q220PQQ0QS30PQQ0PQ10Q2R1PQQ0P0P0PQQ0Q2200<@XPQQ26400P0P
0Q220P0P0PQQ0P0P0PQ10P000PQQ0PQ10Q2R2PQQ0PQ10Q220PQQ0P000PQQ0PQ10P0P00<8@@0P0200
0PQ10QS30ooo0P000Ooo0003ool00`00ooooo`03ool01@00oooooooo00000_oo00<00?ooool00_oo
00<00?ooool00_oo0PQQ0QS30Q2R0PQ100<080Q124401PQQ0Q2210Q12Q220QSS0Q22100P0Q220R44
0Q2R11220P000PQQ0a220QS30P0P0PQQ0Q220PQQ0Q220QS30PQQ0Q2R10Q10QS30PQQ0QS30Q2R0P00
0P0P0RU50Q2R0R440QS30P0000<Hha2R4:800RU50Q2R0R4T0S660T880SW70Xaa0R4T0/HH0U[;0_oo
0T880[gg0SWW0Xaa0RUU0R4T0S660SW70Q2R0QSS0PQQ00<Q10Q124400Q220QS30PQQ0Q220R4T0QS3
0PQ10R440PQQ0PQ10Q220PQQ0QS30PQQ0PQ10Q2R1PQQ0P0P0PQQ0Q2200<@XPQQ26400P0P0Q220P0P
0PQQ0P0P0PQ10P000PQQ0PQ10Q2R2PQQ0PQ10Q220PQQ0P000PQQ0PQ10P0P00<8@@0P02000PQ10QS3
1?oo0@000Ooo0003ool00`00ooooo`04ool01000ooooo`000_oo00<00?ooool00_oo00<00?ooool0
0_oo0Q2R0QS30Q2R0PQQ00<0812248800Q2220QQ10Q10Q2R0PQ10Q2R0PQQ0PQ10Q2210QQ0P0P0PQQ
0PQ10P0P0PQQ0Q220PQQ00<@PQ2R4:800Q220P0011220PQ10Q2210QQ0Q2210QQ0QS30PQ10PQQ0P0P
0PQQ11220P0P0Q2R0QS30P0000<Q12UU:FD01RU50R4T0R440SW70X@@0RUU0/HH0V<<0_oo0S6V0]kK
0U:Z0YBB0RU50T8X0TYY0RUU0PQ10PQQ0R4400<YI@QQ26400QS31PQ10R4T0Q220P0P0R4411220QSS
0P0P10Q10R440PQ10P0P0R440QS30PQ10Q2R0PQQ00<080QQ26400QSS0P0P0PQ10PQQ10Q110QQ0P0P
0Q2R0PQQ0Q2R0QS30PQ10Q2R100011220P0P0P000P0P00<H`a2248800PQ10Q221?oo0@000Ooo0000
1?oo000000000ooo00@00?ooool000;oo`04003ooooo0004ool00`00ooooo`02ool24:826<<24:82
26400`0P488@PP024888264424424:8224424:822642244248842642020226422442020226424882
26400a224:8@XP02488200044882244248842642488426426<<22442264202022644488202024:82
6<<200000b44:FDYI@06:DD28B@28@@2>LL2Q102:FD2aQP2H``2ool2<JH2g]/2DZX2U982:DD2@RP2
BVT2:FD2244226428@@00bUU2648H@026<<624428B@2488202028@@448826><2020424428@@22442
02028@@26<<224424:8226400`0P2648H@026><20202244226442444264202024:8226424:826<<2
24424:84000448820202000202000aS3488@PP0224424884ool10001ool000?oo`03003ooooo00;o
o`8000Coo`8000Goo`03003ooooo00;oo`@H``88H@88@@030208H@QQ008H``88H@808088@@@00088
H@8Hh`88@@88H@88@@800088@@8Q10@@XP@8@@@@PP8Q10800003488H`aS3008@PP80808@PP88H@8H
``8@PP8@XP8@PP8H``8Hh`8@XP8H``80008@XP80808Hh`8H``88@@8Hh`88@@800088@@036<<0800P
0080808@PP@YA@8Q108YA@9cSP8Q90;6609Jb`;oo`92:0;>N@92:0:DTP8ia`8aYP8ii`88@@88H@8a
QP8Q10038B@HhaSS008Hh`80808@XP8000@8@@8@XP8H``8@PP88@@8YA@H8@@8H``88H@80808@PP@8
H@8Q108H``034888@@Q1008H``88H@8H``8@PP8000@080@8@@8@PP88H@80008@XP8@PP88@@808088
@@88H@8H``@8@@88H@03488@XQ2R00@@PPCoo`40007oo`005Ooo00<00?ooool00_oo11S30PQQ0PQ1
00<080QQ26400QS30PQQ0P0P0PQ110000PQQ0QSS0PQ10PQQ0PQ10P000PQ10R44112R10Q111220R44
0P0000<@PQS36<<00Q220P0P0Q220PQQ0QS30Q220Q2R0Q220QS30QSS0Q2R0QS30P000Q2R0P0P0QSS
0QS30PQ10QSS0PQ10P000PQ100<H``0P02000P0P0Q2212U50R440RU50W>>0R4T0/HH0U[;0_oo0T8X
0/ii0T8X0YBB0SW70S6V0SWW0PQ10PQQ0S660R4400<Q91SS6><00QSS0P0P0Q2R0P0010Q10Q2R0QS3
0Q220PQ10RU51PQ10QS30PQQ0P0P0Q2210QQ0R440QS300<@PPQ124400QS30PQQ0QS30Q220P00100P
10Q10Q220PQQ0P000Q2R0Q220PQ10P0P0PQ10PQQ0QS310Q10PQQ00<@PQ2R4:8011221?oo0@000Ooo
000Eool00`00ooooo`02ool224424882264502024882264402022442000226426<<248824:824882
000226424:826><248822642244248826><2488200000a222648H@026><22642244202024:822442
488224424:84488224424:828@@26<<48@@202028@@2488202024:800`0P488@PP0248824:822642
:DD2>NL2<HH2Jfd2@RP2g_/2F//2ool2BVT2YC@2BTT2Ljh2<JH48B@24:826><28B@2:DD00c66488@
PP028B@24:84488224424:826<<28@@24:822442488424424:8248826<<24:8224426<<202026<<2
0203244202024:8202024:820002264224420206244200022442488200022642244248824:822642
244226400a222448@@042644ool10001ool001Goo`03003ooooo00;oo`88@@8@PP88H@D0808@PP88
H@@08088@@800088H@8H``8@PP8@XP8@PP800088H@8@XP8Hh`8@PP88H@88@@8@PP8Hh`8@PP800003
4888H@QQ008Hh`88H@88@@80808@XP88@@8@PP88@@8@XP@@PP88@@8@XP8Q108H``@Q1080808Q108@
PP80808@XP03020@PQ22008@PP8@XP88H@8YA@8ii`8aQP9[K@92:0;Nn`9Jb`;oo`9:J@:U=09:B@9c
[P8aYP@Q908@XP8Hh`8Q908YA@03<HH@PQ22008Q908@XP@@PP88@@8@XP8H``8Q108@XP88@@8@PP@8
@@8@XP8@PP8H``8@XP88@@8H``80808H``8080<8@@80808@XP80808@XP800088H@88@@8080H8@@80
0088@@8@PP800088H@88@@8@PP8@XP88H@88@@88H@034888@@Q100@8H@Coo`40007oo`005Ooo00<0
0?ooool00_oo0P0P0Q220PQQ0PQ100<8H@Q124400Q2R10QQ10Q10P00100P0PQQ0P0P0PQQ0PQ10PQQ
0Q2R0Q220PQQ0PQ10Q2R0PQQ0QSS0P0P0PQQ00<@PP0P02000R4T0P000R4T0PQ10QSS0P0P0Q220QS3
10Q1100P0R4T1Q220PQ10PQQ0PQ10P0P10QQ0a220QS30QSS0Q220T8X0RUU0PQ10Xaa0SW70ZDd0SWW
0_oo0T8X0/ii0RU50X@@0QSS0RU50R4T0PQ112440RUU00<Q11SS6><00QSS0R4411220Q2R11S311SS
1Q220P0P0PQ10PQQ0Q220Q2R0PQQ11220QSS0P0000<@XPQQ26400P0P0Q2210Q10P0P0P000P0P0PQ1
0Q220P0P0P0010QQ0QS30P0P0PQ10Q2R10QQ0PQ10Q220PQQ00<0000P02000PQ10P001?oo0@000Ooo
000Eool00`00ooooo`02ool202024882264224400`QQ2448@@024:84264424420004020226420202
2642244226424:824882264224424:8226426><2020226400a22020080028B@200028B@224426><2
020248826<<4244402028B@648822442264224420204264348826<<26><24882@RP2:FD22442S742
>LL2YC@2>NL2ool2@RP2cWT2:DD2Q1026><2:DD28B@224448@@2:FD00b446><Hh`026><28@@44882
4:846<<46><6488202022442264248824:82264448826><200000a2R2648H@020202488424420202
00020202244248820202000426426<<2020224424:8426422442488226400`000200800224420004
ool10001ool001Goo`8000?oo`808088H@@080034:8Q1244008@XP@080@8H@88@@H08088@@88H@@8
@@88H@8@PP8@XP88H@8Q108@PP@8@@88H@038@@@XQ2R008@XP80808Q9088H@8@XP8H``88@@8H``8@
PP@8H@80808@PPH@XP8H``80808@PP8@XP8@PP<Q108Q90@8H@88@@8aYP92208Q109[K@9BRP;>F@9B
RP;oo`92:0:U509Jb`:<D@8YI@8Hh`8Q10@@XP@Hh`<Q908@XP8H``@080@8@@8Hh`88@@808088@@80
808@XP8Q10808088H@8@PP8@XP@8H@8@XP8@PP8@XP036><8@@Q10088@@88H@8@PP8@XP88H@8@XP8@
PP@8@@@08088@@8@XP88H@88@@8@PP88H@@0808@XP8@PP8000032640800P00@080?oo`80007oo`00
5Ooo00<00?ooool00_oo0P0P0PQQ100P00<@XR448@@00Q2R100P10QQ0PQ11P0P0PQ10PQQ10Q10PQQ
0Q220Q2R0PQQ0R440Q2210Q10PQQ00<Q112R4:800Q2R0P0P0R4T0PQQ0Q2R0QS30PQ10QS30Q2210QQ
0P0P0Q221Q2R0QS30P0P0Q220Q2R0Q220b440R4T10QQ0PQ10S6V0T880R440V]]0U::0/iI0U::0_oo
0T8X0ZDD0U[;0XaA0RUU0QSS0R44112R11SS0b4T0Q2R0QS3100P10Q10QSS0PQ10P0P0PQ10P0P0Q2R
0R440P0P0PQQ0Q220Q2R10QQ0Q2R0Q220Q2R00<Hh`Q124400PQ10PQQ0Q220Q2R0PQQ0Q2R0Q2210Q1
100P0PQ10Q2R0PQQ0PQ10Q220PQQ100P0Q2R0Q220P0000<8H@0P0200100P1?oo0@000Ooo000Eool0
0`00ooooo`02ool24:82264402000`QQ488@PP026<<226422444264424420002020226464:820202
24424:826<<28@@24:822642244202000b442448@@0248844:8200024:8226426<<224424:824882
264202026<<2264224426<<24:826<<48@@226424883:DD2488202024882@PP2:DD26<<2H``2BVT2
[ED2BTT2ool2@PP2aSP2DZX2Nnl2<JH26><248828@@2264224426><00bU56><Hh`02:FD28@@42642
6<<248822442:FD202022642020226428@@2264248824:8248824:8248840202488326424:824882
4:8248824:8226424:8202022644000248826><2488224424:8624420002488202000`QQ02008002
26422444ool10001ool001Goo`03003ooooo00;oo`8@XP88H@@08003264@PQ22008H``88H@88@@@8
H@@8@@8000808088H@H@XP808088@@8@XP8H``8Q108@XP88H@88@@8080038@@8@@Q1008@PP@@XP80
008@XP88H@8H``88@@8@XP8@PP88H@80808H``88H@88@@8H``8@XP8H``@Q1088H@8@PP<YA@8@PP80
808@PP92208YA@8H``9S309:J@:]E@9:B@;oo`9220;6>09BZP9kk`8aYP8Hh`8@PP8Q1088H@88@@8H
h`03:DDHhaSS008YI@8Q10@8H@8H``8@PP88@@8YI@808088H@808088H@8Q1088H@8@PP8@XP8@PP8@
XP8@PP@0808@PP<8H@8@XP8@PP8@XP8@PP8@XP88H@8@XP808088H@@0008@PP8Hh`8@PP88@@8@XPH8
@@80008@PP8080032640800P0088H@88@@Coo`40007oo`005Ooo00<00?ooool00_oo11220P0P0PQ1
00<8HA2248800Q2R0Q220P0P0PQQ0PQ111220P0010Q10QSS0R440Q2R20QQ0QSS0PQ10Q220PQQ0P00
00<@XP0000000QS30P0P0PQQ0PQ10RU50PQ1112R0P000Q220Q2R0P0P0QS30RU50Q2R0PQQ0R4T0PQ1
0Q220Q2R10QQ00<Q912R4:800PQQ0Q220PQ10T880RU50R440V]]0RUU0/iI0TYY0_oo0T8X0ZDD0T88
0W__0RUU11S30QSS0P0P0RU50QSS00<Q92448@@00R440RUU0QS30PQQ0QSS0PQ10Q2R0R4T10QQ0P00
0Q220PQQ0QSS0Q220PQQ0Q2R0PQ10PQQ0P0P11221@Q10Q220Q2R10QQ112R0PQ10P0P0Q220PQ10P0P
0QS30PQQ10Q10Q2R100P11220P0P00<@PPQ124400PQQ0PQ11?oo0@000Ooo000Eool00`00ooooo`02
ool44882020224400`QQ488@PP024:8248820202264224444882000424426><28@@24:8826426><2
24424882264200000a2R000000026<<2020226422442:DD224444:82000248824:8202026<<2:DD2
4:8226428B@2244248824:8426400b4T4:8@XP02264248822442@PP2:DD28@@2Jfd2:FD2cUT2BVT2
ool2@RP2YA@2@PP2Nnl2:FD46<<26><20202:DD26><00b4T8@@Q10028@@2:FD26<<226426><22442
4:828B@426420002488226426><2488226424:822442264202044885244248824:8426444:822442
02024882244202026<<2264424424:840204488202000a222448@@0226422444ool10001ool001Go
o`03003ooooo0?ooo`7oo`40007oo`005Ooo00<00?ooool0oooo0Ooo0@000Ooo000Eool00`00oooo
o`3oool1ool10001ool001Goo`03003ooooo00;oo`03003ooooo02Coo`03003ooooo02Coo`03003o
oooo02Coo`03003ooooo02Coo`03003ooooo02Coo`03003ooooo02Coo`03003ooooo017oo`40007o
o`005Ooo0P000ooo00<00?ooool01_oo00<00?ooool01ooo00<00?ooool01ooo00<00?ooool01ooo
00<00?ooool01_oo00<00?ooool01ooo00<00?ooool01ooo00<00?ooool01ooo00<00?ooool01ooo
00<00?ooool01_oo00<00?ooool01ooo00<00?ooool01ooo00<00?ooool01ooo00<00?ooool01_oo
00<00?ooool01ooo00<00?ooool01ooo00<00?ooool01ooo00<00?ooool01_oo00<00?ooool01ooo
00<00?ooool01ooo00<00?ooool01ooo00<00?ooool01_oo00<00?ooool01ooo00<00?ooool01ooo
00<00?ooool01ooo00<00?ooool01_oo0P000Ooo000Eoooo00050001ool00?oooa_oo`00oooo6ooo
003ooolKool00?oooa_oo`00\
\>"],
  ImageRangeCache->{{{0, 281}, {281, 0}} -> {-13.4539, -11.1787, 0.512735, \
0.512735}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Writing the Modified Data", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  "Let's write to a MAT-file (PennyFourier.mat) and name as a MATLAB matrix \
(PennyFourier) the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " matrix (pennyFourier). Got it?"
}], "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(MATLABCreateMATFile["\<PennyFourier.mat\>"]\)\(\ \)\( (*\ 
      This\ will\ overwrite\ any\ existing\ file\ by\ that\ \(name!\)\ *) \
\)\)\)], "Input"],

Cell[BoxData[
    \("PennyFourier.mat"\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(MATLABWriteMatrix["\<PennyFourier.mat\>", "\<PennyFourier\>", 
      pennyFourier]\)\(\ \)\( (*\ Now\ append\ the\ data\ *) \)\)\)], "Input",\

  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \("PennyFourier.mat"\)], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Extending matlabio - advanced uses", "Section",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Writing a list of matrices into a single file", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  "If you want to write a list of matrices to a MAT-file from ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " , simply ",
  StyleBox["Map",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " the writing function over the list of matrices. The variable ",
  StyleBox["matnum",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used to give distinct names to the matrices (otherwise the MATLAB file \
writing library used by ",
  StyleBox["matlabio",
    FontWeight->"Bold"],
  " will overwrite rather than append matrices)."
}], "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \(writeAllMatrices[filename_String, matrices_] := 
      Module[{fname = filename, 
          matnum = 
            1}, \((MATLABWriteMatrix[
                fname, "\<mat\>" <> ToString[\(matnum++\)], #1] &)\) /@ 
          matrices; fname]\)], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Example", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["Let's make a list of three matrices.", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(matList = {Table[
            Sin[x\ y], {x, 0, \[Pi], \[Pi]\/10}, {y, 0, \[Pi], \[Pi]\/10}], 
          Table[Random[], {15}, {15}], 
          Table[Mod[x, y], {x, 1, 10}, {y, 1, 10}]};\)\)], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["Checking the dimensions of the matrices...", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dimensions /@ matList\)], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({{11, 11}, {15, 15}, {10, 10}}\)], "Output"]
}, Open  ]],

Cell["Now writing them...", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(MATLABCreateMATFile["\<TripleThreat.mat\>"]\)], "Input"],

Cell[BoxData[
    \("TripleThreat.mat"\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(writeAllMatrices["\<TripleThreat.mat\>", matList]\)], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \("TripleThreat.mat"\)], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Reading all the matrices in a file", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  "If you want to read all the matrices in a MAT-file into a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " list, simply ",
  StyleBox["Map",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " the reading function over the list of matrix names."
}], "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \(readAllMatrices[filename_String] := 
      Module[{fname = filename}, \((MATLABReadMatrix[fname, #1] &)\) /@ 
          MATLABMatrixNames[fname]]\)], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Example", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["Let's read the matrices we just wrote...", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(newMatList = readAllMatrices["\<TripleThreat.mat\>"];\)\)], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  "...and for fun, let's make a ",
  StyleBox["ListDensityPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " of each. I'm using ",
  StyleBox["DisplayFunction->Identity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " since I want to combine the plots into one graphic."
}], "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(plots = \((ListDensityPlot[#1, DisplayFunction \[Rule] Identity] &)\) /@ 
        newMatList\)], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[\(\[SkeletonIndicator]  
            DensityGraphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  
            DensityGraphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  
            DensityGraphics  \[SkeletonIndicator]\),
          False,
          Editable->False]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Now that I have the plots I'll combine them into one ",
  StyleBox["GraphicsArray",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[GraphicsArray[plots]]\)], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3125 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00744048 0.31746 [
[ 0 0 0 0 ]
[ 1 .3125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .3125 L
0 .3125 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00744048 0.321429 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0874126 0.0192308 0.0874126 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.19406 -0.0125 -3 -9 ]
[.19406 -0.0125 3 0 ]
[.36888 -0.0125 -3 -9 ]
[.36888 -0.0125 3 0 ]
[.54371 -0.0125 -3 -9 ]
[.54371 -0.0125 3 0 ]
[.71853 -0.0125 -3 -9 ]
[.71853 -0.0125 3 0 ]
[.89336 -0.0125 -6 -9 ]
[.89336 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .19406 -6 -4.5 ]
[-0.0125 .19406 0 4.5 ]
[-0.0125 .36888 -6 -4.5 ]
[-0.0125 .36888 0 4.5 ]
[-0.0125 .54371 -6 -4.5 ]
[-0.0125 .54371 0 4.5 ]
[-0.0125 .71853 -6 -4.5 ]
[-0.0125 .71853 0 4.5 ]
[-0.0125 .89336 -12 -4.5 ]
[-0.0125 .89336 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.19406 0 m
.19406 .00625 L
s
[(2)] .19406 -0.0125 0 1 Mshowa
.36888 0 m
.36888 .00625 L
s
[(4)] .36888 -0.0125 0 1 Mshowa
.54371 0 m
.54371 .00625 L
s
[(6)] .54371 -0.0125 0 1 Mshowa
.71853 0 m
.71853 .00625 L
s
[(8)] .71853 -0.0125 0 1 Mshowa
.89336 0 m
.89336 .00625 L
s
[(10)] .89336 -0.0125 0 1 Mshowa
.125 Mabswid
.06294 0 m
.06294 .00375 L
s
.10664 0 m
.10664 .00375 L
s
.15035 0 m
.15035 .00375 L
s
.23776 0 m
.23776 .00375 L
s
.28147 0 m
.28147 .00375 L
s
.32517 0 m
.32517 .00375 L
s
.41259 0 m
.41259 .00375 L
s
.45629 0 m
.45629 .00375 L
s
.5 0 m
.5 .00375 L
s
.58741 0 m
.58741 .00375 L
s
.63112 0 m
.63112 .00375 L
s
.67483 0 m
.67483 .00375 L
s
.76224 0 m
.76224 .00375 L
s
.80594 0 m
.80594 .00375 L
s
.84965 0 m
.84965 .00375 L
s
.93706 0 m
.93706 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .19406 m
.00625 .19406 L
s
[(2)] -0.0125 .19406 1 0 Mshowa
0 .36888 m
.00625 .36888 L
s
[(4)] -0.0125 .36888 1 0 Mshowa
0 .54371 m
.00625 .54371 L
s
[(6)] -0.0125 .54371 1 0 Mshowa
0 .71853 m
.00625 .71853 L
s
[(8)] -0.0125 .71853 1 0 Mshowa
0 .89336 m
.00625 .89336 L
s
[(10)] -0.0125 .89336 1 0 Mshowa
.125 Mabswid
0 .06294 m
.00375 .06294 L
s
0 .10664 m
.00375 .10664 L
s
0 .15035 m
.00375 .15035 L
s
0 .23776 m
.00375 .23776 L
s
0 .28147 m
.00375 .28147 L
s
0 .32517 m
.00375 .32517 L
s
0 .41259 m
.00375 .41259 L
s
0 .45629 m
.00375 .45629 L
s
0 .5 m
.00375 .5 L
s
0 .58741 m
.00375 .58741 L
s
0 .63112 m
.00375 .63112 L
s
0 .67483 m
.00375 .67483 L
s
0 .76224 m
.00375 .76224 L
s
0 .80594 m
.00375 .80594 L
s
0 .84965 m
.00375 .84965 L
s
0 .93706 m
.00375 .93706 L
s
0 .98077 m
.00375 .98077 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.19406 .99375 m
.19406 1 L
s
.36888 .99375 m
.36888 1 L
s
.54371 .99375 m
.54371 1 L
s
.71853 .99375 m
.71853 1 L
s
.89336 .99375 m
.89336 1 L
s
.125 Mabswid
.06294 .99625 m
.06294 1 L
s
.10664 .99625 m
.10664 1 L
s
.15035 .99625 m
.15035 1 L
s
.23776 .99625 m
.23776 1 L
s
.28147 .99625 m
.28147 1 L
s
.32517 .99625 m
.32517 1 L
s
.41259 .99625 m
.41259 1 L
s
.45629 .99625 m
.45629 1 L
s
.5 .99625 m
.5 1 L
s
.58741 .99625 m
.58741 1 L
s
.63112 .99625 m
.63112 1 L
s
.67483 .99625 m
.67483 1 L
s
.76224 .99625 m
.76224 1 L
s
.80594 .99625 m
.80594 1 L
s
.84965 .99625 m
.84965 1 L
s
.93706 .99625 m
.93706 1 L
s
.98077 .99625 m
.98077 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .19406 m
1 .19406 L
s
.99375 .36888 m
1 .36888 L
s
.99375 .54371 m
1 .54371 L
s
.99375 .71853 m
1 .71853 L
s
.99375 .89336 m
1 .89336 L
s
.125 Mabswid
.99625 .06294 m
1 .06294 L
s
.99625 .10664 m
1 .10664 L
s
.99625 .15035 m
1 .15035 L
s
.99625 .23776 m
1 .23776 L
s
.99625 .28147 m
1 .28147 L
s
.99625 .32517 m
1 .32517 L
s
.99625 .41259 m
1 .41259 L
s
.99625 .45629 m
1 .45629 L
s
.99625 .5 m
1 .5 L
s
.99625 .58741 m
1 .58741 L
s
.99625 .63112 m
1 .63112 L
s
.99625 .67483 m
1 .67483 L
s
.99625 .76224 m
1 .76224 L
s
.99625 .80594 m
1 .80594 L
s
.99625 .84965 m
1 .84965 L
s
.99625 .93706 m
1 .93706 L
s
.99625 .98077 m
1 .98077 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
11 string
11 11 8 [11 0 0 11 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
7F7F7F7F7F7F7F7F7F7F7F
7F8C99A5B1BCC7D1DAE3EA
7F99B1C7DAEAF6FDFFFDF5
7FA5C7E3F6FFFDF0D9BA96
7FB1DAF6FFF5D9AF7D4C23
7FBCEAFFF5CF9658230403
7FC7F6FDD9964C14001752
7FD1FDF0AF5814002877CA
7FDAFFD97D23002884DDFF
7FE3FDBA4C041777DDFEC2
7FEAF596230352CAFFC248
pop
P
% End of image
.01923 .01923 m
.01923 .98077 L
s
.10664 .01923 m
.10664 .98077 L
s
.19406 .01923 m
.19406 .98077 L
s
.28147 .01923 m
.28147 .98077 L
s
.36888 .01923 m
.36888 .98077 L
s
.45629 .01923 m
.45629 .98077 L
s
.54371 .01923 m
.54371 .98077 L
s
.63112 .01923 m
.63112 .98077 L
s
.71853 .01923 m
.71853 .98077 L
s
.80594 .01923 m
.80594 .98077 L
s
.89336 .01923 m
.89336 .98077 L
s
.98077 .01923 m
.98077 .98077 L
s
.01923 .01923 m
.98077 .01923 L
s
.01923 .10664 m
.98077 .10664 L
s
.01923 .19406 m
.98077 .19406 L
s
.01923 .28147 m
.98077 .28147 L
s
.01923 .36888 m
.98077 .36888 L
s
.01923 .45629 m
.98077 .45629 L
s
.01923 .54371 m
.98077 .54371 L
s
.01923 .63112 m
.98077 .63112 L
s
.01923 .71853 m
.98077 .71853 L
s
.01923 .80594 m
.98077 .80594 L
s
.01923 .89336 m
.98077 .89336 L
s
.01923 .98077 m
.98077 .98077 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00744048 0.64881 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0641026 0.0192308 0.0641026 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.14744 -0.0125 -3 -9 ]
[.14744 -0.0125 3 0 ]
[.27564 -0.0125 -3 -9 ]
[.27564 -0.0125 3 0 ]
[.40385 -0.0125 -3 -9 ]
[.40385 -0.0125 3 0 ]
[.53205 -0.0125 -3 -9 ]
[.53205 -0.0125 3 0 ]
[.66026 -0.0125 -6 -9 ]
[.66026 -0.0125 6 0 ]
[.78846 -0.0125 -6 -9 ]
[.78846 -0.0125 6 0 ]
[.91667 -0.0125 -6 -9 ]
[.91667 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .14744 -6 -4.5 ]
[-0.0125 .14744 0 4.5 ]
[-0.0125 .27564 -6 -4.5 ]
[-0.0125 .27564 0 4.5 ]
[-0.0125 .40385 -6 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .53205 -6 -4.5 ]
[-0.0125 .53205 0 4.5 ]
[-0.0125 .66026 -12 -4.5 ]
[-0.0125 .66026 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .91667 -12 -4.5 ]
[-0.0125 .91667 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.14744 0 m
.14744 .00625 L
s
[(2)] .14744 -0.0125 0 1 Mshowa
.27564 0 m
.27564 .00625 L
s
[(4)] .27564 -0.0125 0 1 Mshowa
.40385 0 m
.40385 .00625 L
s
[(6)] .40385 -0.0125 0 1 Mshowa
.53205 0 m
.53205 .00625 L
s
[(8)] .53205 -0.0125 0 1 Mshowa
.66026 0 m
.66026 .00625 L
s
[(10)] .66026 -0.0125 0 1 Mshowa
.78846 0 m
.78846 .00625 L
s
[(12)] .78846 -0.0125 0 1 Mshowa
.91667 0 m
.91667 .00625 L
s
[(14)] .91667 -0.0125 0 1 Mshowa
.125 Mabswid
.05128 0 m
.05128 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.17949 0 m
.17949 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.24359 0 m
.24359 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.33974 0 m
.33974 .00375 L
s
.37179 0 m
.37179 .00375 L
s
.4359 0 m
.4359 .00375 L
s
.46795 0 m
.46795 .00375 L
s
.5 0 m
.5 .00375 L
s
.5641 0 m
.5641 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.62821 0 m
.62821 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.72436 0 m
.72436 .00375 L
s
.75641 0 m
.75641 .00375 L
s
.82051 0 m
.82051 .00375 L
s
.85256 0 m
.85256 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.94872 0 m
.94872 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .14744 m
.00625 .14744 L
s
[(2)] -0.0125 .14744 1 0 Mshowa
0 .27564 m
.00625 .27564 L
s
[(4)] -0.0125 .27564 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(6)] -0.0125 .40385 1 0 Mshowa
0 .53205 m
.00625 .53205 L
s
[(8)] -0.0125 .53205 1 0 Mshowa
0 .66026 m
.00625 .66026 L
s
[(10)] -0.0125 .66026 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(12)] -0.0125 .78846 1 0 Mshowa
0 .91667 m
.00625 .91667 L
s
[(14)] -0.0125 .91667 1 0 Mshowa
.125 Mabswid
0 .05128 m
.00375 .05128 L
s
0 .08333 m
.00375 .08333 L
s
0 .11538 m
.00375 .11538 L
s
0 .17949 m
.00375 .17949 L
s
0 .21154 m
.00375 .21154 L
s
0 .24359 m
.00375 .24359 L
s
0 .30769 m
.00375 .30769 L
s
0 .33974 m
.00375 .33974 L
s
0 .37179 m
.00375 .37179 L
s
0 .4359 m
.00375 .4359 L
s
0 .46795 m
.00375 .46795 L
s
0 .5 m
.00375 .5 L
s
0 .5641 m
.00375 .5641 L
s
0 .59615 m
.00375 .59615 L
s
0 .62821 m
.00375 .62821 L
s
0 .69231 m
.00375 .69231 L
s
0 .72436 m
.00375 .72436 L
s
0 .75641 m
.00375 .75641 L
s
0 .82051 m
.00375 .82051 L
s
0 .85256 m
.00375 .85256 L
s
0 .88462 m
.00375 .88462 L
s
0 .94872 m
.00375 .94872 L
s
0 .98077 m
.00375 .98077 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.14744 .99375 m
.14744 1 L
s
.27564 .99375 m
.27564 1 L
s
.40385 .99375 m
.40385 1 L
s
.53205 .99375 m
.53205 1 L
s
.66026 .99375 m
.66026 1 L
s
.78846 .99375 m
.78846 1 L
s
.91667 .99375 m
.91667 1 L
s
.125 Mabswid
.05128 .99625 m
.05128 1 L
s
.08333 .99625 m
.08333 1 L
s
.11538 .99625 m
.11538 1 L
s
.17949 .99625 m
.17949 1 L
s
.21154 .99625 m
.21154 1 L
s
.24359 .99625 m
.24359 1 L
s
.30769 .99625 m
.30769 1 L
s
.33974 .99625 m
.33974 1 L
s
.37179 .99625 m
.37179 1 L
s
.4359 .99625 m
.4359 1 L
s
.46795 .99625 m
.46795 1 L
s
.5 .99625 m
.5 1 L
s
.5641 .99625 m
.5641 1 L
s
.59615 .99625 m
.59615 1 L
s
.62821 .99625 m
.62821 1 L
s
.69231 .99625 m
.69231 1 L
s
.72436 .99625 m
.72436 1 L
s
.75641 .99625 m
.75641 1 L
s
.82051 .99625 m
.82051 1 L
s
.85256 .99625 m
.85256 1 L
s
.88462 .99625 m
.88462 1 L
s
.94872 .99625 m
.94872 1 L
s
.98077 .99625 m
.98077 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .14744 m
1 .14744 L
s
.99375 .27564 m
1 .27564 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .53205 m
1 .53205 L
s
.99375 .66026 m
1 .66026 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .91667 m
1 .91667 L
s
.125 Mabswid
.99625 .05128 m
1 .05128 L
s
.99625 .08333 m
1 .08333 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .17949 m
1 .17949 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .24359 m
1 .24359 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .33974 m
1 .33974 L
s
.99625 .37179 m
1 .37179 L
s
.99625 .4359 m
1 .4359 L
s
.99625 .46795 m
1 .46795 L
s
.99625 .5 m
1 .5 L
s
.99625 .5641 m
1 .5641 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .62821 m
1 .62821 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .72436 m
1 .72436 L
s
.99625 .75641 m
1 .75641 L
s
.99625 .82051 m
1 .82051 L
s
.99625 .85256 m
1 .85256 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .94872 m
1 .94872 L
s
.99625 .98077 m
1 .98077 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
15 string
15 15 8 [15 0 0 15 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
6EBAF4ECCFF40474A0B72F3C4C8F59
DEA086D81BB159607442A16E8975AE
6915D6F93ADA8969E2FDEAE509E139
8BAA6DF8EB3CE5833DD4D0AE459AF7
24DDBAFB3CFAB01A026E05AE0B84CA
CA8947F7FCDC015D04B725A50A7B2C
F6F279C0F0436D3B257AE5F52F8008
F4D37B52CF2E71D8A23A805EE34B3D
F3A825C40DB4F74405C124CAB4F3F6
59DE51BCDA7F6F709C8EC84BDA8014
54957B5530CCC8623B73EB11809A6C
A310FFDFDCC6255FC77191E67241C6
1E0F055334FF86BACA5C76BDEC81B1
988CBC3F06A749FF42893AFAF0553C
74368CE1FF7AA25F4EE415A50FDD6F
pop
P
% End of image
.01923 .01923 m
.01923 .98077 L
s
.08333 .01923 m
.08333 .98077 L
s
.14744 .01923 m
.14744 .98077 L
s
.21154 .01923 m
.21154 .98077 L
s
.27564 .01923 m
.27564 .98077 L
s
.33974 .01923 m
.33974 .98077 L
s
.40385 .01923 m
.40385 .98077 L
s
.46795 .01923 m
.46795 .98077 L
s
.53205 .01923 m
.53205 .98077 L
s
.59615 .01923 m
.59615 .98077 L
s
.66026 .01923 m
.66026 .98077 L
s
.72436 .01923 m
.72436 .98077 L
s
.78846 .01923 m
.78846 .98077 L
s
.85256 .01923 m
.85256 .98077 L
s
.91667 .01923 m
.91667 .98077 L
s
.98077 .01923 m
.98077 .98077 L
s
.01923 .01923 m
.98077 .01923 L
s
.01923 .08333 m
.98077 .08333 L
s
.01923 .14744 m
.98077 .14744 L
s
.01923 .21154 m
.98077 .21154 L
s
.01923 .27564 m
.98077 .27564 L
s
.01923 .33974 m
.98077 .33974 L
s
.01923 .40385 m
.98077 .40385 L
s
.01923 .46795 m
.98077 .46795 L
s
.01923 .53205 m
.98077 .53205 L
s
.01923 .59615 m
.98077 .59615 L
s
.01923 .66026 m
.98077 .66026 L
s
.01923 .72436 m
.98077 .72436 L
s
.01923 .78846 m
.98077 .78846 L
s
.01923 .85256 m
.98077 .85256 L
s
.01923 .91667 m
.98077 .91667 L
s
.01923 .98077 m
.98077 .98077 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00744048 0.97619 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0961538 0.0192308 0.0961538 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.21154 -0.0125 -3 -9 ]
[.21154 -0.0125 3 0 ]
[.40385 -0.0125 -3 -9 ]
[.40385 -0.0125 3 0 ]
[.59615 -0.0125 -3 -9 ]
[.59615 -0.0125 3 0 ]
[.78846 -0.0125 -3 -9 ]
[.78846 -0.0125 3 0 ]
[.98077 -0.0125 -6 -9 ]
[.98077 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -6 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -6 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -6 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.21154 0 m
.21154 .00625 L
s
[(2)] .21154 -0.0125 0 1 Mshowa
.40385 0 m
.40385 .00625 L
s
[(4)] .40385 -0.0125 0 1 Mshowa
.59615 0 m
.59615 .00625 L
s
[(6)] .59615 -0.0125 0 1 Mshowa
.78846 0 m
.78846 .00625 L
s
[(8)] .78846 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(10)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.5 0 m
.5 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(2)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(4)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(6)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(8)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(10)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .25962 m
.00375 .25962 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .45192 m
.00375 .45192 L
s
0 .5 m
.00375 .5 L
s
0 .54808 m
.00375 .54808 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .74038 m
.00375 .74038 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.21154 .99375 m
.21154 1 L
s
.40385 .99375 m
.40385 1 L
s
.59615 .99375 m
.59615 1 L
s
.78846 .99375 m
.78846 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.25962 .99625 m
.25962 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.45192 .99625 m
.45192 1 L
s
.5 .99625 m
.5 1 L
s
.54808 .99625 m
.54808 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.74038 .99625 m
.74038 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .25962 m
1 .25962 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .5 m
1 .5 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .74038 m
1 .74038 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
10 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
001C1C1C1C1C1C1C1C1C
00003838383838383838
001C0055555555555555
00001C00717171717171
001C381C008E8E8E8E8E
000000381C00AAAAAAAA
001C1C55381C00C7C7C7
0000380055381C00E3E3
001C001C7155381C00FF
00001C38007155381C00
pop
P
% End of image
.01923 .01923 m
.01923 .98077 L
s
.11538 .01923 m
.11538 .98077 L
s
.21154 .01923 m
.21154 .98077 L
s
.30769 .01923 m
.30769 .98077 L
s
.40385 .01923 m
.40385 .98077 L
s
.5 .01923 m
.5 .98077 L
s
.59615 .01923 m
.59615 .98077 L
s
.69231 .01923 m
.69231 .98077 L
s
.78846 .01923 m
.78846 .98077 L
s
.88462 .01923 m
.88462 .98077 L
s
.98077 .01923 m
.98077 .98077 L
s
.01923 .01923 m
.98077 .01923 L
s
.01923 .11538 m
.98077 .11538 L
s
.01923 .21154 m
.98077 .21154 L
s
.01923 .30769 m
.98077 .30769 L
s
.01923 .40385 m
.98077 .40385 L
s
.01923 .5 m
.98077 .5 L
s
.01923 .59615 m
.98077 .59615 L
s
.01923 .69231 m
.98077 .69231 L
s
.01923 .78846 m
.98077 .78846 L
s
.01923 .88462 m
.98077 .88462 L
s
.01923 .98077 m
.98077 .98077 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{382, 119.375},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{-0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005n0000Ma000`40n007h00OooooOooo003ooomo
ool00?ooogooo`00ooooOooo003ooomoool00?ooogooo`00ooooOooo000Hool2000>ool4000?ool0
0`00ooooo`0>ool2000?ool2000<ool40003ool2000Pool2000:ool4000:ool00`00ooooo`09ool2
000;ool20006ool40003ool20004ool40002ool40003ool40004ool00`00ooooo`0Lool2000?ool4
000@ool00`00ooooo`0?ool2000@ool2000<ool40003ool2000>ool001Ooo`04003ooooo000=ool0
0`00ooooo`0@ool00`00ooooo`0=ool01000ooooo`003Ooo00@00?ooool000goo`05003oooooool0
0002ool00`00ooooo`0Lool01000ooooo`002Ooo00<00?ooool02ooo00<00?ooool02?oo00@00?oo
ool000Woo`04003ooooo0007ool01@00oooooooo00000_oo00<00?ooool00ooo00D00?ooooooo`00
00Soo`03003ooooo00?oo`03003ooooo01_oo`04003ooooo000>ool00`00ooooo`0Aool00`00oooo
o`0>ool01000ooooo`003_oo00@00?ooool000goo`05003oooooool00002ool00`00ooooo`0;ool0
01Ooo`04003ooooo000>ool00`00ooooo`0<ool5000>ool01000ooooo`003Ooo00@00?ooool000go
o`05003oooooool00002ool00`00ooooo`0Lool01000ooooo`002_oo00<00?ooool01ooo1@002Ooo
00@00?ooool000Woo`04003ooooo0007ool01@00oooooooo00000_oo00<00?ooool00ooo00<00?oo
ool00_oo00<00?ooool01Ooo00<00?ooool01@007?oo00@00?ooool000ooo`03003ooooo00goo`D0
00ooo`04003ooooo000>ool01000ooooo`003Ooo00D00?ooooooo`0000;oo`03003ooooo00_oo`00
5ooo00@00?ooool000ooo`03003ooooo00_oo`04003ooooo000?ool3000?ool2000>ool01@00oooo
oooo00000_oo00<00?ooool07?oo00@00?ooool000_oo`03003ooooo00Koo`04003ooooo000:ool3
000;ool20008ool01@00oooooooo00000_oo00<00?ooool00ooo00<00?ooool00ooo00<00?ooool0
1?oo00@00?ooool000;oo`03003ooooo01_oo`04003ooooo000@ool00`00ooooo`0<ool01000oooo
o`004?oo0`004?oo0P003_oo00D00?ooooooo`0000;oo`03003ooooo00_oo`005ooo00@00?ooool0
013oo`03003ooooo00_oo`03003oo`0000ooo`03003ooooo00koo`04003ooooo000=ool01@00oooo
oooo00000_oo00<00?ooool07?oo00@00?ooool000coo`03003ooooo00Koo`03003oo`0000[oo`03
003ooooo00[oo`04003ooooo0007ool01@00oooooooo00000_oo00<00?ooool00ooo00<00?ooool0
1?oo00<00?ooool00ooo00L00?ooooooo`00ool0000Mool01000ooooo`004Ooo00<00?ooool03?oo
00<00?oo00004?oo00<00?ooool03ooo00@00?ooool000goo`05003oooooool00002ool00`00oooo
o`0;ool001Ooo`04003ooooo000=ool01000ooooo`003_oo0P003ooo00<00?ooool03_oo00@00?oo
ool000_oo`<000?oo`04003ooooo000Nool01000ooooo`002Ooo00@00?ooool000Woo`8000[oo`03
003ooooo00[oo`04003ooooo0005ool30003ool01000ooooo`000ooo0`000ooo00@00?ooool000?o
o`<000Coo`8001goo`04003ooooo000>ool01000ooooo`003ooo0P004?oo00<00?ooool03ooo00@0
0?ooool000_oo`<000?oo`04003ooooo000=ool001Soo`8000ooo`80013oo`03003ooooo00koo`<0
00koo`8000koo`03003ooooo00;oo`80023oo`8000_oo`8000_oo`03003ooooo00Woo`<000[oo`80
00Soo`03003ooooo00;oo`8000Koo`03003ooooo00;oo`8000Koo`03003ooooo00?oo`03003ooooo
01coo`80013oo`80017oo`03003ooooo00ooo`<000ooo`8000koo`03003ooooo00;oo`8000koo`00
ooooOooo000Bool20003oomT000Cool20003oomT000Cool20003oomP000?ool0017oo`04003ooooo
0002ool00`00ooooo`1Pool00`00ooooo`0@ool01000ooooo`000_oo00<00?ooool0H?oo00<00?oo
ool04?oo00@00?ooool000;oo`03003oo`0000?oo`03003ooooo00;oo`05003oooooool00004ool0
0`00ooooo`02ool01@00oooooooo00001?oo00D00?ooooooo`0000Coo`03003ooooo00;oo`05003o
ooooool00004ool01@00oooooooo00001?oo00D00?ooooooo`0000Coo`03003ooooo00;oo`05003o
ooooool00004ool01`00oooooooo003oo`0000ooo`004Ooo00@00?ooool000;oo`03003oo`0005l0
0003ool00?oo017oo`04003ooooo0002ool00`00ool0001O00000ooo003oo`0Aool01000ooooo`00
0_oo00<00?oo0000F`0000?oo`00ool03_oo000Aool01000ooooo`000_oo00<00?oo00001g__00<0
07__Nnl01W__00<007__Nnl01W__00<007__Nnl01G__00<007__Nnl01W__00<007__Nnl01W__00<0
07__Nnl01W__00<007__Nnl01G__00<007__Nnl01W__00<007__Nnl01W__00<007__Nnl01G__00<0
0?oo00004_oo00@00?ooool000;oo`03003oo`0000E[K@03002mekgG00Bme`03003g__Nn00?g_P03
003_ONmm00?_O@03003>NLii00C>N@03003g__Nn00?g_P030000800P00<08003001c[W>^00Ac[P03
002U5:DD00>U5003002e][Ff00>e]P03000YIBUU00@YI@03000iicWW00<ii`03001:JDYY00A:J@03
002<LHaa00><L@03001Jbe[;00=Jb`03003oo`0001;oo`04003ooooo0002ool00`00ool000090008
6><00`006><Hh`066><00`006><Hh`066><00`006><Hh`076><00`006><Hh`066><00`006><Hh`06
6><00`006><Hh`066><00`006><Hh`066><00`006><Hh`066><00`00ool0000?ool0017oo`04003o
oooo0002ool00`00ool00007Nnl00`00Nnmkk`06Nnl00`00Nnmkk`06Nnl00`00Nnmkk`05Nnl00`00
Nnmkk`06Nnl00`00Nnmkk`06Nnl00`00Nnmkk`06Nnl00`00Nnmkk`05Nnl00`00Nnmkk`06Nnl00`00
Nnmkk`06Nnl00`00Nnmkk`05Nnl00`00ool0000Bool01000ooooo`000_oo00<00?oo00001F]]00<0
0;gG_ML01;gG00<00?Nnmkh00oNn00<00>mmkgd00nmm00<00<iicWT01<ii00<00?Nnmkh00oNn00<0
000P02000`0P00<007>^Ljh017>^00<00:DDYA@00jDD00<00;Ff]KH00kFf00<002UU:FD012UU00<0
03WW>NL00cWW00<004YYBVT014YY00<008aaS7400haa00<005[;F//00e[;00<00?oo00004_oo00@0
0?ooool000;oo`03003oo`0000T000PHh`03000HhaSS00HHh`03000HhaSS00HHh`03000HhaSS00LH
h`03000HhaSS00HHh`03000HhaSS00HHh`03000HhaSS00HHh`03000HhaSS00HHh`03000HhaSS00HH
h`03003oo`0000ooo`004Ooo00@00?ooool000;oo`03003oo`0000Mkk`03001kkg__00Ikk`03001k
kg__00Ikk`03001kkg__00Ekk`03001kkg__00Ikk`03001kkg__00Ikk`03001kkg__00Ikk`03001k
kg__00Ekk`03001kkg__00Ikk`03001kkg__00Ikk`03001kkg__00Ekk`03003oo`0001;oo`04003o
oooo0002ool00`00ool00005Jfd00`00_MNme`04_ML00`00mkkg_P03mkh00`00kgg_O@03kgd00`00
cWW>N@04cWT00`00mkkg_P03mkh00`000200800302000`00Ljic[P04Ljh00`00YABU5003YA@00`00
]KJe]P03]KH00`00:FDYI@04:FD00`00>NLii`03>NL00`00BVU:J@04BVT00`00S76<L@03S7400`00
F/]Jb`03F//00`00ool0000Bool01000ooooo`000_oo00<00?oo00002@0021SS00<001SS6><01QSS
00<001SS6><01QSS00<001SS6><01aSS00<001SS6><01QSS00<001SS6><01QSS00<001SS6><01QSS
00<001SS6><01QSS00<001SS6><01QSS00<00?oo00003ooo000Bool20003ool00`00ool00007Nnl0
0`00Nnmkk`06Nnl00`00Nnmkk`06Nnl00`00Nnmkk`05Nnl00`00Nnmkk`06Nnl00`00Nnmkk`06Nnl0
0`00Nnmkk`06Nnl00`00Nnmkk`05Nnl00`00Nnmkk`06Nnl00`00Nnmkk`06Nnl00`00Nnmkk`05Nnl0
0`00ool0000Cool20003ool00`00ool00005Jfd00`00_MNme`04_ML00`00mkkg_P03mkh00`00kgg_
O@03kgd00`00cWW>N@04cWT00`00mkkg_P03mkh00`000200800302000`00Ljic[P04Ljh00`00YABU
5003YA@00`00]KJe]P03]KH00`00:FDYI@04:FD00`00>NLii`03>NL00`00BVU:J@04BVT00`00S76<
L@03S7400`00F/]Jb`03F//00`00ool0000Cool20003ool00`00ool0000900086><00`006><Hh`06
6><00`006><Hh`066><00`006><Hh`076><00`006><Hh`066><00`006><Hh`066><00`006><Hh`06
6><00`006><Hh`066><00`006><Hh`066><00`00ool0000?ool001Ooo`03003oo`0000Mkk`03001k
kg__00Ikk`03001kkg__00Ikk`03001kkg__00Ekk`03001kkg__00Ikk`03001kkg__00Ikk`03001k
kg__00Ikk`03001kkg__00Ekk`03001kkg__00Ikk`03001kkg__00Ikk`03001kkg__00Ekk`03003o
o`0001Soo`03003oo`0000E[K@03002mekgG00Bme`03003g__Nn00?g_P03003_ONmm00?_O@03003>
NLii00C>N@03003g__Nn00?g_P030000800P00<08003001c[W>^00Ac[P03002U5:DD00>U5003002e
][Ff00>e]P03000YIBUU00@YI@03000iicWW00<ii`03001:JDYY00A:J@03002<LHaa00><L@03001J
be[;00=Jb`03003oo`0001Soo`03003oo`0000T000PHh`03000HhaSS00HHh`03000HhaSS00HHh`03
000HhaSS00LHh`03000HhaSS00HHh`03000HhaSS00HHh`03000HhaSS00HHh`03000HhaSS00HHh`03
000HhaSS00HHh`03003oo`0000ooo`005ooo00<00?oo00001g__00<007__Nnl01W__00<007__Nnl0
1W__00<007__Nnl01G__00<007__Nnl01W__00<007__Nnl01W__00<007__Nnl01W__00<007__Nnl0
1G__00<007__Nnl01W__00<007__Nnl01W__00<007__Nnl01G__00<00?oo00006?oo00<00?oo0000
G`0000?oo`00ool05ooo00<00?oo00002@0021SS00<001SS6><01QSS00<001SS6><01QSS00<001SS
6><01aSS00<001SS6><01QSS00<001SS6><01QSS00<001SS6><01QSS00<001SS6><01QSS00<001SS
6><01QSS00<00?oo00003ooo000Gool00`00ool00007Nnl00`00Nnmkk`06Nnl00`00Nnmkk`06Nnl0
0`00Nnmkk`05Nnl00`00Nnmkk`06Nnl00`00Nnmkk`06Nnl00`00Nnmkk`06Nnl00`00Nnmkk`05Nnl0
0`00Nnmkk`06Nnl00`00Nnmkk`06Nnl00`00Nnmkk`05Nnl00`00ool0000Hool00`00ool00005g_/0
0`00YABU5004YA@00`00Q324<003Q3000`00g]_Nf`03g]/00`006<<H``046<<00`00]IJeUP03]IH0
0`00F/]Jb`03F//00`00H`aS3004H``00`00Ljic[P03Ljh00`00@PQ22003@PP00`00YABU5004YA@0
0`00Jfe[K@03Jfd00`00S56<D@04S5400`00Ljic[P03Ljh00`00[GF]M@03[GD00`00ool0000Hool0
0`00ool0000900086><00`006><Hh`066><00`006><Hh`066><00`006><Hh`076><00`006><Hh`06
6><00`006><Hh`066><00`006><Hh`066><00`006><Hh`066><00`006><Hh`066><00`00ool0000?
ool001Ooo`03003oo`0005l00003ool00?oo01Ooo`03003oo`0000GNn`03002U5:DD00BU50030024
<8@`00>4<003003NfmkK00?Nf`03000H`aS300@H``03002eU[FF00>eUP03001Jbe[;00=Jb`03001S
36<<00AS3003001c[W>^00=c[P030012248800=22003002U5:DD00BU5003001[KF]]00=[K@03002<
DHaA00B<D@03001c[W>^00=c[P03002]MJee00>]M@03003oo`0001Soo`03003oo`0000T000PHh`03
000HhaSS00HHh`03000HhaSS00HHh`03000HhaSS00LHh`03000HhaSS00HHh`03000HhaSS00HHh`03
000HhaSS00HHh`03000HhaSS00HHh`03000HhaSS00HHh`03003oo`0000ooo`005ooo00<00?oo0000
1g__00<008aaS7401Xaa00<009cCW=<01YcC00<00:DdYC@01JDd00<00;FF]IH01[FF00<00;gg_OL0
1[gg00<00<HhaSP01/Hh00<00=JJeYX01MJJ00<00=kKg]/01]kK00<00>LLia`01^LL00<00>mMked0
1NmM00<00?oo00006?oo00<00?oo00001Mkk00<00:DDYA@01:DD00<008@`Q3000h@`00<00=kKg]/0
0mkK00<001S36<<011S300<00;FF]IH00kFF00<005[;F//00e[;00<006<<H``016<<00<007>^Ljh0
0g>^00<00488@PP00d8800<00:DDYA@01:DD00<006]]Jfd00f]]00<008aAS54018aA00<007>^Ljh0
0g>^00<00:ee[GD00jee00<00?oo00006?oo00<00?oo0000F`0000?oo`00ool03_oo000Gool00`00
ool00007Nnl00`00S76<L@06S7400`00W=>Ld`06W=<00`00YCBU=005YC@00`00]IJeUP06]IH00`00
_ONmm`06_OL00`00aSS6>006aSP00`00eY[FVP05eYX00`00g]_Nf`06g]/00`00iacW7006ia`00`00
keg_G@05ked00`00ool0000Bool40002ool00`00ool00005g_/00`00YABU5004YA@00`00Q324<003
Q3000`00g]_Nf`03g]/00`006<<H``046<<00`00]IJeUP03]IH00`00F/]Jb`03F//00`00H`aS3004
H``00`00Ljic[P03Ljh00`00@PQ22003@PP00`00YABU5004YA@00`00Jfe[K@03Jfd00`00S56<D@04
S5400`00Ljic[P03Ljh00`00[GF]M@03[GD00`00ool0000Hool00`00ool0000B0008>LL00`00>LLi
a`06>LL00`00>LLia`07>LL00`00>LLia`06>LL00`00>LLia`06>LL00`00>LLia`06>LL00`00>LLi
a`06>LL00`00>LLia`06>LL00`00ool0000?ool001Ooo`03003oo`0000Mkk`03002<LHaa00J<L@03
002LdicC00JLd`03002U=:Dd00FU=003002eU[FF00JeUP03002mmkgg00Jmm`030036><Hh00K6>003
003FV]JJ00GFVP03003NfmkK00KNf`03003W7>LL00KW7003003_GNmM00G_G@03003oo`0001;oo`03
003ooooo00?oo`03003oo`0000GNn`03002U5:DD00BU50030024<8@`00>4<003003NfmkK00?Nf`03
000H`aS300@H``03002eU[FF00>eUP03001Jbe[;00=Jb`03001S36<<00AS3003001c[W>^00=c[P03
0012248800=22003002U5:DD00BU5003001[KF]]00=[K@03002<DHaA00B<D@03001c[W>^00=c[P03
002]MJee00>]M@03003oo`0001Soo`03003oo`00018000Pia`03000iacW700Hia`03000iacW700Li
a`03000iacW700Hia`03000iacW700Hia`03000iacW700Hia`03000iacW700Hia`03000iacW700Hi
a`03003oo`0000ooo`005ooo00<00?oo00001g__00<008aaS7401Xaa00<009cCW=<01YcC00<00:Dd
YC@01JDd00<00;FF]IH01[FF00<00;gg_OL01[gg00<00<HhaSP01/Hh00<00=JJeYX01MJJ00<00=kK
g]/01]kK00<00>LLia`01^LL00<00>mMked01NmM00<00?oo00004ooo00<00?ooool00_oo00<00?oo
0000G`0000?oo`00ool05ooo00<00?oo00004P0023W700<003W7>LL01SW700<003W7>LL01cW700<0
03W7>LL01SW700<003W7>LL01SW700<003W7>LL01SW700<003W7>LL01SW700<003W7>LL01SW700<0
0?oo00003ooo000Gool00`00ool00007Nnl00`00S76<L@06S7400`00W=>Ld`06W=<00`00YCBU=005
YC@00`00]IJeUP06]IH00`00_ONmm`06_OL00`00aSS6>006aSP00`00eY[FVP05eYX00`00g]_Nf`06
g]/00`00iacW7006ia`00`00keg_G@05ked00`00ool0000Dool01`00oooooooo003oo`0000E[C@03
000@XQ2R00@@XP03003F^]Jj00?F^P03003ogooO00?og`03000iacW700@ia`03003NfmkK00?Nf`03
002<DHaA00><D@03001[CF]=00A[C@03003W7>LL00?W7003003ooooo00?oo`03003_GNmM00C_G@03
003W?>Ll00?W?0030008@@Q100@8@@03003W7>LL00?W7003000iacW700<ia`03003oo`0001Soo`03
003oo`00018000Pia`03000iacW700Hia`03000iacW700Lia`03000iacW700Hia`03000iacW700Hi
a`03000iacW700Hia`03000iacW700Hia`03000iacW700Hia`03003oo`0000ooo`005ooo00<00?oo
00001g__00<008aaS7401Xaa00<009cCW=<01YcC00<00:DdYC@01JDd00<00;FF]IH01[FF00<00;gg
_OL01[gg00<00<HhaSP01/Hh00<00=JJeYX01MJJ00<00=kKg]/01]kK00<00>LLia`01^LL00<00>mM
ked01NmM00<00?oo00005Ooo00H00?ooool00?oo0005Jdd00`004:8@XP044:800`00e[[F^P03e[X0
0`00omoog`03oml00`00>LLia`04>LL00`00g]_Nf`03g]/00`00S56<D@03S5400`00Jde[C@04Jdd0
0`00iacW7003ia`00`00ooooo`03ool00`00keg_G@04ked00`00iccW?003ic`00`002448@@042440
0`00iacW7003ia`00`00>LLia`03>LL00`00ool0000Hool00`00ool0000B0008>LL00`00>LLia`06
>LL00`00>LLia`07>LL00`00>LLia`06>LL00`00>LLia`06>LL00`00>LLia`06>LL00`00>LLia`06
>LL00`00>LLia`06>LL00`00ool0000?ool0017oo`@000;oo`03003oo`0000Mkk`03002<LHaa00J<
L@03002LdicC00JLd`03002U=:Dd00FU=003002eU[FF00JeUP03002mmkgg00Jmm`030036><Hh00K6
>003003FV]JJ00GFVP03003NfmkK00KNf`03003W7>LL00KW7003003_GNmM00G_G@03003oo`0001;o
o`04003ooooo0002ool00`00ool00005Jdd00`004:8@XP044:800`00e[[F^P03e[X00`00omoog`03
oml00`00>LLia`04>LL00`00g]_Nf`03g]/00`00S56<D@03S5400`00Jde[C@04Jdd00`00iacW7003
ia`00`00ooooo`03ool00`00keg_G@04ked00`00iccW?003ic`00`002448@@0424400`00iacW7003
ia`00`00>LLia`03>LL00`00ool0000Hool00`00ool0000B0008>LL00`00>LLia`06>LL00`00>LLi
a`07>LL00`00>LLia`06>LL00`00>LLia`06>LL00`00>LLia`06>LL00`00>LLia`06>LL00`00>LLi
a`06>LL00`00ool0000?ool0017oo`03003ooooo00?oo`03003oo`0000Mkk`03002<LHaa00J<L@03
002LdicC00JLd`03002U=:Dd00FU=003002eU[FF00JeUP03002mmkgg00Jmm`030036><Hh00K6>003
003FV]JJ00GFVP03003NfmkK00KNf`03003W7>LL00KW7003003_GNmM00G_G@03003oo`0001?oo`80
00?oo`03003oo`0000E[C@03000@XQ2R00@@XP03003F^]Jj00?F^P03003ogooO00?og`03000iacW7
00@ia`03003NfmkK00?Nf`03002<DHaA00><D@03001[CF]=00A[C@03003W7>LL00?W7003003ooooo
00?oo`03003_GNmM00C_G@03003W?>Ll00?W?0030008@@Q100@8@@03003W7>LL00?W7003000iacW7
00<ia`03003oo`0001Soo`03003oo`00018000Pia`03000iacW700Hia`03000iacW700Lia`03000i
acW700Hia`03000iacW700Hia`03000iacW700Hia`03000iacW700Hia`03000iacW700Hia`03003o
o`0000ooo`004_oo00<00?ooool00_oo00<00?oo0000G`0000?oo`00ool05ooo00<00?oo00001F]=
00<0012R4:80112R00<00=Jje[X00mJj00<00?oOoml00ooO00<003W7>LL013W700<00=kKg]/00mkK
00<008aAS5400haA00<006]=Jdd016]=00<00>LLia`00nLL00<00?ooool00ooo00<00>mMked01>mM
00<00>Llic`00nLl00<000Q1244010Q100<00>LLia`00nLL00<003W7>LL00cW700<00?oo00004_oo
10000_oo00<00?oo00004P0023W700<003W7>LL01SW700<003W7>LL01cW700<003W7>LL01SW700<0
03W7>LL01SW700<003W7>LL01SW700<003W7>LL01SW700<003W7>LL01SW700<00?oo00003ooo000C
ool01`00oooooooo003oo`0000Mkk`03002LdicC00JLd`03002eU[FF00JeUP030036><Hh00G6>003
003NfmkK00KNf`03003_GNmM00K_G@03003g__Nn00Kg_P03003ooooo00Goo`03003ooooo00Koo`03
003ooooo00Koo`03003g__Nn00Gg_P03003oo`0001Soo`03003oo`0000E[C@03000@XQ2R00@@XP03
003F^]Jj00?F^P03003ogooO00?og`03000iacW700@ia`03003NfmkK00?Nf`03002<DHaA00><D@03
001[CF]=00A[C@03003W7>LL00?W7003003ooooo00?oo`03003_GNmM00C_G@03003W?>Ll00?W?003
0008@@Q100@8@@03003W7>LL00?W7003000iacW700<ia`03003oo`0001;oo`03003ooooo00?oo`03
003oo`00018000Pia`03000iacW700Hia`03000iacW700Lia`03000iacW700Hia`03000iacW700Hi
a`03000iacW700Hia`03000iacW700Hia`03000iacW700Hia`03003oo`0000ooo`005?oo00H00?oo
ool00?oo0007Nnl00`00W=>Ld`06W=<00`00]IJeUP06]IH00`00aSS6>005aSP00`00g]_Nf`06g]/0
0`00keg_G@06ked00`00mkkg_P06mkh00`00ooooo`05ool00`00ooooo`06ool00`00ooooo`06ool0
0`00mkkg_P05mkh00`00ool0000Hool00`00ool0001O00000ooo003oo`0Bool00`00ooooo`02ool0
0`00ool0001K00000ooo003oo`0>ool0017oo`04003ooooo0002ool00`00ool00007Nnl00`00W=>L
d`06W=<00`00]IJeUP06]IH00`00aSS6>005aSP00`00g]_Nf`06g]/00`00keg_G@06ked00`00mkkg
_P06mkh00`00ooooo`05ool00`00ooooo`06ool00`00ooooo`06ool00`00mkkg_P05mkh00`00ool0
000Hool00`00ool00005S5400`00[EF]E@04[ED00`00Jfe[K@03Jfd00`00omoog`03oml00`00keg_
G@04ked00`00>NLii`03>NL00`00iccW?003ic`00`00Q1244004Q1000`00>NLii`03>NL00`00e[[F
^P03e[X00`00eY[FVP04eYX00`00[GF]M@03[GD00`00@RQ2:004@RP00`00W=>Ld`03W=<00`00mkkg
_P03mkh00`00ool0000Dool01P00oooooooo003oo`X000PHh`X000QBZP03001BZU:Z00MBZP03001B
ZU:Z00IBZP03001BZU:Z00IBZP03001BZU:Z00IBZP03001BZU:Z00IBZP03001BZU:Z00IBZP03003o
o`0000ooo`004_oo0P000ooo00<00?oo00001g__00<009cCW=<01YcC00<00;FF]IH01[FF00<00<Hh
aSP01LHh00<00=kKg]/01]kK00<00>mMked01^mM00<00?Nnmkh01_Nn00<00?ooool01Ooo00<00?oo
ool01_oo00<00?ooool01_oo00<00?Nnmkh01ONn00<00?oo00006?oo00<00?oo00001HaA00<00:eE
[ED01:eE00<006]]Jfd00f]]00<00?oOoml00ooO00<00>mMked01>mM00<003WW>NL00cWW00<00>Ll
ic`00nLl00<008@@Q10018@@00<003WW>NL00cWW00<00=Jje[X00mJj00<00=JJeYX01=JJ00<00:ee
[GD00jee00<0048X@RP0148X00<009cCW=<00icC00<00?Nnmkh00oNn00<00?oo00005Ooo00D00?oo
ool00?oo00X000PHh`X000QBZP03001BZU:Z00MBZP03001BZU:Z00IBZP03001BZU:Z00IBZP03001B
ZU:Z00IBZP03001BZU:Z00IBZP03001BZU:Z00IBZP03003oo`0000ooo`005ooo00<00?oo00001g__
00<009cCW=<01YcC00<00;FF]IH01[FF00<00<HhaSP01LHh00<00=kKg]/01]kK00<00>mMked01^mM
00<00?Nnmkh01_Nn00<00?ooool01Ooo00<00?ooool01_oo00<00?ooool01_oo00<00?Nnmkh01ONn
00<00?oo00006?oo00<00?oo00001HaA00<00:eE[ED01:eE00<006]]Jfd00f]]00<00?oOoml00ooO
00<00>mMked01>mM00<003WW>NL00cWW00<00>Llic`00nLl00<008@@Q10018@@00<003WW>NL00cWW
00<00=Jje[X00mJj00<00=JJeYX01=JJ00<00:ee[GD00jee00<0048X@RP0148X00<009cCW=<00icC
00<00?Nnmkh00oNn00<00?oo00004_oo00@00?ooool000;oo`03003oo`0000T000PHh`X000QBZP03
001BZU:Z00MBZP03001BZU:Z00IBZP03001BZU:Z00IBZP03001BZU:Z00IBZP03001BZU:Z00IBZP03
001BZU:Z00IBZP03003oo`0000ooo`005ooo00<00?oo00001g__00<009cCW=<01YcC00<00;FF]IH0
1[FF00<00<HhaSP01LHh00<00=kKg]/01]kK00<00>mMked01^mM00<00?Nnmkh01_Nn00<00?ooool0
1Ooo00<00?ooool01_oo00<00?ooool01_oo00<00?Nnmkh01ONn00<00?oo00005?oo00L00?oooooo
o`00ool00005S5400`00[EF]E@04[ED00`00Jfe[K@03Jfd00`00omoog`03oml00`00keg_G@04ked0
0`00>NLii`03>NL00`00iccW?003ic`00`00Q1244004Q1000`00>NLii`03>NL00`00e[[F^P03e[X0
0`00eY[FVP04eYX00`00[GF]M@03[GD00`00@RQ2:004@RP00`00W=>Ld`03W=<00`00mkkg_P03mkh0
0`00ool0000Cool20003ool00`00ool0000900086><:0008DZX00`00DZYBZP07DZX00`00DZYBZP06
DZX00`00DZYBZP06DZX00`00DZYBZP06DZX00`00DZYBZP06DZX00`00DZYBZP06DZX00`00ool0000?
ool001Ooo`03003oo`0000Mkk`03002LdicC00JLd`03002eU[FF00JeUP030036><Hh00G6>003003N
fmkK00KNf`03003_GNmM00K_G@03003g__Nn00Kg_P03003ooooo00Goo`03003ooooo00Koo`03003o
oooo00Koo`03003g__Nn00Gg_P03003oo`0001Coo`07003oooooool00?oo00001HaA00<00:eE[ED0
1:eE00<006]]Jfd00f]]00<00?oOoml00ooO00<00>mMked01>mM00<003WW>NL00cWW00<00>Llic`0
0nLl00<008@@Q10018@@00<003WW>NL00cWW00<00=Jje[X00mJj00<00=JJeYX01=JJ00<00:ee[GD0
0jee00<0048X@RP0148X00<009cCW=<00icC00<00?Nnmkh00oNn00<00?oo00006?oo00<00?oo0000
2@0021SS2P0025:Z00<005:ZDZX01e:Z00<005:ZDZX01U:Z00<005:ZDZX01U:Z00<005:ZDZX01U:Z
00<005:ZDZX01U:Z00<005:ZDZX01U:Z00<00?oo00003ooo000Gool00`00ool00007Nnl00`00W=>L
d`06W=<00`00]IJeUP06]IH00`00aSS6>005aSP00`00g]_Nf`06g]/00`00keg_G@06ked00`00mkkg
_P06mkh00`00ooooo`05ool00`00ooooo`06ool00`00ooooo`06ool00`00mkkg_P05mkh00`00ool0
000Aool50002ool00`00ool0001O00000ooo003oo`0Gool00`00ool0000900086><:0008DZX00`00
DZYBZP07DZX00`00DZYBZP06DZX00`00DZYBZP06DZX00`00DZYBZP06DZX00`00DZYBZP06DZX00`00
DZYBZP06DZX00`00ool0000?ool001Ooo`03003oo`0005l00003ool00?oo013oo`04003ooooo0003
ool00`00ool000058B@00`00g__Nn`04g_/00`00_MNme`03_ML00`00omoog`03oml00`00>NLii`04
>NL00`00omoog`03oml00`00]IJeUP03]IH00`006<<H``046<<70005Jfd00`000200800402000`00
[GF]M@03[GD00`002448@@0424400`00Q324<003Q3000`00cUW>F@03cUT00`00ool0000Hool00`00
ool0000900086><:0008DZX00`00DZYBZP07DZX00`00DZYBZP06DZX00`00DZYBZP06DZX00`00DZYB
ZP06DZX00`00DZYBZP06DZX00`00DZYBZP06DZX00`00ool0000?ool001Ooo`03003oo`0000Mkk`03
002U=:Dd00JU=0030036><Hh00K6>003003W7>LL00GW7003003g__Nn00Kg_P03003ooooo00Koo`03
003ooooo00Koo`03003gW_NN00GgWP03003NfmkK00KNf`03002mekgG00Jme`03002D/YBb00FD/P03
003oo`0001;oo`03003oo`0000?oo`03003oo`0000DQ9003003Nnmkk00CNn`03002mekgG00>me`03
003ogooO00?og`03000iicWW00@ii`03003ogooO00?og`03002eU[FF00>eUP03000H`aS300@H``L0
00E[K@030000800P00@08003002]MJee00>]M@030008@@Q100@8@@030024<8@`00>4<003003>FLiI
00?>F@03003oo`0001Soo`03003oo`0000T000PHh`X000QBZP03001BZU:Z00MBZP03001BZU:Z00IB
ZP03001BZU:Z00IBZP03001BZU:Z00IBZP03001BZU:Z00IBZP03001BZU:Z00IBZP03003oo`0000oo
o`005ooo00<00?oo00001g__00<00:DdYC@01ZDd00<00<HhaSP01/Hh00<00>LLia`01NLL00<00?Nn
mkh01_Nn00<00?ooool01_oo00<00?ooool01_oo00<00?NNmih01ONN00<00=kKg]/01]kK00<00;gG
_ML01[gG00<009BbU;801IBb00<00?oo00004ooo0P000ooo00<00?oo00001B4T00<00=kkg_/01=kk
00<00;gG_ML00kgG00<00?oOoml00ooO00<003WW>NL013WW00<00?oOoml00ooO00<00;FF]IH00kFF
00<001S36<<011S31`001F]]00<0000P0200100P00<00:ee[GD00jee00<000Q1244010Q100<008@`
Q3000h@`00<00<iIcUT00liI00<00?oo00006?oo00<00?oo0000F`0000?oo`00ool03_oo000Gool0
0`00ool00007Nnl00`00YCBU=006YC@00`00aSS6>006aSP00`00iacW7005ia`00`00mkkg_P06mkh0
0`00ooooo`06ool00`00ooooo`06ool00`00mikgWP05mih00`00g]_Nf`06g]/00`00_MNme`06_ML0
0`00U;:D/P05U;800`00ool0000Dool01`00oooooooo003oo`0000DQ9003003Nnmkk00CNn`03002m
ekgG00>me`03003ogooO00?og`03000iicWW00@ii`03003ogooO00?og`03002eU[FF00>eUP03000H
`aS300@H``L000E[K@030000800P00@08003002]MJee00>]M@030008@@Q100@8@@030024<8@`00>4
<003003>FLiI00?>F@03003oo`0001Soo`03003oo`00018000PHh`X000UcSP03001cSW>>00IcSP03
001cSW>>00IcSP03001cSW>>00IcSP03001cSW>>00IcSP03001cSW>>00IcSP03003oo`0000ooo`00
5ooo00<00?oo00001g__00<00:DdYC@01ZDd00<00<HhaSP01/Hh00<00>LLia`01NLL00<00?Nnmkh0
1_Nn00<00?ooool01_oo00<00?ooool01_oo00<00?NNmih01ONN00<00=kKg]/01]kK00<00;gG_ML0
1[gG00<009BbU;801IBb00<00?oo00006?oo00<00?oo00001B4T00<00=kkg_/01=kk00<00;gG_ML0
0kgG00<00?oOoml00ooO00<003WW>NL013WW00<00?oOoml00ooO00<00;FF]IH00kFF00<001S36<<0
11S31`001F]]00<0000P0200100P00<00:ee[GD00jee00<000Q1244010Q100<008@`Q3000h@`00<0
0<iIcUT00liI00<00?oo00006?oo00<00?oo00004P0021SS2P002G>>00<007>>Lhh01W>>00<007>>
Lhh01W>>00<007>>Lhh01W>>00<007>>Lhh01W>>00<007>>Lhh01W>>00<00?oo00003ooo000Gool0
0`00ool00007Nnl00`00YCBU=006YC@00`00aSS6>006aSP00`00iacW7005ia`00`00mkkg_P06mkh0
0`00ooooo`06ool00`00ooooo`06ool00`00mikgWP05mih00`00g]_Nf`06g]/00`00_MNme`06_ML0
0`00U;:D/P05U;800`00ool0000Hool00`00ool000058B@00`00g__Nn`04g_/00`00_MNme`03_ML0
0`00omoog`03oml00`00>NLii`04>NL00`00omoog`03oml00`00]IJeUP03]IH00`006<<H``046<<7
0005Jfd00`000200800402000`00[GF]M@03[GD00`002448@@0424400`00Q324<003Q3000`00cUW>
F@03cUT00`00ool0000Hool00`00ool0000B00086><:0009Lhh00`00LhicSP06Lhh00`00LhicSP06
Lhh00`00LhicSP06Lhh00`00LhicSP06Lhh00`00LhicSP06Lhh00`00ool0000?ool001?oo`07003o
ooooool00?oo00001g__00<00:DdYC@01ZDd00<00<HhaSP01/Hh00<00>LLia`01NLL00<00?Nnmkh0
1_Nn00<00?ooool01_oo00<00?ooool01_oo00<00?NNmih01ONN00<00=kKg]/01]kK00<00;gG_ML0
1[gG00<009BbU;801IBb00<00?oo00006?oo00<00?oo0000G`0000?oo`00ool05ooo00<00?oo0000
4P0021SS2P002G>>00<007>>Lhh01W>>00<007>>Lhh01W>>00<007>>Lhh01W>>00<007>>Lhh01W>>
00<007>>Lhh01W>>00<00?oo00003ooo000Cool01`00oooooooo003oo`0000Mkk`03002U=:Dd00JU
=0030036><Hh00K6>003003W7>LL00GW7003003g__Nn00Kg_P03003ooooo00Koo`03003ooooo00Ko
o`03003gW_NN00GgWP03003NfmkK00KNf`03002mekgG00Jme`03002D/YBb00FD/P03003oo`0001So
o`03003oo`0000G>F@03002<DHaA00B<D@030012:48X00=2:003003g__Nn00?g_P03003ooooo00Co
o`03003Nnmkk00?Nn`L000IJj`030000800P00<08003002e][Ff00>e]P03000Q924T00@Q9003002U
=:Dd00>U=0030008@@Q100@8@@03001kcg_?00=kc`03000YIBUU00<YI@03003oo`0001Soo`03003o
o`00018000PHh`X000UcSP03001cSW>>00IcSP03001cSW>>00IcSP03001cSW>>00IcSP03001cSW>>
00IcSP03001cSW>>00IcSP03003oo`0000ooo`004?oo1@000_oo00<00?oo0000G`0000?oo`00ool0
5ooo00<00?oo00001LiI00<008aAS54018aA00<0048X@RP00d8X00<00?Nnmkh00oNn00<00?ooool0
1?oo00<00=kkg_/00mkk1`001U[[00<0000P02000`0P00<00;Ff]KH00kFf00<0024T8B@0124T00<0
0:DdYC@00jDd00<000Q1244010Q100<007_?Nll00g_?00<002UU:FD00bUU00<00?oo00006?oo00<0
0?oo00004P0021SS2P002G>>00<007>>Lhh01W>>00<007>>Lhh01W>>00<007>>Lhh01W>>00<007>>
Lhh01W>>00<007>>Lhh01W>>00<00?oo00003ooo000@ool01000ooooo`000ooo00<00?oo00001g__
00<00;FF]IH01[FF00<00=kKg]/01]kK00<00?Nnmkh01ONn00<00?ooool01_oo00<00?Nnmkh01_Nn
00<00=kKg]/01]kK00<00:ee[GD01Jee00<007__Nnl01W__00<004YYBVT01TYY00<002448@@01B44
00<00?oo00006?oo00<00?oo00001LiI00<008aAS54018aA00<0048X@RP00d8X00<00?Nnmkh00oNn
00<00?ooool01?oo00<00=kkg_/00mkk1`001U[[00<0000P02000`0P00<00;Ff]KH00kFf00<0024T
8B@0124T00<00:DdYC@00jDd00<000Q1244010Q100<007_?Nll00g_?00<002UU:FD00bUU00<00?oo
00005?oo00H00?ooooooo`00oolC00086><:0009Lhh00`00LhicSP06Lhh00`00LhicSP06Lhh00`00
LhicSP06Lhh00`00LhicSP06Lhh00`00LhicSP06Lhh00`00ool0000?ool0017oo`03003oo`0000?o
o`03003oo`0000Mkk`03002eU[FF00JeUP03003NfmkK00KNf`03003g__Nn00Gg_P03003ooooo00Ko
o`03003g__Nn00Kg_P03003NfmkK00KNf`03002]MJee00F]M@03001kkg__00Ikk`03001:JDYY00I:
J@03000Q124400DQ1003003oo`0001?oo`8000?oo`03003oo`0000G>F@03002<DHaA00B<D@030012
:48X00=2:003003g__Nn00?g_P03003ooooo00Coo`03003Nnmkk00?Nn`L000IJj`030000800P00<0
8003002e][Ff00>e]P03000Q924T00@Q9003002U=:Dd00>U=0030008@@Q100@8@@03001kcg_?00=k
c`03000YIBUU00<YI@03003oo`0001Coo`06003oooooool00?oo4`0021SS2P002G>>00<007>>Lhh0
1W>>00<007>>Lhh01W>>00<007>>Lhh01W>>00<007>>Lhh01W>>00<007>>Lhh01W>>00<00?oo0000
3ooo000Bool20003ool00`00ool00007Nnl00`00]IJeUP06]IH00`00g]_Nf`06g]/00`00mkkg_P05
mkh00`00ooooo`06ool00`00mkkg_P06mkh00`00g]_Nf`06g]/00`00[GF]M@05[GD00`00Nnmkk`06
Nnl00`00BVU:J@06BVT00`008@@Q10058@@00`00ool0000Bool01000ooooo`000_oo00<00?oo0000
1LiI00<008aAS54018aA00<0048X@RP00d8X00<00?Nnmkh00oNn00<00?ooool01?oo00<00=kkg_/0
0mkk1`001U[[00<0000P02000`0P00<00;Ff]KH00kFf00<0024T8B@0124T00<00:DdYC@00jDd00<0
00Q1244010Q100<007_?Nll00g_?00<002UU:FD00bUU00<00?oo00004Ooo1@000_oo00<00?oo0000
F`0000?oo`00ool03_oo000Cool01`00oooooooo003oo`0000Mkk`03002eU[FF00JeUP03003NfmkK
00KNf`03003g__Nn00Gg_P03003ooooo00Koo`03003g__Nn00Kg_P03003NfmkK00KNf`03002]MJee
00F]M@03001kkg__00Ikk`03001:JDYY00I:J@03000Q124400DQ1003003oo`0001;oo`04003ooooo
0002ool00`00ool0001O00000ooo003oo`0@ool01000ooooo`000ooo00<00?oo00002@0021SS00<0
03W7>LL01SW700<001SS6><01QSS2`0028aa00<008aaS7401Xaa00<008aaS7401Xaa00<008aaS740
1Xaa00<008aaS7401Xaa00<00?oo00003ooo000Gool00`00ool00007Nnl00`00]IJeUP06]IH00`00
g]_Nf`06g]/00`00mkkg_P05mkh00`00ooooo`06ool00`00mkkg_P06mkh00`00g]_Nf`06g]/00`00
[GF]M@05[GD00`00Nnmkk`06Nnl00`00BVU:J@06BVT00`008@@Q10058@@00`00ool0000Bool30003
ool00`00ool00005mkh00`00mikgWP04mih00`00Nlmkc`03Nll00`00aQS66003aQP00`00mikgWP04
mih00`00@PQ22003@PP00`00Jfe[K@03Jfd00`00>LLia`04>LL00`008B@Q90038B@00`00Nlmkc`03
Nll00`00iccW?004ic`00`00mkkg_P03mkh00`00:FDYI@04:FD00`00Q1244003Q1000`002448@@03
24400`00ool0000Bool00`00ool00003ool00`00ool0000900086><00`00>LLia`06>LL00`006><H
h`066><;0008S7400`00S76<L@06S7400`00S76<L@06S7400`00S76<L@06S7400`00S76<L@06S740
0`00ool0000?ool001Ooo`03003oo`0000Mkk`03002eU[FF00JeUP03003NfmkK00KNf`03003g__Nn
00Gg_P03003ooooo00Koo`03003g__Nn00Kg_P03003NfmkK00KNf`03002]MJee00F]M@03001kkg__
00Ikk`03001:JDYY00I:J@03000Q124400DQ1003003oo`0001;oo`03003ooooo00?oo`03003oo`00
00Gg_P03003gW_NN00CgWP03001kcg_?00=kc`0300366<HH00?66003003gW_NN00CgWP0300122488
00=22003001[KF]]00=[K@03000iacW700@ia`03000Q924T00<Q9003001kcg_?00=kc`03003W?>Ll
00CW?003003g__Nn00?g_P03000YIBUU00@YI@03002448@@00>440030008@@Q100<8@@03003oo`00
01?oo`8000?oo`03003oo`0000T000PHh`03000iacW700Hia`03000HhaSS00HHh`/000R<L@03002<
LHaa00J<L@03002<LHaa00J<L@03002<LHaa00J<L@03002<LHaa00J<L@03003oo`0000ooo`005ooo
00<00?oo00001g__00<00;FF]IH01[FF00<00=kKg]/01]kK00<00?Nnmkh01ONn00<00?ooool01_oo
00<00?Nnmkh01_Nn00<00=kKg]/01]kK00<00:ee[GD01Jee00<007__Nnl01W__00<004YYBVT01TYY
00<002448@@01B4400<00?oo00004_oo00<00?ooool00ooo00<00?oo00001ONn00<00?NNmih01?NN
00<007_?Nll00g_?00<00<HHaQP00lHH00<00?NNmih01?NN00<00488@PP00d8800<006]]Jfd00f]]
00<003W7>LL013W700<0024T8B@00b4T00<007_?Nll00g_?00<00>Llic`01>Ll00<00?Nnmkh00oNn
00<002UU:FD012UU00<008@@Q1000h@@00<000Q124400`Q100<00?oo00005?oo00H00?ooooooo`00
ool:00086><00`00>LLia`06>LL00`006><Hh`066><;0008S7400`00S76<L@06S7400`00S76<L@06
S7400`00S76<L@06S7400`00S76<L@06S7400`00ool0000?ool001Ooo`03003oo`0000Mkk`03002e
U[FF00JeUP03003NfmkK00KNf`03003g__Nn00Gg_P03003ooooo00Koo`03003g__Nn00Kg_P03003N
fmkK00KNf`03002]MJee00F]M@03001kkg__00Ikk`03001:JDYY00I:J@03000Q124400DQ1003003o
o`0001?oo`<000;oo`03003oo`0000Gg_P03003gW_NN00CgWP03001kcg_?00=kc`0300366<HH00?6
6003003gW_NN00CgWP030012248800=22003001[KF]]00=[K@03000iacW700@ia`03000Q924T00<Q
9003001kcg_?00=kc`03003W?>Ll00CW?003003g__Nn00?g_P03000YIBUU00@YI@03002448@@00>4
40030008@@Q100<8@@03003oo`0001Soo`03003oo`0000T000PHh`03000iacW700Hia`03000HhaSS
00HHh`/000R<L@03002<LHaa00J<L@03002<LHaa00J<L@03002<LHaa00J<L@03002<LHaa00J<L@03
003oo`0000ooo`005ooo00<00?oo0000G`0000?oo`00ool05ooo00<00?oo00001ONn00<00?NNmih0
1?NN00<007_?Nll00g_?00<00<HHaQP00lHH00<00?NNmih01?NN00<00488@PP00d8800<006]]Jfd0
0f]]00<003W7>LL013W700<0024T8B@00b4T00<007_?Nll00g_?00<00>Llic`01>Ll00<00?Nnmkh0
0oNn00<002UU:FD012UU00<008@@Q1000h@@00<000Q124400`Q100<00?oo00006?oo00<00?oo0000
2@0021SS00<003W7>LL01SW700<001SS6><01QSS2`0028aa00<008aaS7401Xaa00<008aaS7401Xaa
00<008aaS7401Xaa00<008aaS7401Xaa00<00?oo00003ooo000Gool00`00ool00007Nnl00`00_ONm
m`06_OL00`00keg_G@06ked00`00ooooo`05ool00`00mkkg_P06mkh00`00cWW>N@06cWT00`00U;:D
/P06U;800`00F/]Jb`05F//00`008@@Q10068@@00`0002008006020900000ooo003oo`0Gool00`00
ool0001O00000ooo003oo`0Gool00`00ool0000900086><00`00>LLia`06>LL00`006><Hh`066><;
0008S7400`00S76<L@06S7400`00S76<L@06S7400`00S76<L@06S7400`00S76<L@06S7400`00ool0
000?ool001Ooo`03003oo`0000Mkk`03002mmkgg00Jmm`03003_GNmM00K_G@03003ooooo00Goo`03
003g__Nn00Kg_P03003>NLii00K>N@03002D/YBb00JD/P03001Jbe[;00EJb`03000Q124400HQ1003
0000800P00H080T00003ool00?oo01Ooo`03003oo`0000Gg_P03003FV]JJ00CFVP03001kcg_?00=k
c`03001BRU::00=BRP03003>NLii00C>N@03000YIBUU00<YI@03001cSW>>00=cSP03003NfmkK00CN
f`03002U5:DD00>U5003000iacW700<ia`03002448@@00B44003001Jje[[00=Jj`03003W7>LL00CW
7003001:BDY900=:B@03000iicWW00<ii`03003oo`0001Soo`03003oo`0000T000PHh`03000iacW7
00Hia`03000HhaSS00HHh`/000R<L@03002<LHaa00J<L@03002<LHaa00J<L@03002<LHaa00J<L@03
002<LHaa00J<L@03003oo`0000ooo`005ooo00<00?oo00001g__00<00;gg_OL01[gg00<00>mMked0
1^mM00<00?ooool01Ooo00<00?Nnmkh01_Nn00<00<iicWT01/ii00<009BbU;801YBb00<005[;F//0
1E[;00<002448@@01R4400<0000P02001P0P2@0000?oo`00ool05ooo00<00?oo00001ONn00<00=JJ
eYX01=JJ00<007_?Nll00g_?00<005::DXX00e::00<00<iicWT01<ii00<002UU:FD00bUU00<007>>
Lhh00g>>00<00=kKg]/01=kK00<00:DDYA@00jDD00<003W7>LL00cW700<008@@Q10018@@00<005[[
F^/00e[[00<00>LLia`01>LL00<004Y9BTT00dY900<003WW>NL00cWW00<00?oo00006?oo00<00?oo
0000F`0000?oo`00ool03_oo000Gool00`00ool00007Nnl00`00_ONmm`06_OL00`00keg_G@06ked0
0`00ooooo`05ool00`00mkkg_P06mkh00`00cWW>N@06cWT00`00U;:D/P06U;800`00F/]Jb`05F//0
0`008@@Q10068@@00`0002008006020900000ooo003oo`0Gool00`00ool00005mkh00`00eY[FVP04
eYX00`00Nlmkc`03Nll00`00DXYBRP03DXX00`00cWW>N@04cWT00`00:FDYI@03:FD00`00LhicSP03
Lhh00`00g]_Nf`04g]/00`00YABU5003YA@00`00>LLia`03>LL00`00Q1244004Q1000`00F^]Jj`03
F^/00`00iacW7004ia`00`00BTU:B@03BTT00`00>NLii`03>NL00`00ool0000Hool00`00ool0000K
0008>LL00`006><Hh`076><:0008[ED00`00[EF]E@06[ED00`00[EF]E@06[ED00`00[EF]E@06[ED0
0`00ool0000?ool001Ooo`03003oo`0000Mkk`03002mmkgg00Jmm`03003_GNmM00K_G@03003ooooo
00Goo`03003g__Nn00Kg_P03003>NLii00K>N@03002D/YBb00JD/P03001Jbe[;00EJb`03000Q1244
00HQ10030000800P00H080T00003ool00?oo01Ooo`03003oo`0000Gg_P03003FV]JJ00CFVP03001k
cg_?00=kc`03001BRU::00=BRP03003>NLii00C>N@03000YIBUU00<YI@03001cSW>>00=cSP03003N
fmkK00CNf`03002U5:DD00>U5003000iacW700<ia`03002448@@00B44003001Jje[[00=Jj`03003W
7>LL00CW7003001:BDY900=:B@03000iicWW00<ii`03003oo`0001Soo`03003oo`0001/000Pia`03
000HhaSS00LHh`X000R]E@03002]EJeE00J]E@03002]EJeE00J]E@03002]EJeE00J]E@03003oo`00
00ooo`005ooo00<00?oo00001g__00<00;gg_OL01[gg00<00>mMked01^mM00<00?ooool01Ooo00<0
0?Nnmkh01_Nn00<00<iicWT01/ii00<009BbU;801YBb00<005[;F//01E[;00<002448@@01R4400<0
000P02001P0P2@0000?oo`00ool04_oo0P000ooo00<00?oo00001ONn00<00=JJeYX01=JJ00<007_?
Nll00g_?00<005::DXX00e::00<00<iicWT01<ii00<002UU:FD00bUU00<007>>Lhh00g>>00<00=kK
g]/01=kK00<00:DDYA@00jDD00<003W7>LL00cW700<008@@Q10018@@00<005[[F^/00e[[00<00>LL
ia`01>LL00<004Y9BTT00dY900<003WW>NL00cWW00<00?oo00006?oo00<00?oo00006`0023W700<0
01SS6><01aSS2P002:eE00<00:eE[ED01ZeE00<00:eE[ED01ZeE00<00:eE[ED01ZeE00<00?oo0000
3ooo000Bool20003ool00`00ool00007Nnl00`00_ONmm`06_OL00`00keg_G@06ked00`00ooooo`05
ool00`00mkkg_P06mkh00`00cWW>N@06cWT00`00U;:D/P06U;800`00F/]Jb`05F//00`008@@Q1006
8@@00`0002008006020900000ooo003oo`0Aool01000ooooo`000_oo00<00?oo00001ONn00<00=JJ
eYX01=JJ00<007_?Nll00g_?00<005::DXX00e::00<00<iicWT01<ii00<002UU:FD00bUU00<007>>
Lhh00g>>00<00=kKg]/01=kK00<00:DDYA@00jDD00<003W7>LL00cW700<008@@Q10018@@00<005[[
F^/00e[[00<00>LLia`01>LL00<004Y9BTT00dY900<003WW>NL00cWW00<00?oo00006?oo00<00?oo
00006`0023W700<001SS6><01aSS2P002:eE00<00:eE[ED01ZeE00<00:eE[ED01ZeE00<00:eE[ED0
1ZeE00<00?oo00003ooo000Aool01000ooooo`000_oo00<00?oo00001g__00<00;gg_OL01[gg00<0
0>mMked01^mM00<00?ooool01Ooo00<00?Nnmkh01_Nn00<00<iicWT01/ii00<009BbU;801YBb00<0
05[;F//01E[;00<002448@@01R4400<0000P02001P0P2@0000?oo`00ool04Ooo00@00?ooool000;o
o`03003oo`0005l00003ool00?oo01Ooo`03003oo`0001/000Pia`03000HhaSS00LHh`X000R]E@03
002]EJeE00J]E@03002]EJeE00J]E@03002]EJeE00J]E@03003oo`0000ooo`004Ooo00@00?ooool0
00;oo`03003oo`0005l00003ool00?oo01;oo`8000?oo`03003oo`0000GgWP03002]EJeE00B]E@03
000Q924T00<Q90030036><Hh00?6>0030008H@QQ00@8H@03002e][Ff00>e]P03003g__Nn00?g_P03
0012:48X00A2:0030000800P00<0800300366<HH00?66003000Q924T00@Q9003003>FLiI00?>F@03
002e][Ff00Be]P03003gW_NN00?gWP03003g__Nn00?g_P03003oo`0001Soo`03003oo`0001/000Pi
a`03000HhaSS00LHh`X000R]E@03002]EJeE00J]E@03002]EJeE00J]E@03002]EJeE00J]E@03003o
o`0000ooo`004Ooo0`000ooo00<00?oo00001g__00<00<HhaSP01/Hh00<00?Nnmkh01_Nn00<00?oo
ool01Ooo00<00=kKg]/01]kK00<009BbU;801YBb00<004YYBVT01TYY00<0012R4:801A2R2P00212R
00<005::DXX01E::00<00?oo00004_oo00@00?ooool000;oo`03003oo`0000GgWP03002]EJeE00B]
E@03000Q924T00<Q90030036><Hh00?6>0030008H@QQ00@8H@03002e][Ff00>e]P03003g__Nn00?g
_P030012:48X00A2:0030000800P00<0800300366<HH00?66003000Q924T00@Q9003003>FLiI00?>
F@03002e][Ff00Be]P03003gW_NN00?gWP03003g__Nn00?g_P03003oo`0001?oo`8000?oo`03003o
o`0001/000Pia`03000HhaSS00LHh`X000R]E@03002]EJeE00J]E@03002]EJeE00J]E@03002]EJeE
00J]E@03003oo`0000ooo`004Ooo00<00?ooool00ooo00<00?oo00001g__00<00<HhaSP01/Hh00<0
0?Nnmkh01_Nn00<00?ooool01Ooo00<00=kKg]/01]kK00<009BbU;801YBb00<004YYBVT01TYY00<0
012R4:801A2R2P00212R00<005::DXX01E::00<00?oo00004_oo00@00?ooool000;oo`03003oo`00
00GgWP03002]EJeE00B]E@03000Q924T00<Q90030036><Hh00?6>0030008H@QQ00@8H@03002e][Ff
00>e]P03003g__Nn00?g_P030012:48X00A2:0030000800P00<0800300366<HH00?66003000Q924T
00@Q9003003>FLiI00?>F@03002e][Ff00Be]P03003gW_NN00?gWP03003g__Nn00?g_P03003oo`00
01;oo`04003ooooo0002ool00`00ool0000K0008>LL00`006><Hh`076><:0008[ED00`00[EF]E@06
[ED00`00[EF]E@06[ED00`00[EF]E@06[ED00`00ool0000?ool0017oo`03003ooooo00?oo`03003o
o`0000Mkk`030036><Hh00K6>003003g__Nn00Kg_P03003ooooo00Goo`03003NfmkK00KNf`03002D
/YBb00JD/P03001:JDYY00I:J@03000@XQ2R00D@XPX000P@XP03001BRU::00EBRP03003oo`0001?o
o`8000?oo`03003oo`0000GgWP03002]EJeE00B]E@03000Q924T00<Q90030036><Hh00?6>0030008
H@QQ00@8H@03002e][Ff00>e]P03003g__Nn00?g_P030012:48X00A2:0030000800P00<080030036
6<HH00?66003000Q924T00@Q9003003>FLiI00?>F@03002e][Ff00Be]P03003gW_NN00?gWP03003g
__Nn00?g_P03003oo`0001;oo`04003ooooo0002ool00`00ool0001K00000ooo003oo`0>ool001;o
o`<000;oo`03003oo`0000Mkk`030036><Hh00K6>003003g__Nn00Kg_P03003ooooo00Goo`03003N
fmkK00KNf`03002D/YBb00JD/P03001:JDYY00I:J@03000@XQ2R00D@XPX000P@XP03001BRU::00EB
RP03003oo`0001Soo`03003oo`0000GgWP03002]EJeE00B]E@03000Q924T00<Q90030036><Hh00?6
>0030008H@QQ00@8H@03002e][Ff00>e]P03003g__Nn00?g_P030012:48X00A2:0030000800P00<0
800300366<HH00?66003000Q924T00@Q9003003>FLiI00?>F@03002e][Ff00Be]P03003gW_NN00?g
WP03003g__Nn00?g_P03003oo`0001;oo`<000?oo`03003oo`0000T000PHh`03000HhaSS00HHh`03
001BZU:Z00IBZP03000iacW700Lia`03000HhaSS00HHh`X000S6>0030036><Hh00K6>0030036><Hh
00K6>003003oo`0000ooo`005ooo00<00?oo00001g__00<00<HhaSP01/Hh00<00?Nnmkh01_Nn00<0
0?ooool01Ooo00<00=kKg]/01]kK00<009BbU;801YBb00<004YYBVT01TYY00<0012R4:801A2R2P00
212R00<005::DXX01E::00<00?oo00006?oo00<00?oo0000G`0000?oo`00ool04Ooo00<00?ooool0
0ooo00<00?oo00002@0021SS00<001SS6><01QSS00<005:ZDZX01U:Z00<003W7>LL01cW700<001SS
6><01QSS2P002<Hh00<00<HhaSP01/Hh00<00<HhaSP01/Hh00<00?oo00003ooo000Gool00`00ool0
0007Nnl00`00aSS6>006aSP00`00mkkg_P06mkh00`00ooooo`05ool00`00g]_Nf`06g]/00`00U;:D
/P06U;800`00BVU:J@06BVT00`004:8@XP054:8:00084:800`00DXYBRP05DXX00`00ool0000Hool0
0`00ool00005F//00`00g__Nn`04g_/00`00DXYBRP03DXX00`00_ONmm`03_OL00`00g]_Nf`04g]/0
0`00Nnmkk`03Nnl00`00Jfe[K@03Jfd00`00LhicSP04Lhh00`00W?>Ll`03W?<00`00S76<L@03S740
0`00cUW>F@04cUT00`00BTU:B@03BTT00`00g]_Nf`04g]/00`00Q1244003Q1000`004:8@XP034:80
0`00ool0000Bool00`00ooooo`03ool00`00ool0000900086><00`006><Hh`066><00`00DZYBZP06
DZX00`00>LLia`07>LL00`006><Hh`066><:0008aSP00`00aSS6>006aSP00`00aSS6>006aSP00`00
ool0000?ool001Ooo`03003oo`0000Mkk`030036><Hh00K6>003003g__Nn00Kg_P03003ooooo00Go
o`03003NfmkK00KNf`03002D/YBb00JD/P03001:JDYY00I:J@03000@XQ2R00D@XPX000P@XP03001B
RU::00EBRP03003oo`0001Soo`03003oo`0000EJb`03003Nnmkk00CNn`03001BRU::00=BRP03002m
mkgg00>mm`03003NfmkK00CNf`03001kkg__00=kk`03001[KF]]00=[K@03001cSW>>00AcSP03002L
licc00>Ll`03002<LHaa00><L@03003>FLiI00C>F@03001:BDY900=:B@03003NfmkK00CNf`030024
48@@00>44003000@XQ2R00<@XP03003oo`0001?oo`<000;oo`03003oo`0000T000PHh`03000HhaSS
00HHh`03001BZU:Z00IBZP03000iacW700Lia`03000HhaSS00HHh`X000S6>0030036><Hh00K6>003
0036><Hh00K6>003003oo`0000ooo`005ooo00<00?oo0000G`0000?oo`00ool05ooo00<00?oo0000
1E[;00<00=kkg_/01=kk00<005::DXX00e::00<00;gg_OL00kgg00<00=kKg]/01=kK00<007__Nnl0
0g__00<006]]Jfd00f]]00<007>>Lhh017>>00<009ccW?<00icc00<008aaS7400haa00<00<iIcUT0
1<iI00<004Y9BTT00dY900<00=kKg]/01=kK00<008@@Q1000h@@00<0012R4:800a2R00<00?oo0000
6?oo00<00?oo00002@0021SS00<001SS6><01QSS00<005:ZDZX01U:Z00<003W7>LL01cW700<001SS
6><01QSS2P002<Hh00<00<HhaSP01/Hh00<00<HhaSP01/Hh00<00?oo00003ooo000Gool00`00ool0
0007Nnl00`00eY[FVP06eYX00`00ooooo`06ool00`00mikgWP05mih00`00[GF]M@06[GD00`00F/]J
b`06F//00`004:8@XP064:890008:DD00`00Ljic[P06Ljh00`00cUW>F@05cUT00`00ool0000<ool4
0003ool20003ool00`00ool00005F//00`00g__Nn`04g_/00`00DXYBRP03DXX00`00_ONmm`03_OL0
0`00g]_Nf`04g]/00`00Nnmkk`03Nnl00`00Jfe[K@03Jfd00`00LhicSP04Lhh00`00W?>Ll`03W?<0
0`00S76<L@03S7400`00cUW>F@04cUT00`00BTU:B@03BTT00`00g]_Nf`04g]/00`00Q1244003Q100
0`004:8@XP034:800`00ool0000Hool00`00ool0000900086><00`006><Hh`066><00`00DZYBZP06
DZX00`00>LLia`07>LL00`006><Hh`066><:0008aSP00`00aSS6>006aSP00`00aSS6>006aSP00`00
ool0000?ool001Ooo`03003oo`0000Mkk`03003FV]JJ00KFVP03003ooooo00Koo`03003gW_NN00Gg
WP03002]MJee00J]M@03001Jbe[;00IJb`03000@XQ2R00H@XPT000PYA@03001c[W>^00Ic[P03003>
FLiI00G>F@03003oo`0000koo`05003oooooool00002ool01P00ooooo`00ool000EJb`03003Nnmkk
00CNn`03001BRU::00=BRP03002mmkgg00>mm`03003NfmkK00CNf`03001kkg__00=kk`03001[KF]]
00=[K@03001cSW>>00AcSP03002Llicc00>Ll`03002<LHaa00><L@03003>FLiI00C>F@03001:BDY9
00=:B@03003NfmkK00CNf`03002448@@00>44003000@XQ2R00<@XP03003oo`0001Soo`03003oo`00
00T000PHh`03000HhaSS00HHh`03001BZU:Z00IBZP03000iacW700Lia`03000HhaSS00HHh`X000S6
>0030036><Hh00K6>0030036><Hh00K6>003003oo`0000ooo`005ooo00<00?oo00001g__00<00=JJ
eYX01]JJ00<00?ooool01_oo00<00?NNmih01ONN00<00:ee[GD01Zee00<005[;F//01U[;00<0012R
4:801Q2R2@0022U500<007>^Ljh01W>^00<00<iIcUT01LiI00<00?oo00003_oo00D00?ooooooo`00
00;oo`05003ooooo003oo`1P00000ooo003oo`0Gool00`00ool0000900086><00`006><Hh`066><0
0`00DZYBZP06DZX00`00>LLia`07>LL00`006><Hh`066><:0008aSP00`00aSS6>006aSP00`00aSS6
>006aSP00`00ool0000?ool001Ooo`03003oo`0000Mkk`03003FV]JJ00KFVP03003ooooo00Koo`03
003gW_NN00GgWP03002]MJee00J]M@03001Jbe[;00IJb`03000@XQ2R00H@XPT000PYA@03001c[W>^
00Ic[P03003>FLiI00G>F@03003oo`0000koo`05003oooooool00002ool01P00ooooo`00ool000EB
ZP03002D/YBb00BD/P03001kcg_?00=kc`03001BZU:Z00=BZP03000aQS6600@aQP03003>NLii00?>
N@03003>FLiI00?>F@03001S36<<00AS3003000iacW700<ia`03001cSW>>00=cSP03003_GNmM00C_
G@03000@PQ2200<@PP03002448@@00B44003002LdicC00>Ld`03001[KF]]00=[K@03003oo`0001So
o`03003oo`0005/00003ool00?oo00koo`005ooo00<00?oo00001g__00<00=JJeYX01]JJ00<00?oo
ool01_oo00<00?NNmih01ONN00<00:ee[GD01Zee00<005[;F//01U[;00<0012R4:801Q2R2@0022U5
00<007>^Ljh01W>^00<00<iIcUT01LiI00<00?oo00003_oo00D00?ooooooo`0000;oo`06003ooooo
003oo`001E:Z00<009BbU;8019Bb00<007_?Nll00g_?00<005:ZDZX00e:Z00<00366<HH0136600<0
0<iicWT00lii00<00<iIcUT00liI00<006<<H``016<<00<003W7>LL00cW700<007>>Lhh00g>>00<0
0>mMked01>mM00<0012248800a2200<008@@Q10018@@00<009cCW=<00icC00<006]]Jfd00f]]00<0
0?oo00006?oo00<00?oo00004P0023W72P002E:Z00<003W7>LL01SW700<001SS6><01QSS2P002>LL
00<00>LLia`01^LL00<00?oo00003ooo000Gool00`00ool00007Nnl00`00eY[FVP06eYX00`00oooo
o`06ool00`00mikgWP05mih00`00[GF]M@06[GD00`00F/]Jb`06F//00`004:8@XP064:890008:DD0
0`00Ljic[P06Ljh00`00cUW>F@05cUT00`00ool0000<ool30003ool01000ooooo`000_oo00<00?oo
00001E:Z00<009BbU;8019Bb00<007_?Nll00g_?00<005:ZDZX00e:Z00<00366<HH0136600<00<ii
cWT00lii00<00<iIcUT00liI00<006<<H``016<<00<003W7>LL00cW700<007>>Lhh00g>>00<00>mM
ked01>mM00<0012248800a2200<008@@Q10018@@00<009cCW=<00icC00<006]]Jfd00f]]00<00?oo
00006?oo00<00?oo00004P0023W72P002E:Z00<003W7>LL01SW700<001SS6><01QSS2P002>LL00<0
0>LLia`01^LL00<00?oo00003ooo000Bool20003ool00`00ool00007Nnl00`00eY[FVP06eYX00`00
ooooo`06ool00`00mikgWP05mih00`00[GF]M@06[GD00`00F/]Jb`06F//00`004:8@XP064:890008
:DD00`00Ljic[P06Ljh00`00cUW>F@05cUT00`00ool0000>ool00`00ooooo`02ool20003ool00`00
ool00005DZX00`00U;:D/P04U;800`00Nlmkc`03Nll00`00DZYBZP03DZX00`00<HHaQP04<HH00`00
cWW>N@03cWT00`00cUW>F@03cUT00`00H`aS3004H``00`00>LLia`03>LL00`00LhicSP03Lhh00`00
keg_G@04ked00`00488@PP0348800`00Q1244004Q1000`00W=>Ld`03W=<00`00Jfe[K@03Jfd00`00
ool0000Hool00`00ool0000B0008>LL:0009DZX00`00>LLia`06>LL00`006><Hh`066><:0008ia`0
0`00iacW7006ia`00`00ool0000?ool0017oo`04003ooooo0002ool00`00ool00007Nnl00`00eY[F
VP06eYX00`00ooooo`06ool00`00mikgWP05mih00`00[GF]M@06[GD00`00F/]Jb`06F//00`004:8@
XP064:890008:DD00`00Ljic[P06Ljh00`00cUW>F@05cUT00`00ool0000Hool00`00ool00005DZX0
0`00U;:D/P04U;800`00Nlmkc`03Nll00`00DZYBZP03DZX00`00<HHaQP04<HH00`00cWW>N@03cWT0
0`00cUW>F@03cUT00`00H`aS3004H``00`00>LLia`03>LL00`00LhicSP03Lhh00`00keg_G@04ked0
0`00488@PP0348800`00Q1244004Q1000`00W=>Ld`03W=<00`00Jfe[K@03Jfd00`00ool0000Hool0
0`00ool0000B0008>LL:0009DZX00`00>LLia`06>LL00`006><Hh`066><:0008ia`00`00iacW7006
ia`00`00ool0000?ool0017oo`04003ooooo0002ool00`00ool0001O00000ooo003oo`0Gool00`00
ool00005DZX00`00U;:D/P04U;800`00Nlmkc`03Nll00`00DZYBZP03DZX00`00<HHaQP04<HH00`00
cWW>N@03cWT00`00cUW>F@03cUT00`00H`aS3004H``00`00>LLia`03>LL00`00LhicSP03Lhh00`00
keg_G@04ked00`00488@PP0348800`00Q1244004Q1000`00W=>Ld`03W=<00`00Jfe[K@03Jfd00`00
ool0000Hool00`00ool0000B0008>LL:0009DZX00`00>LLia`06>LL00`006><Hh`066><:0008ia`0
0`00iacW7006ia`00`00ool0000?ool001;oo`8000?oo`03003oo`0000Mkk`03003NfmkK00KNf`03
003ooooo00Koo`03003NfmkK00GNf`03001kkg__00Ikk`03000Q124400HQ10X000LYA@030024<8@`
00J4<003003Nnmkk00KNn`03003ooooo00Goo`03003oo`0001Soo`03003oo`0005l00003ool00?oo
01Ooo`03003oo`00018000Pia`X000UBZP03000iacW700Hia`03000HhaSS00HHh`X000SW7003003W
7>LL00KW7003003oo`0000ooo`004Ooo00@00?ooool000;oo`03003oo`0000Mkk`03003NfmkK00KN
f`03003ooooo00Koo`03003NfmkK00GNf`03001kkg__00Ikk`03000Q124400HQ10X000LYA@030024
<8@`00J4<003003Nnmkk00KNn`03003ooooo00Goo`03003oo`0001Soo`03003oo`0000FU5003000@
PQ2200@@PP03003ooooo00?oo`03003Nnmkk00?Nn`03003Nnmkk00CNn`030036><Hh00?6>003000Q
924T00<Q9003001Jje[[00AJj`030036><Hh00?6>003001cSW>>00=cSP03002DTYBB00BDTP03003W
?>Ll00?W?003001cSW>>00AcSP030012248800=220030036><Hh00?6>003003oo`0001Soo`03003o
o`00018000Pia`X000UBZP03000iacW700Hia`03000HhaSS00HHh`X000SW7003003W7>LL00KW7003
003oo`0000ooo`004Ooo00@00?ooool000;oo`03003oo`0000Mkk`03003NfmkK00KNf`03003ooooo
00Koo`03003NfmkK00GNf`03001kkg__00Ikk`03000Q124400HQ10X000LYA@030024<8@`00J4<003
003Nnmkk00KNn`03003ooooo00Goo`03003oo`0001Soo`03003oo`0000FU5003000@PQ2200@@PP03
003ooooo00?oo`03003Nnmkk00?Nn`03003Nnmkk00CNn`030036><Hh00?6>003000Q924T00<Q9003
001Jje[[00AJj`030036><Hh00?6>003001cSW>>00=cSP03002DTYBB00BDTP03003W?>Ll00?W?003
001cSW>>00AcSP030012248800=220030036><Hh00?6>003003oo`0001?oo`8000?oo`03003oo`00
018000Pia`X000UBZP03000iacW700Hia`03000HhaSS00HHh`X000SW7003003W7>LL00KW7003003o
o`0000ooo`004_oo0P000ooo00<00?oo00001g__00<00=kKg]/01]kK00<00?ooool01_oo00<00=kK
g]/01MkK00<007__Nnl01W__00<002448@@01R442P001bU500<008@`Q3001X@`00<00=kkg_/01]kk
00<00?ooool01Ooo00<00?oo00006?oo00<00?oo00001JDD00<001224880112200<00?ooool00ooo
00<00=kkg_/00mkk00<00=kkg_/01=kk00<00<HhaSP00lHh00<0024T8B@00b4T00<005[[F^/015[[
00<00<HhaSP00lHh00<007>>Lhh00g>>00<009BBU98019BB00<00>Llic`00nLl00<007>>Lhh017>>
00<00488@PP00d8800<00<HhaSP00lHh00<00?oo00004_oo00@00?ooool000;oo`03003oo`000180
00Pia`X000UBZP03000iacW700Hia`03000HhaSS00HHh`X000SW7003003W7>LL00KW7003003oo`00
00ooo`005ooo00<00?oo00001g__00<00=kKg]/01]kK00<00?ooool01_oo00<00=kKg]/01MkK00<0
07__Nnl01W__00<002448@@01R442P001bU500<008@`Q3001X@`00<00=kkg_/01]kk00<00?ooool0
1Ooo00<00?oo00003?oo10000_oo10000_oo00<00?oo00001JDD00<001224880112200<00?ooool0
0ooo00<00=kkg_/00mkk00<00=kkg_/01=kk00<00<HhaSP00lHh00<0024T8B@00b4T00<005[[F^/0
15[[00<00<HhaSP00lHh00<007>>Lhh00g>>00<009BBU98019BB00<00>Llic`00nLl00<007>>Lhh0
17>>00<00488@PP00d8800<00<HhaSP00lHh00<00?oo00004_oo00@00?ooool000;oo`03003oo`00
05/00003ool00?oo00koo`005ooo00<00?oo00001g__00<00=kKg]/01]kK00<00?ooool01_oo00<0
0=kKg]/01MkK00<007__Nnl01W__00<002448@@01R442P001bU500<008@`Q3001X@`00<00=kkg_/0
1]kk00<00?ooool01Ooo00<00?oo00003_oo00D00?ooooooo`0000Goo`03003oo`0000FU5003000@
PQ2200@@PP03003ooooo00?oo`03003Nnmkk00?Nn`03003Nnmkk00CNn`030036><Hh00?6>003000Q
924T00<Q9003001Jje[[00AJj`030036><Hh00?6>003001cSW>>00=cSP03002DTYBB00BDTP03003W
?>Ll00?W?003001cSW>>00AcSP030012248800=220030036><Hh00?6>003003oo`0001?oo`8000?o
o`03003oo`0000T000PHh`X000PHh`03001cSW>>00McSP03001BZU:Z00IBZP03000iacW700Hia`03
000HhaSS00HHh`X000Soo`03003oo`0000ooo`005ooo00<00?oo00001g__00<00=kKg]/01]kK00<0
0?ooool01_oo00<00=kKg]/01MkK00<007__Nnl01W__00<002448@@01R442P001bU500<008@`Q300
1X@`00<00=kkg_/01]kk00<00?ooool01Ooo00<00?oo00003_oo00<00?ooool00_oo00<00?ooool0
0_oo00<00?oo0000G`0000?oo`00ool04Ooo00@00?ooool000;oo`03003oo`0000T000PHh`X000PH
h`03001cSW>>00McSP03001BZU:Z00IBZP03000iacW700Hia`03000HhaSS00HHh`X000Soo`03003o
o`0000ooo`005ooo00<00?oo00001g__00<00=kKg]/01]kK00<00?ooool01_oo00<00=kKg]/01MkK
00<007__Nnl01W__00<002448@@01R442P001bU500<008@`Q3001X@`00<00=kkg_/01]kk00<00?oo
ool01Ooo00<00?oo00003_oo00<00?ooool00ooo00L00?ooooooo`00ool000056><00`002648H@04
26400`000200800302000`00DXYBRP03DXX00`00<JHaYP04<JH00`00ooooo`03ool00`00Q324<003
Q3000`00_MNme`04_ML00`00cUW>F@03cUT00`00F^]Jj`03F^/00`00Ljic[P04Ljh00`00_ONmm`03
_OL00`00kgg_O@04kgd00`00Q1244003Q1000`00]IJeUP03]IH00`00ool0000Bool01000ooooo`00
0_oo00<00?oo00002@0021SS2P0021SS00<007>>Lhh01g>>00<005:ZDZX01U:Z00<003W7>LL01SW7
00<001SS6><01QSS2P002?oo00<00?oo00003ooo000Gool00`00ool0001O00000ooo003oo`0=ool0
0`00ooooo`04ool01P00ooooo`00ool000DHh`030008H@QQ00@8H@030000800P00<08003001BRU::
00=BRP03000aYS6V00@aYP03003ooooo00?oo`030024<8@`00>4<003002mekgG00Bme`03003>FLiI
00?>F@03001Jje[[00=Jj`03001c[W>^00Ac[P03002mmkgg00>mm`03003_ONmm00C_O@03002448@@
00>44003002eU[FF00>eUP03003oo`0001?oo`8000?oo`03003oo`0000T000PHh`X000PHh`03001c
SW>>00McSP03001BZU:Z00IBZP03000iacW700Hia`03000HhaSS00HHh`X000Soo`03003oo`0000oo
o`005ooo00<00?oo00001g__00<00>LLia`01^LL00<00?ooool01_oo00<00;gG_ML01KgG00<004YY
BVT01TYY00<0000P02001P0P00<0012R4:801Q2R00<007>^Ljh01G>^00<00=kkg_/01]kk00<00?oo
ool01_oo00<00<HHaQP01LHH00<00?oo00003?oo0`000ooo00@00?ooool000;oo`03003oo`0000DH
h`030008H@QQ00@8H@030000800P00<08003001BRU::00=BRP03000aYS6V00@aYP03003ooooo00?o
o`030024<8@`00>4<003002mekgG00Bme`03003>FLiI00?>F@03001Jje[[00=Jj`03001c[W>^00Ac
[P03002mmkgg00>mm`03003_ONmm00C_O@03002448@@00>44003002eU[FF00>eUP03003oo`0001So
o`03003oo`0000T000PHh`X000PHh`03001cSW>>00McSP03001BZU:Z00IBZP03000iacW700Hia`03
000HhaSS00HHh`X000Soo`03003oo`0000ooo`005ooo00<00?oo00001g__00<00>LLia`01^LL00<0
0?ooool01_oo00<00;gG_ML01KgG00<004YYBVT01TYY00<0000P02001P0P00<0012R4:801Q2R00<0
07>^Ljh01G>^00<00=kkg_/01]kk00<00?ooool01_oo00<00<HHaQP01LHH00<00?oo00003_oo00<0
0?ooool00_oo0P000ooo00<00?oo00001ASS00<000QQ264010QQ00<0000P02000`0P00<005::DXX0
0e::00<0036V<JH0136V00<00?ooool00ooo00<008@`Q3000h@`00<00;gG_ML01;gG00<00<iIcUT0
0liI00<005[[F^/00e[[00<007>^Ljh017>^00<00;gg_OL00kgg00<00>mmkgd01>mm00<008@@Q100
0h@@00<00;FF]IH00kFF00<00?oo00006?oo00<00?oo00002@0021SS2P0021SS00<007>>Lhh01g>>
00<005:ZDZX01U:Z00<003W7>LL01SW700<001SS6><01QSS2P002?oo00<00?oo00003ooo000Gool0
0`00ool00007Nnl00`00iacW7006ia`00`00ooooo`06ool00`00_MNme`05_ML00`00BVU:J@06BVT0
0`000200800602000`004:8@XP064:800`00Ljic[P05Ljh00`00g__Nn`06g_/00`00ooooo`06ool0
0`00aQS66005aQP00`00ool0000Hool00`00ool000056><00`002648H@0426400`00020080030200
0`00DXYBRP03DXX00`00<JHaYP04<JH00`00ooooo`03ool00`00Q324<003Q3000`00_MNme`04_ML0
0`00cUW>F@03cUT00`00F^]Jj`03F^/00`00Ljic[P04Ljh00`00_ONmm`03_OL00`00kgg_O@04kgd0
0`00Q1244003Q1000`00]IJeUP03]IH00`00ool0000Hool00`00ool0000900086><:00086><00`00
LhicSP07Lhh00`00DZYBZP06DZX00`00>LLia`06>LL00`006><Hh`066><:0008ool00`00ool0000?
ool001Ooo`03003oo`0000Mkk`03003W7>LL00KW7003003ooooo00Koo`03002mekgG00Fme`03001:
JDYY00I:J@030000800P00H08003000@XQ2R00H@XP03001c[W>^00Ec[P03003Nnmkk00KNn`03003o
oooo00Koo`0300366<HH00G66003003oo`0001Soo`03003oo`0005l00003ool00?oo01Ooo`03003o
o`0000T000PHh`X000PHh`03001cSW>>00McSP03001BZU:Z00IBZP03000iacW700Hia`03000HhaSS
00HHh`X000Soo`03003oo`0000ooo`005ooo00<00?oo00001g__00<00>LLia`01^LL00<00?ooool0
1_oo00<00;gG_ML01KgG00<004YYBVT01TYY00<0000P02001P0P00<0012R4:801Q2R00<007>^Ljh0
1G>^00<00=kkg_/01]kk00<00?ooool01_oo00<00<HHaQP01LHH00<00?oo00006?oo00<00?oo0000
1IcC00<008aaS74018aa00<00;gg_OL00kgg00<003WW>NL00cWW00<0000P0200100P00<00:DdYC@0
0jDd00<004Y9BTT00dY900<00?ooool01?oo00<00488@PP00d8800<008aAS5400haA00<003W7>LL0
13W700<00?oOoml00ooO00<00?NNmih01?NN00<005:ZDZX00e:Z00<003WW>NL00cWW00<00?oo0000
6?oo00<00?oo0000F`0000?oo`00ool03_oo000Gool00`00ool00007Nnl00`00iacW7006ia`00`00
ooooo`06ool00`00_MNme`05_ML00`00BVU:J@06BVT00`000200800602000`004:8@XP064:800`00
Ljic[P05Ljh00`00g__Nn`06g_/00`00ooooo`06ool00`00aQS66005aQP00`00ool0000Hool00`00
ool00005W=<00`00S76<L@04S7400`00_ONmm`03_OL00`00>NLii`03>NL00`000200800402000`00
YCBU=003YC@00`00BTU:B@03BTT00`00ooooo`04ool00`00@PQ22003@PP00`00S56<D@03S5400`00
>LLia`04>LL00`00omoog`03oml00`00mikgWP04mih00`00DZYBZP03DZX00`00>NLii`03>NL00`00
ool0000Hool00`00ool0000B00086><00`00>LLia`06>LL;0008Lhh00`00DZYBZP06DZX00`00>LLi
a`06>LL00`006><Hh`066><:00000ooo003oo`0>ool000_oo`@000?oo`8000?oo`03003oo`0000Mk
k`03003W7>LL00KW7003003ooooo00Koo`03002mekgG00Fme`03001:JDYY00I:J@030000800P00H0
8003000@XQ2R00H@XP03001c[W>^00Ec[P03003Nnmkk00KNn`03003ooooo00Koo`0300366<HH00G6
6003003oo`0001Soo`03003oo`0000FLd`03002<LHaa00B<L@03002mmkgg00>mm`03000iicWW00<i
i`030000800P00@08003002U=:Dd00>U=003001:BDY900=:B@03003ooooo00Coo`030012248800=2
2003002<DHaA00><D@03000iacW700@ia`03003ogooO00?og`03003gW_NN00CgWP03001BZU:Z00=B
ZP03000iicWW00<ii`03003oo`0001Soo`03003oo`00018000PHh`03000iacW700Hia`/000QcSP03
001BZU:Z00IBZP03000iacW700Hia`03000HhaSS00HHh`X00003ool00?oo00koo`003Ooo00D00?oo
ooooo`0000;oo`06003ooooo003oo`001g__00<00>LLia`01^LL00<00?ooool01_oo00<00;gG_ML0
1KgG00<004YYBVT01TYY00<0000P02001P0P00<0012R4:801Q2R00<007>^Ljh01G>^00<00=kkg_/0
1]kk00<00?ooool01_oo00<00<HHaQP01LHH00<00?oo00006?oo00<00?oo00001IcC00<008aaS740
18aa00<00;gg_OL00kgg00<003WW>NL00cWW00<0000P0200100P00<00:DdYC@00jDd00<004Y9BTT0
0dY900<00?ooool01?oo00<00488@PP00d8800<008aAS5400haA00<003W7>LL013W700<00?oOoml0
0ooO00<00?NNmih01?NN00<005:ZDZX00e:Z00<003WW>NL00cWW00<00?oo00006?oo00<00?oo0000
4P0021SS00<003W7>LL01SW72`0027>>00<005:ZDZX01U:Z00<003W7>LL01SW700<001SS6><01QSS
2P0000?oo`00ool03_oo000=ool01@00oooooooo00000_oo00D00?ooool00?oo06000003ool00?oo
00_oo`@000Coo`07003oooooool00?oo00001IcC00<008aaS74018aa00<00;gg_OL00kgg00<003WW
>NL00cWW00<0000P0200100P00<00:DdYC@00jDd00<004Y9BTT00dY900<00?ooool01?oo00<00488
@PP00d8800<008aAS5400haA00<003W7>LL013W700<00?oOoml00ooO00<00?NNmih01?NN00<005:Z
DZX00e:Z00<003WW>NL00cWW00<00?oo00006?oo00<00?oo00004P0021SS00<003W7>LL01SW72`00
27>>00<005:ZDZX01U:Z00<003W7>LL01SW700<001SS6><01QSS2P0000?oo`00ool03_oo000=ool0
1@00oooooooo00000_oo00H00?ooool00?oo0007Nnl00`00keg_G@06ked00`00mkkg_P06mkh00`00
U;:D/P05U;800`008@@Q10068@@:0008DXX00`00cUW>F@05cUT00`00ooooo`06ool00`00aQS66006
aQP00`00BTU:B@05BTT00`00ool0000>ool00`00ooooo`03ool01`00oooooooo003oo`0000FLd`03
002<LHaa00B<L@03002mmkgg00>mm`03000iicWW00<ii`030000800P00@08003002U=:Dd00>U=003
001:BDY900=:B@03003ooooo00Coo`030012248800=22003002<DHaA00><D@03000iacW700@ia`03
003ogooO00?og`03003gW_NN00CgWP03001BZU:Z00=BZP03000iicWW00<ii`03003oo`0001Soo`03
003oo`00018000PHh`03000iacW700Hia`/000QcSP03001BZU:Z00IBZP03000iacW700Hia`03000H
haSS00HHh`X00003ool00?oo00koo`003Ooo00D00?ooooooo`0000;oo`06003ooooo003oo`001g__
00<00>mMked01^mM00<00?Nnmkh01_Nn00<009BbU;801IBb00<002448@@01R442P0025::00<00<iI
cUT01LiI00<00?ooool01_oo00<00<HHaQP01/HH00<004Y9BTT01DY900<00?oo00003_oo00<00?oo
ool01@000_oo00<00?oo0000G`0000?oo`00ool05ooo00<00?oo00004P0021SS00<003W7>LL01SW7
2`0027>>00<005:ZDZX01U:Z00<003W7>LL01SW700<001SS6><01QSS2P0000?oo`00ool03_oo000;
ool30003ool01000ooooo`000_oo00<00?oo00001g__00<00>mMked01^mM00<00?Nnmkh01_Nn00<0
09BbU;801IBb00<002448@@01R442P0025::00<00<iIcUT01LiI00<00?ooool01_oo00<00<HHaQP0
1/HH00<004Y9BTT01DY900<00?oo00003_oo00@00?ooool000;oo`07003oooooool00?oo00001G>^
00<0036V<JH0136V00<008aaS7400haa00<00>LLia`00nLL00<00?ooool01?oo00<007_?Nll00g_?
00<00:DDYA@00jDD00<005[[F^/015[[00<004YYBVT00dYY00<00>Llic`00nLl00<0012R4:80112R
00<00:DdYC@00jDd00<000QQ264010QQ00<00=kkg_/00mkk00<006]]Jfd00f]]00<00?oo00003?oo
10000ooo0P000ooo00<00?oo00004P0021SS00<003W7>LL01SW72`0027>>00<005:ZDZX01U:Z00<0
03W7>LL01SW700<001SS6><01QSS2P0000?oo`00ool03_oo000=ool00`00ooooo`02ool20003ool0
0`00ool00007Nnl00`00keg_G@06ked00`00mkkg_P06mkh00`00U;:D/P05U;800`008@@Q10068@@:
0008DXX00`00cUW>F@05cUT00`00ooooo`06ool00`00aQS66006aQP00`00BTU:B@05BTT00`00ool0
000>ool01`00oooooooo003oo`0000?oo`03003oo`0000Ec[P03000aYS6V00@aYP03002<LHaa00><
L@03003W7>LL00?W7003003ooooo00Coo`03001kcg_?00=kc`03002U5:DD00>U5003001Jje[[00AJ
j`03001:JDYY00=:J@03003W?>Ll00?W?003000@XQ2R00@@XP03002U=:Dd00>U=0030008H@QQ00@8
H@03003Nnmkk00?Nn`03001[KF]]00=[K@03003oo`0000koo`05003oooooool00002ool01@00oooo
o`00ool04`0021SS00<003W7>LL01SW72`0027>>00<005:ZDZX01U:Z00<003W7>LL01SW700<001SS
6><01QSS2P0000?oo`00ool03_oo000Gool00`00ool00007Nnl00`00keg_G@06ked00`00mkkg_P06
mkh00`00U;:D/P05U;800`008@@Q10068@@:0008DXX00`00cUW>F@05cUT00`00ooooo`06ool00`00
aQS66006aQP00`00BTU:B@05BTT00`00ool0000<ool30004ool20003ool00`00ool00005Ljh00`00
<JHaYP04<JH00`00S76<L@03S7400`00iacW7003ia`00`00ooooo`04ool00`00Nlmkc`03Nll00`00
YABU5003YA@00`00F^]Jj`04F^/00`00BVU:J@03BVT00`00iccW?003ic`00`004:8@XP044:800`00
YCBU=003YC@00`002648H@0426400`00g__Nn`03g_/00`00Jfe[K@03Jfd00`00ool0000>ool01@00
oooooooo00000_oo00D00?ooool00?oo05`00003ool00?oo00koo`005ooo00<00?oo00001g__00<0
0>mMked01^mM00<00?Nnmkh01_Nn00<009BbU;801IBb00<002448@@01R442P0025::00<00<iIcUT0
1LiI00<00?ooool01_oo00<00<HHaQP01/HH00<004Y9BTT01DY900<00?oo00003_oo00<00?ooool0
0ooo00L00?ooooooo`00ool00005Ljh00`00<JHaYP04<JH00`00S76<L@03S7400`00iacW7003ia`0
0`00ooooo`04ool00`00Nlmkc`03Nll00`00YABU5003YA@00`00F^]Jj`04F^/00`00BVU:J@03BVT0
0`00iccW?003ic`00`004:8@XP044:800`00YCBU=003YC@00`002648H@0426400`00g__Nn`03g_/0
0`00Jfe[K@03Jfd00`00ool0000>ool01@00oooooooo00000_oo00H00?ooool00?oo0003ool00`00
ooooo`02ool01@00oooooooo00001?oo00<00?ooool00_oo00D00?ooooooo`0000Coo`05003ooooo
ool00004ool00`00ooooo`02ool01@00oooooooo00001?oo00D00?ooooooo`0000Coo`05003ooooo
ool00004ool00`00ooooo`02ool01@00oooooooo00001?oo00L00?ooooooo`00ool0000?ool001Oo
o`03003oo`0000Mkk`03003_GNmM00K_G@03003g__Nn00Kg_P03002D/YBb00FD/P03000Q124400HQ
10X000QBRP03003>FLiI00G>F@03003ooooo00Koo`0300366<HH00K66003001:BDY900E:B@03003o
o`0001Soo`03003oo`0000Ec[P03000aYS6V00@aYP03002<LHaa00><L@03003W7>LL00?W7003003o
oooo00Coo`03001kcg_?00=kc`03002U5:DD00>U5003001Jje[[00AJj`03001:JDYY00=:J@03003W
?>Ll00?W?003000@XQ2R00@@XP03002U=:Dd00>U=0030008H@QQ00@8H@03003Nnmkk00?Nn`03001[
KF]]00=[K@03003oo`0000koo`05003oooooool00002ool00`00ooooo`1P000?ool001Ooo`03003o
o`0005l00003ool00?oo01Ooo`03003oo`0005l00003ool00?oo00_oo`<000?oo`04003ooooo001a
ool001Ooo`03003ooooo063oo`03003ooooo01Koo`03003ooooo063oo`03003ooooo00coo`03003o
oooo00;oo`8007;oo`005oooI0006?ooI000Qooo003ooomoool00?ooogooo`00ooooOooo003ooomo
ool00001\
\>"],
  ImageRangeCache->{{{0, 381}, {118.375, 0}} -> {-0.0841632, -0.0234425, \
0.00831583, 0.00831583}, {{10.0625, 122.812}, {115.5, 2.8125}} -> {-2.90271, \
-1.90627, 0.115112, 0.115112}, {{134.125, 246.812}, {115.5, 2.8125}} -> \
{-23.4466, -2.60568, 0.157068, 0.157068}, {{258.125, 370.875}, {115.5, \
2.8125}} -> {-29.7804, -1.86662, 0.109025, 0.109025}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Error Handling and Shutting Down", "Section",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["matlabio",
    FontWeight->"Bold"],
  " functions emit ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " warning messages if something goes wrong. They then return ",
  StyleBox["$Failed",
    FontWeight->"Bold"],
  "."
}], "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(MATLABMatrixNames["\<foobar.mat\>"]\)], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \(MATLABIO::"matlaberr" \(\(:\)\(\ \)\) 
      "MATLAB matrix I/O error; \!\(\"Can't open mat file for \
reading\"\)."\)], "Message"],

Cell[BoxData[
    \($Failed\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["matlabio",
    FontWeight->"Bold"],
  " will properly quit when the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " kernel quits. Nothing special needs to be done. If, however, you wish to \
manually quit ",
  StyleBox["matlabio",
    FontWeight->"Bold"],
  " without quitting ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", simply evaluate:"
}], "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Uninstall[matlabio]\)], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \("./matlabio"\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["How to build matlabio on Linux", "Section"],

Cell["\<\
Type \"make\" in this directory. This should handle running mprep \
and then gcc with the appropriate paths defined. Please see below for the \
original instructions.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Original instructions on how to build matlabio", "Section",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Unix", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  "This is a little tricky since both ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and MATLAB supply scripts to automate the build process of ",
  StyleBox["MathLink",
    FontSlant->"Italic"],
  " programs and MEX/LIBMAT programs respectively. Unfortunately, these \
scripts are oblivious to each other. The basic idea is to \"mprep\" the \
matlabio.tm file into C code (matlabio.tm.c). One then compiles matlabio.tm.c \
and matlabio.c into object code and links the two files with libML.a and \
whatever the MATLAB library is. Here's a quick and dirty way of automating as \
much as possible..."
}], "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
Step 1 - Use mprep to preprocess matlabio.tm into \
matlabio.tm.c\
\>", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["mprep -o matlabio.tm.c matlabio.tm ", "SmallText",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontFamily->"Courier",
  FontSize->9]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 2 - Use cmex to build matlabio", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
cmex -O -Iinclude_path -Llibrary_path -lML matlabio.tm.c matlabio.c \
-o matlabio
   (where include_path is the location of mathlink.h and library_path
    is the location of libML.a)\
\>", "SmallText",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontFamily->"Courier",
  FontSize->9]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Windows", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  "Follow the extensive directions in the ",
  StyleBox["MathLink",
    FontSlant->"Italic"],
  " for Windows Developer's Kit (MLDK). Again, you first use mprep to \
preprocess matlabio.tm into mlabiotm.c."
}], "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\\mathlink\\bin\\mprep matlabio.tm -o mlabiotm.c ", "SmallText",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontFamily->"Courier",
  FontSize->9],

Cell[TextData[{
  "Using the command line suggested in the MLDK, compile and link mlabiotm.c, \
matlabio.c, and the ",
  StyleBox["MathLink",
    FontSlant->"Italic"],
  " and MATLAB libraries. Remember to add the directory containing the MATLAB \
include files to your search path. Also remember to add the appropriate \
LIBMAT library."
}], "Text",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.2 for X",
ScreenRectangle->{{0, 2304}, {0, 1024}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1270, 970},
WindowMargins->{{Automatic, 0}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowSelection->True,
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Info3364912292-5031012"->{
    Cell[3644, 121, 202, 3, 23, "Print",
      CellTags->"Info3364912292-5031012"]},
  "Info3364912293-8828048"->{
    Cell[4003, 133, 138, 3, 23, "Print",
      CellTags->"Info3364912293-8828048"]},
  "Info3364912294-6536674"->{
    Cell[4309, 146, 172, 3, 23, "Print",
      CellTags->"Info3364912294-6536674"]},
  "Info3364912295-1779424"->{
    Cell[4623, 158, 155, 3, 23, "Print",
      CellTags->"Info3364912295-1779424"]},
  "Info3364912295-8635360"->{
    Cell[4947, 171, 261, 4, 39, "Print",
      CellTags->"Info3364912295-8635360"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Info3364912292-5031012", 771036, 26583},
  {"Info3364912293-8828048", 771151, 26586},
  {"Info3364912294-6536674", 771266, 26589},
  {"Info3364912295-1779424", 771381, 26592},
  {"Info3364912295-8635360", 771496, 26595}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 93, 1, 94, "Title"],
Cell[1872, 56, 463, 9, 210, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2360, 69, 65, 1, 73, "Section"],
Cell[2428, 72, 321, 10, 68, "Text"],

Cell[CellGroupData[{
Cell[2774, 86, 101, 2, 27, "Input"],
Cell[2878, 90, 64, 1, 27, "Output"]
}, Open  ]],
Cell[2957, 94, 147, 4, 32, "Text"],

Cell[CellGroupData[{
Cell[3129, 102, 90, 2, 27, "Input"],
Cell[3222, 106, 149, 2, 27, "Output"]
}, Open  ]],
Cell[3386, 111, 101, 1, 32, "Text"],

Cell[CellGroupData[{
Cell[3512, 116, 129, 3, 27, "Input"],
Cell[3644, 121, 202, 3, 23, "Print",
  CellTags->"Info3364912292-5031012"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3883, 129, 117, 2, 27, "Input"],
Cell[4003, 133, 138, 3, 23, "Print",
  CellTags->"Info3364912293-8828048"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4178, 141, 128, 3, 27, "Input"],
Cell[4309, 146, 172, 3, 23, "Print",
  CellTags->"Info3364912294-6536674"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4518, 154, 102, 2, 27, "Input"],
Cell[4623, 158, 155, 3, 23, "Print",
  CellTags->"Info3364912295-1779424"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4815, 166, 129, 3, 27, "Input"],
Cell[4947, 171, 261, 4, 39, "Print",
  CellTags->"Info3364912295-8635360"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[5257, 181, 102, 1, 43, "Section"],

Cell[CellGroupData[{
Cell[5384, 186, 75, 1, 38, "Subsection"],
Cell[5462, 189, 315, 8, 32, "Text"],

Cell[CellGroupData[{
Cell[5802, 201, 101, 2, 27, "Input"],
Cell[5906, 205, 39, 1, 27, "Output"]
}, Open  ]],
Cell[5960, 209, 300, 6, 50, "Text"],
Cell[6263, 217, 140, 3, 27, "Input"],

Cell[CellGroupData[{
Cell[6428, 224, 84, 2, 27, "Input"],
Cell[6515, 228, 44, 1, 27, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[6608, 235, 74, 1, 30, "Subsection"],
Cell[6685, 238, 104, 1, 32, "Text"],

Cell[CellGroupData[{
Cell[6814, 243, 114, 2, 27, "Input"],
Cell[6931, 247, 147477, 2304, 290, 38579, 955, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[154445, 2556, 94, 2, 27, "Input"],
Cell[154542, 2560, 361406, 18743, 290, 270006, 17610, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[515963, 21306, 225, 5, 27, "SmallText"],
Cell[516191, 21313, 109, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[516337, 21320, 85, 1, 30, "Subsection"],
Cell[516425, 21323, 259, 7, 68, "Text"],
Cell[516687, 21332, 148, 3, 27, "Input"],
Cell[516838, 21337, 478, 7, 50, "Text"],
Cell[517319, 21346, 158, 3, 27, "Input"],
Cell[517480, 21351, 153, 3, 27, "Input"],
Cell[517636, 21356, 138, 3, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[517811, 21364, 75, 1, 30, "Subsection"],
Cell[517889, 21367, 602, 15, 50, "Text"],
Cell[518494, 21384, 198, 5, 27, "Input"],
Cell[518695, 21391, 109, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[518829, 21397, 128, 3, 27, "Input"],
Cell[518960, 21402, 167869, 2556, 290, 38579, 955, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[686878, 23964, 81, 1, 30, "Subsection"],
Cell[686962, 23967, 249, 7, 32, "Text"],

Cell[CellGroupData[{
Cell[687236, 23978, 176, 3, 27, "Input"],
Cell[687415, 23983, 52, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[687504, 23989, 201, 4, 27, "Input"],
Cell[687708, 23995, 52, 1, 27, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[687821, 24003, 87, 1, 43, "Section"],

Cell[CellGroupData[{
Cell[687933, 24008, 101, 1, 38, "Subsection"],
Cell[688037, 24011, 610, 18, 50, "Text"],
Cell[688650, 24031, 306, 7, 27, "Input"],

Cell[CellGroupData[{
Cell[688981, 24042, 66, 1, 28, "Subsubsection"],
Cell[689050, 24045, 86, 1, 32, "Text"],
Cell[689139, 24048, 258, 5, 40, "Input"],
Cell[689400, 24055, 92, 1, 32, "Text"],

Cell[CellGroupData[{
Cell[689517, 24060, 88, 2, 27, "Input"],
Cell[689608, 24064, 64, 1, 27, "Output"]
}, Open  ]],
Cell[689687, 24068, 69, 1, 32, "Text"],

Cell[CellGroupData[{
Cell[689781, 24073, 76, 1, 27, "Input"],
Cell[689860, 24076, 52, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[689949, 24082, 116, 2, 27, "Input"],
Cell[690068, 24086, 52, 1, 27, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[690181, 24094, 90, 1, 30, "Subsection"],
Cell[690274, 24097, 324, 10, 32, "Text"],
Cell[690601, 24109, 212, 4, 27, "Input"],

Cell[CellGroupData[{
Cell[690838, 24117, 66, 1, 28, "Subsubsection"],
Cell[690907, 24120, 90, 1, 32, "Text"],
Cell[691000, 24123, 124, 2, 27, "Input"],
Cell[691127, 24127, 353, 11, 32, "Text"],

Cell[CellGroupData[{
Cell[691505, 24142, 159, 3, 27, "Input"],
Cell[691667, 24147, 492, 14, 27, "Output"]
}, Open  ]],
Cell[692174, 24164, 206, 7, 32, "Text"],

Cell[CellGroupData[{
Cell[692405, 24175, 93, 2, 27, "Input"],
Cell[692501, 24179, 73314, 2208, 128, 18532, 1527, "GraphicsData", \
"PostScript", "Graphics"],
Cell[765818, 26389, 135, 3, 27, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[766026, 26400, 85, 1, 43, "Section"],
Cell[766114, 26403, 302, 11, 32, "Text"],

Cell[CellGroupData[{
Cell[766441, 26418, 102, 2, 27, "Input"],
Cell[766546, 26422, 151, 3, 20, "Message"],
Cell[766700, 26427, 41, 1, 27, "Output"]
}, Open  ]],
Cell[766756, 26431, 439, 15, 32, "Text"],

Cell[CellGroupData[{
Cell[767220, 26450, 86, 2, 27, "Input"],
Cell[767309, 26454, 46, 1, 27, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[767404, 26461, 49, 0, 43, "Section"],
Cell[767456, 26463, 190, 4, 32, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[767683, 26472, 99, 1, 43, "Section"],

Cell[CellGroupData[{
Cell[767807, 26477, 60, 1, 38, "Subsection"],
Cell[767870, 26480, 673, 14, 68, "Text"],

Cell[CellGroupData[{
Cell[768568, 26498, 132, 4, 28, "Subsubsection"],
Cell[768703, 26504, 130, 3, 25, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[768870, 26512, 94, 1, 28, "Subsubsection"],
Cell[768967, 26515, 286, 8, 51, "SmallText"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[769302, 26529, 63, 1, 38, "Subsection"],
Cell[769368, 26532, 268, 7, 70, "Text"],
Cell[769639, 26541, 144, 3, 70, "SmallText"],
Cell[769786, 26546, 384, 9, 70, "Text"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

